/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uicolor","id",{title:"Pengambil  Warna UI",options:"Color Options",highlight:"Highlight",selected:"Selected Color",predefined:"Set warna belum terdefinisi.",config:"Tempel string ini ke arsip config.js anda."});