/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("filetools","oc",{loadError:"Una error s'es produita pendent la lectura del fichièr.",networkError:"Una error de ret s'es produita pendent lo mandadís del fichièr.",httpError404:"Una error HTTP s'es produita pendent lo mandadís del fichièr (404 : fichièr pas trobat).",httpError403:"Una error HTTP s'es produita pendent lo mandadís del fichièr (403 : accès refusat).",httpError:"Una error HTTP s'es produita pendent lo mandadís del fichièr (error : %1).",noUrlError:"L'URL de mandadís es pas especificada.",
responseError:"Responsa del servidor incorrècta."});