/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","sk",{abort:"Nahrávanie zrušené používateľom.",doneOne:"Súbor úspešne nahraný.",doneMany:"Úspešne nahraných %1 súborov.",uploadOne:"Nahrávanie súboru ({percentage}%)...",uploadMany:"Nahrávanie súborov, {current} z {max} hotovo ({percentage}%)..."});