/*
Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'image2', 'lt', {
	alt: 'Alternatyvus Tekstas',
	btnUpload: 'Siųsti į serverį',
	captioned: 'Captioned image', // MISSING
	captionPlaceholder: 'Caption', // MISSING
	infoTab: 'Vaizdo informacija',
	lockRatio: 'Išlaikyti proporciją',
	menu: 'Vaizdo savybės',
	pathName: 'image', // MISSING
	pathNameCaption: 'caption', // MISSING
	resetSize: 'Atstatyti dydį',
	resizer: 'Click and drag to resize', // MISSING
	title: 'Vaizdo savybės',
	uploadTab: 'Siųsti',
	urlMissing: 'Paveiksliuko nuorodos nėra.',
	altMissing: 'Alternative text is missing.' // MISSING
} );
