/*
Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
(function(){function ka(a,c){CKEDITOR.tools.extend(this,c,{editor:a,id:"cke-"+CKEDITOR.tools.getUniqueId(),area:a._.notificationArea});c.type||(this.type="info");this.element=this._createElement();a.plugins.clipboard&&CKEDITOR.plugins.clipboard.preventDefaultDropOnElement(this.element)}function la(a){var c=this;this.editor=a;this.notifications=[];this.element=this._createElement();this._uiBuffer=CKEDITOR.tools.eventsBuffer(10,this._layout,this);this._changeBuffer=CKEDITOR.tools.eventsBuffer(500,this._layout,
this);a.on("destroy",function(){c._removeListeners();c.element.remove()})}window.CKEDITOR&&window.CKEDITOR.dom||(window.CKEDITOR||(window.CKEDITOR=function(){var a=/(^|.*[\\\/])ckeditor\.js(?:\?.*|;.*)?$/i,c={timestamp:"H7I7",version:"4.7.2",revision:"c9b79c9",rnd:Math.floor(900*Math.random())+100,_:{pending:[],basePathSrcPattern:a},status:"unloaded",basePath:function(){var e=window.CKEDITOR_BASEPATH||"";if(!e)for(var b=document.getElementsByTagName("script"),c=0;c<b.length;c++){var f=b[c].src.match(a);
if(f){e=f[1];break}}-1==e.indexOf(":/")&&"//"!=e.slice(0,2)&&(e=0===e.indexOf("/")?location.href.match(/^.*?:\/\/[^\/]*/)[0]+e:location.href.match(/^[^\?]*\/(?:)/)[0]+e);if(!e)throw'The CKEditor installation path could not be automatically detected. Please set the global variable "CKEDITOR_BASEPATH" before creating editor instances.';return e}(),getUrl:function(a){-1==a.indexOf(":/")&&0!==a.indexOf("/")&&(a=this.basePath+a);this.timestamp&&"/"!=a.charAt(a.length-1)&&!/[&?]t=/.test(a)&&(a+=(0<=a.indexOf("?")?
"\x26":"?")+"t\x3d"+this.timestamp);return a},domReady:function(){function a(){try{document.addEventListener?(document.removeEventListener("DOMContentLoaded",a,!1),e()):document.attachEvent&&"complete"===document.readyState&&(document.detachEvent("onreadystatechange",a),e())}catch(f){}}function e(){for(var a;a=b.shift();)a()}var b=[];return function(f){function d(){try{document.documentElement.doScroll("left")}catch(g){setTimeout(d,1);return}a()}b.push(f);"complete"===document.readyState&&setTimeout(a,
1);if(1==b.length)if(document.addEventListener)document.addEventListener("DOMContentLoaded",a,!1),window.addEventListener("load",a,!1);else if(document.attachEvent){document.attachEvent("onreadystatechange",a);window.attachEvent("onload",a);f=!1;try{f=!window.frameElement}catch(m){}document.documentElement.doScroll&&f&&d()}}}()},b=window.CKEDITOR_GETURL;if(b){var e=c.getUrl;c.getUrl=function(a){return b.call(c,a)||e.call(c,a)}}return c}()),CKEDITOR.event||(CKEDITOR.event=function(){},CKEDITOR.event.implementOn=
function(a){var c=CKEDITOR.event.prototype,b;for(b in c)null==a[b]&&(a[b]=c[b])},CKEDITOR.event.prototype=function(){function a(a){var h=c(this);return h[a]||(h[a]=new b(a))}var c=function(a){a=a.getPrivate&&a.getPrivate()||a._||(a._={});return a.events||(a.events={})},b=function(a){this.name=a;this.listeners=[]};b.prototype={getListenerIndex:function(a){for(var b=0,c=this.listeners;b<c.length;b++)if(c[b].fn==a)return b;return-1}};return{define:function(e,b){var c=a.call(this,e);CKEDITOR.tools.extend(c,
b,!0)},on:function(e,b,c,k,f){function d(g,a,d,f){g={name:e,sender:this,editor:g,data:a,listenerData:k,stop:d,cancel:f,removeListener:m};return!1===b.call(c,g)?!1:g.data}function m(){n.removeListener(e,b)}var g=a.call(this,e);if(0>g.getListenerIndex(b)){g=g.listeners;c||(c=this);isNaN(f)&&(f=10);var n=this;d.fn=b;d.priority=f;for(var p=g.length-1;0<=p;p--)if(g[p].priority<=f)return g.splice(p+1,0,d),{removeListener:m};g.unshift(d)}return{removeListener:m}},once:function(){var a=Array.prototype.slice.call(arguments),
b=a[1];a[1]=function(a){a.removeListener();return b.apply(this,arguments)};return this.on.apply(this,a)},capture:function(){CKEDITOR.event.useCapture=1;var a=this.on.apply(this,arguments);CKEDITOR.event.useCapture=0;return a},fire:function(){var a=0,b=function(){a=1},l=0,k=function(){l=1};return function(f,d,m){var g=c(this)[f];f=a;var n=l;a=l=0;if(g){var p=g.listeners;if(p.length)for(var p=p.slice(0),q,y=0;y<p.length;y++){if(g.errorProof)try{q=p[y].call(this,m,d,b,k)}catch(v){}else q=p[y].call(this,
m,d,b,k);!1===q?l=1:"undefined"!=typeof q&&(d=q);if(a||l)break}}d=l?!1:"undefined"==typeof d?!0:d;a=f;l=n;return d}}(),fireOnce:function(a,b,l){b=this.fire(a,b,l);delete c(this)[a];return b},removeListener:function(a,b){var l=c(this)[a];if(l){var k=l.getListenerIndex(b);0<=k&&l.listeners.splice(k,1)}},removeAllListeners:function(){var a=c(this),b;for(b in a)delete a[b]},hasListeners:function(a){return(a=c(this)[a])&&0<a.listeners.length}}}()),CKEDITOR.editor||(CKEDITOR.editor=function(){CKEDITOR._.pending.push([this,
arguments]);CKEDITOR.event.call(this)},CKEDITOR.editor.prototype.fire=function(a,c){a in{instanceReady:1,loaded:1}&&(this[a]=!0);return CKEDITOR.event.prototype.fire.call(this,a,c,this)},CKEDITOR.editor.prototype.fireOnce=function(a,c){a in{instanceReady:1,loaded:1}&&(this[a]=!0);return CKEDITOR.event.prototype.fireOnce.call(this,a,c,this)},CKEDITOR.event.implementOn(CKEDITOR.editor.prototype)),CKEDITOR.env||(CKEDITOR.env=function(){var a=navigator.userAgent.toLowerCase(),c=a.match(/edge[ \/](\d+.?\d*)/),
b=-1<a.indexOf("trident/"),b=!(!c&&!b),b={ie:b,edge:!!c,webkit:!b&&-1<a.indexOf(" applewebkit/"),air:-1<a.indexOf(" adobeair/"),mac:-1<a.indexOf("macintosh"),quirks:"BackCompat"==document.compatMode&&(!document.documentMode||10>document.documentMode),mobile:-1<a.indexOf("mobile"),iOS:/(ipad|iphone|ipod)/.test(a),isCustomDomain:function(){if(!this.ie)return!1;var a=document.domain,b=window.location.hostname;return a!=b&&a!="["+b+"]"},secure:"https:"==location.protocol};b.gecko="Gecko"==navigator.product&&
!b.webkit&&!b.ie;b.webkit&&(-1<a.indexOf("chrome")?b.chrome=!0:b.safari=!0);var e=0;b.ie&&(e=c?parseFloat(c[1]):b.quirks||!document.documentMode?parseFloat(a.match(/msie (\d+)/)[1]):document.documentMode,b.ie9Compat=9==e,b.ie8Compat=8==e,b.ie7Compat=7==e,b.ie6Compat=7>e||b.quirks);b.gecko&&(c=a.match(/rv:([\d\.]+)/))&&(c=c[1].split("."),e=1E4*c[0]+100*(c[1]||0)+1*(c[2]||0));b.air&&(e=parseFloat(a.match(/ adobeair\/(\d+)/)[1]));b.webkit&&(e=parseFloat(a.match(/ applewebkit\/(\d+)/)[1]));b.version=
e;b.isCompatible=!(b.ie&&7>e)&&!(b.gecko&&4E4>e)&&!(b.webkit&&534>e);b.hidpi=2<=window.devicePixelRatio;b.needsBrFiller=b.gecko||b.webkit||b.ie&&10<e;b.needsNbspFiller=b.ie&&11>e;b.cssClass="cke_browser_"+(b.ie?"ie":b.gecko?"gecko":b.webkit?"webkit":"unknown");b.quirks&&(b.cssClass+=" cke_browser_quirks");b.ie&&(b.cssClass+=" cke_browser_ie"+(b.quirks?"6 cke_browser_iequirks":b.version));b.air&&(b.cssClass+=" cke_browser_air");b.iOS&&(b.cssClass+=" cke_browser_ios");b.hidpi&&(b.cssClass+=" cke_hidpi");
return b}()),"unloaded"==CKEDITOR.status&&function(){CKEDITOR.event.implementOn(CKEDITOR);CKEDITOR.loadFullCore=function(){if("basic_ready"!=CKEDITOR.status)CKEDITOR.loadFullCore._load=1;else{delete CKEDITOR.loadFullCore;var a=document.createElement("script");a.type="text/javascript";a.src=CKEDITOR.basePath+"ckeditor.js";document.getElementsByTagName("head")[0].appendChild(a)}};CKEDITOR.loadFullCoreTimeout=0;CKEDITOR.add=function(a){(this._.pending||(this._.pending=[])).push(a)};(function(){CKEDITOR.domReady(function(){var a=
CKEDITOR.loadFullCore,c=CKEDITOR.loadFullCoreTimeout;a&&(CKEDITOR.status="basic_ready",a&&a._load?a():c&&setTimeout(function(){CKEDITOR.loadFullCore&&CKEDITOR.loadFullCore()},1E3*c))})})();CKEDITOR.status="basic_loaded"}(),"use strict",CKEDITOR.VERBOSITY_WARN=1,CKEDITOR.VERBOSITY_ERROR=2,CKEDITOR.verbosity=CKEDITOR.VERBOSITY_WARN|CKEDITOR.VERBOSITY_ERROR,CKEDITOR.warn=function(a,c){CKEDITOR.verbosity&CKEDITOR.VERBOSITY_WARN&&CKEDITOR.fire("log",{type:"warn",errorCode:a,additionalData:c})},CKEDITOR.error=
function(a,c){CKEDITOR.verbosity&CKEDITOR.VERBOSITY_ERROR&&CKEDITOR.fire("log",{type:"error",errorCode:a,additionalData:c})},CKEDITOR.on("log",function(a){if(window.console&&window.console.log){var c=console[a.data.type]?a.data.type:"log",b=a.data.errorCode;if(a=a.data.additionalData)console[c]("[CKEDITOR] Error code: "+b+".",a);else console[c]("[CKEDITOR] Error code: "+b+".");console[c]("[CKEDITOR] For more information about this error go to http://docs.ckeditor.com/#!/guide/dev_errors-section-"+
b)}},null,null,999),CKEDITOR.dom={},function(){var a=[],c=CKEDITOR.env.gecko?"-moz-":CKEDITOR.env.webkit?"-webkit-":CKEDITOR.env.ie?"-ms-":"",b=/&/g,e=/>/g,h=/</g,l=/"/g,k=/&(lt|gt|amp|quot|nbsp|shy|#\d{1,5});/g,f={lt:"\x3c",gt:"\x3e",amp:"\x26",quot:'"',nbsp:" ",shy:"­"},d=function(a,g){return"#"==g[0]?String.fromCharCode(parseInt(g.slice(1),10)):f[g]};CKEDITOR.on("reset",function(){a=[]});CKEDITOR.tools={arrayCompare:function(a,g){if(!a&&!g)return!0;if(!a||!g||a.length!=g.length)return!1;for(var d=
0;d<a.length;d++)if(a[d]!=g[d])return!1;return!0},getIndex:function(a,g){for(var d=0;d<a.length;++d)if(g(a[d]))return d;return-1},clone:function(a){var g;if(a&&a instanceof Array){g=[];for(var d=0;d<a.length;d++)g[d]=CKEDITOR.tools.clone(a[d]);return g}if(null===a||"object"!=typeof a||a instanceof String||a instanceof Number||a instanceof Boolean||a instanceof Date||a instanceof RegExp||a.nodeType||a.window===a)return a;g=new a.constructor;for(d in a)g[d]=CKEDITOR.tools.clone(a[d]);return g},capitalize:function(a,
g){return a.charAt(0).toUpperCase()+(g?a.slice(1):a.slice(1).toLowerCase())},extend:function(a){var g=arguments.length,d,f;"boolean"==typeof(d=arguments[g-1])?g--:"boolean"==typeof(d=arguments[g-2])&&(f=arguments[g-1],g-=2);for(var b=1;b<g;b++){var e=arguments[b],c;for(c in e)if(!0===d||null==a[c])if(!f||c in f)a[c]=e[c]}return a},prototypedCopy:function(a){var g=function(){};g.prototype=a;return new g},copy:function(a){var g={},d;for(d in a)g[d]=a[d];return g},isArray:function(a){return"[object Array]"==
Object.prototype.toString.call(a)},isEmpty:function(a){for(var g in a)if(a.hasOwnProperty(g))return!1;return!0},cssVendorPrefix:function(a,g,d){if(d)return c+a+":"+g+";"+a+":"+g;d={};d[a]=g;d[c+a]=g;return d},cssStyleToDomStyle:function(){var a=document.createElement("div").style,g="undefined"!=typeof a.cssFloat?"cssFloat":"undefined"!=typeof a.styleFloat?"styleFloat":"float";return function(a){return"float"==a?g:a.replace(/-./g,function(a){return a.substr(1).toUpperCase()})}}(),buildStyleHtml:function(a){a=
[].concat(a);for(var g,d=[],f=0;f<a.length;f++)if(g=a[f])/@import|[{}]/.test(g)?d.push("\x3cstyle\x3e"+g+"\x3c/style\x3e"):d.push('\x3clink type\x3d"text/css" rel\x3dstylesheet href\x3d"'+g+'"\x3e');return d.join("")},htmlEncode:function(a){return void 0===a||null===a?"":String(a).replace(b,"\x26amp;").replace(e,"\x26gt;").replace(h,"\x26lt;")},htmlDecode:function(a){return a.replace(k,d)},htmlEncodeAttr:function(a){return CKEDITOR.tools.htmlEncode(a).replace(l,"\x26quot;")},htmlDecodeAttr:function(a){return CKEDITOR.tools.htmlDecode(a)},
transformPlainTextToHtml:function(a,g){var d=g==CKEDITOR.ENTER_BR,f=this.htmlEncode(a.replace(/\r\n/g,"\n")),f=f.replace(/\t/g,"\x26nbsp;\x26nbsp; \x26nbsp;"),b=g==CKEDITOR.ENTER_P?"p":"div";if(!d){var e=/\n{2}/g;if(e.test(f))var c="\x3c"+b+"\x3e",h="\x3c/"+b+"\x3e",f=c+f.replace(e,function(){return h+c})+h}f=f.replace(/\n/g,"\x3cbr\x3e");d||(f=f.replace(new RegExp("\x3cbr\x3e(?\x3d\x3c/"+b+"\x3e)"),function(a){return CKEDITOR.tools.repeat(a,2)}));f=f.replace(/^ | $/g,"\x26nbsp;");return f=f.replace(/(>|\s) /g,
function(a,g){return g+"\x26nbsp;"}).replace(/ (?=<)/g,"\x26nbsp;")},getNextNumber:function(){var a=0;return function(){return++a}}(),getNextId:function(){return"cke_"+this.getNextNumber()},getUniqueId:function(){for(var a="e",g=0;8>g;g++)a+=Math.floor(65536*(1+Math.random())).toString(16).substring(1);return a},override:function(a,g){var d=g(a);d.prototype=a.prototype;return d},setTimeout:function(a,g,d,f,b){b||(b=window);d||(d=b);return b.setTimeout(function(){f?a.apply(d,[].concat(f)):a.apply(d)},
g||0)},trim:function(){var a=/(?:^[ \t\n\r]+)|(?:[ \t\n\r]+$)/g;return function(g){return g.replace(a,"")}}(),ltrim:function(){var a=/^[ \t\n\r]+/g;return function(g){return g.replace(a,"")}}(),rtrim:function(){var a=/[ \t\n\r]+$/g;return function(g){return g.replace(a,"")}}(),indexOf:function(a,g){if("function"==typeof g)for(var d=0,f=a.length;d<f;d++){if(g(a[d]))return d}else{if(a.indexOf)return a.indexOf(g);d=0;for(f=a.length;d<f;d++)if(a[d]===g)return d}return-1},search:function(a,g){var d=CKEDITOR.tools.indexOf(a,
g);return 0<=d?a[d]:null},bind:function(a,g){return function(){return a.apply(g,arguments)}},createClass:function(a){var g=a.$,d=a.base,f=a.privates||a._,b=a.proto;a=a.statics;!g&&(g=function(){d&&this.base.apply(this,arguments)});if(f)var e=g,g=function(){var a=this._||(this._={}),g;for(g in f){var d=f[g];a[g]="function"==typeof d?CKEDITOR.tools.bind(d,this):d}e.apply(this,arguments)};d&&(g.prototype=this.prototypedCopy(d.prototype),g.prototype.constructor=g,g.base=d,g.baseProto=d.prototype,g.prototype.base=
function(){this.base=d.prototype.base;d.apply(this,arguments);this.base=arguments.callee});b&&this.extend(g.prototype,b,!0);a&&this.extend(g,a,!0);return g},addFunction:function(d,g){return a.push(function(){return d.apply(g||this,arguments)})-1},removeFunction:function(d){a[d]=null},callFunction:function(d){var g=a[d];return g&&g.apply(window,Array.prototype.slice.call(arguments,1))},cssLength:function(){var a=/^-?\d+\.?\d*px$/,g;return function(d){g=CKEDITOR.tools.trim(d+"")+"px";return a.test(g)?
g:d||""}}(),convertToPx:function(){var a;return function(g){a||(a=CKEDITOR.dom.element.createFromHtml('\x3cdiv style\x3d"position:absolute;left:-9999px;top:-9999px;margin:0px;padding:0px;border:0px;"\x3e\x3c/div\x3e',CKEDITOR.document),CKEDITOR.document.getBody().append(a));return/%$/.test(g)?g:(a.setStyle("width",g),a.$.clientWidth)}}(),repeat:function(a,g){return Array(g+1).join(a)},tryThese:function(){for(var a,g=0,d=arguments.length;g<d;g++){var f=arguments[g];try{a=f();break}catch(b){}}return a},
genKey:function(){return Array.prototype.slice.call(arguments).join("-")},defer:function(a){return function(){var g=arguments,d=this;window.setTimeout(function(){a.apply(d,g)},0)}},normalizeCssText:function(a,g){var d=[],f,b=CKEDITOR.tools.parseCssText(a,!0,g);for(f in b)d.push(f+":"+b[f]);d.sort();return d.length?d.join(";")+";":""},convertRgbToHex:function(a){return a.replace(/(?:rgb\(\s*(\d+)\s*,\s*(\d+)\s*,\s*(\d+)\s*\))/gi,function(a,d,f,m){a=[d,f,m];for(d=0;3>d;d++)a[d]=("0"+parseInt(a[d],10).toString(16)).slice(-2);
return"#"+a.join("")})},normalizeHex:function(a){return a.replace(/#(([0-9a-f]{3}){1,2})($|;|\s+)/gi,function(a,d,f,m){a=d.toLowerCase();3==a.length&&(a=a.split(""),a=[a[0],a[0],a[1],a[1],a[2],a[2]].join(""));return"#"+a+m})},parseCssText:function(a,g,d){var f={};d&&(a=(new CKEDITOR.dom.element("span")).setAttribute("style",a).getAttribute("style")||"");a&&(a=CKEDITOR.tools.normalizeHex(CKEDITOR.tools.convertRgbToHex(a)));if(!a||";"==a)return f;a.replace(/&quot;/g,'"').replace(/\s*([^:;\s]+)\s*:\s*([^;]+)\s*(?=;|$)/g,
function(a,d,m){g&&(d=d.toLowerCase(),"font-family"==d&&(m=m.replace(/\s*,\s*/g,",")),m=CKEDITOR.tools.trim(m));f[d]=m});return f},writeCssText:function(a,g){var d,f=[];for(d in a)f.push(d+":"+a[d]);g&&f.sort();return f.join("; ")},objectCompare:function(a,g,d){var f;if(!a&&!g)return!0;if(!a||!g)return!1;for(f in a)if(a[f]!=g[f])return!1;if(!d)for(f in g)if(a[f]!=g[f])return!1;return!0},objectKeys:function(a){var g=[],d;for(d in a)g.push(d);return g},convertArrayToObject:function(a,g){var d={};1==
arguments.length&&(g=!0);for(var f=0,b=a.length;f<b;++f)d[a[f]]=g;return d},fixDomain:function(){for(var a;;)try{a=window.parent.document.domain;break}catch(g){a=a?a.replace(/.+?(?:\.|$)/,""):document.domain;if(!a)break;document.domain=a}return!!a},eventsBuffer:function(a,g,d){function f(){e=(new Date).getTime();b=!1;d?g.call(d):g()}var b,e=0;return{input:function(){if(!b){var g=(new Date).getTime()-e;g<a?b=setTimeout(f,a-g):f()}},reset:function(){b&&clearTimeout(b);b=e=0}}},enableHtml5Elements:function(a,
g){for(var d="abbr article aside audio bdi canvas data datalist details figcaption figure footer header hgroup main mark meter nav output progress section summary time video".split(" "),f=d.length,b;f--;)b=a.createElement(d[f]),g&&a.appendChild(b)},checkIfAnyArrayItemMatches:function(a,g){for(var d=0,f=a.length;d<f;++d)if(a[d].match(g))return!0;return!1},checkIfAnyObjectPropertyMatches:function(a,g){for(var d in a)if(d.match(g))return!0;return!1},keystrokeToString:function(a,g){var d=g&16711680,f=
g&65535,b=CKEDITOR.env.mac,e=[],c=[];d&CKEDITOR.CTRL&&(e.push(b?"⌘":a[17]),c.push(b?a[224]:a[17]));d&CKEDITOR.ALT&&(e.push(b?"⌥":a[18]),c.push(a[18]));d&CKEDITOR.SHIFT&&(e.push(b?"⇧":a[16]),c.push(a[16]));f&&(a[f]?(e.push(a[f]),c.push(a[f])):(e.push(String.fromCharCode(f)),c.push(String.fromCharCode(f))));return{display:e.join("+"),aria:c.join("+")}},transparentImageData:"data:image/gif;base64,R0lGODlhAQABAPABAP///wAAACH5BAEKAAAALAAAAAABAAEAAAICRAEAOw\x3d\x3d",getCookie:function(a){a=a.toLowerCase();
for(var g=document.cookie.split(";"),d,f,b=0;b<g.length;b++)if(d=g[b].split("\x3d"),f=decodeURIComponent(CKEDITOR.tools.trim(d[0]).toLowerCase()),f===a)return decodeURIComponent(1<d.length?d[1]:"");return null},setCookie:function(a,g){document.cookie=encodeURIComponent(a)+"\x3d"+encodeURIComponent(g)+";path\x3d/"},getCsrfToken:function(){var a=CKEDITOR.tools.getCookie("ckCsrfToken");if(!a||40!=a.length){var a=[],g="";if(window.crypto&&window.crypto.getRandomValues)a=new Uint8Array(40),window.crypto.getRandomValues(a);
else for(var d=0;40>d;d++)a.push(Math.floor(256*Math.random()));for(d=0;d<a.length;d++)var f="abcdefghijklmnopqrstuvwxyz0123456789".charAt(a[d]%36),g=g+(.5<Math.random()?f.toUpperCase():f);a=g;CKEDITOR.tools.setCookie("ckCsrfToken",a)}return a},escapeCss:function(a){return a?window.CSS&&CSS.escape?CSS.escape(a):isNaN(parseInt(a.charAt(0),10))?a:"\\3"+a.charAt(0)+" "+a.substring(1,a.length):""},style:{parse:{_colors:{aliceblue:"#F0F8FF",antiquewhite:"#FAEBD7",aqua:"#00FFFF",aquamarine:"#7FFFD4",azure:"#F0FFFF",
beige:"#F5F5DC",bisque:"#FFE4C4",black:"#000000",blanchedalmond:"#FFEBCD",blue:"#0000FF",blueviolet:"#8A2BE2",brown:"#A52A2A",burlywood:"#DEB887",cadetblue:"#5F9EA0",chartreuse:"#7FFF00",chocolate:"#D2691E",coral:"#FF7F50",cornflowerblue:"#6495ED",cornsilk:"#FFF8DC",crimson:"#DC143C",cyan:"#00FFFF",darkblue:"#00008B",darkcyan:"#008B8B",darkgoldenrod:"#B8860B",darkgray:"#A9A9A9",darkgreen:"#006400",darkgrey:"#A9A9A9",darkkhaki:"#BDB76B",darkmagenta:"#8B008B",darkolivegreen:"#556B2F",darkorange:"#FF8C00",
darkorchid:"#9932CC",darkred:"#8B0000",darksalmon:"#E9967A",darkseagreen:"#8FBC8F",darkslateblue:"#483D8B",darkslategray:"#2F4F4F",darkslategrey:"#2F4F4F",darkturquoise:"#00CED1",darkviolet:"#9400D3",deeppink:"#FF1493",deepskyblue:"#00BFFF",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1E90FF",firebrick:"#B22222",floralwhite:"#FFFAF0",forestgreen:"#228B22",fuchsia:"#FF00FF",gainsboro:"#DCDCDC",ghostwhite:"#F8F8FF",gold:"#FFD700",goldenrod:"#DAA520",gray:"#808080",green:"#008000",greenyellow:"#ADFF2F",
grey:"#808080",honeydew:"#F0FFF0",hotpink:"#FF69B4",indianred:"#CD5C5C",indigo:"#4B0082",ivory:"#FFFFF0",khaki:"#F0E68C",lavender:"#E6E6FA",lavenderblush:"#FFF0F5",lawngreen:"#7CFC00",lemonchiffon:"#FFFACD",lightblue:"#ADD8E6",lightcoral:"#F08080",lightcyan:"#E0FFFF",lightgoldenrodyellow:"#FAFAD2",lightgray:"#D3D3D3",lightgreen:"#90EE90",lightgrey:"#D3D3D3",lightpink:"#FFB6C1",lightsalmon:"#FFA07A",lightseagreen:"#20B2AA",lightskyblue:"#87CEFA",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#B0C4DE",
lightyellow:"#FFFFE0",lime:"#00FF00",limegreen:"#32CD32",linen:"#FAF0E6",magenta:"#FF00FF",maroon:"#800000",mediumaquamarine:"#66CDAA",mediumblue:"#0000CD",mediumorchid:"#BA55D3",mediumpurple:"#9370DB",mediumseagreen:"#3CB371",mediumslateblue:"#7B68EE",mediumspringgreen:"#00FA9A",mediumturquoise:"#48D1CC",mediumvioletred:"#C71585",midnightblue:"#191970",mintcream:"#F5FFFA",mistyrose:"#FFE4E1",moccasin:"#FFE4B5",navajowhite:"#FFDEAD",navy:"#000080",oldlace:"#FDF5E6",olive:"#808000",olivedrab:"#6B8E23",
orange:"#FFA500",orangered:"#FF4500",orchid:"#DA70D6",palegoldenrod:"#EEE8AA",palegreen:"#98FB98",paleturquoise:"#AFEEEE",palevioletred:"#DB7093",papayawhip:"#FFEFD5",peachpuff:"#FFDAB9",peru:"#CD853F",pink:"#FFC0CB",plum:"#DDA0DD",powderblue:"#B0E0E6",purple:"#800080",rebeccapurple:"#663399",red:"#FF0000",rosybrown:"#BC8F8F",royalblue:"#4169E1",saddlebrown:"#8B4513",salmon:"#FA8072",sandybrown:"#F4A460",seagreen:"#2E8B57",seashell:"#FFF5EE",sienna:"#A0522D",silver:"#C0C0C0",skyblue:"#87CEEB",slateblue:"#6A5ACD",
slategray:"#708090",slategrey:"#708090",snow:"#FFFAFA",springgreen:"#00FF7F",steelblue:"#4682B4",tan:"#D2B48C",teal:"#008080",thistle:"#D8BFD8",tomato:"#FF6347",turquoise:"#40E0D0",violet:"#EE82EE",wheat:"#F5DEB3",white:"#FFFFFF",whitesmoke:"#F5F5F5",yellow:"#FFFF00",yellowgreen:"#9ACD32"},_rgbaRegExp:/rgba?\(\s*\d+%?\s*,\s*\d+%?\s*,\s*\d+%?\s*(?:,\s*[0-9.]+\s*)?\)/gi,_hslaRegExp:/hsla?\(\s*[0-9.]+\s*,\s*\d+%\s*,\s*\d+%\s*(?:,\s*[0-9.]+\s*)?\)/gi,background:function(a){var g={},d=this._findColor(a);
d.length&&(g.color=d[0],CKEDITOR.tools.array.forEach(d,function(g){a=a.replace(g,"")}));if(a=CKEDITOR.tools.trim(a))g.unprocessed=a;return g},margin:function(a){function g(a){d.top=f[a[0]];d.right=f[a[1]];d.bottom=f[a[2]];d.left=f[a[3]]}var d={},f=a.match(/(?:\-?[\.\d]+(?:%|\w*)|auto|inherit|initial|unset)/g)||["0px"];switch(f.length){case 1:g([0,0,0,0]);break;case 2:g([0,1,0,1]);break;case 3:g([0,1,2,1]);break;case 4:g([0,1,2,3])}return d},_findColor:function(a){var g=[],d=CKEDITOR.tools.array,g=
g.concat(a.match(this._rgbaRegExp)||[]),g=g.concat(a.match(this._hslaRegExp)||[]);return g=g.concat(d.filter(a.split(/\s+/),function(a){return a.match(/^\#[a-f0-9]{3}(?:[a-f0-9]{3})?$/gi)?!0:a.toLowerCase()in CKEDITOR.tools.style.parse._colors}))}}},array:{filter:function(a,g,d){var f=[];this.forEach(a,function(b,e){g.call(d,b,e,a)&&f.push(b)});return f},forEach:function(a,g,d){var f=a.length,b;for(b=0;b<f;b++)g.call(d,a[b],b,a)},map:function(a,g,d){for(var f=[],b=0;b<a.length;b++)f.push(g.call(d,
a[b],b,a));return f},reduce:function(a,g,d,f){for(var b=0;b<a.length;b++)d=g.call(f,d,a[b],b,a);return d}},object:{findKey:function(a,g){if("object"!==typeof a)return null;for(var d in a)if(a[d]===g)return d;return null}}};CKEDITOR.tools.array.indexOf=CKEDITOR.tools.indexOf;CKEDITOR.tools.array.isArray=CKEDITOR.tools.isArray}(),CKEDITOR.dtd=function(){var a=CKEDITOR.tools.extend,c=function(a,g){for(var d=CKEDITOR.tools.clone(a),f=1;f<arguments.length;f++){g=arguments[f];for(var b in g)delete d[b]}return d},
b={},e={},h={address:1,article:1,aside:1,blockquote:1,details:1,div:1,dl:1,fieldset:1,figure:1,footer:1,form:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1,header:1,hgroup:1,hr:1,main:1,menu:1,nav:1,ol:1,p:1,pre:1,section:1,table:1,ul:1},l={command:1,link:1,meta:1,noscript:1,script:1,style:1},k={},f={"#":1},d={center:1,dir:1,noframes:1};a(b,{a:1,abbr:1,area:1,audio:1,b:1,bdi:1,bdo:1,br:1,button:1,canvas:1,cite:1,code:1,command:1,datalist:1,del:1,dfn:1,em:1,embed:1,i:1,iframe:1,img:1,input:1,ins:1,kbd:1,keygen:1,
label:1,map:1,mark:1,meter:1,noscript:1,object:1,output:1,progress:1,q:1,ruby:1,s:1,samp:1,script:1,select:1,small:1,span:1,strong:1,sub:1,sup:1,textarea:1,time:1,u:1,"var":1,video:1,wbr:1},f,{acronym:1,applet:1,basefont:1,big:1,font:1,isindex:1,strike:1,style:1,tt:1});a(e,h,b,d);c={a:c(b,{a:1,button:1}),abbr:b,address:e,area:k,article:e,aside:e,audio:a({source:1,track:1},e),b:b,base:k,bdi:b,bdo:b,blockquote:e,body:e,br:k,button:c(b,{a:1,button:1}),canvas:b,caption:e,cite:b,code:b,col:k,colgroup:{col:1},
command:k,datalist:a({option:1},b),dd:e,del:b,details:a({summary:1},e),dfn:b,div:e,dl:{dt:1,dd:1},dt:e,em:b,embed:k,fieldset:a({legend:1},e),figcaption:e,figure:a({figcaption:1},e),footer:e,form:e,h1:b,h2:b,h3:b,h4:b,h5:b,h6:b,head:a({title:1,base:1},l),header:e,hgroup:{h1:1,h2:1,h3:1,h4:1,h5:1,h6:1},hr:k,html:a({head:1,body:1},e,l),i:b,iframe:f,img:k,input:k,ins:b,kbd:b,keygen:k,label:b,legend:b,li:e,link:k,main:e,map:e,mark:b,menu:a({li:1},e),meta:k,meter:c(b,{meter:1}),nav:e,noscript:a({link:1,
meta:1,style:1},b),object:a({param:1},b),ol:{li:1},optgroup:{option:1},option:f,output:b,p:b,param:k,pre:b,progress:c(b,{progress:1}),q:b,rp:b,rt:b,ruby:a({rp:1,rt:1},b),s:b,samp:b,script:f,section:e,select:{optgroup:1,option:1},small:b,source:k,span:b,strong:b,style:f,sub:b,summary:a({h1:1,h2:1,h3:1,h4:1,h5:1,h6:1},b),sup:b,table:{caption:1,colgroup:1,thead:1,tfoot:1,tbody:1,tr:1},tbody:{tr:1},td:e,textarea:f,tfoot:{tr:1},th:e,thead:{tr:1},time:c(b,{time:1}),title:f,tr:{th:1,td:1},track:k,u:b,ul:{li:1},
"var":b,video:a({source:1,track:1},e),wbr:k,acronym:b,applet:a({param:1},e),basefont:k,big:b,center:e,dialog:k,dir:{li:1},font:b,isindex:k,noframes:e,strike:b,tt:b};a(c,{$block:a({audio:1,dd:1,dt:1,figcaption:1,li:1,video:1},h,d),$blockLimit:{article:1,aside:1,audio:1,body:1,caption:1,details:1,dir:1,div:1,dl:1,fieldset:1,figcaption:1,figure:1,footer:1,form:1,header:1,hgroup:1,main:1,menu:1,nav:1,ol:1,section:1,table:1,td:1,th:1,tr:1,ul:1,video:1},$cdata:{script:1,style:1},$editable:{address:1,article:1,
aside:1,blockquote:1,body:1,details:1,div:1,fieldset:1,figcaption:1,footer:1,form:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1,header:1,hgroup:1,main:1,nav:1,p:1,pre:1,section:1},$empty:{area:1,base:1,basefont:1,br:1,col:1,command:1,dialog:1,embed:1,hr:1,img:1,input:1,isindex:1,keygen:1,link:1,meta:1,param:1,source:1,track:1,wbr:1},$inline:b,$list:{dl:1,ol:1,ul:1},$listItem:{dd:1,dt:1,li:1},$nonBodyContent:a({body:1,head:1,html:1},c.head),$nonEditable:{applet:1,audio:1,button:1,embed:1,iframe:1,map:1,object:1,
option:1,param:1,script:1,textarea:1,video:1},$object:{applet:1,audio:1,button:1,hr:1,iframe:1,img:1,input:1,object:1,select:1,table:1,textarea:1,video:1},$removeEmpty:{abbr:1,acronym:1,b:1,bdi:1,bdo:1,big:1,cite:1,code:1,del:1,dfn:1,em:1,font:1,i:1,ins:1,label:1,kbd:1,mark:1,meter:1,output:1,q:1,ruby:1,s:1,samp:1,small:1,span:1,strike:1,strong:1,sub:1,sup:1,time:1,tt:1,u:1,"var":1},$tabIndex:{a:1,area:1,button:1,input:1,object:1,select:1,textarea:1},$tableContent:{caption:1,col:1,colgroup:1,tbody:1,
td:1,tfoot:1,th:1,thead:1,tr:1},$transparent:{a:1,audio:1,canvas:1,del:1,ins:1,map:1,noscript:1,object:1,video:1},$intermediate:{caption:1,colgroup:1,dd:1,dt:1,figcaption:1,legend:1,li:1,optgroup:1,option:1,rp:1,rt:1,summary:1,tbody:1,td:1,tfoot:1,th:1,thead:1,tr:1}});return c}(),CKEDITOR.dom.event=function(a){this.$=a},CKEDITOR.dom.event.prototype={getKey:function(){return this.$.keyCode||this.$.which},getKeystroke:function(){var a=this.getKey();if(this.$.ctrlKey||this.$.metaKey)a+=CKEDITOR.CTRL;
this.$.shiftKey&&(a+=CKEDITOR.SHIFT);this.$.altKey&&(a+=CKEDITOR.ALT);return a},preventDefault:function(a){var c=this.$;c.preventDefault?c.preventDefault():c.returnValue=!1;a&&this.stopPropagation()},stopPropagation:function(){var a=this.$;a.stopPropagation?a.stopPropagation():a.cancelBubble=!0},getTarget:function(){var a=this.$.target||this.$.srcElement;return a?new CKEDITOR.dom.node(a):null},getPhase:function(){return this.$.eventPhase||2},getPageOffset:function(){var a=this.getTarget().getDocument().$;
return{x:this.$.pageX||this.$.clientX+(a.documentElement.scrollLeft||a.body.scrollLeft),y:this.$.pageY||this.$.clientY+(a.documentElement.scrollTop||a.body.scrollTop)}}},CKEDITOR.CTRL=1114112,CKEDITOR.SHIFT=2228224,CKEDITOR.ALT=4456448,CKEDITOR.EVENT_PHASE_CAPTURING=1,CKEDITOR.EVENT_PHASE_AT_TARGET=2,CKEDITOR.EVENT_PHASE_BUBBLING=3,CKEDITOR.dom.domObject=function(a){a&&(this.$=a)},CKEDITOR.dom.domObject.prototype=function(){var a=function(a,b){return function(e){"undefined"!=typeof CKEDITOR&&a.fire(b,
new CKEDITOR.dom.event(e))}};return{getPrivate:function(){var a;(a=this.getCustomData("_"))||this.setCustomData("_",a={});return a},on:function(c){var b=this.getCustomData("_cke_nativeListeners");b||(b={},this.setCustomData("_cke_nativeListeners",b));b[c]||(b=b[c]=a(this,c),this.$.addEventListener?this.$.addEventListener(c,b,!!CKEDITOR.event.useCapture):this.$.attachEvent&&this.$.attachEvent("on"+c,b));return CKEDITOR.event.prototype.on.apply(this,arguments)},removeListener:function(a){CKEDITOR.event.prototype.removeListener.apply(this,
arguments);if(!this.hasListeners(a)){var b=this.getCustomData("_cke_nativeListeners"),e=b&&b[a];e&&(this.$.removeEventListener?this.$.removeEventListener(a,e,!1):this.$.detachEvent&&this.$.detachEvent("on"+a,e),delete b[a])}},removeAllListeners:function(){var a=this.getCustomData("_cke_nativeListeners"),b;for(b in a){var e=a[b];this.$.detachEvent?this.$.detachEvent("on"+b,e):this.$.removeEventListener&&this.$.removeEventListener(b,e,!1);delete a[b]}CKEDITOR.event.prototype.removeAllListeners.call(this)}}}(),
function(a){var c={};CKEDITOR.on("reset",function(){c={}});a.equals=function(a){try{return a&&a.$===this.$}catch(e){return!1}};a.setCustomData=function(a,e){var h=this.getUniqueId();(c[h]||(c[h]={}))[a]=e;return this};a.getCustomData=function(a){var e=this.$["data-cke-expando"];return(e=e&&c[e])&&a in e?e[a]:null};a.removeCustomData=function(a){var e=this.$["data-cke-expando"],e=e&&c[e],h,l;e&&(h=e[a],l=a in e,delete e[a]);return l?h:null};a.clearCustomData=function(){this.removeAllListeners();var a=
this.$["data-cke-expando"];a&&delete c[a]};a.getUniqueId=function(){return this.$["data-cke-expando"]||(this.$["data-cke-expando"]=CKEDITOR.tools.getNextNumber())};CKEDITOR.event.implementOn(a)}(CKEDITOR.dom.domObject.prototype),CKEDITOR.dom.node=function(a){return a?new CKEDITOR.dom[a.nodeType==CKEDITOR.NODE_DOCUMENT?"document":a.nodeType==CKEDITOR.NODE_ELEMENT?"element":a.nodeType==CKEDITOR.NODE_TEXT?"text":a.nodeType==CKEDITOR.NODE_COMMENT?"comment":a.nodeType==CKEDITOR.NODE_DOCUMENT_FRAGMENT?
"documentFragment":"domObject"](a):this},CKEDITOR.dom.node.prototype=new CKEDITOR.dom.domObject,CKEDITOR.NODE_ELEMENT=1,CKEDITOR.NODE_DOCUMENT=9,CKEDITOR.NODE_TEXT=3,CKEDITOR.NODE_COMMENT=8,CKEDITOR.NODE_DOCUMENT_FRAGMENT=11,CKEDITOR.POSITION_IDENTICAL=0,CKEDITOR.POSITION_DISCONNECTED=1,CKEDITOR.POSITION_FOLLOWING=2,CKEDITOR.POSITION_PRECEDING=4,CKEDITOR.POSITION_IS_CONTAINED=8,CKEDITOR.POSITION_CONTAINS=16,CKEDITOR.tools.extend(CKEDITOR.dom.node.prototype,{appendTo:function(a,c){a.append(this,c);
return a},clone:function(a,c){function b(e){e["data-cke-expando"]&&(e["data-cke-expando"]=!1);if(e.nodeType==CKEDITOR.NODE_ELEMENT||e.nodeType==CKEDITOR.NODE_DOCUMENT_FRAGMENT)if(c||e.nodeType!=CKEDITOR.NODE_ELEMENT||e.removeAttribute("id",!1),a){e=e.childNodes;for(var h=0;h<e.length;h++)b(e[h])}}function e(b){if(b.type==CKEDITOR.NODE_ELEMENT||b.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT){if(b.type!=CKEDITOR.NODE_DOCUMENT_FRAGMENT){var c=b.getName();":"==c[0]&&b.renameNode(c.substring(1))}if(a)for(c=0;c<
b.getChildCount();c++)e(b.getChild(c))}}var h=this.$.cloneNode(a);b(h);h=new CKEDITOR.dom.node(h);CKEDITOR.env.ie&&9>CKEDITOR.env.version&&(this.type==CKEDITOR.NODE_ELEMENT||this.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT)&&e(h);return h},hasPrevious:function(){return!!this.$.previousSibling},hasNext:function(){return!!this.$.nextSibling},insertAfter:function(a){a.$.parentNode.insertBefore(this.$,a.$.nextSibling);return a},insertBefore:function(a){a.$.parentNode.insertBefore(this.$,a.$);return a},insertBeforeMe:function(a){this.$.parentNode.insertBefore(a.$,
this.$);return a},getAddress:function(a){for(var c=[],b=this.getDocument().$.documentElement,e=this.$;e&&e!=b;){var h=e.parentNode;h&&c.unshift(this.getIndex.call({$:e},a));e=h}return c},getDocument:function(){return new CKEDITOR.dom.document(this.$.ownerDocument||this.$.parentNode.ownerDocument)},getIndex:function(a){function c(a,f){var d=f?a.nextSibling:a.previousSibling;return d&&d.nodeType==CKEDITOR.NODE_TEXT?b(d)?c(d,f):d:null}function b(a){return!a.nodeValue||a.nodeValue==CKEDITOR.dom.selection.FILLING_CHAR_SEQUENCE}
var e=this.$,h=-1,l;if(!this.$.parentNode||a&&e.nodeType==CKEDITOR.NODE_TEXT&&b(e)&&!c(e)&&!c(e,!0))return-1;do a&&e!=this.$&&e.nodeType==CKEDITOR.NODE_TEXT&&(l||b(e))||(h++,l=e.nodeType==CKEDITOR.NODE_TEXT);while(e=e.previousSibling);return h},getNextSourceNode:function(a,c,b){if(b&&!b.call){var e=b;b=function(a){return!a.equals(e)}}a=!a&&this.getFirst&&this.getFirst();var h;if(!a){if(this.type==CKEDITOR.NODE_ELEMENT&&b&&!1===b(this,!0))return null;a=this.getNext()}for(;!a&&(h=(h||this).getParent());){if(b&&
!1===b(h,!0))return null;a=h.getNext()}return!a||b&&!1===b(a)?null:c&&c!=a.type?a.getNextSourceNode(!1,c,b):a},getPreviousSourceNode:function(a,c,b){if(b&&!b.call){var e=b;b=function(a){return!a.equals(e)}}a=!a&&this.getLast&&this.getLast();var h;if(!a){if(this.type==CKEDITOR.NODE_ELEMENT&&b&&!1===b(this,!0))return null;a=this.getPrevious()}for(;!a&&(h=(h||this).getParent());){if(b&&!1===b(h,!0))return null;a=h.getPrevious()}return!a||b&&!1===b(a)?null:c&&a.type!=c?a.getPreviousSourceNode(!1,c,b):
a},getPrevious:function(a){var c=this.$,b;do b=(c=c.previousSibling)&&10!=c.nodeType&&new CKEDITOR.dom.node(c);while(b&&a&&!a(b));return b},getNext:function(a){var c=this.$,b;do b=(c=c.nextSibling)&&new CKEDITOR.dom.node(c);while(b&&a&&!a(b));return b},getParent:function(a){var c=this.$.parentNode;return c&&(c.nodeType==CKEDITOR.NODE_ELEMENT||a&&c.nodeType==CKEDITOR.NODE_DOCUMENT_FRAGMENT)?new CKEDITOR.dom.node(c):null},getParents:function(a){var c=this,b=[];do b[a?"push":"unshift"](c);while(c=c.getParent());
return b},getCommonAncestor:function(a){if(a.equals(this))return this;if(a.contains&&a.contains(this))return a;var c=this.contains?this:this.getParent();do if(c.contains(a))return c;while(c=c.getParent());return null},getPosition:function(a){var c=this.$,b=a.$;if(c.compareDocumentPosition)return c.compareDocumentPosition(b);if(c==b)return CKEDITOR.POSITION_IDENTICAL;if(this.type==CKEDITOR.NODE_ELEMENT&&a.type==CKEDITOR.NODE_ELEMENT){if(c.contains){if(c.contains(b))return CKEDITOR.POSITION_CONTAINS+
CKEDITOR.POSITION_PRECEDING;if(b.contains(c))return CKEDITOR.POSITION_IS_CONTAINED+CKEDITOR.POSITION_FOLLOWING}if("sourceIndex"in c)return 0>c.sourceIndex||0>b.sourceIndex?CKEDITOR.POSITION_DISCONNECTED:c.sourceIndex<b.sourceIndex?CKEDITOR.POSITION_PRECEDING:CKEDITOR.POSITION_FOLLOWING}c=this.getAddress();a=a.getAddress();for(var b=Math.min(c.length,a.length),e=0;e<b;e++)if(c[e]!=a[e])return c[e]<a[e]?CKEDITOR.POSITION_PRECEDING:CKEDITOR.POSITION_FOLLOWING;return c.length<a.length?CKEDITOR.POSITION_CONTAINS+
CKEDITOR.POSITION_PRECEDING:CKEDITOR.POSITION_IS_CONTAINED+CKEDITOR.POSITION_FOLLOWING},getAscendant:function(a,c){var b=this.$,e,h;c||(b=b.parentNode);"function"==typeof a?(h=!0,e=a):(h=!1,e=function(b){b="string"==typeof b.nodeName?b.nodeName.toLowerCase():"";return"string"==typeof a?b==a:b in a});for(;b;){if(e(h?new CKEDITOR.dom.node(b):b))return new CKEDITOR.dom.node(b);try{b=b.parentNode}catch(l){b=null}}return null},hasAscendant:function(a,c){var b=this.$;c||(b=b.parentNode);for(;b;){if(b.nodeName&&
b.nodeName.toLowerCase()==a)return!0;b=b.parentNode}return!1},move:function(a,c){a.append(this.remove(),c)},remove:function(a){var c=this.$,b=c.parentNode;if(b){if(a)for(;a=c.firstChild;)b.insertBefore(c.removeChild(a),c);b.removeChild(c)}return this},replace:function(a){this.insertBefore(a);a.remove()},trim:function(){this.ltrim();this.rtrim()},ltrim:function(){for(var a;this.getFirst&&(a=this.getFirst());){if(a.type==CKEDITOR.NODE_TEXT){var c=CKEDITOR.tools.ltrim(a.getText()),b=a.getLength();if(c)c.length<
b&&(a.split(b-c.length),this.$.removeChild(this.$.firstChild));else{a.remove();continue}}break}},rtrim:function(){for(var a;this.getLast&&(a=this.getLast());){if(a.type==CKEDITOR.NODE_TEXT){var c=CKEDITOR.tools.rtrim(a.getText()),b=a.getLength();if(c)c.length<b&&(a.split(c.length),this.$.lastChild.parentNode.removeChild(this.$.lastChild));else{a.remove();continue}}break}CKEDITOR.env.needsBrFiller&&(a=this.$.lastChild)&&1==a.type&&"br"==a.nodeName.toLowerCase()&&a.parentNode.removeChild(a)},isReadOnly:function(a){var c=
this;this.type!=CKEDITOR.NODE_ELEMENT&&(c=this.getParent());CKEDITOR.env.edge&&c&&c.is("textarea","input")&&(a=!0);if(!a&&c&&"undefined"!=typeof c.$.isContentEditable)return!(c.$.isContentEditable||c.data("cke-editable"));for(;c;){if(c.data("cke-editable"))return!1;if(c.hasAttribute("contenteditable"))return"false"==c.getAttribute("contenteditable");c=c.getParent()}return!0}}),CKEDITOR.dom.window=function(a){CKEDITOR.dom.domObject.call(this,a)},CKEDITOR.dom.window.prototype=new CKEDITOR.dom.domObject,
CKEDITOR.tools.extend(CKEDITOR.dom.window.prototype,{focus:function(){this.$.focus()},getViewPaneSize:function(){var a=this.$.document,c="CSS1Compat"==a.compatMode;return{width:(c?a.documentElement.clientWidth:a.body.clientWidth)||0,height:(c?a.documentElement.clientHeight:a.body.clientHeight)||0}},getScrollPosition:function(){var a=this.$;if("pageXOffset"in a)return{x:a.pageXOffset||0,y:a.pageYOffset||0};a=a.document;return{x:a.documentElement.scrollLeft||a.body.scrollLeft||0,y:a.documentElement.scrollTop||
a.body.scrollTop||0}},getFrame:function(){var a=this.$.frameElement;return a?new CKEDITOR.dom.element.get(a):null}}),CKEDITOR.dom.document=function(a){CKEDITOR.dom.domObject.call(this,a)},CKEDITOR.dom.document.prototype=new CKEDITOR.dom.domObject,CKEDITOR.tools.extend(CKEDITOR.dom.document.prototype,{type:CKEDITOR.NODE_DOCUMENT,appendStyleSheet:function(a){if(this.$.createStyleSheet)this.$.createStyleSheet(a);else{var c=new CKEDITOR.dom.element("link");c.setAttributes({rel:"stylesheet",type:"text/css",
href:a});this.getHead().append(c)}},appendStyleText:function(a){if(this.$.createStyleSheet){var c=this.$.createStyleSheet("");c.cssText=a}else{var b=new CKEDITOR.dom.element("style",this);b.append(new CKEDITOR.dom.text(a,this));this.getHead().append(b)}return c||b.$.sheet},createElement:function(a,c){var b=new CKEDITOR.dom.element(a,this);c&&(c.attributes&&b.setAttributes(c.attributes),c.styles&&b.setStyles(c.styles));return b},createText:function(a){return new CKEDITOR.dom.text(a,this)},focus:function(){this.getWindow().focus()},
getActive:function(){var a;try{a=this.$.activeElement}catch(c){return null}return new CKEDITOR.dom.element(a)},getById:function(a){return(a=this.$.getElementById(a))?new CKEDITOR.dom.element(a):null},getByAddress:function(a,c){for(var b=this.$.documentElement,e=0;b&&e<a.length;e++){var h=a[e];if(c)for(var l=-1,k=0;k<b.childNodes.length;k++){var f=b.childNodes[k];if(!0!==c||3!=f.nodeType||!f.previousSibling||3!=f.previousSibling.nodeType)if(l++,l==h){b=f;break}}else b=b.childNodes[h]}return b?new CKEDITOR.dom.node(b):
null},getElementsByTag:function(a,c){CKEDITOR.env.ie&&8>=document.documentMode||!c||(a=c+":"+a);return new CKEDITOR.dom.nodeList(this.$.getElementsByTagName(a))},getHead:function(){var a=this.$.getElementsByTagName("head")[0];return a=a?new CKEDITOR.dom.element(a):this.getDocumentElement().append(new CKEDITOR.dom.element("head"),!0)},getBody:function(){return new CKEDITOR.dom.element(this.$.body)},getDocumentElement:function(){return new CKEDITOR.dom.element(this.$.documentElement)},getWindow:function(){return new CKEDITOR.dom.window(this.$.parentWindow||
this.$.defaultView)},write:function(a){this.$.open("text/html","replace");CKEDITOR.env.ie&&(a=a.replace(/(?:^\s*<!DOCTYPE[^>]*?>)|^/i,'$\x26\n\x3cscript data-cke-temp\x3d"1"\x3e('+CKEDITOR.tools.fixDomain+")();\x3c/script\x3e"));this.$.write(a);this.$.close()},find:function(a){return new CKEDITOR.dom.nodeList(this.$.querySelectorAll(a))},findOne:function(a){return(a=this.$.querySelector(a))?new CKEDITOR.dom.element(a):null},_getHtml5ShivFrag:function(){var a=this.getCustomData("html5ShivFrag");a||
(a=this.$.createDocumentFragment(),CKEDITOR.tools.enableHtml5Elements(a,!0),this.setCustomData("html5ShivFrag",a));return a}}),CKEDITOR.dom.nodeList=function(a){this.$=a},CKEDITOR.dom.nodeList.prototype={count:function(){return this.$.length},getItem:function(a){return 0>a||a>=this.$.length?null:(a=this.$[a])?new CKEDITOR.dom.node(a):null},toArray:function(){return CKEDITOR.tools.array.map(this.$,function(a){return new CKEDITOR.dom.node(a)})}},CKEDITOR.dom.element=function(a,c){"string"==typeof a&&
(a=(c?c.$:document).createElement(a));CKEDITOR.dom.domObject.call(this,a)},CKEDITOR.dom.element.get=function(a){return(a="string"==typeof a?document.getElementById(a)||document.getElementsByName(a)[0]:a)&&(a.$?a:new CKEDITOR.dom.element(a))},CKEDITOR.dom.element.prototype=new CKEDITOR.dom.node,CKEDITOR.dom.element.createFromHtml=function(a,c){var b=new CKEDITOR.dom.element("div",c);b.setHtml(a);return b.getFirst().remove()},CKEDITOR.dom.element.setMarker=function(a,c,b,e){var h=c.getCustomData("list_marker_id")||
c.setCustomData("list_marker_id",CKEDITOR.tools.getNextNumber()).getCustomData("list_marker_id"),l=c.getCustomData("list_marker_names")||c.setCustomData("list_marker_names",{}).getCustomData("list_marker_names");a[h]=c;l[b]=1;return c.setCustomData(b,e)},CKEDITOR.dom.element.clearAllMarkers=function(a){for(var c in a)CKEDITOR.dom.element.clearMarkers(a,a[c],1)},CKEDITOR.dom.element.clearMarkers=function(a,c,b){var e=c.getCustomData("list_marker_names"),h=c.getCustomData("list_marker_id"),l;for(l in e)c.removeCustomData(l);
c.removeCustomData("list_marker_names");b&&(c.removeCustomData("list_marker_id"),delete a[h])},function(){function a(a,d){return-1<(" "+a+" ").replace(l," ").indexOf(" "+d+" ")}function c(a){var d=!0;a.$.id||(a.$.id="cke_tmp_"+CKEDITOR.tools.getNextNumber(),d=!1);return function(){d||a.removeAttribute("id")}}function b(a,d){var b=CKEDITOR.tools.escapeCss(a.$.id);return"#"+b+" "+d.split(/,\s*/).join(", #"+b+" ")}function e(a){for(var d=0,b=0,g=k[a].length;b<g;b++)d+=parseFloat(this.getComputedStyle(k[a][b])||
0,10)||0;return d}var h=document.createElement("_").classList,h="undefined"!==typeof h&&null!==String(h.add).match(/\[Native code\]/gi),l=/[\n\t\r]/g;CKEDITOR.tools.extend(CKEDITOR.dom.element.prototype,{type:CKEDITOR.NODE_ELEMENT,addClass:h?function(a){this.$.classList.add(a);return this}:function(f){var d=this.$.className;d&&(a(d,f)||(d+=" "+f));this.$.className=d||f;return this},removeClass:h?function(a){var d=this.$;d.classList.remove(a);d.className||d.removeAttribute("class");return this}:function(f){var d=
this.getAttribute("class");d&&a(d,f)&&((d=d.replace(new RegExp("(?:^|\\s+)"+f+"(?\x3d\\s|$)"),"").replace(/^\s+/,""))?this.setAttribute("class",d):this.removeAttribute("class"));return this},hasClass:function(f){return a(this.$.className,f)},append:function(a,d){"string"==typeof a&&(a=this.getDocument().createElement(a));d?this.$.insertBefore(a.$,this.$.firstChild):this.$.appendChild(a.$);return a},appendHtml:function(a){if(this.$.childNodes.length){var d=new CKEDITOR.dom.element("div",this.getDocument());
d.setHtml(a);d.moveChildren(this)}else this.setHtml(a)},appendText:function(a){null!=this.$.text&&CKEDITOR.env.ie&&9>CKEDITOR.env.version?this.$.text+=a:this.append(new CKEDITOR.dom.text(a))},appendBogus:function(a){if(a||CKEDITOR.env.needsBrFiller){for(a=this.getLast();a&&a.type==CKEDITOR.NODE_TEXT&&!CKEDITOR.tools.rtrim(a.getText());)a=a.getPrevious();a&&a.is&&a.is("br")||(a=this.getDocument().createElement("br"),CKEDITOR.env.gecko&&a.setAttribute("type","_moz"),this.append(a))}},breakParent:function(a,
d){var b=new CKEDITOR.dom.range(this.getDocument());b.setStartAfter(this);b.setEndAfter(a);var g=b.extractContents(!1,d||!1),e;b.insertNode(this.remove());if(CKEDITOR.env.ie&&!CKEDITOR.env.edge){for(b=new CKEDITOR.dom.element("div");e=g.getFirst();)e.$.style.backgroundColor&&(e.$.style.backgroundColor=e.$.style.backgroundColor),b.append(e);b.insertAfter(this);b.remove(!0)}else g.insertAfterNode(this)},contains:document.compareDocumentPosition?function(a){return!!(this.$.compareDocumentPosition(a.$)&
16)}:function(a){var d=this.$;return a.type!=CKEDITOR.NODE_ELEMENT?d.contains(a.getParent().$):d!=a.$&&d.contains(a.$)},focus:function(){function a(){try{this.$.focus()}catch(d){}}return function(d){d?CKEDITOR.tools.setTimeout(a,100,this):a.call(this)}}(),getHtml:function(){var a=this.$.innerHTML;return CKEDITOR.env.ie?a.replace(/<\?[^>]*>/g,""):a},getOuterHtml:function(){if(this.$.outerHTML)return this.$.outerHTML.replace(/<\?[^>]*>/,"");var a=this.$.ownerDocument.createElement("div");a.appendChild(this.$.cloneNode(!0));
return a.innerHTML},getClientRect:function(){var a=CKEDITOR.tools.extend({},this.$.getBoundingClientRect());!a.width&&(a.width=a.right-a.left);!a.height&&(a.height=a.bottom-a.top);return a},setHtml:CKEDITOR.env.ie&&9>CKEDITOR.env.version?function(a){try{var d=this.$;if(this.getParent())return d.innerHTML=a;var b=this.getDocument()._getHtml5ShivFrag();b.appendChild(d);d.innerHTML=a;b.removeChild(d);return a}catch(g){this.$.innerHTML="";d=new CKEDITOR.dom.element("body",this.getDocument());d.$.innerHTML=
a;for(d=d.getChildren();d.count();)this.append(d.getItem(0));return a}}:function(a){return this.$.innerHTML=a},setText:function(){var a=document.createElement("p");a.innerHTML="x";a=a.textContent;return function(d){this.$[a?"textContent":"innerText"]=d}}(),getAttribute:function(){var a=function(a){return this.$.getAttribute(a,2)};return CKEDITOR.env.ie&&(CKEDITOR.env.ie7Compat||CKEDITOR.env.quirks)?function(a){switch(a){case "class":a="className";break;case "http-equiv":a="httpEquiv";break;case "name":return this.$.name;
case "tabindex":return a=this.$.getAttribute(a,2),0!==a&&0===this.$.tabIndex&&(a=null),a;case "checked":return a=this.$.attributes.getNamedItem(a),(a.specified?a.nodeValue:this.$.checked)?"checked":null;case "hspace":case "value":return this.$[a];case "style":return this.$.style.cssText;case "contenteditable":case "contentEditable":return this.$.attributes.getNamedItem("contentEditable").specified?this.$.getAttribute("contentEditable"):null}return this.$.getAttribute(a,2)}:a}(),getAttributes:function(a){var d=
{},b=this.$.attributes,g;a=CKEDITOR.tools.isArray(a)?a:[];for(g=0;g<b.length;g++)-1===CKEDITOR.tools.indexOf(a,b[g].name)&&(d[b[g].name]=b[g].value);return d},getChildren:function(){return new CKEDITOR.dom.nodeList(this.$.childNodes)},getComputedStyle:document.defaultView&&document.defaultView.getComputedStyle?function(a){var d=this.getWindow().$.getComputedStyle(this.$,null);return d?d.getPropertyValue(a):""}:function(a){return this.$.currentStyle[CKEDITOR.tools.cssStyleToDomStyle(a)]},getDtd:function(){var a=
CKEDITOR.dtd[this.getName()];this.getDtd=function(){return a};return a},getElementsByTag:CKEDITOR.dom.document.prototype.getElementsByTag,getTabIndex:function(){var a=this.$.tabIndex;return 0!==a||CKEDITOR.dtd.$tabIndex[this.getName()]||0===parseInt(this.getAttribute("tabindex"),10)?a:-1},getText:function(){return this.$.textContent||this.$.innerText||""},getWindow:function(){return this.getDocument().getWindow()},getId:function(){return this.$.id||null},getNameAtt:function(){return this.$.name||
null},getName:function(){var a=this.$.nodeName.toLowerCase();if(CKEDITOR.env.ie&&8>=document.documentMode){var d=this.$.scopeName;"HTML"!=d&&(a=d.toLowerCase()+":"+a)}this.getName=function(){return a};return this.getName()},getValue:function(){return this.$.value},getFirst:function(a){var d=this.$.firstChild;(d=d&&new CKEDITOR.dom.node(d))&&a&&!a(d)&&(d=d.getNext(a));return d},getLast:function(a){var d=this.$.lastChild;(d=d&&new CKEDITOR.dom.node(d))&&a&&!a(d)&&(d=d.getPrevious(a));return d},getStyle:function(a){return this.$.style[CKEDITOR.tools.cssStyleToDomStyle(a)]},
is:function(){var a=this.getName();if("object"==typeof arguments[0])return!!arguments[0][a];for(var d=0;d<arguments.length;d++)if(arguments[d]==a)return!0;return!1},isEditable:function(a){var d=this.getName();return this.isReadOnly()||"none"==this.getComputedStyle("display")||"hidden"==this.getComputedStyle("visibility")||CKEDITOR.dtd.$nonEditable[d]||CKEDITOR.dtd.$empty[d]||this.is("a")&&(this.data("cke-saved-name")||this.hasAttribute("name"))&&!this.getChildCount()?!1:!1!==a?(a=CKEDITOR.dtd[d]||
CKEDITOR.dtd.span,!(!a||!a["#"])):!0},isIdentical:function(a){var d=this.clone(0,1);a=a.clone(0,1);d.removeAttributes(["_moz_dirty","data-cke-expando","data-cke-saved-href","data-cke-saved-name"]);a.removeAttributes(["_moz_dirty","data-cke-expando","data-cke-saved-href","data-cke-saved-name"]);if(d.$.isEqualNode)return d.$.style.cssText=CKEDITOR.tools.normalizeCssText(d.$.style.cssText),a.$.style.cssText=CKEDITOR.tools.normalizeCssText(a.$.style.cssText),d.$.isEqualNode(a.$);d=d.getOuterHtml();a=
a.getOuterHtml();if(CKEDITOR.env.ie&&9>CKEDITOR.env.version&&this.is("a")){var b=this.getParent();b.type==CKEDITOR.NODE_ELEMENT&&(b=b.clone(),b.setHtml(d),d=b.getHtml(),b.setHtml(a),a=b.getHtml())}return d==a},isVisible:function(){var a=(this.$.offsetHeight||this.$.offsetWidth)&&"hidden"!=this.getComputedStyle("visibility"),d,b;a&&CKEDITOR.env.webkit&&(d=this.getWindow(),!d.equals(CKEDITOR.document.getWindow())&&(b=d.$.frameElement)&&(a=(new CKEDITOR.dom.element(b)).isVisible()));return!!a},isEmptyInlineRemoveable:function(){if(!CKEDITOR.dtd.$removeEmpty[this.getName()])return!1;
for(var a=this.getChildren(),d=0,b=a.count();d<b;d++){var g=a.getItem(d);if(g.type!=CKEDITOR.NODE_ELEMENT||!g.data("cke-bookmark"))if(g.type==CKEDITOR.NODE_ELEMENT&&!g.isEmptyInlineRemoveable()||g.type==CKEDITOR.NODE_TEXT&&CKEDITOR.tools.trim(g.getText()))return!1}return!0},hasAttributes:CKEDITOR.env.ie&&(CKEDITOR.env.ie7Compat||CKEDITOR.env.quirks)?function(){for(var a=this.$.attributes,d=0;d<a.length;d++){var b=a[d];switch(b.nodeName){case "class":if(this.getAttribute("class"))return!0;case "data-cke-expando":continue;
default:if(b.specified)return!0}}return!1}:function(){var a=this.$.attributes,d=a.length,b={"data-cke-expando":1,_moz_dirty:1};return 0<d&&(2<d||!b[a[0].nodeName]||2==d&&!b[a[1].nodeName])},hasAttribute:function(){function a(d){var b=this.$.attributes.getNamedItem(d);if("input"==this.getName())switch(d){case "class":return 0<this.$.className.length;case "checked":return!!this.$.checked;case "value":return d=this.getAttribute("type"),"checkbox"==d||"radio"==d?"on"!=this.$.value:!!this.$.value}return b?
b.specified:!1}return CKEDITOR.env.ie?8>CKEDITOR.env.version?function(d){return"name"==d?!!this.$.name:a.call(this,d)}:a:function(a){return!!this.$.attributes.getNamedItem(a)}}(),hide:function(){this.setStyle("display","none")},moveChildren:function(a,d){var b=this.$;a=a.$;if(b!=a){var g;if(d)for(;g=b.lastChild;)a.insertBefore(b.removeChild(g),a.firstChild);else for(;g=b.firstChild;)a.appendChild(b.removeChild(g))}},mergeSiblings:function(){function a(d,b,g){if(b&&b.type==CKEDITOR.NODE_ELEMENT){for(var e=
[];b.data("cke-bookmark")||b.isEmptyInlineRemoveable();)if(e.push(b),b=g?b.getNext():b.getPrevious(),!b||b.type!=CKEDITOR.NODE_ELEMENT)return;if(d.isIdentical(b)){for(var f=g?d.getLast():d.getFirst();e.length;)e.shift().move(d,!g);b.moveChildren(d,!g);b.remove();f&&f.type==CKEDITOR.NODE_ELEMENT&&f.mergeSiblings()}}}return function(d){if(!1===d||CKEDITOR.dtd.$removeEmpty[this.getName()]||this.is("a"))a(this,this.getNext(),!0),a(this,this.getPrevious())}}(),show:function(){this.setStyles({display:"",
visibility:""})},setAttribute:function(){var a=function(a,b){this.$.setAttribute(a,b);return this};return CKEDITOR.env.ie&&(CKEDITOR.env.ie7Compat||CKEDITOR.env.quirks)?function(d,b){"class"==d?this.$.className=b:"style"==d?this.$.style.cssText=b:"tabindex"==d?this.$.tabIndex=b:"checked"==d?this.$.checked=b:"contenteditable"==d?a.call(this,"contentEditable",b):a.apply(this,arguments);return this}:CKEDITOR.env.ie8Compat&&CKEDITOR.env.secure?function(d,b){if("src"==d&&b.match(/^http:\/\//))try{a.apply(this,
arguments)}catch(g){}else a.apply(this,arguments);return this}:a}(),setAttributes:function(a){for(var d in a)this.setAttribute(d,a[d]);return this},setValue:function(a){this.$.value=a;return this},removeAttribute:function(){var a=function(a){this.$.removeAttribute(a)};return CKEDITOR.env.ie&&(CKEDITOR.env.ie7Compat||CKEDITOR.env.quirks)?function(a){"class"==a?a="className":"tabindex"==a?a="tabIndex":"contenteditable"==a&&(a="contentEditable");this.$.removeAttribute(a)}:a}(),removeAttributes:function(a){if(CKEDITOR.tools.isArray(a))for(var d=
0;d<a.length;d++)this.removeAttribute(a[d]);else for(d in a=a||this.getAttributes(),a)a.hasOwnProperty(d)&&this.removeAttribute(d)},removeStyle:function(a){var d=this.$.style;if(d.removeProperty||"border"!=a&&"margin"!=a&&"padding"!=a)d.removeProperty?d.removeProperty(a):d.removeAttribute(CKEDITOR.tools.cssStyleToDomStyle(a)),this.$.style.cssText||this.removeAttribute("style");else{var b=["top","left","right","bottom"],g;"border"==a&&(g=["color","style","width"]);for(var d=[],e=0;e<b.length;e++)if(g)for(var c=
0;c<g.length;c++)d.push([a,b[e],g[c]].join("-"));else d.push([a,b[e]].join("-"));for(a=0;a<d.length;a++)this.removeStyle(d[a])}},setStyle:function(a,d){this.$.style[CKEDITOR.tools.cssStyleToDomStyle(a)]=d;return this},setStyles:function(a){for(var d in a)this.setStyle(d,a[d]);return this},setOpacity:function(a){CKEDITOR.env.ie&&9>CKEDITOR.env.version?(a=Math.round(100*a),this.setStyle("filter",100<=a?"":"progid:DXImageTransform.Microsoft.Alpha(opacity\x3d"+a+")")):this.setStyle("opacity",a)},unselectable:function(){this.setStyles(CKEDITOR.tools.cssVendorPrefix("user-select",
"none"));if(CKEDITOR.env.ie){this.setAttribute("unselectable","on");for(var a,d=this.getElementsByTag("*"),b=0,g=d.count();b<g;b++)a=d.getItem(b),a.setAttribute("unselectable","on")}},getPositionedAncestor:function(){for(var a=this;"html"!=a.getName();){if("static"!=a.getComputedStyle("position"))return a;a=a.getParent()}return null},getDocumentPosition:function(a){var d=0,b=0,g=this.getDocument(),e=g.getBody(),c="BackCompat"==g.$.compatMode;if(document.documentElement.getBoundingClientRect&&(CKEDITOR.env.ie?
8!==CKEDITOR.env.version:1)){var h=this.$.getBoundingClientRect(),k=g.$.documentElement,l=k.clientTop||e.$.clientTop||0,t=k.clientLeft||e.$.clientLeft||0,r=!0;CKEDITOR.env.ie&&(r=g.getDocumentElement().contains(this),g=g.getBody().contains(this),r=c&&g||!c&&r);r&&(CKEDITOR.env.webkit||CKEDITOR.env.ie&&12<=CKEDITOR.env.version?(d=e.$.scrollLeft||k.scrollLeft,b=e.$.scrollTop||k.scrollTop):(b=c?e.$:k,d=b.scrollLeft,b=b.scrollTop),d=h.left+d-t,b=h.top+b-l)}else for(l=this,t=null;l&&"body"!=l.getName()&&
"html"!=l.getName();){d+=l.$.offsetLeft-l.$.scrollLeft;b+=l.$.offsetTop-l.$.scrollTop;l.equals(this)||(d+=l.$.clientLeft||0,b+=l.$.clientTop||0);for(;t&&!t.equals(l);)d-=t.$.scrollLeft,b-=t.$.scrollTop,t=t.getParent();t=l;l=(h=l.$.offsetParent)?new CKEDITOR.dom.element(h):null}a&&(h=this.getWindow(),l=a.getWindow(),!h.equals(l)&&h.$.frameElement&&(a=(new CKEDITOR.dom.element(h.$.frameElement)).getDocumentPosition(a),d+=a.x,b+=a.y));document.documentElement.getBoundingClientRect||!CKEDITOR.env.gecko||
c||(d+=this.$.clientLeft?1:0,b+=this.$.clientTop?1:0);return{x:d,y:b}},scrollIntoView:function(a){var d=this.getParent();if(d){do if((d.$.clientWidth&&d.$.clientWidth<d.$.scrollWidth||d.$.clientHeight&&d.$.clientHeight<d.$.scrollHeight)&&!d.is("body")&&this.scrollIntoParent(d,a,1),d.is("html")){var b=d.getWindow();try{var g=b.$.frameElement;g&&(d=new CKEDITOR.dom.element(g))}catch(e){}}while(d=d.getParent())}},scrollIntoParent:function(a,d,b){var g,e,c,h;function k(g,d){/body|html/.test(a.getName())?
a.getWindow().$.scrollBy(g,d):(a.$.scrollLeft+=g,a.$.scrollTop+=d)}function l(a,g){var d={x:0,y:0};if(!a.is(r?"body":"html")){var b=a.$.getBoundingClientRect();d.x=b.left;d.y=b.top}b=a.getWindow();b.equals(g)||(b=l(CKEDITOR.dom.element.get(b.$.frameElement),g),d.x+=b.x,d.y+=b.y);return d}function t(a,g){return parseInt(a.getComputedStyle("margin-"+g)||0,10)||0}!a&&(a=this.getWindow());c=a.getDocument();var r="BackCompat"==c.$.compatMode;a instanceof CKEDITOR.dom.window&&(a=r?c.getBody():c.getDocumentElement());
CKEDITOR.env.webkit&&(c=this.getEditor(!1))&&(c._.previousScrollTop=null);c=a.getWindow();e=l(this,c);var w=l(a,c),z=this.$.offsetHeight;g=this.$.offsetWidth;var u=a.$.clientHeight,B=a.$.clientWidth;c=e.x-t(this,"left")-w.x||0;h=e.y-t(this,"top")-w.y||0;g=e.x+g+t(this,"right")-(w.x+B)||0;e=e.y+z+t(this,"bottom")-(w.y+u)||0;(0>h||0<e)&&k(0,!0===d?h:!1===d?e:0>h?h:e);b&&(0>c||0<g)&&k(0>c?c:g,0)},setState:function(a,d,b){d=d||"cke";switch(a){case CKEDITOR.TRISTATE_ON:this.addClass(d+"_on");this.removeClass(d+
"_off");this.removeClass(d+"_disabled");b&&this.setAttribute("aria-pressed",!0);b&&this.removeAttribute("aria-disabled");break;case CKEDITOR.TRISTATE_DISABLED:this.addClass(d+"_disabled");this.removeClass(d+"_off");this.removeClass(d+"_on");b&&this.setAttribute("aria-disabled",!0);b&&this.removeAttribute("aria-pressed");break;default:this.addClass(d+"_off"),this.removeClass(d+"_on"),this.removeClass(d+"_disabled"),b&&this.removeAttribute("aria-pressed"),b&&this.removeAttribute("aria-disabled")}},
getFrameDocument:function(){var a=this.$;try{a.contentWindow.document}catch(d){a.src=a.src}return a&&new CKEDITOR.dom.document(a.contentWindow.document)},copyAttributes:function(a,d){var b=this.$.attributes;d=d||{};for(var g=0;g<b.length;g++){var e=b[g],c=e.nodeName.toLowerCase(),h;if(!(c in d))if("checked"==c&&(h=this.getAttribute(c)))a.setAttribute(c,h);else if(!CKEDITOR.env.ie||this.hasAttribute(c))h=this.getAttribute(c),null===h&&(h=e.nodeValue),a.setAttribute(c,h)}""!==this.$.style.cssText&&
(a.$.style.cssText=this.$.style.cssText)},renameNode:function(a){if(this.getName()!=a){var d=this.getDocument();a=new CKEDITOR.dom.element(a,d);this.copyAttributes(a);this.moveChildren(a);this.getParent(!0)&&this.$.parentNode.replaceChild(a.$,this.$);a.$["data-cke-expando"]=this.$["data-cke-expando"];this.$=a.$;delete this.getName}},getChild:function(){function a(d,b){var g=d.childNodes;if(0<=b&&b<g.length)return g[b]}return function(d){var b=this.$;if(d.slice)for(d=d.slice();0<d.length&&b;)b=a(b,
d.shift());else b=a(b,d);return b?new CKEDITOR.dom.node(b):null}}(),getChildCount:function(){return this.$.childNodes.length},disableContextMenu:function(){function a(d){return d.type==CKEDITOR.NODE_ELEMENT&&d.hasClass("cke_enable_context_menu")}this.on("contextmenu",function(d){d.data.getTarget().getAscendant(a,!0)||d.data.preventDefault()})},getDirection:function(a){return a?this.getComputedStyle("direction")||this.getDirection()||this.getParent()&&this.getParent().getDirection(1)||this.getDocument().$.dir||
"ltr":this.getStyle("direction")||this.getAttribute("dir")},data:function(a,d){a="data-"+a;if(void 0===d)return this.getAttribute(a);!1===d?this.removeAttribute(a):this.setAttribute(a,d);return null},getEditor:function(a){var d=CKEDITOR.instances,b,g,e;a=a||void 0===a;for(b in d)if(g=d[b],g.element.equals(this)&&g.elementMode!=CKEDITOR.ELEMENT_MODE_APPENDTO||!a&&(e=g.editable())&&(e.equals(this)||e.contains(this)))return g;return null},find:function(a){var d=c(this);a=new CKEDITOR.dom.nodeList(this.$.querySelectorAll(b(this,
a)));d();return a},findOne:function(a){var d=c(this);a=this.$.querySelector(b(this,a));d();return a?new CKEDITOR.dom.element(a):null},forEach:function(a,d,b){if(!(b||d&&this.type!=d))var g=a(this);if(!1!==g){b=this.getChildren();for(var e=0;e<b.count();e++)g=b.getItem(e),g.type==CKEDITOR.NODE_ELEMENT?g.forEach(a,d):d&&g.type!=d||a(g)}}});var k={width:["border-left-width","border-right-width","padding-left","padding-right"],height:["border-top-width","border-bottom-width","padding-top","padding-bottom"]};
CKEDITOR.dom.element.prototype.setSize=function(a,b,c){"number"==typeof b&&(!c||CKEDITOR.env.ie&&CKEDITOR.env.quirks||(b-=e.call(this,a)),this.setStyle(a,b+"px"))};CKEDITOR.dom.element.prototype.getSize=function(a,b){var c=Math.max(this.$["offset"+CKEDITOR.tools.capitalize(a)],this.$["client"+CKEDITOR.tools.capitalize(a)])||0;b&&(c-=e.call(this,a));return c}}(),CKEDITOR.dom.documentFragment=function(a){a=a||CKEDITOR.document;this.$=a.type==CKEDITOR.NODE_DOCUMENT?a.$.createDocumentFragment():a},CKEDITOR.tools.extend(CKEDITOR.dom.documentFragment.prototype,
CKEDITOR.dom.element.prototype,{type:CKEDITOR.NODE_DOCUMENT_FRAGMENT,insertAfterNode:function(a){a=a.$;a.parentNode.insertBefore(this.$,a.nextSibling)},getHtml:function(){var a=new CKEDITOR.dom.element("div");this.clone(1,1).appendTo(a);return a.getHtml().replace(/\s*data-cke-expando=".*?"/g,"")}},!0,{append:1,appendBogus:1,clone:1,getFirst:1,getHtml:1,getLast:1,getParent:1,getNext:1,getPrevious:1,appendTo:1,moveChildren:1,insertBefore:1,insertAfterNode:1,replace:1,trim:1,type:1,ltrim:1,rtrim:1,getDocument:1,
getChildCount:1,getChild:1,getChildren:1}),function(){function a(a,g){var b=this.range;if(this._.end)return null;if(!this._.start){this._.start=1;if(b.collapsed)return this.end(),null;b.optimize()}var d,e=b.startContainer;d=b.endContainer;var c=b.startOffset,f=b.endOffset,m,h=this.guard,n=this.type,k=a?"getPreviousSourceNode":"getNextSourceNode";if(!a&&!this._.guardLTR){var l=d.type==CKEDITOR.NODE_ELEMENT?d:d.getParent(),A=d.type==CKEDITOR.NODE_ELEMENT?d.getChild(f):d.getNext();this._.guardLTR=function(a,
g){return(!g||!l.equals(a))&&(!A||!a.equals(A))&&(a.type!=CKEDITOR.NODE_ELEMENT||!g||!a.equals(b.root))}}if(a&&!this._.guardRTL){var D=e.type==CKEDITOR.NODE_ELEMENT?e:e.getParent(),H=e.type==CKEDITOR.NODE_ELEMENT?c?e.getChild(c-1):null:e.getPrevious();this._.guardRTL=function(a,g){return(!g||!D.equals(a))&&(!H||!a.equals(H))&&(a.type!=CKEDITOR.NODE_ELEMENT||!g||!a.equals(b.root))}}var E=a?this._.guardRTL:this._.guardLTR;m=h?function(a,g){return!1===E(a,g)?!1:h(a,g)}:E;this.current?d=this.current[k](!1,
n,m):(a?d.type==CKEDITOR.NODE_ELEMENT&&(d=0<f?d.getChild(f-1):!1===m(d,!0)?null:d.getPreviousSourceNode(!0,n,m)):(d=e,d.type==CKEDITOR.NODE_ELEMENT&&((d=d.getChild(c))||(d=!1===m(e,!0)?null:e.getNextSourceNode(!0,n,m)))),d&&!1===m(d)&&(d=null));for(;d&&!this._.end;){this.current=d;if(!this.evaluator||!1!==this.evaluator(d)){if(!g)return d}else if(g&&this.evaluator)return!1;d=d[k](!1,n,m)}this.end();return this.current=null}function c(g){for(var d,b=null;d=a.call(this,g);)b=d;return b}CKEDITOR.dom.walker=
CKEDITOR.tools.createClass({$:function(a){this.range=a;this._={}},proto:{end:function(){this._.end=1},next:function(){return a.call(this)},previous:function(){return a.call(this,1)},checkForward:function(){return!1!==a.call(this,0,1)},checkBackward:function(){return!1!==a.call(this,1,1)},lastForward:function(){return c.call(this)},lastBackward:function(){return c.call(this,1)},reset:function(){delete this.current;this._={}}}});var b={block:1,"list-item":1,table:1,"table-row-group":1,"table-header-group":1,
"table-footer-group":1,"table-row":1,"table-column-group":1,"table-column":1,"table-cell":1,"table-caption":1},e={absolute:1,fixed:1};CKEDITOR.dom.element.prototype.isBlockBoundary=function(a){return"none"!=this.getComputedStyle("float")||this.getComputedStyle("position")in e||!b[this.getComputedStyle("display")]?!!(this.is(CKEDITOR.dtd.$block)||a&&this.is(a)):!0};CKEDITOR.dom.walker.blockBoundary=function(a){return function(g){return!(g.type==CKEDITOR.NODE_ELEMENT&&g.isBlockBoundary(a))}};CKEDITOR.dom.walker.listItemBoundary=
function(){return this.blockBoundary({br:1})};CKEDITOR.dom.walker.bookmark=function(a,g){function d(a){return a&&a.getName&&"span"==a.getName()&&a.data("cke-bookmark")}return function(b){var e,c;e=b&&b.type!=CKEDITOR.NODE_ELEMENT&&(c=b.getParent())&&d(c);e=a?e:e||d(b);return!!(g^e)}};CKEDITOR.dom.walker.whitespaces=function(a){return function(g){var d;g&&g.type==CKEDITOR.NODE_TEXT&&(d=!CKEDITOR.tools.trim(g.getText())||CKEDITOR.env.webkit&&g.getText()==CKEDITOR.dom.selection.FILLING_CHAR_SEQUENCE);
return!!(a^d)}};CKEDITOR.dom.walker.invisible=function(a){var g=CKEDITOR.dom.walker.whitespaces(),d=CKEDITOR.env.webkit?1:0;return function(b){g(b)?b=1:(b.type==CKEDITOR.NODE_TEXT&&(b=b.getParent()),b=b.$.offsetWidth<=d);return!!(a^b)}};CKEDITOR.dom.walker.nodeType=function(a,g){return function(b){return!!(g^b.type==a)}};CKEDITOR.dom.walker.bogus=function(a){function g(a){return!l(a)&&!k(a)}return function(b){var d=CKEDITOR.env.needsBrFiller?b.is&&b.is("br"):b.getText&&h.test(b.getText());d&&(d=b.getParent(),
b=b.getNext(g),d=d.isBlockBoundary()&&(!b||b.type==CKEDITOR.NODE_ELEMENT&&b.isBlockBoundary()));return!!(a^d)}};CKEDITOR.dom.walker.temp=function(a){return function(g){g.type!=CKEDITOR.NODE_ELEMENT&&(g=g.getParent());g=g&&g.hasAttribute("data-cke-temp");return!!(a^g)}};var h=/^[\t\r\n ]*(?:&nbsp;|\xa0)$/,l=CKEDITOR.dom.walker.whitespaces(),k=CKEDITOR.dom.walker.bookmark(),f=CKEDITOR.dom.walker.temp(),d=function(a){return k(a)||l(a)||a.type==CKEDITOR.NODE_ELEMENT&&a.is(CKEDITOR.dtd.$inline)&&!a.is(CKEDITOR.dtd.$empty)};
CKEDITOR.dom.walker.ignored=function(a){return function(g){g=l(g)||k(g)||f(g);return!!(a^g)}};var m=CKEDITOR.dom.walker.ignored();CKEDITOR.dom.walker.empty=function(a){return function(g){for(var b=0,d=g.getChildCount();b<d;++b)if(!m(g.getChild(b)))return!!a;return!a}};var g=CKEDITOR.dom.walker.empty(),n=CKEDITOR.dom.walker.validEmptyBlockContainers=CKEDITOR.tools.extend(function(a){var g={},b;for(b in a)CKEDITOR.dtd[b]["#"]&&(g[b]=1);return g}(CKEDITOR.dtd.$block),{caption:1,td:1,th:1});CKEDITOR.dom.walker.editable=
function(a){return function(b){b=m(b)?!1:b.type==CKEDITOR.NODE_TEXT||b.type==CKEDITOR.NODE_ELEMENT&&(b.is(CKEDITOR.dtd.$inline)||b.is("hr")||"false"==b.getAttribute("contenteditable")||!CKEDITOR.env.needsBrFiller&&b.is(n)&&g(b))?!0:!1;return!!(a^b)}};CKEDITOR.dom.element.prototype.getBogus=function(){var a=this;do a=a.getPreviousSourceNode();while(d(a));return a&&(CKEDITOR.env.needsBrFiller?a.is&&a.is("br"):a.getText&&h.test(a.getText()))?a:!1}}(),CKEDITOR.dom.range=function(a){this.endOffset=this.endContainer=
this.startOffset=this.startContainer=null;this.collapsed=!0;var c=a instanceof CKEDITOR.dom.document;this.document=c?a:a.getDocument();this.root=c?a.getBody():a},function(){function a(a){a.collapsed=a.startContainer&&a.endContainer&&a.startContainer.equals(a.endContainer)&&a.startOffset==a.endOffset}function c(a,b,d,e,c){function f(a,g,b,d){var e=b?a.getPrevious():a.getNext();if(d&&k)return e;u||d?g.append(a.clone(!0,c),b):(a.remove(),l&&g.append(a,b));return e}function m(){var a,g,b,d=Math.min(J.length,
F.length);for(a=0;a<d;a++)if(g=J[a],b=F[a],!g.equals(b))return a;return a-1}function h(){var b=S-1,d=E&&I&&!B.equals(C);b<N-1||b<Q-1||d?(d?a.moveToPosition(C,CKEDITOR.POSITION_BEFORE_START):Q==b+1&&H?a.moveToPosition(F[b],CKEDITOR.POSITION_BEFORE_END):a.moveToPosition(F[b+1],CKEDITOR.POSITION_BEFORE_START),e&&(b=J[b+1])&&b.type==CKEDITOR.NODE_ELEMENT&&(d=CKEDITOR.dom.element.createFromHtml('\x3cspan data-cke-bookmark\x3d"1" style\x3d"display:none"\x3e\x26nbsp;\x3c/span\x3e',a.document),d.insertAfter(b),
b.mergeSiblings(!1),a.moveToBookmark({startNode:d}))):a.collapse(!0)}a.optimizeBookmark();var k=0===b,l=1==b,u=2==b;b=u||l;var B=a.startContainer,C=a.endContainer,x=a.startOffset,A=a.endOffset,D,H,E,I,G,K;if(u&&C.type==CKEDITOR.NODE_TEXT&&(B.equals(C)||B.type===CKEDITOR.NODE_ELEMENT&&B.getFirst().equals(C)))d.append(a.document.createText(C.substring(x,A)));else{C.type==CKEDITOR.NODE_TEXT?u?K=!0:C=C.split(A):0<C.getChildCount()?A>=C.getChildCount()?(C=C.getChild(A-1),H=!0):C=C.getChild(A):I=H=!0;B.type==
CKEDITOR.NODE_TEXT?u?G=!0:B.split(x):0<B.getChildCount()?0===x?(B=B.getChild(x),D=!0):B=B.getChild(x-1):E=D=!0;for(var J=B.getParents(),F=C.getParents(),S=m(),N=J.length-1,Q=F.length-1,M=d,U,Z,W,da=-1,O=S;O<=N;O++){Z=J[O];W=Z.getNext();for(O!=N||Z.equals(F[O])&&N<Q?b&&(U=M.append(Z.clone(0,c))):D?f(Z,M,!1,E):G&&M.append(a.document.createText(Z.substring(x)));W;){if(W.equals(F[O])){da=O;break}W=f(W,M)}M=U}M=d;for(O=S;O<=Q;O++)if(d=F[O],W=d.getPrevious(),d.equals(J[O]))b&&(M=M.getChild(0));else{O!=
Q||d.equals(J[O])&&Q<N?b&&(U=M.append(d.clone(0,c))):H?f(d,M,!1,I):K&&M.append(a.document.createText(d.substring(0,A)));if(O>da)for(;W;)W=f(W,M,!0);M=U}u||h()}}function b(){var a=!1,b=CKEDITOR.dom.walker.whitespaces(),d=CKEDITOR.dom.walker.bookmark(!0),e=CKEDITOR.dom.walker.bogus();return function(c){return d(c)||b(c)?!0:e(c)&&!a?a=!0:c.type==CKEDITOR.NODE_TEXT&&(c.hasAscendant("pre")||CKEDITOR.tools.trim(c.getText()).length)||c.type==CKEDITOR.NODE_ELEMENT&&!c.is(l)?!1:!0}}function e(a){var b=CKEDITOR.dom.walker.whitespaces(),
d=CKEDITOR.dom.walker.bookmark(1);return function(e){return d(e)||b(e)?!0:!a&&k(e)||e.type==CKEDITOR.NODE_ELEMENT&&e.is(CKEDITOR.dtd.$removeEmpty)}}function h(a){return function(){var b;return this[a?"getPreviousNode":"getNextNode"](function(a){!b&&m(a)&&(b=a);return d(a)&&!(k(a)&&a.equals(b))})}}var l={abbr:1,acronym:1,b:1,bdo:1,big:1,cite:1,code:1,del:1,dfn:1,em:1,font:1,i:1,ins:1,label:1,kbd:1,q:1,samp:1,small:1,span:1,strike:1,strong:1,sub:1,sup:1,tt:1,u:1,"var":1},k=CKEDITOR.dom.walker.bogus(),
f=/^[\t\r\n ]*(?:&nbsp;|\xa0)$/,d=CKEDITOR.dom.walker.editable(),m=CKEDITOR.dom.walker.ignored(!0);CKEDITOR.dom.range.prototype={clone:function(){var a=new CKEDITOR.dom.range(this.root);a._setStartContainer(this.startContainer);a.startOffset=this.startOffset;a._setEndContainer(this.endContainer);a.endOffset=this.endOffset;a.collapsed=this.collapsed;return a},collapse:function(a){a?(this._setEndContainer(this.startContainer),this.endOffset=this.startOffset):(this._setStartContainer(this.endContainer),
this.startOffset=this.endOffset);this.collapsed=!0},cloneContents:function(a){var b=new CKEDITOR.dom.documentFragment(this.document);this.collapsed||c(this,2,b,!1,"undefined"==typeof a?!0:a);return b},deleteContents:function(a){this.collapsed||c(this,0,null,a)},extractContents:function(a,b){var d=new CKEDITOR.dom.documentFragment(this.document);this.collapsed||c(this,1,d,a,"undefined"==typeof b?!0:b);return d},createBookmark:function(a){var b,d,e,c,f=this.collapsed;b=this.document.createElement("span");
b.data("cke-bookmark",1);b.setStyle("display","none");b.setHtml("\x26nbsp;");a&&(e="cke_bm_"+CKEDITOR.tools.getNextNumber(),b.setAttribute("id",e+(f?"C":"S")));f||(d=b.clone(),d.setHtml("\x26nbsp;"),a&&d.setAttribute("id",e+"E"),c=this.clone(),c.collapse(),c.insertNode(d));c=this.clone();c.collapse(!0);c.insertNode(b);d?(this.setStartAfter(b),this.setEndBefore(d)):this.moveToPosition(b,CKEDITOR.POSITION_AFTER_END);return{startNode:a?e+(f?"C":"S"):b,endNode:a?e+"E":d,serializable:a,collapsed:f}},createBookmark2:function(){function a(g){var b=
g.container,e=g.offset,c;c=b;var f=e;c=c.type!=CKEDITOR.NODE_ELEMENT||0===f||f==c.getChildCount()?0:c.getChild(f-1).type==CKEDITOR.NODE_TEXT&&c.getChild(f).type==CKEDITOR.NODE_TEXT;c&&(b=b.getChild(e-1),e=b.getLength());if(b.type==CKEDITOR.NODE_ELEMENT&&0<e){a:{for(c=b;e--;)if(f=c.getChild(e).getIndex(!0),0<=f){e=f;break a}e=-1}e+=1}if(b.type==CKEDITOR.NODE_TEXT){c=b;for(f=0;(c=c.getPrevious())&&c.type==CKEDITOR.NODE_TEXT;)f+=c.getText().replace(CKEDITOR.dom.selection.FILLING_CHAR_SEQUENCE,"").length;
c=f;b.getText()?e+=c:(f=b.getPrevious(d),c?(e=c,b=f?f.getNext():b.getParent().getFirst()):(b=b.getParent(),e=f?f.getIndex(!0)+1:0))}g.container=b;g.offset=e}function b(a,g){var d=g.getCustomData("cke-fillingChar");if(d){var e=a.container;d.equals(e)&&(a.offset-=CKEDITOR.dom.selection.FILLING_CHAR_SEQUENCE.length,0>=a.offset&&(a.offset=e.getIndex(),a.container=e.getParent()))}}var d=CKEDITOR.dom.walker.nodeType(CKEDITOR.NODE_TEXT,!0);return function(d){var e=this.collapsed,c={container:this.startContainer,
offset:this.startOffset},f={container:this.endContainer,offset:this.endOffset};d&&(a(c),b(c,this.root),e||(a(f),b(f,this.root)));return{start:c.container.getAddress(d),end:e?null:f.container.getAddress(d),startOffset:c.offset,endOffset:f.offset,normalized:d,collapsed:e,is2:!0}}}(),moveToBookmark:function(a){if(a.is2){var b=this.document.getByAddress(a.start,a.normalized),d=a.startOffset,e=a.end&&this.document.getByAddress(a.end,a.normalized);a=a.endOffset;this.setStart(b,d);e?this.setEnd(e,a):this.collapse(!0)}else b=
(d=a.serializable)?this.document.getById(a.startNode):a.startNode,a=d?this.document.getById(a.endNode):a.endNode,this.setStartBefore(b),b.remove(),a?(this.setEndBefore(a),a.remove()):this.collapse(!0)},getBoundaryNodes:function(){var a=this.startContainer,b=this.endContainer,d=this.startOffset,e=this.endOffset,c;if(a.type==CKEDITOR.NODE_ELEMENT)if(c=a.getChildCount(),c>d)a=a.getChild(d);else if(1>c)a=a.getPreviousSourceNode();else{for(a=a.$;a.lastChild;)a=a.lastChild;a=new CKEDITOR.dom.node(a);a=
a.getNextSourceNode()||a}if(b.type==CKEDITOR.NODE_ELEMENT)if(c=b.getChildCount(),c>e)b=b.getChild(e).getPreviousSourceNode(!0);else if(1>c)b=b.getPreviousSourceNode();else{for(b=b.$;b.lastChild;)b=b.lastChild;b=new CKEDITOR.dom.node(b)}a.getPosition(b)&CKEDITOR.POSITION_FOLLOWING&&(a=b);return{startNode:a,endNode:b}},getCommonAncestor:function(a,b){var d=this.startContainer,e=this.endContainer,d=d.equals(e)?a&&d.type==CKEDITOR.NODE_ELEMENT&&this.startOffset==this.endOffset-1?d.getChild(this.startOffset):
d:d.getCommonAncestor(e);return b&&!d.is?d.getParent():d},optimize:function(){var a=this.startContainer,b=this.startOffset;a.type!=CKEDITOR.NODE_ELEMENT&&(b?b>=a.getLength()&&this.setStartAfter(a):this.setStartBefore(a));a=this.endContainer;b=this.endOffset;a.type!=CKEDITOR.NODE_ELEMENT&&(b?b>=a.getLength()&&this.setEndAfter(a):this.setEndBefore(a))},optimizeBookmark:function(){var a=this.startContainer,b=this.endContainer;a.is&&a.is("span")&&a.data("cke-bookmark")&&this.setStartAt(a,CKEDITOR.POSITION_BEFORE_START);
b&&b.is&&b.is("span")&&b.data("cke-bookmark")&&this.setEndAt(b,CKEDITOR.POSITION_AFTER_END)},trim:function(a,b){var d=this.startContainer,e=this.startOffset,c=this.collapsed;if((!a||c)&&d&&d.type==CKEDITOR.NODE_TEXT){if(e)if(e>=d.getLength())e=d.getIndex()+1,d=d.getParent();else{var f=d.split(e),e=d.getIndex()+1,d=d.getParent();this.startContainer.equals(this.endContainer)?this.setEnd(f,this.endOffset-this.startOffset):d.equals(this.endContainer)&&(this.endOffset+=1)}else e=d.getIndex(),d=d.getParent();
this.setStart(d,e);if(c){this.collapse(!0);return}}d=this.endContainer;e=this.endOffset;b||c||!d||d.type!=CKEDITOR.NODE_TEXT||(e?(e>=d.getLength()||d.split(e),e=d.getIndex()+1):e=d.getIndex(),d=d.getParent(),this.setEnd(d,e))},enlarge:function(a,b){function d(a){return a&&a.type==CKEDITOR.NODE_ELEMENT&&a.hasAttribute("contenteditable")?null:a}var e=new RegExp(/[^\s\ufeff]/);switch(a){case CKEDITOR.ENLARGE_INLINE:var c=1;case CKEDITOR.ENLARGE_ELEMENT:var f=function(a,b){var d=new CKEDITOR.dom.range(h);
d.setStart(a,b);d.setEndAt(h,CKEDITOR.POSITION_BEFORE_END);var d=new CKEDITOR.dom.walker(d),g;for(d.guard=function(a){return!(a.type==CKEDITOR.NODE_ELEMENT&&a.isBlockBoundary())};g=d.next();){if(g.type!=CKEDITOR.NODE_TEXT)return!1;D=g!=a?g.getText():g.substring(b);if(e.test(D))return!1}return!0};if(this.collapsed)break;var m=this.getCommonAncestor(),h=this.root,k,l,u,B,C,x=!1,A,D;A=this.startContainer;var H=this.startOffset;A.type==CKEDITOR.NODE_TEXT?(H&&(A=!CKEDITOR.tools.trim(A.substring(0,H)).length&&
A,x=!!A),A&&((B=A.getPrevious())||(u=A.getParent()))):(H&&(B=A.getChild(H-1)||A.getLast()),B||(u=A));for(u=d(u);u||B;){if(u&&!B){!C&&u.equals(m)&&(C=!0);if(c?u.isBlockBoundary():!h.contains(u))break;x&&"inline"==u.getComputedStyle("display")||(x=!1,C?k=u:this.setStartBefore(u));B=u.getPrevious()}for(;B;)if(A=!1,B.type==CKEDITOR.NODE_COMMENT)B=B.getPrevious();else{if(B.type==CKEDITOR.NODE_TEXT)D=B.getText(),e.test(D)&&(B=null),A=/[\s\ufeff]$/.test(D);else if((B.$.offsetWidth>(CKEDITOR.env.webkit?1:
0)||b&&B.is("br"))&&!B.data("cke-bookmark"))if(x&&CKEDITOR.dtd.$removeEmpty[B.getName()]){D=B.getText();if(e.test(D))B=null;else for(var H=B.$.getElementsByTagName("*"),E=0,I;I=H[E++];)if(!CKEDITOR.dtd.$removeEmpty[I.nodeName.toLowerCase()]){B=null;break}B&&(A=!!D.length)}else B=null;A&&(x?C?k=u:u&&this.setStartBefore(u):x=!0);if(B){A=B.getPrevious();if(!u&&!A){u=B;B=null;break}B=A}else u=null}u&&(u=d(u.getParent()))}A=this.endContainer;H=this.endOffset;u=B=null;C=x=!1;A.type==CKEDITOR.NODE_TEXT?
CKEDITOR.tools.trim(A.substring(H)).length?x=!0:(x=!A.getLength(),H==A.getLength()?(B=A.getNext())||(u=A.getParent()):f(A,H)&&(u=A.getParent())):(B=A.getChild(H))||(u=A);for(;u||B;){if(u&&!B){!C&&u.equals(m)&&(C=!0);if(c?u.isBlockBoundary():!h.contains(u))break;x&&"inline"==u.getComputedStyle("display")||(x=!1,C?l=u:u&&this.setEndAfter(u));B=u.getNext()}for(;B;){A=!1;if(B.type==CKEDITOR.NODE_TEXT)D=B.getText(),f(B,0)||(B=null),A=/^[\s\ufeff]/.test(D);else if(B.type==CKEDITOR.NODE_ELEMENT){if((0<B.$.offsetWidth||
b&&B.is("br"))&&!B.data("cke-bookmark"))if(x&&CKEDITOR.dtd.$removeEmpty[B.getName()]){D=B.getText();if(e.test(D))B=null;else for(H=B.$.getElementsByTagName("*"),E=0;I=H[E++];)if(!CKEDITOR.dtd.$removeEmpty[I.nodeName.toLowerCase()]){B=null;break}B&&(A=!!D.length)}else B=null}else A=1;A&&x&&(C?l=u:this.setEndAfter(u));if(B){A=B.getNext();if(!u&&!A){u=B;B=null;break}B=A}else u=null}u&&(u=d(u.getParent()))}k&&l&&(m=k.contains(l)?l:k,this.setStartBefore(m),this.setEndAfter(m));break;case CKEDITOR.ENLARGE_BLOCK_CONTENTS:case CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS:u=
new CKEDITOR.dom.range(this.root);h=this.root;u.setStartAt(h,CKEDITOR.POSITION_AFTER_START);u.setEnd(this.startContainer,this.startOffset);u=new CKEDITOR.dom.walker(u);var G,K,J=CKEDITOR.dom.walker.blockBoundary(a==CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS?{br:1}:null),F=null,S=function(a){if(a.type==CKEDITOR.NODE_ELEMENT&&"false"==a.getAttribute("contenteditable"))if(F){if(F.equals(a)){F=null;return}}else F=a;else if(F)return;var b=J(a);b||(G=a);return b},c=function(a){var b=S(a);!b&&a.is&&a.is("br")&&
(K=a);return b};u.guard=S;u=u.lastBackward();G=G||h;this.setStartAt(G,!G.is("br")&&(!u&&this.checkStartOfBlock()||u&&G.contains(u))?CKEDITOR.POSITION_AFTER_START:CKEDITOR.POSITION_AFTER_END);if(a==CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS){u=this.clone();u=new CKEDITOR.dom.walker(u);var N=CKEDITOR.dom.walker.whitespaces(),Q=CKEDITOR.dom.walker.bookmark();u.evaluator=function(a){return!N(a)&&!Q(a)};if((u=u.previous())&&u.type==CKEDITOR.NODE_ELEMENT&&u.is("br"))break}u=this.clone();u.collapse();u.setEndAt(h,
CKEDITOR.POSITION_BEFORE_END);u=new CKEDITOR.dom.walker(u);u.guard=a==CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS?c:S;G=F=K=null;u=u.lastForward();G=G||h;this.setEndAt(G,!u&&this.checkEndOfBlock()||u&&G.contains(u)?CKEDITOR.POSITION_BEFORE_END:CKEDITOR.POSITION_BEFORE_START);K&&this.setEndAfter(K)}},shrink:function(a,b,d){var e="boolean"===typeof d?d:d&&"boolean"===typeof d.shrinkOnBlockBoundary?d.shrinkOnBlockBoundary:!0,c=d&&d.skipBogus;if(!this.collapsed){a=a||CKEDITOR.SHRINK_TEXT;var f=this.clone(),m=
this.startContainer,h=this.endContainer,k=this.startOffset,l=this.endOffset,u=d=1;m&&m.type==CKEDITOR.NODE_TEXT&&(k?k>=m.getLength()?f.setStartAfter(m):(f.setStartBefore(m),d=0):f.setStartBefore(m));h&&h.type==CKEDITOR.NODE_TEXT&&(l?l>=h.getLength()?f.setEndAfter(h):(f.setEndAfter(h),u=0):f.setEndBefore(h));var f=new CKEDITOR.dom.walker(f),B=CKEDITOR.dom.walker.bookmark(),C=CKEDITOR.dom.walker.bogus();f.evaluator=function(b){return b.type==(a==CKEDITOR.SHRINK_ELEMENT?CKEDITOR.NODE_ELEMENT:CKEDITOR.NODE_TEXT)};
var x;f.guard=function(b,d){if(c&&C(b)||B(b))return!0;if(a==CKEDITOR.SHRINK_ELEMENT&&b.type==CKEDITOR.NODE_TEXT||d&&b.equals(x)||!1===e&&b.type==CKEDITOR.NODE_ELEMENT&&b.isBlockBoundary()||b.type==CKEDITOR.NODE_ELEMENT&&b.hasAttribute("contenteditable"))return!1;d||b.type!=CKEDITOR.NODE_ELEMENT||(x=b);return!0};d&&(m=f[a==CKEDITOR.SHRINK_ELEMENT?"lastForward":"next"]())&&this.setStartAt(m,b?CKEDITOR.POSITION_AFTER_START:CKEDITOR.POSITION_BEFORE_START);u&&(f.reset(),(f=f[a==CKEDITOR.SHRINK_ELEMENT?
"lastBackward":"previous"]())&&this.setEndAt(f,b?CKEDITOR.POSITION_BEFORE_END:CKEDITOR.POSITION_AFTER_END));return!(!d&&!u)}},insertNode:function(a){this.optimizeBookmark();this.trim(!1,!0);var b=this.startContainer,d=b.getChild(this.startOffset);d?a.insertBefore(d):b.append(a);a.getParent()&&a.getParent().equals(this.endContainer)&&this.endOffset++;this.setStartBefore(a)},moveToPosition:function(a,b){this.setStartAt(a,b);this.collapse(!0)},moveToRange:function(a){this.setStart(a.startContainer,a.startOffset);
this.setEnd(a.endContainer,a.endOffset)},selectNodeContents:function(a){this.setStart(a,0);this.setEnd(a,a.type==CKEDITOR.NODE_TEXT?a.getLength():a.getChildCount())},setStart:function(b,d){b.type==CKEDITOR.NODE_ELEMENT&&CKEDITOR.dtd.$empty[b.getName()]&&(d=b.getIndex(),b=b.getParent());this._setStartContainer(b);this.startOffset=d;this.endContainer||(this._setEndContainer(b),this.endOffset=d);a(this)},setEnd:function(b,d){b.type==CKEDITOR.NODE_ELEMENT&&CKEDITOR.dtd.$empty[b.getName()]&&(d=b.getIndex()+
1,b=b.getParent());this._setEndContainer(b);this.endOffset=d;this.startContainer||(this._setStartContainer(b),this.startOffset=d);a(this)},setStartAfter:function(a){this.setStart(a.getParent(),a.getIndex()+1)},setStartBefore:function(a){this.setStart(a.getParent(),a.getIndex())},setEndAfter:function(a){this.setEnd(a.getParent(),a.getIndex()+1)},setEndBefore:function(a){this.setEnd(a.getParent(),a.getIndex())},setStartAt:function(b,d){switch(d){case CKEDITOR.POSITION_AFTER_START:this.setStart(b,0);
break;case CKEDITOR.POSITION_BEFORE_END:b.type==CKEDITOR.NODE_TEXT?this.setStart(b,b.getLength()):this.setStart(b,b.getChildCount());break;case CKEDITOR.POSITION_BEFORE_START:this.setStartBefore(b);break;case CKEDITOR.POSITION_AFTER_END:this.setStartAfter(b)}a(this)},setEndAt:function(b,d){switch(d){case CKEDITOR.POSITION_AFTER_START:this.setEnd(b,0);break;case CKEDITOR.POSITION_BEFORE_END:b.type==CKEDITOR.NODE_TEXT?this.setEnd(b,b.getLength()):this.setEnd(b,b.getChildCount());break;case CKEDITOR.POSITION_BEFORE_START:this.setEndBefore(b);
break;case CKEDITOR.POSITION_AFTER_END:this.setEndAfter(b)}a(this)},fixBlock:function(a,b){var d=this.createBookmark(),e=this.document.createElement(b);this.collapse(a);this.enlarge(CKEDITOR.ENLARGE_BLOCK_CONTENTS);this.extractContents().appendTo(e);e.trim();this.insertNode(e);var c=e.getBogus();c&&c.remove();e.appendBogus();this.moveToBookmark(d);return e},splitBlock:function(a,b){var d=new CKEDITOR.dom.elementPath(this.startContainer,this.root),e=new CKEDITOR.dom.elementPath(this.endContainer,this.root),
c=d.block,f=e.block,m=null;if(!d.blockLimit.equals(e.blockLimit))return null;"br"!=a&&(c||(c=this.fixBlock(!0,a),f=(new CKEDITOR.dom.elementPath(this.endContainer,this.root)).block),f||(f=this.fixBlock(!1,a)));d=c&&this.checkStartOfBlock();e=f&&this.checkEndOfBlock();this.deleteContents();c&&c.equals(f)&&(e?(m=new CKEDITOR.dom.elementPath(this.startContainer,this.root),this.moveToPosition(f,CKEDITOR.POSITION_AFTER_END),f=null):d?(m=new CKEDITOR.dom.elementPath(this.startContainer,this.root),this.moveToPosition(c,
CKEDITOR.POSITION_BEFORE_START),c=null):(f=this.splitElement(c,b||!1),c.is("ul","ol")||c.appendBogus()));return{previousBlock:c,nextBlock:f,wasStartOfBlock:d,wasEndOfBlock:e,elementPath:m}},splitElement:function(a,b){if(!this.collapsed)return null;this.setEndAt(a,CKEDITOR.POSITION_BEFORE_END);var d=this.extractContents(!1,b||!1),e=a.clone(!1,b||!1);d.appendTo(e);e.insertAfter(a);this.moveToPosition(a,CKEDITOR.POSITION_AFTER_END);return e},removeEmptyBlocksAtEnd:function(){function a(g){return function(a){return b(a)||
d(a)||a.type==CKEDITOR.NODE_ELEMENT&&a.isEmptyInlineRemoveable()||g.is("table")&&a.is("caption")?!1:!0}}var b=CKEDITOR.dom.walker.whitespaces(),d=CKEDITOR.dom.walker.bookmark(!1);return function(b){for(var d=this.createBookmark(),e=this[b?"endPath":"startPath"](),c=e.block||e.blockLimit,f;c&&!c.equals(e.root)&&!c.getFirst(a(c));)f=c.getParent(),this[b?"setEndAt":"setStartAt"](c,CKEDITOR.POSITION_AFTER_END),c.remove(1),c=f;this.moveToBookmark(d)}}(),startPath:function(){return new CKEDITOR.dom.elementPath(this.startContainer,
this.root)},endPath:function(){return new CKEDITOR.dom.elementPath(this.endContainer,this.root)},checkBoundaryOfElement:function(a,b){var d=b==CKEDITOR.START,c=this.clone();c.collapse(d);c[d?"setStartAt":"setEndAt"](a,d?CKEDITOR.POSITION_AFTER_START:CKEDITOR.POSITION_BEFORE_END);c=new CKEDITOR.dom.walker(c);c.evaluator=e(d);return c[d?"checkBackward":"checkForward"]()},checkStartOfBlock:function(){var a=this.startContainer,d=this.startOffset;CKEDITOR.env.ie&&d&&a.type==CKEDITOR.NODE_TEXT&&(a=CKEDITOR.tools.ltrim(a.substring(0,
d)),f.test(a)&&this.trim(0,1));this.trim();a=new CKEDITOR.dom.elementPath(this.startContainer,this.root);d=this.clone();d.collapse(!0);d.setStartAt(a.block||a.blockLimit,CKEDITOR.POSITION_AFTER_START);a=new CKEDITOR.dom.walker(d);a.evaluator=b();return a.checkBackward()},checkEndOfBlock:function(){var a=this.endContainer,d=this.endOffset;CKEDITOR.env.ie&&a.type==CKEDITOR.NODE_TEXT&&(a=CKEDITOR.tools.rtrim(a.substring(d)),f.test(a)&&this.trim(1,0));this.trim();a=new CKEDITOR.dom.elementPath(this.endContainer,
this.root);d=this.clone();d.collapse(!1);d.setEndAt(a.block||a.blockLimit,CKEDITOR.POSITION_BEFORE_END);a=new CKEDITOR.dom.walker(d);a.evaluator=b();return a.checkForward()},getPreviousNode:function(a,b,d){var e=this.clone();e.collapse(1);e.setStartAt(d||this.root,CKEDITOR.POSITION_AFTER_START);d=new CKEDITOR.dom.walker(e);d.evaluator=a;d.guard=b;return d.previous()},getNextNode:function(a,b,d){var e=this.clone();e.collapse();e.setEndAt(d||this.root,CKEDITOR.POSITION_BEFORE_END);d=new CKEDITOR.dom.walker(e);
d.evaluator=a;d.guard=b;return d.next()},checkReadOnly:function(){function a(b,d){for(;b;){if(b.type==CKEDITOR.NODE_ELEMENT){if("false"==b.getAttribute("contentEditable")&&!b.data("cke-editable"))return 0;if(b.is("html")||"true"==b.getAttribute("contentEditable")&&(b.contains(d)||b.equals(d)))break}b=b.getParent()}return 1}return function(){var b=this.startContainer,d=this.endContainer;return!(a(b,d)&&a(d,b))}}(),moveToElementEditablePosition:function(a,b){if(a.type==CKEDITOR.NODE_ELEMENT&&!a.isEditable(!1))return this.moveToPosition(a,
b?CKEDITOR.POSITION_AFTER_END:CKEDITOR.POSITION_BEFORE_START),!0;for(var d=0;a;){if(a.type==CKEDITOR.NODE_TEXT){b&&this.endContainer&&this.checkEndOfBlock()&&f.test(a.getText())?this.moveToPosition(a,CKEDITOR.POSITION_BEFORE_START):this.moveToPosition(a,b?CKEDITOR.POSITION_AFTER_END:CKEDITOR.POSITION_BEFORE_START);d=1;break}if(a.type==CKEDITOR.NODE_ELEMENT)if(a.isEditable())this.moveToPosition(a,b?CKEDITOR.POSITION_BEFORE_END:CKEDITOR.POSITION_AFTER_START),d=1;else if(b&&a.is("br")&&this.endContainer&&
this.checkEndOfBlock())this.moveToPosition(a,CKEDITOR.POSITION_BEFORE_START);else if("false"==a.getAttribute("contenteditable")&&a.is(CKEDITOR.dtd.$block))return this.setStartBefore(a),this.setEndAfter(a),!0;var e=a,c=d,h=void 0;e.type==CKEDITOR.NODE_ELEMENT&&e.isEditable(!1)&&(h=e[b?"getLast":"getFirst"](m));c||h||(h=e[b?"getPrevious":"getNext"](m));a=h}return!!d},moveToClosestEditablePosition:function(a,b){var d,e=0,c,f,m=[CKEDITOR.POSITION_AFTER_END,CKEDITOR.POSITION_BEFORE_START];a?(d=new CKEDITOR.dom.range(this.root),
d.moveToPosition(a,m[b?0:1])):d=this.clone();if(a&&!a.is(CKEDITOR.dtd.$block))e=1;else if(c=d[b?"getNextEditableNode":"getPreviousEditableNode"]())e=1,(f=c.type==CKEDITOR.NODE_ELEMENT)&&c.is(CKEDITOR.dtd.$block)&&"false"==c.getAttribute("contenteditable")?(d.setStartAt(c,CKEDITOR.POSITION_BEFORE_START),d.setEndAt(c,CKEDITOR.POSITION_AFTER_END)):!CKEDITOR.env.needsBrFiller&&f&&c.is(CKEDITOR.dom.walker.validEmptyBlockContainers)?(d.setEnd(c,0),d.collapse()):d.moveToPosition(c,m[b?1:0]);e&&this.moveToRange(d);
return!!e},moveToElementEditStart:function(a){return this.moveToElementEditablePosition(a)},moveToElementEditEnd:function(a){return this.moveToElementEditablePosition(a,!0)},getEnclosedNode:function(){var a=this.clone();a.optimize();if(a.startContainer.type!=CKEDITOR.NODE_ELEMENT||a.endContainer.type!=CKEDITOR.NODE_ELEMENT)return null;var a=new CKEDITOR.dom.walker(a),b=CKEDITOR.dom.walker.bookmark(!1,!0),d=CKEDITOR.dom.walker.whitespaces(!0);a.evaluator=function(a){return d(a)&&b(a)};var e=a.next();
a.reset();return e&&e.equals(a.previous())?e:null},getTouchedStartNode:function(){var a=this.startContainer;return this.collapsed||a.type!=CKEDITOR.NODE_ELEMENT?a:a.getChild(this.startOffset)||a},getTouchedEndNode:function(){var a=this.endContainer;return this.collapsed||a.type!=CKEDITOR.NODE_ELEMENT?a:a.getChild(this.endOffset-1)||a},getNextEditableNode:h(),getPreviousEditableNode:h(1),_getTableElement:function(a){a=a||{td:1,th:1,tr:1,tbody:1,thead:1,tfoot:1,table:1};var b=this.startContainer,d=
this.endContainer,e=b.getAscendant("table",!0),c=d.getAscendant("table",!0);return CKEDITOR.env.safari&&e&&d.equals(this.root)?b.getAscendant(a,!0):this.getEnclosedNode()?this.getEnclosedNode().getAscendant(a,!0):e&&c&&(e.equals(c)||e.contains(c)||c.contains(e))?b.getAscendant(a,!0):null},scrollIntoView:function(){var a=new CKEDITOR.dom.element.createFromHtml("\x3cspan\x3e\x26nbsp;\x3c/span\x3e",this.document),b,d,e,c=this.clone();c.optimize();(e=c.startContainer.type==CKEDITOR.NODE_TEXT)?(d=c.startContainer.getText(),
b=c.startContainer.split(c.startOffset),a.insertAfter(c.startContainer)):c.insertNode(a);a.scrollIntoView();e&&(c.startContainer.setText(d),b.remove());a.remove()},_setStartContainer:function(a){this.startContainer=a},_setEndContainer:function(a){this.endContainer=a},_find:function(a,b){var d=this.getCommonAncestor(),e=this.getBoundaryNodes(),c=[],f,m,h,k;if(d&&d.find)for(m=d.find(a),f=0;f<m.count();f++)if(d=m.getItem(f),b||!d.isReadOnly())h=d.getPosition(e.startNode)&CKEDITOR.POSITION_FOLLOWING||
e.startNode.equals(d),k=d.getPosition(e.endNode)&CKEDITOR.POSITION_PRECEDING+CKEDITOR.POSITION_IS_CONTAINED||e.endNode.equals(d),h&&k&&c.push(d);return c}};CKEDITOR.dom.range.mergeRanges=function(a){return CKEDITOR.tools.array.reduce(a,function(a,b){var d=a[a.length-1],e=!1;b=b.clone();b.enlarge(CKEDITOR.ENLARGE_ELEMENT);if(d){var g=new CKEDITOR.dom.range(b.root),e=new CKEDITOR.dom.walker(g),c=CKEDITOR.dom.walker.whitespaces();g.setStart(d.endContainer,d.endOffset);g.setEnd(b.startContainer,b.startOffset);
for(g=e.next();c(g)||b.endContainer.equals(g);)g=e.next();e=!g}e?d.setEnd(b.endContainer,b.endOffset):a.push(b);return a},[])}}(),CKEDITOR.POSITION_AFTER_START=1,CKEDITOR.POSITION_BEFORE_END=2,CKEDITOR.POSITION_BEFORE_START=3,CKEDITOR.POSITION_AFTER_END=4,CKEDITOR.ENLARGE_ELEMENT=1,CKEDITOR.ENLARGE_BLOCK_CONTENTS=2,CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS=3,CKEDITOR.ENLARGE_INLINE=4,CKEDITOR.START=1,CKEDITOR.END=2,CKEDITOR.SHRINK_ELEMENT=1,CKEDITOR.SHRINK_TEXT=2,"use strict",function(){function a(a){1>
arguments.length||(this.range=a,this.forceBrBreak=0,this.enlargeBr=1,this.enforceRealBlocks=0,this._||(this._={}))}function c(a){var b=[];a.forEach(function(a){if("true"==a.getAttribute("contenteditable"))return b.push(a),!1},CKEDITOR.NODE_ELEMENT,!0);return b}function b(a,d,e,f){a:{null==f&&(f=c(e));for(var h;h=f.shift();)if(h.getDtd().p){f={element:h,remaining:f};break a}f=null}if(!f)return 0;if((h=CKEDITOR.filter.instances[f.element.data("cke-filter")])&&!h.check(d))return b(a,d,e,f.remaining);
d=new CKEDITOR.dom.range(f.element);d.selectNodeContents(f.element);d=d.createIterator();d.enlargeBr=a.enlargeBr;d.enforceRealBlocks=a.enforceRealBlocks;d.activeFilter=d.filter=h;a._.nestedEditable={element:f.element,container:e,remaining:f.remaining,iterator:d};return 1}function e(a,b,d){if(!b)return!1;a=a.clone();a.collapse(!d);return a.checkBoundaryOfElement(b,d?CKEDITOR.START:CKEDITOR.END)}var h=/^[\r\n\t ]+$/,l=CKEDITOR.dom.walker.bookmark(!1,!0),k=CKEDITOR.dom.walker.whitespaces(!0),f=function(a){return l(a)&&
k(a)},d={dd:1,dt:1,li:1};a.prototype={getNextParagraph:function(a){var g,c,k,q,y;a=a||"p";if(this._.nestedEditable){if(g=this._.nestedEditable.iterator.getNextParagraph(a))return this.activeFilter=this._.nestedEditable.iterator.activeFilter,g;this.activeFilter=this.filter;if(b(this,a,this._.nestedEditable.container,this._.nestedEditable.remaining))return this.activeFilter=this._.nestedEditable.iterator.activeFilter,this._.nestedEditable.iterator.getNextParagraph(a);this._.nestedEditable=null}if(!this.range.root.getDtd()[a])return null;
if(!this._.started){var v=this.range.clone();c=v.startPath();var t=v.endPath(),r=!v.collapsed&&e(v,c.block),w=!v.collapsed&&e(v,t.block,1);v.shrink(CKEDITOR.SHRINK_ELEMENT,!0);r&&v.setStartAt(c.block,CKEDITOR.POSITION_BEFORE_END);w&&v.setEndAt(t.block,CKEDITOR.POSITION_AFTER_START);c=v.endContainer.hasAscendant("pre",!0)||v.startContainer.hasAscendant("pre",!0);v.enlarge(this.forceBrBreak&&!c||!this.enlargeBr?CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS:CKEDITOR.ENLARGE_BLOCK_CONTENTS);v.collapsed||(c=new CKEDITOR.dom.walker(v.clone()),
t=CKEDITOR.dom.walker.bookmark(!0,!0),c.evaluator=t,this._.nextNode=c.next(),c=new CKEDITOR.dom.walker(v.clone()),c.evaluator=t,c=c.previous(),this._.lastNode=c.getNextSourceNode(!0,null,v.root),this._.lastNode&&this._.lastNode.type==CKEDITOR.NODE_TEXT&&!CKEDITOR.tools.trim(this._.lastNode.getText())&&this._.lastNode.getParent().isBlockBoundary()&&(t=this.range.clone(),t.moveToPosition(this._.lastNode,CKEDITOR.POSITION_AFTER_END),t.checkEndOfBlock()&&(t=new CKEDITOR.dom.elementPath(t.endContainer,
t.root),this._.lastNode=(t.block||t.blockLimit).getNextSourceNode(!0))),this._.lastNode&&v.root.contains(this._.lastNode)||(this._.lastNode=this._.docEndMarker=v.document.createText(""),this._.lastNode.insertAfter(c)),v=null);this._.started=1;c=v}t=this._.nextNode;v=this._.lastNode;for(this._.nextNode=null;t;){var r=0,w=t.hasAscendant("pre"),z=t.type!=CKEDITOR.NODE_ELEMENT,u=0;if(z)t.type==CKEDITOR.NODE_TEXT&&h.test(t.getText())&&(z=0);else{var B=t.getName();if(CKEDITOR.dtd.$block[B]&&"false"==t.getAttribute("contenteditable")){g=
t;b(this,a,g);break}else if(t.isBlockBoundary(this.forceBrBreak&&!w&&{br:1})){if("br"==B)z=1;else if(!c&&!t.getChildCount()&&"hr"!=B){g=t;k=t.equals(v);break}c&&(c.setEndAt(t,CKEDITOR.POSITION_BEFORE_START),"br"!=B&&(this._.nextNode=t));r=1}else{if(t.getFirst()){c||(c=this.range.clone(),c.setStartAt(t,CKEDITOR.POSITION_BEFORE_START));t=t.getFirst();continue}z=1}}z&&!c&&(c=this.range.clone(),c.setStartAt(t,CKEDITOR.POSITION_BEFORE_START));k=(!r||z)&&t.equals(v);if(c&&!r)for(;!t.getNext(f)&&!k;){B=
t.getParent();if(B.isBlockBoundary(this.forceBrBreak&&!w&&{br:1})){r=1;z=0;k||B.equals(v);c.setEndAt(B,CKEDITOR.POSITION_BEFORE_END);break}t=B;z=1;k=t.equals(v);u=1}z&&c.setEndAt(t,CKEDITOR.POSITION_AFTER_END);t=this._getNextSourceNode(t,u,v);if((k=!t)||r&&c)break}if(!g){if(!c)return this._.docEndMarker&&this._.docEndMarker.remove(),this._.nextNode=null;g=new CKEDITOR.dom.elementPath(c.startContainer,c.root);t=g.blockLimit;r={div:1,th:1,td:1};g=g.block;!g&&t&&!this.enforceRealBlocks&&r[t.getName()]&&
c.checkStartOfBlock()&&c.checkEndOfBlock()&&!t.equals(c.root)?g=t:!g||this.enforceRealBlocks&&g.is(d)?(g=this.range.document.createElement(a),c.extractContents().appendTo(g),g.trim(),c.insertNode(g),q=y=!0):"li"!=g.getName()?c.checkStartOfBlock()&&c.checkEndOfBlock()||(g=g.clone(!1),c.extractContents().appendTo(g),g.trim(),y=c.splitBlock(),q=!y.wasStartOfBlock,y=!y.wasEndOfBlock,c.insertNode(g)):k||(this._.nextNode=g.equals(v)?null:this._getNextSourceNode(c.getBoundaryNodes().endNode,1,v))}q&&(q=
g.getPrevious())&&q.type==CKEDITOR.NODE_ELEMENT&&("br"==q.getName()?q.remove():q.getLast()&&"br"==q.getLast().$.nodeName.toLowerCase()&&q.getLast().remove());y&&(q=g.getLast())&&q.type==CKEDITOR.NODE_ELEMENT&&"br"==q.getName()&&(!CKEDITOR.env.needsBrFiller||q.getPrevious(l)||q.getNext(l))&&q.remove();this._.nextNode||(this._.nextNode=k||g.equals(v)||!v?null:this._getNextSourceNode(g,1,v));return g},_getNextSourceNode:function(a,b,d){function e(a){return!(a.equals(d)||a.equals(c))}var c=this.range.root;
for(a=a.getNextSourceNode(b,null,e);!l(a);)a=a.getNextSourceNode(b,null,e);return a}};CKEDITOR.dom.range.prototype.createIterator=function(){return new a(this)}}(),CKEDITOR.command=function(a,c){this.uiItems=[];this.exec=function(b){if(this.state==CKEDITOR.TRISTATE_DISABLED||!this.checkAllowed())return!1;this.editorFocus&&a.focus();return!1===this.fire("exec")?!0:!1!==c.exec.call(this,a,b)};this.refresh=function(a,b){if(!this.readOnly&&a.readOnly)return!0;if(this.context&&!b.isContextFor(this.context)||
!this.checkAllowed(!0))return this.disable(),!0;this.startDisabled||this.enable();this.modes&&!this.modes[a.mode]&&this.disable();return!1===this.fire("refresh",{editor:a,path:b})?!0:c.refresh&&!1!==c.refresh.apply(this,arguments)};var b;this.checkAllowed=function(e){return e||"boolean"!=typeof b?b=a.activeFilter.checkFeature(this):b};CKEDITOR.tools.extend(this,c,{modes:{wysiwyg:1},editorFocus:1,contextSensitive:!!c.context,state:CKEDITOR.TRISTATE_DISABLED});CKEDITOR.event.call(this)},CKEDITOR.command.prototype=
{enable:function(){this.state==CKEDITOR.TRISTATE_DISABLED&&this.checkAllowed()&&this.setState(this.preserveState&&"undefined"!=typeof this.previousState?this.previousState:CKEDITOR.TRISTATE_OFF)},disable:function(){this.setState(CKEDITOR.TRISTATE_DISABLED)},setState:function(a){if(this.state==a||a!=CKEDITOR.TRISTATE_DISABLED&&!this.checkAllowed())return!1;this.previousState=this.state;this.state=a;this.fire("state");return!0},toggleState:function(){this.state==CKEDITOR.TRISTATE_OFF?this.setState(CKEDITOR.TRISTATE_ON):
this.state==CKEDITOR.TRISTATE_ON&&this.setState(CKEDITOR.TRISTATE_OFF)}},CKEDITOR.event.implementOn(CKEDITOR.command.prototype),CKEDITOR.ENTER_P=1,CKEDITOR.ENTER_BR=2,CKEDITOR.ENTER_DIV=3,CKEDITOR.config={customConfig:"config.js",autoUpdateElement:!0,language:"",defaultLanguage:"en",contentsLangDirection:"",enterMode:CKEDITOR.ENTER_P,forceEnterMode:!1,shiftEnterMode:CKEDITOR.ENTER_BR,docType:"\x3c!DOCTYPE html\x3e",bodyId:"",bodyClass:"",fullPage:!1,height:200,contentsCss:CKEDITOR.getUrl("contents.css"),
extraPlugins:"",removePlugins:"",protectedSource:[],tabIndex:0,width:"",baseFloatZIndex:1E4,blockedKeystrokes:[CKEDITOR.CTRL+66,CKEDITOR.CTRL+73,CKEDITOR.CTRL+85]},function(){function a(a,b,d,e,g){var c,f;a=[];for(c in b){f=b[c];f="boolean"==typeof f?{}:"function"==typeof f?{match:f}:E(f);"$"!=c.charAt(0)&&(f.elements=c);d&&(f.featureName=d.toLowerCase());var h=f;h.elements=k(h.elements,/\s+/)||null;h.propertiesOnly=h.propertiesOnly||!0===h.elements;var m=/\s*,\s*/,l=void 0;for(l in K){h[l]=k(h[l],
m)||null;var n=h,t=J[l],u=k(h[J[l]],m),F=h[l],x=[],B=!0,w=void 0;u?B=!1:u={};for(w in F)"!"==w.charAt(0)&&(w=w.slice(1),x.push(w),u[w]=!0,B=!1);for(;w=x.pop();)F[w]=F["!"+w],delete F["!"+w];n[t]=(B?!1:u)||null}h.match=h.match||null;e.push(f);a.push(f)}b=g.elements;g=g.generic;var D;d=0;for(e=a.length;d<e;++d){c=E(a[d]);f=!0===c.classes||!0===c.styles||!0===c.attributes;h=c;l=t=m=void 0;for(m in K)h[m]=r(h[m]);n=!0;for(l in J){m=J[l];t=h[m];u=[];F=void 0;for(F in t)-1<F.indexOf("*")?u.push(new RegExp("^"+
F.replace(/\*/g,".*")+"$")):u.push(F);t=u;t.length&&(h[m]=t,n=!1)}h.nothingRequired=n;h.noProperties=!(h.attributes||h.classes||h.styles);if(!0===c.elements||null===c.elements)g[f?"unshift":"push"](c);else for(D in h=c.elements,delete c.elements,h)if(b[D])b[D][f?"unshift":"push"](c);else b[D]=[c]}}function c(a,d,e,g){if(!a.match||a.match(d))if(g||f(a,d))if(a.propertiesOnly||(e.valid=!0),e.allAttributes||(e.allAttributes=b(a.attributes,d.attributes,e.validAttributes)),e.allStyles||(e.allStyles=b(a.styles,
d.styles,e.validStyles)),!e.allClasses){a=a.classes;d=d.classes;g=e.validClasses;if(a)if(!0===a)a=!0;else{for(var c=0,h=d.length,m;c<h;++c)m=d[c],g[m]||(g[m]=a(m));a=!1}else a=!1;e.allClasses=a}}function b(a,b,d){if(!a)return!1;if(!0===a)return!0;for(var e in b)d[e]||(d[e]=a(e));return!1}function e(a,b,d){if(!a.match||a.match(b)){if(a.noProperties)return!1;d.hadInvalidAttribute=h(a.attributes,b.attributes)||d.hadInvalidAttribute;d.hadInvalidStyle=h(a.styles,b.styles)||d.hadInvalidStyle;a=a.classes;
b=b.classes;if(a){for(var e=!1,g=!0===a,c=b.length;c--;)if(g||a(b[c]))b.splice(c,1),e=!0;a=e}else a=!1;d.hadInvalidClass=a||d.hadInvalidClass}}function h(a,b){if(!a)return!1;var d=!1,e=!0===a,g;for(g in b)if(e||a(g))delete b[g],d=!0;return d}function l(a,b,d){if(a.disabled||a.customConfig&&!d||!b)return!1;a._.cachedChecks={};return!0}function k(a,b){if(!a)return!1;if(!0===a)return a;if("string"==typeof a)return a=I(a),"*"==a?!0:CKEDITOR.tools.convertArrayToObject(a.split(b));if(CKEDITOR.tools.isArray(a))return a.length?
CKEDITOR.tools.convertArrayToObject(a):!1;var d={},e=0,g;for(g in a)d[g]=a[g],e++;return e?d:!1}function f(a,b){if(a.nothingRequired)return!0;var e,g,c,f;if(c=a.requiredClasses)for(f=b.classes,e=0;e<c.length;++e)if(g=c[e],"string"==typeof g){if(-1==CKEDITOR.tools.indexOf(f,g))return!1}else if(!CKEDITOR.tools.checkIfAnyArrayItemMatches(f,g))return!1;return d(b.styles,a.requiredStyles)&&d(b.attributes,a.requiredAttributes)}function d(a,b){if(!b)return!0;for(var d=0,e;d<b.length;++d)if(e=b[d],"string"==
typeof e){if(!(e in a))return!1}else if(!CKEDITOR.tools.checkIfAnyObjectPropertyMatches(a,e))return!1;return!0}function m(a){if(!a)return{};a=a.split(/\s*,\s*/).sort();for(var b={};a.length;)b[a.shift()]="cke-test";return b}function g(a){var b,d,e,g,c={},f=1;for(a=I(a);b=a.match(F);)(d=b[2])?(e=n(d,"styles"),g=n(d,"attrs"),d=n(d,"classes")):e=g=d=null,c["$"+f++]={elements:b[1],classes:d,styles:e,attributes:g},a=a.slice(b[0].length);return c}function n(a,b){var d=a.match(S[b]);return d?I(d[1]):null}
function p(a){var b=a.styleBackup=a.attributes.style,d=a.classBackup=a.attributes["class"];a.styles||(a.styles=CKEDITOR.tools.parseCssText(b||"",1));a.classes||(a.classes=d?d.split(/\s+/):[])}function q(a,b,d,g){var f=0,h;g.toHtml&&(b.name=b.name.replace(N,"$1"));if(g.doCallbacks&&a.elementCallbacks){a:{h=a.elementCallbacks;for(var m=0,k=h.length,l;m<k;++m)if(l=h[m](b)){h=l;break a}h=void 0}if(h)return h}if(g.doTransform&&(h=a._.transformations[b.name])){p(b);for(m=0;m<h.length;++m)B(a,b,h[m]);v(b)}if(g.doFilter){a:{m=
b.name;k=a._;a=k.allowedRules.elements[m];h=k.allowedRules.generic;m=k.disallowedRules.elements[m];k=k.disallowedRules.generic;l=g.skipRequired;var u={valid:!1,validAttributes:{},validClasses:{},validStyles:{},allAttributes:!1,allClasses:!1,allStyles:!1,hadInvalidAttribute:!1,hadInvalidClass:!1,hadInvalidStyle:!1},n,r;if(a||h){p(b);if(m)for(n=0,r=m.length;n<r;++n)if(!1===e(m[n],b,u)){a=null;break a}if(k)for(n=0,r=k.length;n<r;++n)e(k[n],b,u);if(a)for(n=0,r=a.length;n<r;++n)c(a[n],b,u,l);if(h)for(n=
0,r=h.length;n<r;++n)c(h[n],b,u,l);a=u}else a=null}if(!a||!a.valid)return d.push(b),1;r=a.validAttributes;var F=a.validStyles;h=a.validClasses;var m=b.attributes,x=b.styles,k=b.classes;l=b.classBackup;var w=b.styleBackup,J,D,E=[],u=[],C=/^data-cke-/;n=!1;delete m.style;delete m["class"];delete b.classBackup;delete b.styleBackup;if(!a.allAttributes)for(J in m)r[J]||(C.test(J)?J==(D=J.replace(/^data-cke-saved-/,""))||r[D]||(delete m[J],n=!0):(delete m[J],n=!0));if(!a.allStyles||a.hadInvalidStyle){for(J in x)a.allStyles||
F[J]?E.push(J+":"+x[J]):n=!0;E.length&&(m.style=E.sort().join("; "))}else w&&(m.style=w);if(!a.allClasses||a.hadInvalidClass){for(J=0;J<k.length;++J)(a.allClasses||h[k[J]])&&u.push(k[J]);u.length&&(m["class"]=u.sort().join(" "));l&&u.length<l.split(/\s+/).length&&(n=!0)}else l&&(m["class"]=l);n&&(f=1);if(!g.skipFinalValidation&&!t(b))return d.push(b),1}g.toHtml&&(b.name=b.name.replace(Q,"cke:$1"));return f}function y(a){var b=[],d;for(d in a)-1<d.indexOf("*")&&b.push(d.replace(/\*/g,".*"));return b.length?
new RegExp("^(?:"+b.join("|")+")$"):null}function v(a){var b=a.attributes,d;delete b.style;delete b["class"];if(d=CKEDITOR.tools.writeCssText(a.styles,!0))b.style=d;a.classes.length&&(b["class"]=a.classes.sort().join(" "))}function t(a){switch(a.name){case "a":if(!(a.children.length||a.attributes.name||a.attributes.id))return!1;break;case "img":if(!a.attributes.src)return!1}return!0}function r(a){if(!a)return!1;if(!0===a)return!0;var b=y(a);return function(d){return d in a||b&&d.match(b)}}function w(){return new CKEDITOR.htmlParser.element("br")}
function z(a){return a.type==CKEDITOR.NODE_ELEMENT&&("br"==a.name||H.$block[a.name])}function u(a,b,d){var e=a.name;if(H.$empty[e]||!a.children.length)"hr"==e&&"br"==b?a.replaceWith(w()):(a.parent&&d.push({check:"it",el:a.parent}),a.remove());else if(H.$block[e]||"tr"==e)if("br"==b)a.previous&&!z(a.previous)&&(b=w(),b.insertBefore(a)),a.next&&!z(a.next)&&(b=w(),b.insertAfter(a)),a.replaceWithChildren();else{var e=a.children,g;b:{g=H[b];for(var c=0,f=e.length,h;c<f;++c)if(h=e[c],h.type==CKEDITOR.NODE_ELEMENT&&
!g[h.name]){g=!1;break b}g=!0}if(g)a.name=b,a.attributes={},d.push({check:"parent-down",el:a});else{g=a.parent;for(var c=g.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT||"body"==g.name,m,k,f=e.length;0<f;)h=e[--f],c&&(h.type==CKEDITOR.NODE_TEXT||h.type==CKEDITOR.NODE_ELEMENT&&H.$inline[h.name])?(m||(m=new CKEDITOR.htmlParser.element(b),m.insertAfter(a),d.push({check:"parent-down",el:m})),m.add(h,0)):(m=null,k=H[g.name]||H.span,h.insertAfter(a),g.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT||h.type!=CKEDITOR.NODE_ELEMENT||
k[h.name]||d.push({check:"el-up",el:h}));a.remove()}}else e in{style:1,script:1}?a.remove():(a.parent&&d.push({check:"it",el:a.parent}),a.replaceWithChildren())}function B(a,b,d){var e,g;for(e=0;e<d.length;++e)if(g=d[e],!(g.check&&!a.check(g.check,!1)||g.left&&!g.left(b))){g.right(b,M);break}}function C(a,b){var d=b.getDefinition(),e=d.attributes,g=d.styles,c,f,h,m;if(a.name!=d.element)return!1;for(c in e)if("class"==c)for(d=e[c].split(/\s+/),h=a.classes.join("|");m=d.pop();){if(-1==h.indexOf(m))return!1}else if(a.attributes[c]!=
e[c])return!1;for(f in g)if(a.styles[f]!=g[f])return!1;return!0}function x(a,b){var d,e;"string"==typeof a?d=a:a instanceof CKEDITOR.style?e=a:(d=a[0],e=a[1]);return[{element:d,left:e,right:function(a,d){d.transform(a,b)}}]}function A(a){return function(b){return C(b,a)}}function D(a){return function(b,d){d[a](b)}}var H=CKEDITOR.dtd,E=CKEDITOR.tools.copy,I=CKEDITOR.tools.trim,G=["","p","br","div"];CKEDITOR.FILTER_SKIP_TREE=2;CKEDITOR.filter=function(a){this.allowedContent=[];this.disallowedContent=
[];this.elementCallbacks=null;this.disabled=!1;this.editor=null;this.id=CKEDITOR.tools.getNextNumber();this._={allowedRules:{elements:{},generic:[]},disallowedRules:{elements:{},generic:[]},transformations:{},cachedTests:{}};CKEDITOR.filter.instances[this.id]=this;if(a instanceof CKEDITOR.editor){a=this.editor=a;this.customConfig=!0;var b=a.config.allowedContent;!0===b?this.disabled=!0:(b||(this.customConfig=!1),this.allow(b,"config",1),this.allow(a.config.extraAllowedContent,"extra",1),this.allow(G[a.enterMode]+
" "+G[a.shiftEnterMode],"default",1),this.disallow(a.config.disallowedContent))}else this.customConfig=!1,this.allow(a,"default",1)};CKEDITOR.filter.instances={};CKEDITOR.filter.prototype={allow:function(b,d,e){if(!l(this,b,e))return!1;var c,f;if("string"==typeof b)b=g(b);else if(b instanceof CKEDITOR.style){if(b.toAllowedContentRules)return this.allow(b.toAllowedContentRules(this.editor),d,e);c=b.getDefinition();b={};e=c.attributes;b[c.element]=c={styles:c.styles,requiredStyles:c.styles&&CKEDITOR.tools.objectKeys(c.styles)};
e&&(e=E(e),c.classes=e["class"]?e["class"].split(/\s+/):null,c.requiredClasses=c.classes,delete e["class"],c.attributes=e,c.requiredAttributes=e&&CKEDITOR.tools.objectKeys(e))}else if(CKEDITOR.tools.isArray(b)){for(c=0;c<b.length;++c)f=this.allow(b[c],d,e);return f}a(this,b,d,this.allowedContent,this._.allowedRules);return!0},applyTo:function(a,b,d,e){if(this.disabled)return!1;var g=this,c=[],f=this.editor&&this.editor.config.protectedSource,h,m=!1,k={doFilter:!d,doTransform:!0,doCallbacks:!0,toHtml:b};
a.forEach(function(a){if(a.type==CKEDITOR.NODE_ELEMENT){if("off"==a.attributes["data-cke-filter"])return!1;if(!b||"span"!=a.name||!~CKEDITOR.tools.objectKeys(a.attributes).join("|").indexOf("data-cke-"))if(h=q(g,a,c,k),h&1)m=!0;else if(h&2)return!1}else if(a.type==CKEDITOR.NODE_COMMENT&&a.value.match(/^\{cke_protected\}(?!\{C\})/)){var d;a:{var e=decodeURIComponent(a.value.replace(/^\{cke_protected\}/,""));d=[];var l,n,u;if(f)for(n=0;n<f.length;++n)if((u=e.match(f[n]))&&u[0].length==e.length){d=!0;
break a}e=CKEDITOR.htmlParser.fragment.fromHtml(e);1==e.children.length&&(l=e.children[0]).type==CKEDITOR.NODE_ELEMENT&&q(g,l,d,k);d=!d.length}d||c.push(a)}},null,!0);c.length&&(m=!0);var l;a=[];e=G[e||(this.editor?this.editor.enterMode:CKEDITOR.ENTER_P)];for(var n;d=c.pop();)d.type==CKEDITOR.NODE_ELEMENT?u(d,e,a):d.remove();for(;l=a.pop();)if(d=l.el,d.parent)switch(n=H[d.parent.name]||H.span,l.check){case "it":H.$removeEmpty[d.name]&&!d.children.length?u(d,e,a):t(d)||u(d,e,a);break;case "el-up":d.parent.type==
CKEDITOR.NODE_DOCUMENT_FRAGMENT||n[d.name]||u(d,e,a);break;case "parent-down":d.parent.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT||n[d.name]||u(d.parent,e,a)}return m},checkFeature:function(a){if(this.disabled||!a)return!0;a.toFeature&&(a=a.toFeature(this.editor));return!a.requiredContent||this.check(a.requiredContent)},disable:function(){this.disabled=!0},disallow:function(b){if(!l(this,b,!0))return!1;"string"==typeof b&&(b=g(b));a(this,b,null,this.disallowedContent,this._.disallowedRules);return!0},
addContentForms:function(a){if(!this.disabled&&a){var b,d,e=[],g;for(b=0;b<a.length&&!g;++b)d=a[b],("string"==typeof d||d instanceof CKEDITOR.style)&&this.check(d)&&(g=d);if(g){for(b=0;b<a.length;++b)e.push(x(a[b],g));this.addTransformations(e)}}},addElementCallback:function(a){this.elementCallbacks||(this.elementCallbacks=[]);this.elementCallbacks.push(a)},addFeature:function(a){if(this.disabled||!a)return!0;a.toFeature&&(a=a.toFeature(this.editor));this.allow(a.allowedContent,a.name);this.addTransformations(a.contentTransformations);
this.addContentForms(a.contentForms);return a.requiredContent&&(this.customConfig||this.disallowedContent.length)?this.check(a.requiredContent):!0},addTransformations:function(a){var b,d;if(!this.disabled&&a){var e=this._.transformations,g;for(g=0;g<a.length;++g){b=a[g];var c=void 0,f=void 0,h=void 0,m=void 0,k=void 0,l=void 0;d=[];for(f=0;f<b.length;++f)h=b[f],"string"==typeof h?(h=h.split(/\s*:\s*/),m=h[0],k=null,l=h[1]):(m=h.check,k=h.left,l=h.right),c||(c=h,c=c.element?c.element:m?m.match(/^([a-z0-9]+)/i)[0]:
c.left.getDefinition().element),k instanceof CKEDITOR.style&&(k=A(k)),d.push({check:m==c?null:m,left:k,right:"string"==typeof l?D(l):l});b=c;e[b]||(e[b]=[]);e[b].push(d)}}},check:function(a,b,d){if(this.disabled)return!0;if(CKEDITOR.tools.isArray(a)){for(var e=a.length;e--;)if(this.check(a[e],b,d))return!0;return!1}var c,f;if("string"==typeof a){f=a+"\x3c"+(!1===b?"0":"1")+(d?"1":"0")+"\x3e";if(f in this._.cachedChecks)return this._.cachedChecks[f];e=g(a).$1;c=e.styles;var h=e.classes;e.name=e.elements;
e.classes=h=h?h.split(/\s*,\s*/):[];e.styles=m(c);e.attributes=m(e.attributes);e.children=[];h.length&&(e.attributes["class"]=h.join(" "));c&&(e.attributes.style=CKEDITOR.tools.writeCssText(e.styles));c=e}else e=a.getDefinition(),c=e.styles,h=e.attributes||{},c&&!CKEDITOR.tools.isEmpty(c)?(c=E(c),h.style=CKEDITOR.tools.writeCssText(c,!0)):c={},c={name:e.element,attributes:h,classes:h["class"]?h["class"].split(/\s+/):[],styles:c,children:[]};var h=CKEDITOR.tools.clone(c),k=[],l;if(!1!==b&&(l=this._.transformations[c.name])){for(e=
0;e<l.length;++e)B(this,c,l[e]);v(c)}q(this,h,k,{doFilter:!0,doTransform:!1!==b,skipRequired:!d,skipFinalValidation:!d});b=0<k.length?!1:CKEDITOR.tools.objectCompare(c.attributes,h.attributes,!0)?!0:!1;"string"==typeof a&&(this._.cachedChecks[f]=b);return b},getAllowedEnterMode:function(){var a=["p","div","br"],b={p:CKEDITOR.ENTER_P,div:CKEDITOR.ENTER_DIV,br:CKEDITOR.ENTER_BR};return function(d,e){var g=a.slice(),c;if(this.check(G[d]))return d;for(e||(g=g.reverse());c=g.pop();)if(this.check(c))return b[c];
return CKEDITOR.ENTER_BR}}(),destroy:function(){delete CKEDITOR.filter.instances[this.id];delete this._;delete this.allowedContent;delete this.disallowedContent}};var K={styles:1,attributes:1,classes:1},J={styles:"requiredStyles",attributes:"requiredAttributes",classes:"requiredClasses"},F=/^([a-z0-9\-*\s]+)((?:\s*\{[!\w\-,\s\*]+\}\s*|\s*\[[!\w\-,\s\*]+\]\s*|\s*\([!\w\-,\s\*]+\)\s*){0,3})(?:;\s*|$)/i,S={styles:/{([^}]+)}/,attrs:/\[([^\]]+)\]/,classes:/\(([^\)]+)\)/},N=/^cke:(object|embed|param)$/,
Q=/^(object|embed|param)$/,M;M=CKEDITOR.filter.transformationsTools={sizeToStyle:function(a){this.lengthToStyle(a,"width");this.lengthToStyle(a,"height")},sizeToAttribute:function(a){this.lengthToAttribute(a,"width");this.lengthToAttribute(a,"height")},lengthToStyle:function(a,b,d){d=d||b;if(!(d in a.styles)){var e=a.attributes[b];e&&(/^\d+$/.test(e)&&(e+="px"),a.styles[d]=e)}delete a.attributes[b]},lengthToAttribute:function(a,b,d){d=d||b;if(!(d in a.attributes)){var e=a.styles[b],g=e&&e.match(/^(\d+)(?:\.\d*)?px$/);
g?a.attributes[d]=g[1]:"cke-test"==e&&(a.attributes[d]="cke-test")}delete a.styles[b]},alignmentToStyle:function(a){if(!("float"in a.styles)){var b=a.attributes.align;if("left"==b||"right"==b)a.styles["float"]=b}delete a.attributes.align},alignmentToAttribute:function(a){if(!("align"in a.attributes)){var b=a.styles["float"];if("left"==b||"right"==b)a.attributes.align=b}delete a.styles["float"]},splitBorderShorthand:function(a){function b(e){a.styles["border-top-width"]=d[e[0]];a.styles["border-right-width"]=
d[e[1]];a.styles["border-bottom-width"]=d[e[2]];a.styles["border-left-width"]=d[e[3]]}if(a.styles.border){var d=a.styles.border.match(/([\.\d]+\w+)/g)||["0px"];switch(d.length){case 1:a.styles["border-width"]=d[0];break;case 2:b([0,1,0,1]);break;case 3:b([0,1,2,1]);break;case 4:b([0,1,2,3])}a.styles["border-style"]=a.styles["border-style"]||(a.styles.border.match(/(none|hidden|dotted|dashed|solid|double|groove|ridge|inset|outset|initial|inherit)/)||[])[0];a.styles["border-style"]||delete a.styles["border-style"];
delete a.styles.border}},listTypeToStyle:function(a){if(a.attributes.type)switch(a.attributes.type){case "a":a.styles["list-style-type"]="lower-alpha";break;case "A":a.styles["list-style-type"]="upper-alpha";break;case "i":a.styles["list-style-type"]="lower-roman";break;case "I":a.styles["list-style-type"]="upper-roman";break;case "1":a.styles["list-style-type"]="decimal";break;default:a.styles["list-style-type"]=a.attributes.type}},splitMarginShorthand:function(a){function b(e){a.styles["margin-top"]=
d[e[0]];a.styles["margin-right"]=d[e[1]];a.styles["margin-bottom"]=d[e[2]];a.styles["margin-left"]=d[e[3]]}if(a.styles.margin){var d=a.styles.margin.match(/(\-?[\.\d]+\w+)/g)||["0px"];switch(d.length){case 1:b([0,0,0,0]);break;case 2:b([0,1,0,1]);break;case 3:b([0,1,2,1]);break;case 4:b([0,1,2,3])}delete a.styles.margin}},matchesStyle:C,transform:function(a,b){if("string"==typeof b)a.name=b;else{var d=b.getDefinition(),e=d.styles,g=d.attributes,c,f,h,m;a.name=d.element;for(c in g)if("class"==c)for(d=
a.classes.join("|"),h=g[c].split(/\s+/);m=h.pop();)-1==d.indexOf(m)&&a.classes.push(m);else a.attributes[c]=g[c];for(f in e)a.styles[f]=e[f]}}}}(),function(){CKEDITOR.focusManager=function(a){if(a.focusManager)return a.focusManager;this.hasFocus=!1;this.currentActive=null;this._={editor:a};return this};CKEDITOR.focusManager._={blurDelay:200};CKEDITOR.focusManager.prototype={focus:function(a){this._.timer&&clearTimeout(this._.timer);a&&(this.currentActive=a);this.hasFocus||this._.locked||((a=CKEDITOR.currentInstance)&&
a.focusManager.blur(1),this.hasFocus=!0,(a=this._.editor.container)&&a.addClass("cke_focus"),this._.editor.fire("focus"))},lock:function(){this._.locked=1},unlock:function(){delete this._.locked},blur:function(a){function c(){if(this.hasFocus){this.hasFocus=!1;var a=this._.editor.container;a&&a.removeClass("cke_focus");this._.editor.fire("blur")}}if(!this._.locked){this._.timer&&clearTimeout(this._.timer);var b=CKEDITOR.focusManager._.blurDelay;a||!b?c.call(this):this._.timer=CKEDITOR.tools.setTimeout(function(){delete this._.timer;
c.call(this)},b,this)}},add:function(a,c){var b=a.getCustomData("focusmanager");if(!b||b!=this){b&&b.remove(a);var b="focus",e="blur";c&&(CKEDITOR.env.ie?(b="focusin",e="focusout"):CKEDITOR.event.useCapture=1);var h={blur:function(){a.equals(this.currentActive)&&this.blur()},focus:function(){this.focus(a)}};a.on(b,h.focus,this);a.on(e,h.blur,this);c&&(CKEDITOR.event.useCapture=0);a.setCustomData("focusmanager",this);a.setCustomData("focusmanager_handlers",h)}},remove:function(a){a.removeCustomData("focusmanager");
var c=a.removeCustomData("focusmanager_handlers");a.removeListener("blur",c.blur);a.removeListener("focus",c.focus)}}}(),CKEDITOR.keystrokeHandler=function(a){if(a.keystrokeHandler)return a.keystrokeHandler;this.keystrokes={};this.blockedKeystrokes={};this._={editor:a};return this},function(){var a,c=function(b){b=b.data;var c=b.getKeystroke(),l=this.keystrokes[c],k=this._.editor;a=!1===k.fire("key",{keyCode:c,domEvent:b});a||(l&&(a=!1!==k.execCommand(l,{from:"keystrokeHandler"})),a||(a=!!this.blockedKeystrokes[c]));
a&&b.preventDefault(!0);return!a},b=function(b){a&&(a=!1,b.data.preventDefault(!0))};CKEDITOR.keystrokeHandler.prototype={attach:function(a){a.on("keydown",c,this);if(CKEDITOR.env.gecko&&CKEDITOR.env.mac)a.on("keypress",b,this)}}}(),function(){CKEDITOR.lang={languages:{af:1,ar:1,az:1,bg:1,bn:1,bs:1,ca:1,cs:1,cy:1,da:1,de:1,"de-ch":1,el:1,"en-au":1,"en-ca":1,"en-gb":1,en:1,eo:1,es:1,"es-mx":1,et:1,eu:1,fa:1,fi:1,fo:1,"fr-ca":1,fr:1,gl:1,gu:1,he:1,hi:1,hr:1,hu:1,id:1,is:1,it:1,ja:1,ka:1,km:1,ko:1,ku:1,
lt:1,lv:1,mk:1,mn:1,ms:1,nb:1,nl:1,no:1,oc:1,pl:1,"pt-br":1,pt:1,ro:1,ru:1,si:1,sk:1,sl:1,sq:1,"sr-latn":1,sr:1,sv:1,th:1,tr:1,tt:1,ug:1,uk:1,vi:1,"zh-cn":1,zh:1},rtl:{ar:1,fa:1,he:1,ku:1,ug:1},load:function(a,c,b){a&&CKEDITOR.lang.languages[a]||(a=this.detect(c,a));var e=this;c=function(){e[a].dir=e.rtl[a]?"rtl":"ltr";b(a,e[a])};this[a]?c():CKEDITOR.scriptLoader.load(CKEDITOR.getUrl("lang/"+a+".js"),c,this)},detect:function(a,c){var b=this.languages;c=c||navigator.userLanguage||navigator.language||
a;var e=c.toLowerCase().match(/([a-z]+)(?:-([a-z]+))?/),h=e[1],e=e[2];b[h+"-"+e]?h=h+"-"+e:b[h]||(h=null);CKEDITOR.lang.detect=h?function(){return h}:function(a){return a};return h||a}}}(),CKEDITOR.scriptLoader=function(){var a={},c={};return{load:function(b,e,h,l){var k="string"==typeof b;k&&(b=[b]);h||(h=CKEDITOR);var f=b.length,d=[],m=[],g=function(a){e&&(k?e.call(h,a):e.call(h,d,m))};if(0===f)g(!0);else{var n=function(a,b){(b?d:m).push(a);0>=--f&&(l&&CKEDITOR.document.getDocumentElement().removeStyle("cursor"),
g(b))},p=function(b,d){a[b]=1;var e=c[b];delete c[b];for(var g=0;g<e.length;g++)e[g](b,d)},q=function(b){if(a[b])n(b,!0);else{var d=c[b]||(c[b]=[]);d.push(n);if(!(1<d.length)){var g=new CKEDITOR.dom.element("script");g.setAttributes({type:"text/javascript",src:b});e&&(CKEDITOR.env.ie&&(8>=CKEDITOR.env.version||CKEDITOR.env.ie9Compat)?g.$.onreadystatechange=function(){if("loaded"==g.$.readyState||"complete"==g.$.readyState)g.$.onreadystatechange=null,p(b,!0)}:(g.$.onload=function(){setTimeout(function(){p(b,
!0)},0)},g.$.onerror=function(){p(b,!1)}));g.appendTo(CKEDITOR.document.getHead())}}};l&&CKEDITOR.document.getDocumentElement().setStyle("cursor","wait");for(var y=0;y<f;y++)q(b[y])}},queue:function(){function a(){var b;(b=e[0])&&this.load(b.scriptUrl,b.callback,CKEDITOR,0)}var e=[];return function(c,l){var k=this;e.push({scriptUrl:c,callback:function(){l&&l.apply(this,arguments);e.shift();a.call(k)}});1==e.length&&a.call(this)}}()}}(),CKEDITOR.resourceManager=function(a,c){this.basePath=a;this.fileName=
c;this.registered={};this.loaded={};this.externals={};this._={waitingList:{}}},CKEDITOR.resourceManager.prototype={add:function(a,c){if(this.registered[a])throw Error('[CKEDITOR.resourceManager.add] The resource name "'+a+'" is already registered.');var b=this.registered[a]=c||{};b.name=a;b.path=this.getPath(a);CKEDITOR.fire(a+CKEDITOR.tools.capitalize(this.fileName)+"Ready",b);return this.get(a)},get:function(a){return this.registered[a]||null},getPath:function(a){var c=this.externals[a];return CKEDITOR.getUrl(c&&
c.dir||this.basePath+a+"/")},getFilePath:function(a){var c=this.externals[a];return CKEDITOR.getUrl(this.getPath(a)+(c?c.file:this.fileName+".js"))},addExternal:function(a,c,b){a=a.split(",");for(var e=0;e<a.length;e++){var h=a[e];b||(c=c.replace(/[^\/]+$/,function(a){b=a;return""}));this.externals[h]={dir:c,file:b||this.fileName+".js"}}},load:function(a,c,b){CKEDITOR.tools.isArray(a)||(a=a?[a]:[]);for(var e=this.loaded,h=this.registered,l=[],k={},f={},d=0;d<a.length;d++){var m=a[d];if(m)if(e[m]||
h[m])f[m]=this.get(m);else{var g=this.getFilePath(m);l.push(g);g in k||(k[g]=[]);k[g].push(m)}}CKEDITOR.scriptLoader.load(l,function(a,d){if(d.length)throw Error('[CKEDITOR.resourceManager.load] Resource name "'+k[d[0]].join(",")+'" was not found at "'+d[0]+'".');for(var g=0;g<a.length;g++)for(var h=k[a[g]],m=0;m<h.length;m++){var l=h[m];f[l]=this.get(l);e[l]=1}c.call(b,f)},this)}},CKEDITOR.plugins=new CKEDITOR.resourceManager("plugins/","plugin"),CKEDITOR.plugins.load=CKEDITOR.tools.override(CKEDITOR.plugins.load,
function(a){var c={};return function(b,e,h){var l={},k=function(b){a.call(this,b,function(a){CKEDITOR.tools.extend(l,a);var b=[],g;for(g in a){var f=a[g],p=f&&f.requires;if(!c[g]){if(f.icons)for(var q=f.icons.split(","),y=q.length;y--;)CKEDITOR.skin.addIcon(q[y],f.path+"icons/"+(CKEDITOR.env.hidpi&&f.hidpi?"hidpi/":"")+q[y]+".png");c[g]=1}if(p)for(p.split&&(p=p.split(",")),f=0;f<p.length;f++)l[p[f]]||b.push(p[f])}if(b.length)k.call(this,b);else{for(g in l)f=l[g],f.onLoad&&!f.onLoad._called&&(!1===
f.onLoad()&&delete l[g],f.onLoad._called=1);e&&e.call(h||window,l)}},this)};k.call(this,b)}}),CKEDITOR.plugins.setLang=function(a,c,b){var e=this.get(a);a=e.langEntries||(e.langEntries={});e=e.lang||(e.lang=[]);e.split&&(e=e.split(","));-1==CKEDITOR.tools.indexOf(e,c)&&e.push(c);a[c]=b},CKEDITOR.ui=function(a){if(a.ui)return a.ui;this.items={};this.instances={};this.editor=a;this._={handlers:{}};return this},CKEDITOR.ui.prototype={add:function(a,c,b){b.name=a.toLowerCase();var e=this.items[a]={type:c,
command:b.command||null,args:Array.prototype.slice.call(arguments,2)};CKEDITOR.tools.extend(e,b)},get:function(a){return this.instances[a]},create:function(a){var c=this.items[a],b=c&&this._.handlers[c.type],e=c&&c.command&&this.editor.getCommand(c.command),b=b&&b.create.apply(this,c.args);this.instances[a]=b;e&&e.uiItems.push(b);b&&!b.type&&(b.type=c.type);return b},addHandler:function(a,c){this._.handlers[a]=c},space:function(a){return CKEDITOR.document.getById(this.spaceId(a))},spaceId:function(a){return this.editor.id+
"_"+a}},CKEDITOR.event.implementOn(CKEDITOR.ui),function(){function a(a,d,g){CKEDITOR.event.call(this);a=a&&CKEDITOR.tools.clone(a);if(void 0!==d){if(!(d instanceof CKEDITOR.dom.element))throw Error("Expect element of type CKEDITOR.dom.element.");if(!g)throw Error("One of the element modes must be specified.");if(CKEDITOR.env.ie&&CKEDITOR.env.quirks&&g==CKEDITOR.ELEMENT_MODE_INLINE)throw Error("Inline element mode is not supported on IE quirks.");if(!b(d,g))throw Error('The specified element mode is not supported on element: "'+
d.getName()+'".');this.element=d;this.elementMode=g;this.name=this.elementMode!=CKEDITOR.ELEMENT_MODE_APPENDTO&&(d.getId()||d.getNameAtt())}else this.elementMode=CKEDITOR.ELEMENT_MODE_NONE;this._={};this.commands={};this.templates={};this.name=this.name||c();this.id=CKEDITOR.tools.getNextId();this.status="unloaded";this.config=CKEDITOR.tools.prototypedCopy(CKEDITOR.config);this.ui=new CKEDITOR.ui(this);this.focusManager=new CKEDITOR.focusManager(this);this.keystrokeHandler=new CKEDITOR.keystrokeHandler(this);
this.on("readOnly",e);this.on("selectionChange",function(a){l(this,a.data.path)});this.on("activeFilterChange",function(){l(this,this.elementPath(),!0)});this.on("mode",e);this.on("instanceReady",function(){this.config.startupFocus&&this.focus()});CKEDITOR.fire("instanceCreated",null,this);CKEDITOR.add(this);CKEDITOR.tools.setTimeout(function(){"destroyed"!==this.status?f(this,a):CKEDITOR.warn("editor-incorrect-destroy")},0,this)}function c(){do var a="editor"+ ++y;while(CKEDITOR.instances[a]);return a}
function b(a,b){return b==CKEDITOR.ELEMENT_MODE_INLINE?a.is(CKEDITOR.dtd.$editable)||a.is("textarea"):b==CKEDITOR.ELEMENT_MODE_REPLACE?!a.is(CKEDITOR.dtd.$nonBodyContent):1}function e(){var a=this.commands,b;for(b in a)h(this,a[b])}function h(a,b){b[b.startDisabled?"disable":a.readOnly&&!b.readOnly?"disable":b.modes[a.mode]?"enable":"disable"]()}function l(a,b,d){if(b){var e,g,c=a.commands;for(g in c)e=c[g],(d||e.contextSensitive)&&e.refresh(a,b)}}function k(a){var b=a.config.customConfig;if(!b)return!1;
var b=CKEDITOR.getUrl(b),d=v[b]||(v[b]={});d.fn?(d.fn.call(a,a.config),CKEDITOR.getUrl(a.config.customConfig)!=b&&k(a)||a.fireOnce("customConfigLoaded")):CKEDITOR.scriptLoader.queue(b,function(){d.fn=CKEDITOR.editorConfig?CKEDITOR.editorConfig:function(){};k(a)});return!0}function f(a,b){a.on("customConfigLoaded",function(){if(b){if(b.on)for(var e in b.on)a.on(e,b.on[e]);CKEDITOR.tools.extend(a.config,b,!0);delete a.config.on}e=a.config;a.readOnly=e.readOnly?!0:a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?
a.element.is("textarea")?a.element.hasAttribute("disabled")||a.element.hasAttribute("readonly"):a.element.isReadOnly():a.elementMode==CKEDITOR.ELEMENT_MODE_REPLACE?a.element.hasAttribute("disabled")||a.element.hasAttribute("readonly"):!1;a.blockless=a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?!(a.element.is("textarea")||CKEDITOR.dtd[a.element.getName()].p):!1;a.tabIndex=e.tabIndex||a.element&&a.element.getAttribute("tabindex")||0;a.activeEnterMode=a.enterMode=a.blockless?CKEDITOR.ENTER_BR:e.enterMode;
a.activeShiftEnterMode=a.shiftEnterMode=a.blockless?CKEDITOR.ENTER_BR:e.shiftEnterMode;e.skin&&(CKEDITOR.skinName=e.skin);a.fireOnce("configLoaded");a.dataProcessor=new CKEDITOR.htmlDataProcessor(a);a.filter=a.activeFilter=new CKEDITOR.filter(a);d(a)});b&&null!=b.customConfig&&(a.config.customConfig=b.customConfig);k(a)||a.fireOnce("customConfigLoaded")}function d(a){CKEDITOR.skin.loadPart("editor",function(){m(a)})}function m(a){CKEDITOR.lang.load(a.config.language,a.config.defaultLanguage,function(b,
d){var e=a.config.title;a.langCode=b;a.lang=CKEDITOR.tools.prototypedCopy(d);a.title="string"==typeof e||!1===e?e:[a.lang.editor,a.name].join(", ");a.config.contentsLangDirection||(a.config.contentsLangDirection=a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?a.element.getDirection(1):a.lang.dir);a.fire("langLoaded");g(a)})}function g(a){a.getStylesSet(function(b){a.once("loaded",function(){a.fire("stylesSet",{styles:b})},null,null,1);n(a)})}function n(a){var b=a.config,d=b.plugins,e=b.extraPlugins,g=
b.removePlugins;if(e)var c=new RegExp("(?:^|,)(?:"+e.replace(/\s*,\s*/g,"|")+")(?\x3d,|$)","g"),d=d.replace(c,""),d=d+(","+e);if(g)var f=new RegExp("(?:^|,)(?:"+g.replace(/\s*,\s*/g,"|")+")(?\x3d,|$)","g"),d=d.replace(f,"");CKEDITOR.env.air&&(d+=",adobeair");CKEDITOR.plugins.load(d.split(","),function(d){var e=[],g=[],c=[];a.plugins=d;for(var h in d){var m=d[h],k=m.lang,l=null,n=m.requires,u;CKEDITOR.tools.isArray(n)&&(n=n.join(","));if(n&&(u=n.match(f)))for(;n=u.pop();)CKEDITOR.error("editor-plugin-required",
{plugin:n.replace(",",""),requiredBy:h});k&&!a.lang[h]&&(k.split&&(k=k.split(",")),0<=CKEDITOR.tools.indexOf(k,a.langCode)?l=a.langCode:(l=a.langCode.replace(/-.*/,""),l=l!=a.langCode&&0<=CKEDITOR.tools.indexOf(k,l)?l:0<=CKEDITOR.tools.indexOf(k,"en")?"en":k[0]),m.langEntries&&m.langEntries[l]?(a.lang[h]=m.langEntries[l],l=null):c.push(CKEDITOR.getUrl(m.path+"lang/"+l+".js")));g.push(l);e.push(m)}CKEDITOR.scriptLoader.load(c,function(){for(var d=["beforeInit","init","afterInit"],c=0;c<d.length;c++)for(var f=
0;f<e.length;f++){var h=e[f];0===c&&g[f]&&h.lang&&h.langEntries&&(a.lang[h.name]=h.langEntries[g[f]]);if(h[d[c]])h[d[c]](a)}a.fireOnce("pluginsLoaded");b.keystrokes&&a.setKeystroke(a.config.keystrokes);for(f=0;f<a.config.blockedKeystrokes.length;f++)a.keystrokeHandler.blockedKeystrokes[a.config.blockedKeystrokes[f]]=1;a.status="loaded";a.fireOnce("loaded");CKEDITOR.fire("instanceLoaded",null,a)})})}function p(){var a=this.element;if(a&&this.elementMode!=CKEDITOR.ELEMENT_MODE_APPENDTO){var b=this.getData();
this.config.htmlEncodeOutput&&(b=CKEDITOR.tools.htmlEncode(b));a.is("textarea")?a.setValue(b):a.setHtml(b);return!0}return!1}function q(a,b){function d(a){var b=a.startContainer,e=a.endContainer;return b.is&&(b.is("tr")||b.is("td")&&b.equals(e)&&a.endOffset===b.getChildCount())?!0:!1}function e(a){var b=a.startContainer;return b.is("tr")?a.cloneContents():b.clone(!0)}for(var g=new CKEDITOR.dom.documentFragment,c,f,h,m=0;m<a.length;m++){var k=a[m],l=k.startContainer.getAscendant("tr",!0);d(k)?(c||
(c=l.getAscendant("table").clone(),c.append(l.getAscendant({thead:1,tbody:1,tfoot:1}).clone()),g.append(c),c=c.findOne("thead, tbody, tfoot")),f&&f.equals(l)||(f=l,h=l.clone(),c.append(h)),h.append(e(k))):g.append(k.cloneContents())}return c?g:b.getHtmlFromRange(a[0])}a.prototype=CKEDITOR.editor.prototype;CKEDITOR.editor=a;var y=0,v={};CKEDITOR.tools.extend(CKEDITOR.editor.prototype,{addCommand:function(a,b){b.name=a.toLowerCase();var d=new CKEDITOR.command(this,b);this.mode&&h(this,d);return this.commands[a]=
d},_attachToForm:function(){function a(b){d.updateElement();d._.required&&!e.getValue()&&!1===d.fire("required")&&b.data.preventDefault()}function b(a){return!!(a&&a.call&&a.apply)}var d=this,e=d.element,g=new CKEDITOR.dom.element(e.$.form);e.is("textarea")&&g&&(g.on("submit",a),b(g.$.submit)&&(g.$.submit=CKEDITOR.tools.override(g.$.submit,function(b){return function(){a();b.apply?b.apply(this):b()}})),d.on("destroy",function(){g.removeListener("submit",a)}))},destroy:function(a){this.fire("beforeDestroy");
!a&&p.call(this);this.editable(null);this.filter&&(this.filter.destroy(),delete this.filter);delete this.activeFilter;this.status="destroyed";this.fire("destroy");this.removeAllListeners();CKEDITOR.remove(this);CKEDITOR.fire("instanceDestroyed",null,this)},elementPath:function(a){if(!a){a=this.getSelection();if(!a)return null;a=a.getStartElement()}return a?new CKEDITOR.dom.elementPath(a,this.editable()):null},createRange:function(){var a=this.editable();return a?new CKEDITOR.dom.range(a):null},execCommand:function(a,
b){var d=this.getCommand(a),e={name:a,commandData:b||{},command:d};return d&&d.state!=CKEDITOR.TRISTATE_DISABLED&&!1!==this.fire("beforeCommandExec",e)&&(e.returnValue=d.exec(e.commandData),!d.async&&!1!==this.fire("afterCommandExec",e))?e.returnValue:!1},getCommand:function(a){return this.commands[a]},getData:function(a){!a&&this.fire("beforeGetData");var b=this._.data;"string"!=typeof b&&(b=(b=this.element)&&this.elementMode==CKEDITOR.ELEMENT_MODE_REPLACE?b.is("textarea")?b.getValue():b.getHtml():
"");b={dataValue:b};!a&&this.fire("getData",b);return b.dataValue},getSnapshot:function(){var a=this.fire("getSnapshot");"string"!=typeof a&&(a=(a=this.element)&&this.elementMode==CKEDITOR.ELEMENT_MODE_REPLACE?a.is("textarea")?a.getValue():a.getHtml():"");return a},loadSnapshot:function(a){this.fire("loadSnapshot",a)},setData:function(a,b,d){var e=!0,g=b;b&&"object"==typeof b&&(d=b.internal,g=b.callback,e=!b.noSnapshot);!d&&e&&this.fire("saveSnapshot");if(g||!d)this.once("dataReady",function(a){!d&&
e&&this.fire("saveSnapshot");g&&g.call(a.editor)});a={dataValue:a};!d&&this.fire("setData",a);this._.data=a.dataValue;!d&&this.fire("afterSetData",a)},setReadOnly:function(a){a=null==a||a;this.readOnly!=a&&(this.readOnly=a,this.keystrokeHandler.blockedKeystrokes[8]=+a,this.editable().setReadOnly(a),this.fire("readOnly"))},insertHtml:function(a,b,d){this.fire("insertHtml",{dataValue:a,mode:b,range:d})},insertText:function(a){this.fire("insertText",a)},insertElement:function(a){this.fire("insertElement",
a)},getSelectedHtml:function(a){var b=this.editable(),d=this.getSelection(),d=d&&d.getRanges();if(!b||!d||0===d.length)return null;b=q(d,b);return a?b.getHtml():b},extractSelectedHtml:function(a,b){var d=this.editable(),e=this.getSelection().getRanges(),g=new CKEDITOR.dom.documentFragment,c;if(!d||0===e.length)return null;for(c=0;c<e.length;c++)g.append(d.extractHtmlFromRange(e[c],b));b||this.getSelection().selectRanges([e[0]]);return a?g.getHtml():g},focus:function(){this.fire("beforeFocus")},checkDirty:function(){return"ready"==
this.status&&this._.previousValue!==this.getSnapshot()},resetDirty:function(){this._.previousValue=this.getSnapshot()},updateElement:function(){return p.call(this)},setKeystroke:function(){for(var a=this.keystrokeHandler.keystrokes,b=CKEDITOR.tools.isArray(arguments[0])?arguments[0]:[[].slice.call(arguments,0)],d,e,g=b.length;g--;)d=b[g],e=0,CKEDITOR.tools.isArray(d)&&(e=d[1],d=d[0]),e?a[d]=e:delete a[d]},getCommandKeystroke:function(a){if(a="string"===typeof a?this.getCommand(a):a){var b=CKEDITOR.tools.object.findKey(this.commands,
a),d=this.keystrokeHandler.keystrokes,e;if(a.fakeKeystroke)return a.fakeKeystroke;for(e in d)if(d.hasOwnProperty(e)&&d[e]==b)return e}return null},addFeature:function(a){return this.filter.addFeature(a)},setActiveFilter:function(a){a||(a=this.filter);this.activeFilter!==a&&(this.activeFilter=a,this.fire("activeFilterChange"),a===this.filter?this.setActiveEnterMode(null,null):this.setActiveEnterMode(a.getAllowedEnterMode(this.enterMode),a.getAllowedEnterMode(this.shiftEnterMode,!0)))},setActiveEnterMode:function(a,
b){a=a?this.blockless?CKEDITOR.ENTER_BR:a:this.enterMode;b=b?this.blockless?CKEDITOR.ENTER_BR:b:this.shiftEnterMode;if(this.activeEnterMode!=a||this.activeShiftEnterMode!=b)this.activeEnterMode=a,this.activeShiftEnterMode=b,this.fire("activeEnterModeChange")},showNotification:function(a){alert(a)}})}(),CKEDITOR.ELEMENT_MODE_NONE=0,CKEDITOR.ELEMENT_MODE_REPLACE=1,CKEDITOR.ELEMENT_MODE_APPENDTO=2,CKEDITOR.ELEMENT_MODE_INLINE=3,CKEDITOR.htmlParser=function(){this._={htmlPartsRegex:/<(?:(?:\/([^>]+)>)|(?:!--([\S|\s]*?)--\x3e)|(?:([^\/\s>]+)((?:\s+[\w\-:.]+(?:\s*=\s*?(?:(?:"[^"]*")|(?:'[^']*')|[^\s"'\/>]+))?)*)[\S\s]*?(\/?)>))/g}},
function(){var a=/([\w\-:.]+)(?:(?:\s*=\s*(?:(?:"([^"]*)")|(?:'([^']*)')|([^\s>]+)))|(?=\s|$))/g,c={checked:1,compact:1,declare:1,defer:1,disabled:1,ismap:1,multiple:1,nohref:1,noresize:1,noshade:1,nowrap:1,readonly:1,selected:1};CKEDITOR.htmlParser.prototype={onTagOpen:function(){},onTagClose:function(){},onText:function(){},onCDATA:function(){},onComment:function(){},parse:function(b){for(var e,h,l=0,k;e=this._.htmlPartsRegex.exec(b);){h=e.index;if(h>l)if(l=b.substring(l,h),k)k.push(l);else this.onText(l);
l=this._.htmlPartsRegex.lastIndex;if(h=e[1])if(h=h.toLowerCase(),k&&CKEDITOR.dtd.$cdata[h]&&(this.onCDATA(k.join("")),k=null),!k){this.onTagClose(h);continue}if(k)k.push(e[0]);else if(h=e[3]){if(h=h.toLowerCase(),!/="/.test(h)){var f={},d,m=e[4];e=!!e[5];if(m)for(;d=a.exec(m);){var g=d[1].toLowerCase();d=d[2]||d[3]||d[4]||"";f[g]=!d&&c[g]?g:CKEDITOR.tools.htmlDecodeAttr(d)}this.onTagOpen(h,f,e);!k&&CKEDITOR.dtd.$cdata[h]&&(k=[])}}else if(h=e[2])this.onComment(h)}if(b.length>l)this.onText(b.substring(l,
b.length))}}}(),CKEDITOR.htmlParser.basicWriter=CKEDITOR.tools.createClass({$:function(){this._={output:[]}},proto:{openTag:function(a){this._.output.push("\x3c",a)},openTagClose:function(a,c){c?this._.output.push(" /\x3e"):this._.output.push("\x3e")},attribute:function(a,c){"string"==typeof c&&(c=CKEDITOR.tools.htmlEncodeAttr(c));this._.output.push(" ",a,'\x3d"',c,'"')},closeTag:function(a){this._.output.push("\x3c/",a,"\x3e")},text:function(a){this._.output.push(a)},comment:function(a){this._.output.push("\x3c!--",
a,"--\x3e")},write:function(a){this._.output.push(a)},reset:function(){this._.output=[];this._.indent=!1},getHtml:function(a){var c=this._.output.join("");a&&this.reset();return c}}}),"use strict",function(){CKEDITOR.htmlParser.node=function(){};CKEDITOR.htmlParser.node.prototype={remove:function(){var a=this.parent.children,c=CKEDITOR.tools.indexOf(a,this),b=this.previous,e=this.next;b&&(b.next=e);e&&(e.previous=b);a.splice(c,1);this.parent=null},replaceWith:function(a){var c=this.parent.children,
b=CKEDITOR.tools.indexOf(c,this),e=a.previous=this.previous,h=a.next=this.next;e&&(e.next=a);h&&(h.previous=a);c[b]=a;a.parent=this.parent;this.parent=null},insertAfter:function(a){var c=a.parent.children,b=CKEDITOR.tools.indexOf(c,a),e=a.next;c.splice(b+1,0,this);this.next=a.next;this.previous=a;a.next=this;e&&(e.previous=this);this.parent=a.parent},insertBefore:function(a){var c=a.parent.children,b=CKEDITOR.tools.indexOf(c,a);c.splice(b,0,this);this.next=a;(this.previous=a.previous)&&(a.previous.next=
this);a.previous=this;this.parent=a.parent},getAscendant:function(a){var c="function"==typeof a?a:"string"==typeof a?function(b){return b.name==a}:function(b){return b.name in a},b=this.parent;for(;b&&b.type==CKEDITOR.NODE_ELEMENT;){if(c(b))return b;b=b.parent}return null},wrapWith:function(a){this.replaceWith(a);a.add(this);return a},getIndex:function(){return CKEDITOR.tools.indexOf(this.parent.children,this)},getFilterContext:function(a){return a||{}}}}(),"use strict",CKEDITOR.htmlParser.comment=
function(a){this.value=a;this._={isBlockLike:!1}},CKEDITOR.htmlParser.comment.prototype=CKEDITOR.tools.extend(new CKEDITOR.htmlParser.node,{type:CKEDITOR.NODE_COMMENT,filter:function(a,c){var b=this.value;if(!(b=a.onComment(c,b,this)))return this.remove(),!1;if("string"!=typeof b)return this.replaceWith(b),!1;this.value=b;return!0},writeHtml:function(a,c){c&&this.filter(c);a.comment(this.value)}}),"use strict",function(){CKEDITOR.htmlParser.text=function(a){this.value=a;this._={isBlockLike:!1}};CKEDITOR.htmlParser.text.prototype=
CKEDITOR.tools.extend(new CKEDITOR.htmlParser.node,{type:CKEDITOR.NODE_TEXT,filter:function(a,c){if(!(this.value=a.onText(c,this.value,this)))return this.remove(),!1},writeHtml:function(a,c){c&&this.filter(c);a.text(this.value)}})}(),"use strict",function(){CKEDITOR.htmlParser.cdata=function(a){this.value=a};CKEDITOR.htmlParser.cdata.prototype=CKEDITOR.tools.extend(new CKEDITOR.htmlParser.node,{type:CKEDITOR.NODE_TEXT,filter:function(){},writeHtml:function(a){a.write(this.value)}})}(),"use strict",
CKEDITOR.htmlParser.fragment=function(){this.children=[];this.parent=null;this._={isBlockLike:!0,hasInlineStarted:!1}},function(){function a(a){return a.attributes["data-cke-survive"]?!1:"a"==a.name&&a.attributes.href||CKEDITOR.dtd.$removeEmpty[a.name]}var c=CKEDITOR.tools.extend({table:1,ul:1,ol:1,dl:1},CKEDITOR.dtd.table,CKEDITOR.dtd.ul,CKEDITOR.dtd.ol,CKEDITOR.dtd.dl),b={ol:1,ul:1},e=CKEDITOR.tools.extend({},{html:1},CKEDITOR.dtd.html,CKEDITOR.dtd.body,CKEDITOR.dtd.head,{style:1,script:1}),h={ul:"li",
ol:"li",dl:"dd",table:"tbody",tbody:"tr",thead:"tr",tfoot:"tr",tr:"td"};CKEDITOR.htmlParser.fragment.fromHtml=function(l,k,f){function d(a){var b;if(0<t.length)for(var d=0;d<t.length;d++){var e=t[d],g=e.name,c=CKEDITOR.dtd[g],f=w.name&&CKEDITOR.dtd[w.name];f&&!f[g]||a&&c&&!c[a]&&CKEDITOR.dtd[a]?g==w.name&&(n(w,w.parent,1),d--):(b||(m(),b=1),e=e.clone(),e.parent=w,w=e,t.splice(d,1),d--)}}function m(){for(;r.length;)n(r.shift(),w)}function g(a){if(a._.isBlockLike&&"pre"!=a.name&&"textarea"!=a.name){var b=
a.children.length,d=a.children[b-1],e;d&&d.type==CKEDITOR.NODE_TEXT&&((e=CKEDITOR.tools.rtrim(d.value))?d.value=e:a.children.length=b-1)}}function n(b,d,e){d=d||w||v;var c=w;void 0===b.previous&&(p(d,b)&&(w=d,y.onTagOpen(f,{}),b.returnPoint=d=w),g(b),a(b)&&!b.children.length||d.add(b),"pre"==b.name&&(u=!1),"textarea"==b.name&&(z=!1));b.returnPoint?(w=b.returnPoint,delete b.returnPoint):w=e?d:c}function p(a,b){if((a==v||"body"==a.name)&&f&&(!a.name||CKEDITOR.dtd[a.name][f])){var d,e;return(d=b.attributes&&
(e=b.attributes["data-cke-real-element-type"])?e:b.name)&&d in CKEDITOR.dtd.$inline&&!(d in CKEDITOR.dtd.head)&&!b.isOrphan||b.type==CKEDITOR.NODE_TEXT}}function q(a,b){return a in CKEDITOR.dtd.$listItem||a in CKEDITOR.dtd.$tableContent?a==b||"dt"==a&&"dd"==b||"dd"==a&&"dt"==b:!1}var y=new CKEDITOR.htmlParser,v=k instanceof CKEDITOR.htmlParser.element?k:"string"==typeof k?new CKEDITOR.htmlParser.element(k):new CKEDITOR.htmlParser.fragment,t=[],r=[],w=v,z="textarea"==v.name,u="pre"==v.name;y.onTagOpen=
function(g,f,h,k){f=new CKEDITOR.htmlParser.element(g,f);f.isUnknown&&h&&(f.isEmpty=!0);f.isOptionalClose=k;if(a(f))t.push(f);else{if("pre"==g)u=!0;else{if("br"==g&&u){w.add(new CKEDITOR.htmlParser.text("\n"));return}"textarea"==g&&(z=!0)}if("br"==g)r.push(f);else{for(;!(k=(h=w.name)?CKEDITOR.dtd[h]||(w._.isBlockLike?CKEDITOR.dtd.div:CKEDITOR.dtd.span):e,f.isUnknown||w.isUnknown||k[g]);)if(w.isOptionalClose)y.onTagClose(h);else if(g in b&&h in b)h=w.children,(h=h[h.length-1])&&"li"==h.name||n(h=new CKEDITOR.htmlParser.element("li"),
w),!f.returnPoint&&(f.returnPoint=w),w=h;else if(g in CKEDITOR.dtd.$listItem&&!q(g,h))y.onTagOpen("li"==g?"ul":"dl",{},0,1);else if(h in c&&!q(g,h))!f.returnPoint&&(f.returnPoint=w),w=w.parent;else if(h in CKEDITOR.dtd.$inline&&t.unshift(w),w.parent)n(w,w.parent,1);else{f.isOrphan=1;break}d(g);m();f.parent=w;f.isEmpty?n(f):w=f}}};y.onTagClose=function(a){for(var b=t.length-1;0<=b;b--)if(a==t[b].name){t.splice(b,1);return}for(var d=[],e=[],g=w;g!=v&&g.name!=a;)g._.isBlockLike||e.unshift(g),d.push(g),
g=g.returnPoint||g.parent;if(g!=v){for(b=0;b<d.length;b++){var c=d[b];n(c,c.parent)}w=g;g._.isBlockLike&&m();n(g,g.parent);g==w&&(w=w.parent);t=t.concat(e)}"body"==a&&(f=!1)};y.onText=function(a){if(!(w._.hasInlineStarted&&!r.length||u||z)&&(a=CKEDITOR.tools.ltrim(a),0===a.length))return;var b=w.name,g=b?CKEDITOR.dtd[b]||(w._.isBlockLike?CKEDITOR.dtd.div:CKEDITOR.dtd.span):e;if(!z&&!g["#"]&&b in c)y.onTagOpen(h[b]||""),y.onText(a);else{m();d();u||z||(a=a.replace(/[\t\r\n ]{2,}|[\t\r\n]/g," "));a=
new CKEDITOR.htmlParser.text(a);if(p(w,a))this.onTagOpen(f,{},0,1);w.add(a)}};y.onCDATA=function(a){w.add(new CKEDITOR.htmlParser.cdata(a))};y.onComment=function(a){m();d();w.add(new CKEDITOR.htmlParser.comment(a))};y.parse(l);for(m();w!=v;)n(w,w.parent,1);g(v);return v};CKEDITOR.htmlParser.fragment.prototype={type:CKEDITOR.NODE_DOCUMENT_FRAGMENT,add:function(a,b){isNaN(b)&&(b=this.children.length);var e=0<b?this.children[b-1]:null;if(e){if(a._.isBlockLike&&e.type==CKEDITOR.NODE_TEXT&&(e.value=CKEDITOR.tools.rtrim(e.value),
0===e.value.length)){this.children.pop();this.add(a);return}e.next=a}a.previous=e;a.parent=this;this.children.splice(b,0,a);this._.hasInlineStarted||(this._.hasInlineStarted=a.type==CKEDITOR.NODE_TEXT||a.type==CKEDITOR.NODE_ELEMENT&&!a._.isBlockLike)},filter:function(a,b){b=this.getFilterContext(b);a.onRoot(b,this);this.filterChildren(a,!1,b)},filterChildren:function(a,b,e){if(this.childrenFilteredBy!=a.id){e=this.getFilterContext(e);if(b&&!this.parent)a.onRoot(e,this);this.childrenFilteredBy=a.id;
for(b=0;b<this.children.length;b++)!1===this.children[b].filter(a,e)&&b--}},writeHtml:function(a,b){b&&this.filter(b);this.writeChildrenHtml(a)},writeChildrenHtml:function(a,b,e){var d=this.getFilterContext();if(e&&!this.parent&&b)b.onRoot(d,this);b&&this.filterChildren(b,!1,d);b=0;e=this.children;for(d=e.length;b<d;b++)e[b].writeHtml(a)},forEach:function(a,b,e){if(!(e||b&&this.type!=b))var d=a(this);if(!1!==d){e=this.children;for(var c=0;c<e.length;c++)d=e[c],d.type==CKEDITOR.NODE_ELEMENT?d.forEach(a,
b):b&&d.type!=b||a(d)}},getFilterContext:function(a){return a||{}}}}(),"use strict",function(){function a(){this.rules=[]}function c(b,e,c,l){var k,f;for(k in e)(f=b[k])||(f=b[k]=new a),f.add(e[k],c,l)}CKEDITOR.htmlParser.filter=CKEDITOR.tools.createClass({$:function(b){this.id=CKEDITOR.tools.getNextNumber();this.elementNameRules=new a;this.attributeNameRules=new a;this.elementsRules={};this.attributesRules={};this.textRules=new a;this.commentRules=new a;this.rootRules=new a;b&&this.addRules(b,10)},
proto:{addRules:function(a,e){var h;"number"==typeof e?h=e:e&&"priority"in e&&(h=e.priority);"number"!=typeof h&&(h=10);"object"!=typeof e&&(e={});a.elementNames&&this.elementNameRules.addMany(a.elementNames,h,e);a.attributeNames&&this.attributeNameRules.addMany(a.attributeNames,h,e);a.elements&&c(this.elementsRules,a.elements,h,e);a.attributes&&c(this.attributesRules,a.attributes,h,e);a.text&&this.textRules.add(a.text,h,e);a.comment&&this.commentRules.add(a.comment,h,e);a.root&&this.rootRules.add(a.root,
h,e)},applyTo:function(a){a.filter(this)},onElementName:function(a,e){return this.elementNameRules.execOnName(a,e)},onAttributeName:function(a,e){return this.attributeNameRules.execOnName(a,e)},onText:function(a,e,c){return this.textRules.exec(a,e,c)},onComment:function(a,e,c){return this.commentRules.exec(a,e,c)},onRoot:function(a,e){return this.rootRules.exec(a,e)},onElement:function(a,e){for(var c=[this.elementsRules["^"],this.elementsRules[e.name],this.elementsRules.$],l,k=0;3>k;k++)if(l=c[k]){l=
l.exec(a,e,this);if(!1===l)return null;if(l&&l!=e)return this.onNode(a,l);if(e.parent&&!e.name)break}return e},onNode:function(a,e){var c=e.type;return c==CKEDITOR.NODE_ELEMENT?this.onElement(a,e):c==CKEDITOR.NODE_TEXT?new CKEDITOR.htmlParser.text(this.onText(a,e.value)):c==CKEDITOR.NODE_COMMENT?new CKEDITOR.htmlParser.comment(this.onComment(a,e.value)):null},onAttribute:function(a,e,c,l){return(c=this.attributesRules[c])?c.exec(a,l,e,this):l}}});CKEDITOR.htmlParser.filterRulesGroup=a;a.prototype=
{add:function(a,e,c){this.rules.splice(this.findIndex(e),0,{value:a,priority:e,options:c})},addMany:function(a,e,c){for(var l=[this.findIndex(e),0],k=0,f=a.length;k<f;k++)l.push({value:a[k],priority:e,options:c});this.rules.splice.apply(this.rules,l)},findIndex:function(a){for(var e=this.rules,c=e.length-1;0<=c&&a<e[c].priority;)c--;return c+1},exec:function(a,e){var c=e instanceof CKEDITOR.htmlParser.node||e instanceof CKEDITOR.htmlParser.fragment,l=Array.prototype.slice.call(arguments,1),k=this.rules,
f=k.length,d,m,g,n;for(n=0;n<f;n++)if(c&&(d=e.type,m=e.name),g=k[n],!(a.nonEditable&&!g.options.applyToAll||a.nestedEditable&&g.options.excludeNestedEditable)){g=g.value.apply(null,l);if(!1===g||c&&g&&(g.name!=m||g.type!=d))return g;null!=g&&(l[0]=e=g)}return e},execOnName:function(a,e){for(var c=0,l=this.rules,k=l.length,f;e&&c<k;c++)f=l[c],a.nonEditable&&!f.options.applyToAll||a.nestedEditable&&f.options.excludeNestedEditable||(e=e.replace(f.value[0],f.value[1]));return e}}}(),function(){function a(a,
d){function g(a){return a||CKEDITOR.env.needsNbspFiller?new CKEDITOR.htmlParser.text(" "):new CKEDITOR.htmlParser.element("br",{"data-cke-bogus":1})}function c(a,d){return function(c){if(c.type!=CKEDITOR.NODE_DOCUMENT_FRAGMENT){var h=[],m=b(c),k,u;if(m)for(f(m,1)&&h.push(m);m;)l(m)&&(k=e(m))&&f(k)&&((u=e(k))&&!l(u)?h.push(k):(g(n).insertAfter(k),k.remove())),m=m.previous;for(m=0;m<h.length;m++)h[m].remove();if(h=!a||!1!==("function"==typeof d?d(c):d))n||CKEDITOR.env.needsBrFiller||c.type!=CKEDITOR.NODE_DOCUMENT_FRAGMENT?
n||CKEDITOR.env.needsBrFiller||!(7<document.documentMode||c.name in CKEDITOR.dtd.tr||c.name in CKEDITOR.dtd.$listItem)?(h=b(c),h=!h||"form"==c.name&&"input"==h.name):h=!1:h=!1;h&&c.add(g(a))}}}function f(a,b){if((!n||CKEDITOR.env.needsBrFiller)&&a.type==CKEDITOR.NODE_ELEMENT&&"br"==a.name&&!a.attributes["data-cke-eol"])return!0;var d;return a.type==CKEDITOR.NODE_TEXT&&(d=a.value.match(t))&&(d.index&&((new CKEDITOR.htmlParser.text(a.value.substring(0,d.index))).insertBefore(a),a.value=d[0]),!CKEDITOR.env.needsBrFiller&&
n&&(!b||a.parent.name in F)||!n&&((d=a.previous)&&"br"==d.name||!d||l(d)))?!0:!1}var m={elements:{}},n="html"==d,F=CKEDITOR.tools.extend({},u),J;for(J in F)"#"in w[J]||delete F[J];for(J in F)m.elements[J]=c(n,a.config.fillEmptyBlocks);m.root=c(n,!1);m.elements.br=function(a){return function(b){if(b.parent.type!=CKEDITOR.NODE_DOCUMENT_FRAGMENT){var d=b.attributes;if("data-cke-bogus"in d||"data-cke-eol"in d)delete d["data-cke-bogus"];else{for(d=b.next;d&&h(d);)d=d.next;var c=e(b);!d&&l(b.parent)?k(b.parent,
g(a)):l(d)&&c&&!l(c)&&g(a).insertBefore(d)}}}}(n);return m}function c(a,b){return a!=CKEDITOR.ENTER_BR&&!1!==b?a==CKEDITOR.ENTER_DIV?"div":"p":!1}function b(a){for(a=a.children[a.children.length-1];a&&h(a);)a=a.previous;return a}function e(a){for(a=a.previous;a&&h(a);)a=a.previous;return a}function h(a){return a.type==CKEDITOR.NODE_TEXT&&!CKEDITOR.tools.trim(a.value)||a.type==CKEDITOR.NODE_ELEMENT&&a.attributes["data-cke-bookmark"]}function l(a){return a&&(a.type==CKEDITOR.NODE_ELEMENT&&a.name in
u||a.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT)}function k(a,b){var d=a.children[a.children.length-1];a.children.push(b);b.parent=a;d&&(d.next=b,b.previous=d)}function f(a){a=a.attributes;"false"!=a.contenteditable&&(a["data-cke-editable"]=a.contenteditable?"true":1);a.contenteditable="false"}function d(a){a=a.attributes;switch(a["data-cke-editable"]){case "true":a.contenteditable="true";break;case "1":delete a.contenteditable}}function m(a){return a.replace(D,function(a,b,d){return"\x3c"+b+d.replace(H,
function(a,b){return E.test(b)&&-1==d.indexOf("data-cke-saved-"+b)?" data-cke-saved-"+a+" data-cke-"+CKEDITOR.rnd+"-"+a:a})+"\x3e"})}function g(a,b){return a.replace(b,function(a,b,d){0===a.indexOf("\x3ctextarea")&&(a=b+q(d).replace(/</g,"\x26lt;").replace(/>/g,"\x26gt;")+"\x3c/textarea\x3e");return"\x3ccke:encoded\x3e"+encodeURIComponent(a)+"\x3c/cke:encoded\x3e"})}function n(a){return a.replace(K,function(a,b){return decodeURIComponent(b)})}function p(a){return a.replace(/\x3c!--(?!{cke_protected})[\s\S]+?--\x3e/g,
function(a){return"\x3c!--"+r+"{C}"+encodeURIComponent(a).replace(/--/g,"%2D%2D")+"--\x3e"})}function q(a){return a.replace(/\x3c!--\{cke_protected\}\{C\}([\s\S]+?)--\x3e/g,function(a,b){return decodeURIComponent(b)})}function y(a,b){var d=b._.dataStore;return a.replace(/\x3c!--\{cke_protected\}([\s\S]+?)--\x3e/g,function(a,b){return decodeURIComponent(b)}).replace(/\{cke_protected_(\d+)\}/g,function(a,b){return d&&d[b]||""})}function v(a,b){var d=[],e=b.config.protectedSource,g=b._.dataStore||(b._.dataStore=
{id:1}),c=/<\!--\{cke_temp(comment)?\}(\d*?)--\x3e/g,e=[/<script[\s\S]*?(<\/script>|$)/gi,/<noscript[\s\S]*?<\/noscript>/gi,/<meta[\s\S]*?\/?>/gi].concat(e);a=a.replace(/\x3c!--[\s\S]*?--\x3e/g,function(a){return"\x3c!--{cke_tempcomment}"+(d.push(a)-1)+"--\x3e"});for(var f=0;f<e.length;f++)a=a.replace(e[f],function(a){a=a.replace(c,function(a,b,e){return d[e]});return/cke_temp(comment)?/.test(a)?a:"\x3c!--{cke_temp}"+(d.push(a)-1)+"--\x3e"});a=a.replace(c,function(a,b,e){return"\x3c!--"+r+(b?"{C}":
"")+encodeURIComponent(d[e]).replace(/--/g,"%2D%2D")+"--\x3e"});a=a.replace(/<\w+(?:\s+(?:(?:[^\s=>]+\s*=\s*(?:[^'"\s>]+|'[^']*'|"[^"]*"))|[^\s=\/>]+))+\s*\/?>/g,function(a){return a.replace(/\x3c!--\{cke_protected\}([^>]*)--\x3e/g,function(a,b){g[g.id]=decodeURIComponent(b);return"{cke_protected_"+g.id++ +"}"})});return a=a.replace(/<(title|iframe|textarea)([^>]*)>([\s\S]*?)<\/\1>/g,function(a,d,e,g){return"\x3c"+d+e+"\x3e"+y(q(g),b)+"\x3c/"+d+"\x3e"})}CKEDITOR.htmlDataProcessor=function(b){var d,
e,f=this;this.editor=b;this.dataFilter=d=new CKEDITOR.htmlParser.filter;this.htmlFilter=e=new CKEDITOR.htmlParser.filter;this.writer=new CKEDITOR.htmlParser.basicWriter;d.addRules(B);d.addRules(C,{applyToAll:!0});d.addRules(a(b,"data"),{applyToAll:!0});e.addRules(x);e.addRules(A,{applyToAll:!0});e.addRules(a(b,"html"),{applyToAll:!0});b.on("toHtml",function(a){a=a.data;var d=a.dataValue,e,d=v(d,b),d=g(d,G),d=m(d),d=g(d,I),d=d.replace(J,"$1cke:$2"),d=d.replace(S,"\x3ccke:$1$2\x3e\x3c/cke:$1\x3e"),
d=d.replace(/(<pre\b[^>]*>)(\r\n|\n)/g,"$1$2$2"),d=d.replace(/([^a-z0-9<\-])(on\w{3,})(?!>)/gi,"$1data-cke-"+CKEDITOR.rnd+"-$2");e=a.context||b.editable().getName();var f;CKEDITOR.env.ie&&9>CKEDITOR.env.version&&"pre"==e&&(e="div",d="\x3cpre\x3e"+d+"\x3c/pre\x3e",f=1);e=b.document.createElement(e);e.setHtml("a"+d);d=e.getHtml().substr(1);d=d.replace(new RegExp("data-cke-"+CKEDITOR.rnd+"-","ig"),"");f&&(d=d.replace(/^<pre>|<\/pre>$/gi,""));d=d.replace(F,"$1$2");d=n(d);d=q(d);e=!1===a.fixForBody?!1:
c(a.enterMode,b.config.autoParagraph);d=CKEDITOR.htmlParser.fragment.fromHtml(d,a.context,e);e&&(f=d,!f.children.length&&CKEDITOR.dtd[f.name][e]&&(e=new CKEDITOR.htmlParser.element(e),f.add(e)));a.dataValue=d},null,null,5);b.on("toHtml",function(a){a.data.filter.applyTo(a.data.dataValue,!0,a.data.dontFilter,a.data.enterMode)&&b.fire("dataFiltered")},null,null,6);b.on("toHtml",function(a){a.data.dataValue.filterChildren(f.dataFilter,!0)},null,null,10);b.on("toHtml",function(a){a=a.data;var b=a.dataValue,
d=new CKEDITOR.htmlParser.basicWriter;b.writeChildrenHtml(d);b=d.getHtml(!0);a.dataValue=p(b)},null,null,15);b.on("toDataFormat",function(a){var d=a.data.dataValue;a.data.enterMode!=CKEDITOR.ENTER_BR&&(d=d.replace(/^<br *\/?>/i,""));a.data.dataValue=CKEDITOR.htmlParser.fragment.fromHtml(d,a.data.context,c(a.data.enterMode,b.config.autoParagraph))},null,null,5);b.on("toDataFormat",function(a){a.data.dataValue.filterChildren(f.htmlFilter,!0)},null,null,10);b.on("toDataFormat",function(a){a.data.filter.applyTo(a.data.dataValue,
!1,!0)},null,null,11);b.on("toDataFormat",function(a){var d=a.data.dataValue,e=f.writer;e.reset();d.writeChildrenHtml(e);d=e.getHtml(!0);d=q(d);d=y(d,b);a.data.dataValue=d},null,null,15)};CKEDITOR.htmlDataProcessor.prototype={toHtml:function(a,b,d,e){var g=this.editor,c,f,h,m;b&&"object"==typeof b?(c=b.context,d=b.fixForBody,e=b.dontFilter,f=b.filter,h=b.enterMode,m=b.protectedWhitespaces):c=b;c||null===c||(c=g.editable().getName());return g.fire("toHtml",{dataValue:a,context:c,fixForBody:d,dontFilter:e,
filter:f||g.filter,enterMode:h||g.enterMode,protectedWhitespaces:m}).dataValue},toDataFormat:function(a,b){var d,e,g;b&&(d=b.context,e=b.filter,g=b.enterMode);d||null===d||(d=this.editor.editable().getName());return this.editor.fire("toDataFormat",{dataValue:a,filter:e||this.editor.filter,context:d,enterMode:g||this.editor.enterMode}).dataValue}};var t=/(?:&nbsp;|\xa0)$/,r="{cke_protected}",w=CKEDITOR.dtd,z="caption colgroup col thead tfoot tbody".split(" "),u=CKEDITOR.tools.extend({},w.$blockLimit,
w.$block),B={elements:{input:f,textarea:f}},C={attributeNames:[[/^on/,"data-cke-pa-on"],[/^srcdoc/,"data-cke-pa-srcdoc"],[/^data-cke-expando$/,""]],elements:{iframe:function(a){if(a.attributes&&a.attributes.src){var b=a.attributes.src.toLowerCase().replace(/[^a-z]/gi,"");if(0===b.indexOf("javascript")||0===b.indexOf("data"))a.attributes["data-cke-pa-src"]=a.attributes.src,delete a.attributes.src}}}},x={elements:{embed:function(a){var b=a.parent;if(b&&"object"==b.name){var d=b.attributes.width,b=b.attributes.height;
d&&(a.attributes.width=d);b&&(a.attributes.height=b)}},a:function(a){var b=a.attributes;if(!(a.children.length||b.name||b.id||a.attributes["data-cke-saved-name"]))return!1}}},A={elementNames:[[/^cke:/,""],[/^\?xml:namespace$/,""]],attributeNames:[[/^data-cke-(saved|pa)-/,""],[/^data-cke-.*/,""],["hidefocus",""]],elements:{$:function(a){var b=a.attributes;if(b){if(b["data-cke-temp"])return!1;for(var d=["name","href","src"],e,g=0;g<d.length;g++)e="data-cke-saved-"+d[g],e in b&&delete b[d[g]]}return a},
table:function(a){a.children.slice(0).sort(function(a,b){var d,e;a.type==CKEDITOR.NODE_ELEMENT&&b.type==a.type&&(d=CKEDITOR.tools.indexOf(z,a.name),e=CKEDITOR.tools.indexOf(z,b.name));-1<d&&-1<e&&d!=e||(d=a.parent?a.getIndex():-1,e=b.parent?b.getIndex():-1);return d>e?1:-1})},param:function(a){a.children=[];a.isEmpty=!0;return a},span:function(a){"Apple-style-span"==a.attributes["class"]&&delete a.name},html:function(a){delete a.attributes.contenteditable;delete a.attributes["class"]},body:function(a){delete a.attributes.spellcheck;
delete a.attributes.contenteditable},style:function(a){var b=a.children[0];b&&b.value&&(b.value=CKEDITOR.tools.trim(b.value));a.attributes.type||(a.attributes.type="text/css")},title:function(a){var b=a.children[0];!b&&k(a,b=new CKEDITOR.htmlParser.text);b.value=a.attributes["data-cke-title"]||""},input:d,textarea:d},attributes:{"class":function(a){return CKEDITOR.tools.ltrim(a.replace(/(?:^|\s+)cke_[^\s]*/g,""))||!1}}};CKEDITOR.env.ie&&(A.attributes.style=function(a){return a.replace(/(^|;)([^\:]+)/g,
function(a){return a.toLowerCase()})});var D=/<(a|area|img|input|source)\b([^>]*)>/gi,H=/([\w-:]+)\s*=\s*(?:(?:"[^"]*")|(?:'[^']*')|(?:[^ "'>]+))/gi,E=/^(href|src|name)$/i,I=/(?:<style(?=[ >])[^>]*>[\s\S]*?<\/style>)|(?:<(:?link|meta|base)[^>]*>)/gi,G=/(<textarea(?=[ >])[^>]*>)([\s\S]*?)(?:<\/textarea>)/gi,K=/<cke:encoded>([^<]*)<\/cke:encoded>/gi,J=/(<\/?)((?:object|embed|param|html|body|head|title)[^>]*>)/gi,F=/(<\/?)cke:((?:html|body|head|title)[^>]*>)/gi,S=/<cke:(param|embed)([^>]*?)\/?>(?!\s*<\/cke:\1)/gi}(),
"use strict",CKEDITOR.htmlParser.element=function(a,c){this.name=a;this.attributes=c||{};this.children=[];var b=a||"",e=b.match(/^cke:(.*)/);e&&(b=e[1]);b=!!(CKEDITOR.dtd.$nonBodyContent[b]||CKEDITOR.dtd.$block[b]||CKEDITOR.dtd.$listItem[b]||CKEDITOR.dtd.$tableContent[b]||CKEDITOR.dtd.$nonEditable[b]||"br"==b);this.isEmpty=!!CKEDITOR.dtd.$empty[a];this.isUnknown=!CKEDITOR.dtd[a];this._={isBlockLike:b,hasInlineStarted:this.isEmpty||!b}},CKEDITOR.htmlParser.cssStyle=function(a){var c={};((a instanceof
CKEDITOR.htmlParser.element?a.attributes.style:a)||"").replace(/&quot;/g,'"').replace(/\s*([^ :;]+)\s*:\s*([^;]+)\s*(?=;|$)/g,function(a,e,h){"font-family"==e&&(h=h.replace(/["']/g,""));c[e.toLowerCase()]=h});return{rules:c,populate:function(a){var e=this.toString();e&&(a instanceof CKEDITOR.dom.element?a.setAttribute("style",e):a instanceof CKEDITOR.htmlParser.element?a.attributes.style=e:a.style=e)},toString:function(){var a=[],e;for(e in c)c[e]&&a.push(e,":",c[e],";");return a.join("")}}},function(){function a(a){return function(b){return b.type==
CKEDITOR.NODE_ELEMENT&&("string"==typeof a?b.name==a:b.name in a)}}var c=function(a,b){a=a[0];b=b[0];return a<b?-1:a>b?1:0},b=CKEDITOR.htmlParser.fragment.prototype;CKEDITOR.htmlParser.element.prototype=CKEDITOR.tools.extend(new CKEDITOR.htmlParser.node,{type:CKEDITOR.NODE_ELEMENT,add:b.add,clone:function(){return new CKEDITOR.htmlParser.element(this.name,this.attributes)},filter:function(a,b){var c=this,k,f;b=c.getFilterContext(b);if(b.off)return!0;if(!c.parent)a.onRoot(b,c);for(;;){k=c.name;if(!(f=
a.onElementName(b,k)))return this.remove(),!1;c.name=f;if(!(c=a.onElement(b,c)))return this.remove(),!1;if(c!==this)return this.replaceWith(c),!1;if(c.name==k)break;if(c.type!=CKEDITOR.NODE_ELEMENT)return this.replaceWith(c),!1;if(!c.name)return this.replaceWithChildren(),!1}k=c.attributes;var d,m;for(d in k){for(f=k[d];;)if(m=a.onAttributeName(b,d))if(m!=d)delete k[d],d=m;else break;else{delete k[d];break}m&&(!1===(f=a.onAttribute(b,c,m,f))?delete k[m]:k[m]=f)}c.isEmpty||this.filterChildren(a,!1,
b);return!0},filterChildren:b.filterChildren,writeHtml:function(a,b){b&&this.filter(b);var l=this.name,k=[],f=this.attributes,d,m;a.openTag(l,f);for(d in f)k.push([d,f[d]]);a.sortAttributes&&k.sort(c);d=0;for(m=k.length;d<m;d++)f=k[d],a.attribute(f[0],f[1]);a.openTagClose(l,this.isEmpty);this.writeChildrenHtml(a);this.isEmpty||a.closeTag(l)},writeChildrenHtml:b.writeChildrenHtml,replaceWithChildren:function(){for(var a=this.children,b=a.length;b;)a[--b].insertAfter(this);this.remove()},forEach:b.forEach,
getFirst:function(b){if(!b)return this.children.length?this.children[0]:null;"function"!=typeof b&&(b=a(b));for(var c=0,l=this.children.length;c<l;++c)if(b(this.children[c]))return this.children[c];return null},getHtml:function(){var a=new CKEDITOR.htmlParser.basicWriter;this.writeChildrenHtml(a);return a.getHtml()},setHtml:function(a){a=this.children=CKEDITOR.htmlParser.fragment.fromHtml(a).children;for(var b=0,c=a.length;b<c;++b)a[b].parent=this},getOuterHtml:function(){var a=new CKEDITOR.htmlParser.basicWriter;
this.writeHtml(a);return a.getHtml()},split:function(a){for(var b=this.children.splice(a,this.children.length-a),c=this.clone(),k=0;k<b.length;++k)b[k].parent=c;c.children=b;b[0]&&(b[0].previous=null);0<a&&(this.children[a-1].next=null);this.parent.add(c,this.getIndex()+1);return c},find:function(a,b){void 0===b&&(b=!1);var c=[],k;for(k=0;k<this.children.length;k++){var f=this.children[k];"function"==typeof a&&a(f)?c.push(f):"string"==typeof a&&f.name===a&&c.push(f);b&&f.find&&(c=c.concat(f.find(a,
b)))}return c},addClass:function(a){if(!this.hasClass(a)){var b=this.attributes["class"]||"";this.attributes["class"]=b+(b?" ":"")+a}},removeClass:function(a){var b=this.attributes["class"];b&&((b=CKEDITOR.tools.trim(b.replace(new RegExp("(?:\\s+|^)"+a+"(?:\\s+|$)")," ")))?this.attributes["class"]=b:delete this.attributes["class"])},hasClass:function(a){var b=this.attributes["class"];return b?(new RegExp("(?:^|\\s)"+a+"(?\x3d\\s|$)")).test(b):!1},getFilterContext:function(a){var b=[];a||(a={off:!1,
nonEditable:!1,nestedEditable:!1});a.off||"off"!=this.attributes["data-cke-processor"]||b.push("off",!0);a.nonEditable||"false"!=this.attributes.contenteditable?a.nonEditable&&!a.nestedEditable&&"true"==this.attributes.contenteditable&&b.push("nestedEditable",!0):b.push("nonEditable",!0);if(b.length){a=CKEDITOR.tools.copy(a);for(var c=0;c<b.length;c+=2)a[b[c]]=b[c+1]}return a}},!0)}(),function(){var a=/{([^}]+)}/g;CKEDITOR.template=function(a){this.source=String(a)};CKEDITOR.template.prototype.output=
function(c,b){var e=this.source.replace(a,function(a,b){return void 0!==c[b]?c[b]:a});return b?b.push(e):e}}(),delete CKEDITOR.loadFullCore,CKEDITOR.instances={},CKEDITOR.document=new CKEDITOR.dom.document(document),CKEDITOR.add=function(a){CKEDITOR.instances[a.name]=a;a.on("focus",function(){CKEDITOR.currentInstance!=a&&(CKEDITOR.currentInstance=a,CKEDITOR.fire("currentInstance"))});a.on("blur",function(){CKEDITOR.currentInstance==a&&(CKEDITOR.currentInstance=null,CKEDITOR.fire("currentInstance"))});
CKEDITOR.fire("instance",null,a)},CKEDITOR.remove=function(a){delete CKEDITOR.instances[a.name]},function(){var a={};CKEDITOR.addTemplate=function(c,b){var e=a[c];if(e)return e;e={name:c,source:b};CKEDITOR.fire("template",e);return a[c]=new CKEDITOR.template(e.source)};CKEDITOR.getTemplate=function(c){return a[c]}}(),function(){var a=[];CKEDITOR.addCss=function(c){a.push(c)};CKEDITOR.getCss=function(){return a.join("\n")}}(),CKEDITOR.on("instanceDestroyed",function(){CKEDITOR.tools.isEmpty(this.instances)&&
CKEDITOR.fire("reset")}),CKEDITOR.TRISTATE_ON=1,CKEDITOR.TRISTATE_OFF=2,CKEDITOR.TRISTATE_DISABLED=0,function(){CKEDITOR.inline=function(a,c){if(!CKEDITOR.env.isCompatible)return null;a=CKEDITOR.dom.element.get(a);if(a.getEditor())throw'The editor instance "'+a.getEditor().name+'" is already attached to the provided element.';var b=new CKEDITOR.editor(c,a,CKEDITOR.ELEMENT_MODE_INLINE),e=a.is("textarea")?a:null;e?(b.setData(e.getValue(),null,!0),a=CKEDITOR.dom.element.createFromHtml('\x3cdiv contenteditable\x3d"'+
!!b.readOnly+'" class\x3d"cke_textarea_inline"\x3e'+e.getValue()+"\x3c/div\x3e",CKEDITOR.document),a.insertAfter(e),e.hide(),e.$.form&&b._attachToForm()):b.setData(a.getHtml(),null,!0);b.on("loaded",function(){b.fire("uiReady");b.editable(a);b.container=a;b.ui.contentsElement=a;b.setData(b.getData(1));b.resetDirty();b.fire("contentDom");b.mode="wysiwyg";b.fire("mode");b.status="ready";b.fireOnce("instanceReady");CKEDITOR.fire("instanceReady",null,b)},null,null,1E4);b.on("destroy",function(){e&&(b.container.clearCustomData(),
b.container.remove(),e.show());b.element.clearCustomData();delete b.element});return b};CKEDITOR.inlineAll=function(){var a,c,b;for(b in CKEDITOR.dtd.$editable)for(var e=CKEDITOR.document.getElementsByTag(b),h=0,l=e.count();h<l;h++)a=e.getItem(h),"true"==a.getAttribute("contenteditable")&&(c={element:a,config:{}},!1!==CKEDITOR.fire("inline",c)&&CKEDITOR.inline(a,c.config))};CKEDITOR.domReady(function(){!CKEDITOR.disableAutoInline&&CKEDITOR.inlineAll()})}(),CKEDITOR.replaceClass="ckeditor",function(){function a(a,
h,l,k){if(!CKEDITOR.env.isCompatible)return null;a=CKEDITOR.dom.element.get(a);if(a.getEditor())throw'The editor instance "'+a.getEditor().name+'" is already attached to the provided element.';var f=new CKEDITOR.editor(h,a,k);k==CKEDITOR.ELEMENT_MODE_REPLACE&&(a.setStyle("visibility","hidden"),f._.required=a.hasAttribute("required"),a.removeAttribute("required"));l&&f.setData(l,null,!0);f.on("loaded",function(){b(f);k==CKEDITOR.ELEMENT_MODE_REPLACE&&f.config.autoUpdateElement&&a.$.form&&f._attachToForm();
f.setMode(f.config.startupMode,function(){f.resetDirty();f.status="ready";f.fireOnce("instanceReady");CKEDITOR.fire("instanceReady",null,f)})});f.on("destroy",c);return f}function c(){var a=this.container,b=this.element;a&&(a.clearCustomData(),a.remove());b&&(b.clearCustomData(),this.elementMode==CKEDITOR.ELEMENT_MODE_REPLACE&&(b.show(),this._.required&&b.setAttribute("required","required")),delete this.element)}function b(a){var b=a.name,c=a.element,k=a.elementMode,f=a.fire("uiSpace",{space:"top",
html:""}).html,d=a.fire("uiSpace",{space:"bottom",html:""}).html,m=new CKEDITOR.template('\x3c{outerEl} id\x3d"cke_{name}" class\x3d"{id} cke cke_reset cke_chrome cke_editor_{name} cke_{langDir} '+CKEDITOR.env.cssClass+'"  dir\x3d"{langDir}" lang\x3d"{langCode}" role\x3d"application"'+(a.title?' aria-labelledby\x3d"cke_{name}_arialbl"':"")+"\x3e"+(a.title?'\x3cspan id\x3d"cke_{name}_arialbl" class\x3d"cke_voice_label"\x3e{voiceLabel}\x3c/span\x3e':"")+'\x3c{outerEl} class\x3d"cke_inner cke_reset" role\x3d"presentation"\x3e{topHtml}\x3c{outerEl} id\x3d"{contentId}" class\x3d"cke_contents cke_reset" role\x3d"presentation"\x3e\x3c/{outerEl}\x3e{bottomHtml}\x3c/{outerEl}\x3e\x3c/{outerEl}\x3e'),
b=CKEDITOR.dom.element.createFromHtml(m.output({id:a.id,name:b,langDir:a.lang.dir,langCode:a.langCode,voiceLabel:a.title,topHtml:f?'\x3cspan id\x3d"'+a.ui.spaceId("top")+'" class\x3d"cke_top cke_reset_all" role\x3d"presentation" style\x3d"height:auto"\x3e'+f+"\x3c/span\x3e":"",contentId:a.ui.spaceId("contents"),bottomHtml:d?'\x3cspan id\x3d"'+a.ui.spaceId("bottom")+'" class\x3d"cke_bottom cke_reset_all" role\x3d"presentation"\x3e'+d+"\x3c/span\x3e":"",outerEl:CKEDITOR.env.ie?"span":"div"}));k==CKEDITOR.ELEMENT_MODE_REPLACE?
(c.hide(),b.insertAfter(c)):c.append(b);a.container=b;a.ui.contentsElement=a.ui.space("contents");f&&a.ui.space("top").unselectable();d&&a.ui.space("bottom").unselectable();c=a.config.width;k=a.config.height;c&&b.setStyle("width",CKEDITOR.tools.cssLength(c));k&&a.ui.space("contents").setStyle("height",CKEDITOR.tools.cssLength(k));b.disableContextMenu();CKEDITOR.env.webkit&&b.on("focus",function(){a.focus()});a.fireOnce("uiReady")}CKEDITOR.replace=function(b,c){return a(b,c,null,CKEDITOR.ELEMENT_MODE_REPLACE)};
CKEDITOR.appendTo=function(b,c,l){return a(b,c,l,CKEDITOR.ELEMENT_MODE_APPENDTO)};CKEDITOR.replaceAll=function(){for(var a=document.getElementsByTagName("textarea"),b=0;b<a.length;b++){var c=null,k=a[b];if(k.name||k.id){if("string"==typeof arguments[0]){if(!(new RegExp("(?:^|\\s)"+arguments[0]+"(?:$|\\s)")).test(k.className))continue}else if("function"==typeof arguments[0]&&(c={},!1===arguments[0](k,c)))continue;this.replace(k,c)}}};CKEDITOR.editor.prototype.addMode=function(a,b){(this._.modes||(this._.modes=
{}))[a]=b};CKEDITOR.editor.prototype.setMode=function(a,b){var c=this,k=this._.modes;if(a!=c.mode&&k&&k[a]){c.fire("beforeSetMode",a);if(c.mode){var f=c.checkDirty(),k=c._.previousModeData,d,m=0;c.fire("beforeModeUnload");c.editable(0);c._.previousMode=c.mode;c._.previousModeData=d=c.getData(1);"source"==c.mode&&k==d&&(c.fire("lockSnapshot",{forceUpdate:!0}),m=1);c.ui.space("contents").setHtml("");c.mode=""}else c._.previousModeData=c.getData(1);this._.modes[a](function(){c.mode=a;void 0!==f&&!f&&
c.resetDirty();m?c.fire("unlockSnapshot"):"wysiwyg"==a&&c.fire("saveSnapshot");setTimeout(function(){c.fire("mode");b&&b.call(c)},0)})}};CKEDITOR.editor.prototype.resize=function(a,b,c,k){var f=this.container,d=this.ui.space("contents"),m=CKEDITOR.env.webkit&&this.document&&this.document.getWindow().$.frameElement;k=k?this.container.getFirst(function(a){return a.type==CKEDITOR.NODE_ELEMENT&&a.hasClass("cke_inner")}):f;k.setSize("width",a,!0);m&&(m.style.width="1%");var g=(k.$.offsetHeight||0)-(d.$.clientHeight||
0),f=Math.max(b-(c?0:g),0);b=c?b+g:b;d.setStyle("height",f+"px");m&&(m.style.width="100%");this.fire("resize",{outerHeight:b,contentsHeight:f,outerWidth:a||k.getSize("width")})};CKEDITOR.editor.prototype.getResizable=function(a){return a?this.ui.space("contents"):this.container};CKEDITOR.domReady(function(){CKEDITOR.replaceClass&&CKEDITOR.replaceAll(CKEDITOR.replaceClass)})}(),CKEDITOR.config.startupMode="wysiwyg",function(){function a(a){var b=a.editor,d=a.data.path,g=d.blockLimit,f=a.data.selection,
m=f.getRanges()[0],h;if(CKEDITOR.env.gecko||CKEDITOR.env.ie&&CKEDITOR.env.needsBrFiller)if(f=c(f,d))f.appendBogus(),h=CKEDITOR.env.ie;k(b,d.block,g)&&m.collapsed&&!m.getCommonAncestor().isReadOnly()&&(d=m.clone(),d.enlarge(CKEDITOR.ENLARGE_BLOCK_CONTENTS),g=new CKEDITOR.dom.walker(d),g.guard=function(a){return!e(a)||a.type==CKEDITOR.NODE_COMMENT||a.isReadOnly()},!g.checkForward()||d.checkStartOfBlock()&&d.checkEndOfBlock())&&(b=m.fixBlock(!0,b.activeEnterMode==CKEDITOR.ENTER_DIV?"div":"p"),CKEDITOR.env.needsBrFiller||
(b=b.getFirst(e))&&b.type==CKEDITOR.NODE_TEXT&&CKEDITOR.tools.trim(b.getText()).match(/^(?:&nbsp;|\xa0)$/)&&b.remove(),h=1,a.cancel());h&&m.select()}function c(a,b){if(a.isFake)return 0;var d=b.block||b.blockLimit,c=d&&d.getLast(e);if(!(!d||!d.isBlockBoundary()||c&&c.type==CKEDITOR.NODE_ELEMENT&&c.isBlockBoundary()||d.is("pre")||d.getBogus()))return d}function b(a){var b=a.data.getTarget();b.is("input")&&(b=b.getAttribute("type"),"submit"!=b&&"reset"!=b||a.data.preventDefault())}function e(a){return g(a)&&
n(a)}function h(a,b){return function(d){var c=d.data.$.toElement||d.data.$.fromElement||d.data.$.relatedTarget;(c=c&&c.nodeType==CKEDITOR.NODE_ELEMENT?new CKEDITOR.dom.element(c):null)&&(b.equals(c)||b.contains(c))||a.call(this,d)}}function l(a){function b(a){return function(b,c){c&&b.type==CKEDITOR.NODE_ELEMENT&&b.is(g)&&(d=b);if(!(c||!e(b)||a&&q(b)))return!1}}var d,c=a.getRanges()[0];a=a.root;var g={table:1,ul:1,ol:1,dl:1};if(c.startPath().contains(g)){var f=c.clone();f.collapse(1);f.setStartAt(a,
CKEDITOR.POSITION_AFTER_START);a=new CKEDITOR.dom.walker(f);a.guard=b();a.checkBackward();if(d)return f=c.clone(),f.collapse(),f.setEndAt(d,CKEDITOR.POSITION_AFTER_END),a=new CKEDITOR.dom.walker(f),a.guard=b(!0),d=!1,a.checkForward(),d}return null}function k(a,b,d){return!1!==a.config.autoParagraph&&a.activeEnterMode!=CKEDITOR.ENTER_BR&&(a.editable().equals(d)&&!b||b&&"true"==b.getAttribute("contenteditable"))}function f(a){return a.activeEnterMode!=CKEDITOR.ENTER_BR&&!1!==a.config.autoParagraph?
a.activeEnterMode==CKEDITOR.ENTER_DIV?"div":"p":!1}function d(a){var b=a.editor;b.getSelection().scrollIntoView();setTimeout(function(){b.fire("saveSnapshot")},0)}function m(a,b,d){var c=a.getCommonAncestor(b);for(b=a=d?b:a;(a=a.getParent())&&!c.equals(a)&&1==a.getChildCount();)b=a;b.remove()}var g,n,p,q,y,v,t,r,w,z;CKEDITOR.editable=CKEDITOR.tools.createClass({base:CKEDITOR.dom.element,$:function(a,b){this.base(b.$||b);this.editor=a;this.status="unloaded";this.hasFocus=!1;this.setup()},proto:{focus:function(){var a;
if(CKEDITOR.env.webkit&&!this.hasFocus&&(a=this.editor._.previousActive||this.getDocument().getActive(),this.contains(a))){a.focus();return}CKEDITOR.env.edge&&14<CKEDITOR.env.version&&!this.hasFocus&&this.getDocument().equals(CKEDITOR.document)&&(this.editor._.previousScrollTop=this.$.scrollTop);try{if(!CKEDITOR.env.ie||CKEDITOR.env.edge&&14<CKEDITOR.env.version||!this.getDocument().equals(CKEDITOR.document))if(CKEDITOR.env.chrome){var b=this.$.scrollTop;this.$.focus();this.$.scrollTop=b}else this.$.focus();
else this.$.setActive()}catch(d){if(!CKEDITOR.env.ie)throw d;}CKEDITOR.env.safari&&!this.isInline()&&(a=CKEDITOR.document.getActive(),a.equals(this.getWindow().getFrame())||this.getWindow().focus())},on:function(a,b){var d=Array.prototype.slice.call(arguments,0);CKEDITOR.env.ie&&/^focus|blur$/.exec(a)&&(a="focus"==a?"focusin":"focusout",b=h(b,this),d[0]=a,d[1]=b);return CKEDITOR.dom.element.prototype.on.apply(this,d)},attachListener:function(a){!this._.listeners&&(this._.listeners=[]);var b=Array.prototype.slice.call(arguments,
1),b=a.on.apply(a,b);this._.listeners.push(b);return b},clearListeners:function(){var a=this._.listeners;try{for(;a.length;)a.pop().removeListener()}catch(b){}},restoreAttrs:function(){var a=this._.attrChanges,b,d;for(d in a)a.hasOwnProperty(d)&&(b=a[d],null!==b?this.setAttribute(d,b):this.removeAttribute(d))},attachClass:function(a){var b=this.getCustomData("classes");this.hasClass(a)||(!b&&(b=[]),b.push(a),this.setCustomData("classes",b),this.addClass(a))},changeAttr:function(a,b){var d=this.getAttribute(a);
b!==d&&(!this._.attrChanges&&(this._.attrChanges={}),a in this._.attrChanges||(this._.attrChanges[a]=d),this.setAttribute(a,b))},insertText:function(a){this.editor.focus();this.insertHtml(this.transformPlainTextToHtml(a),"text")},transformPlainTextToHtml:function(a){var b=this.editor.getSelection().getStartElement().hasAscendant("pre",!0)?CKEDITOR.ENTER_BR:this.editor.activeEnterMode;return CKEDITOR.tools.transformPlainTextToHtml(a,b)},insertHtml:function(a,b,c){var e=this.editor;e.focus();e.fire("saveSnapshot");
c||(c=e.getSelection().getRanges()[0]);v(this,b||"html",a,c);c.select();d(this);this.editor.fire("afterInsertHtml",{})},insertHtmlIntoRange:function(a,b,d){v(this,d||"html",a,b);this.editor.fire("afterInsertHtml",{intoRange:b})},insertElement:function(a,b){var c=this.editor;c.focus();c.fire("saveSnapshot");var g=c.activeEnterMode,c=c.getSelection(),f=a.getName(),f=CKEDITOR.dtd.$block[f];b||(b=c.getRanges()[0]);this.insertElementIntoRange(a,b)&&(b.moveToPosition(a,CKEDITOR.POSITION_AFTER_END),f&&((f=
a.getNext(function(a){return e(a)&&!q(a)}))&&f.type==CKEDITOR.NODE_ELEMENT&&f.is(CKEDITOR.dtd.$block)?f.getDtd()["#"]?b.moveToElementEditStart(f):b.moveToElementEditEnd(a):f||g==CKEDITOR.ENTER_BR||(f=b.fixBlock(!0,g==CKEDITOR.ENTER_DIV?"div":"p"),b.moveToElementEditStart(f))));c.selectRanges([b]);d(this)},insertElementIntoSelection:function(a){this.insertElement(a)},insertElementIntoRange:function(a,b){var d=this.editor,c=d.config.enterMode,e=a.getName(),g=CKEDITOR.dtd.$block[e];if(b.checkReadOnly())return!1;
b.deleteContents(1);b.startContainer.type==CKEDITOR.NODE_ELEMENT&&(b.startContainer.is({tr:1,table:1,tbody:1,thead:1,tfoot:1})?t(b):b.startContainer.is(CKEDITOR.dtd.$list)&&r(b));var f,m;if(g)for(;(f=b.getCommonAncestor(0,1))&&(m=CKEDITOR.dtd[f.getName()])&&(!m||!m[e]);)f.getName()in CKEDITOR.dtd.span?b.splitElement(f):b.checkStartOfBlock()&&b.checkEndOfBlock()?(b.setStartBefore(f),b.collapse(!0),f.remove()):b.splitBlock(c==CKEDITOR.ENTER_DIV?"div":"p",d.editable());b.insertNode(a);return!0},setData:function(a,
b){b||(a=this.editor.dataProcessor.toHtml(a));this.setHtml(a);this.fixInitialSelection();"unloaded"==this.status&&(this.status="ready");this.editor.fire("dataReady")},getData:function(a){var b=this.getHtml();a||(b=this.editor.dataProcessor.toDataFormat(b));return b},setReadOnly:function(a){this.setAttribute("contenteditable",!a)},detach:function(){this.removeClass("cke_editable");this.status="detached";var a=this.editor;this._.detach();delete a.document;delete a.window},isInline:function(){return this.getDocument().equals(CKEDITOR.document)},
fixInitialSelection:function(){function a(){var b=d.getDocument().$,c=b.getSelection(),e;a:if(c.anchorNode&&c.anchorNode==d.$)e=!0;else{if(CKEDITOR.env.webkit&&(e=d.getDocument().getActive())&&e.equals(d)&&!c.anchorNode){e=!0;break a}e=void 0}e&&(e=new CKEDITOR.dom.range(d),e.moveToElementEditStart(d),b=b.createRange(),b.setStart(e.startContainer.$,e.startOffset),b.collapse(!0),c.removeAllRanges(),c.addRange(b))}function b(){var a=d.getDocument().$,c=a.selection,e=d.getDocument().getActive();"None"==
c.type&&e.equals(d)&&(c=new CKEDITOR.dom.range(d),a=a.body.createTextRange(),c.moveToElementEditStart(d),c=c.startContainer,c.type!=CKEDITOR.NODE_ELEMENT&&(c=c.getParent()),a.moveToElementText(c.$),a.collapse(!0),a.select())}var d=this;if(CKEDITOR.env.ie&&(9>CKEDITOR.env.version||CKEDITOR.env.quirks))this.hasFocus&&(this.focus(),b());else if(this.hasFocus)this.focus(),a();else this.once("focus",function(){a()},null,null,-999)},getHtmlFromRange:function(a){if(a.collapsed)return new CKEDITOR.dom.documentFragment(a.document);
a={doc:this.getDocument(),range:a.clone()};w.eol.detect(a,this);w.bogus.exclude(a);w.cell.shrink(a);a.fragment=a.range.cloneContents();w.tree.rebuild(a,this);w.eol.fix(a,this);return new CKEDITOR.dom.documentFragment(a.fragment.$)},extractHtmlFromRange:function(a,b){var d=z,c={range:a,doc:a.document},e=this.getHtmlFromRange(a);if(a.collapsed)return a.optimize(),e;a.enlarge(CKEDITOR.ENLARGE_INLINE,1);d.table.detectPurge(c);c.bookmark=a.createBookmark();delete c.range;var g=this.editor.createRange();
g.moveToPosition(c.bookmark.startNode,CKEDITOR.POSITION_BEFORE_START);c.targetBookmark=g.createBookmark();d.list.detectMerge(c,this);d.table.detectRanges(c,this);d.block.detectMerge(c,this);c.tableContentsRanges?(d.table.deleteRanges(c),a.moveToBookmark(c.bookmark),c.range=a):(a.moveToBookmark(c.bookmark),c.range=a,a.extractContents(d.detectExtractMerge(c)));a.moveToBookmark(c.targetBookmark);a.optimize();d.fixUneditableRangePosition(a);d.list.merge(c,this);d.table.purge(c,this);d.block.merge(c,this);
if(b){d=a.startPath();if(c=a.checkStartOfBlock()&&a.checkEndOfBlock()&&d.block&&!a.root.equals(d.block)){a:{var c=d.block.getElementsByTag("span"),g=0,f;if(c)for(;f=c.getItem(g++);)if(!n(f)){c=!0;break a}c=!1}c=!c}c&&(a.moveToPosition(d.block,CKEDITOR.POSITION_BEFORE_START),d.block.remove())}else d.autoParagraph(this.editor,a),p(a.startContainer)&&a.startContainer.appendBogus();a.startContainer.mergeSiblings();return e},setup:function(){var a=this.editor;this.attachListener(a,"beforeGetData",function(){var b=
this.getData();this.is("textarea")||!1!==a.config.ignoreEmptyParagraph&&(b=b.replace(y,function(a,b){return b}));a.setData(b,null,1)},this);this.attachListener(a,"getSnapshot",function(a){a.data=this.getData(1)},this);this.attachListener(a,"afterSetData",function(){this.setData(a.getData(1))},this);this.attachListener(a,"loadSnapshot",function(a){this.setData(a.data,1)},this);this.attachListener(a,"beforeFocus",function(){var b=a.getSelection();(b=b&&b.getNative())&&"Control"==b.type||this.focus()},
this);this.attachListener(a,"insertHtml",function(a){this.insertHtml(a.data.dataValue,a.data.mode,a.data.range)},this);this.attachListener(a,"insertElement",function(a){this.insertElement(a.data)},this);this.attachListener(a,"insertText",function(a){this.insertText(a.data)},this);this.setReadOnly(a.readOnly);this.attachClass("cke_editable");a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?this.attachClass("cke_editable_inline"):a.elementMode!=CKEDITOR.ELEMENT_MODE_REPLACE&&a.elementMode!=CKEDITOR.ELEMENT_MODE_APPENDTO||
this.attachClass("cke_editable_themed");this.attachClass("cke_contents_"+a.config.contentsLangDirection);a.keystrokeHandler.blockedKeystrokes[8]=+a.readOnly;a.keystrokeHandler.attach(this);this.on("blur",function(){this.hasFocus=!1},null,null,-1);this.on("focus",function(){this.hasFocus=!0},null,null,-1);if(CKEDITOR.env.webkit)this.on("scroll",function(){a._.previousScrollTop=a.editable().$.scrollTop},null,null,-1);if(CKEDITOR.env.edge&&14<CKEDITOR.env.version){var d=function(){var b=a.editable();
null!=a._.previousScrollTop&&b.getDocument().equals(CKEDITOR.document)&&(b.$.scrollTop=a._.previousScrollTop,a._.previousScrollTop=null,this.removeListener("scroll",d))};this.on("scroll",d)}a.focusManager.add(this);this.equals(CKEDITOR.document.getActive())&&(this.hasFocus=!0,a.once("contentDom",function(){a.focusManager.focus(this)},this));this.isInline()&&this.changeAttr("tabindex",a.tabIndex);if(!this.is("textarea")){a.document=this.getDocument();a.window=this.getWindow();var c=a.document;this.changeAttr("spellcheck",
!a.config.disableNativeSpellChecker);var f=a.config.contentsLangDirection;this.getDirection(1)!=f&&this.changeAttr("dir",f);var h=CKEDITOR.getCss();if(h){var f=c.getHead(),k=f.getCustomData("stylesheet");k?h!=k.getText()&&(CKEDITOR.env.ie&&9>CKEDITOR.env.version?k.$.styleSheet.cssText=h:k.setText(h)):(h=c.appendStyleText(h),h=new CKEDITOR.dom.element(h.ownerNode||h.owningElement),f.setCustomData("stylesheet",h),h.data("cke-temp",1))}f=c.getCustomData("stylesheet_ref")||0;c.setCustomData("stylesheet_ref",
f+1);this.setCustomData("cke_includeReadonly",!a.config.disableReadonlyStyling);this.attachListener(this,"click",function(a){a=a.data;var b=(new CKEDITOR.dom.elementPath(a.getTarget(),this)).contains("a");b&&2!=a.$.button&&b.isReadOnly()&&a.preventDefault()});var n={8:1,46:1};this.attachListener(a,"key",function(b){if(a.readOnly)return!0;var d=b.data.domEvent.getKey(),c;b=a.getSelection();if(0!==b.getRanges().length){if(d in n){var e,f=b.getRanges()[0],m=f.startPath(),h,k,t,d=8==d;CKEDITOR.env.ie&&
11>CKEDITOR.env.version&&(e=b.getSelectedElement())||(e=l(b))?(a.fire("saveSnapshot"),f.moveToPosition(e,CKEDITOR.POSITION_BEFORE_START),e.remove(),f.select(),a.fire("saveSnapshot"),c=1):f.collapsed&&((h=m.block)&&(t=h[d?"getPrevious":"getNext"](g))&&t.type==CKEDITOR.NODE_ELEMENT&&t.is("table")&&f[d?"checkStartOfBlock":"checkEndOfBlock"]()?(a.fire("saveSnapshot"),f[d?"checkEndOfBlock":"checkStartOfBlock"]()&&h.remove(),f["moveToElementEdit"+(d?"End":"Start")](t),f.select(),a.fire("saveSnapshot"),
c=1):m.blockLimit&&m.blockLimit.is("td")&&(k=m.blockLimit.getAscendant("table"))&&f.checkBoundaryOfElement(k,d?CKEDITOR.START:CKEDITOR.END)&&(t=k[d?"getPrevious":"getNext"](g))?(a.fire("saveSnapshot"),f["moveToElementEdit"+(d?"End":"Start")](t),f.checkStartOfBlock()&&f.checkEndOfBlock()?t.remove():f.select(),a.fire("saveSnapshot"),c=1):(k=m.contains(["td","th","caption"]))&&f.checkBoundaryOfElement(k,d?CKEDITOR.START:CKEDITOR.END)&&(c=1))}return!c}});a.blockless&&CKEDITOR.env.ie&&CKEDITOR.env.needsBrFiller&&
this.attachListener(this,"keyup",function(b){b.data.getKeystroke()in n&&!this.getFirst(e)&&(this.appendBogus(),b=a.createRange(),b.moveToPosition(this,CKEDITOR.POSITION_AFTER_START),b.select())});this.attachListener(this,"dblclick",function(b){if(a.readOnly)return!1;b={element:b.data.getTarget()};a.fire("doubleclick",b)});CKEDITOR.env.ie&&this.attachListener(this,"click",b);CKEDITOR.env.ie&&!CKEDITOR.env.edge||this.attachListener(this,"mousedown",function(b){var d=b.data.getTarget();d.is("img","hr",
"input","textarea","select")&&!d.isReadOnly()&&(a.getSelection().selectElement(d),d.is("input","textarea","select")&&b.data.preventDefault())});CKEDITOR.env.edge&&this.attachListener(this,"mouseup",function(b){(b=b.data.getTarget())&&b.is("img")&&a.getSelection().selectElement(b)});CKEDITOR.env.gecko&&this.attachListener(this,"mouseup",function(b){if(2==b.data.$.button&&(b=b.data.getTarget(),!b.getOuterHtml().replace(y,""))){var d=a.createRange();d.moveToElementEditStart(b);d.select(!0)}});CKEDITOR.env.webkit&&
(this.attachListener(this,"click",function(a){a.data.getTarget().is("input","select")&&a.data.preventDefault()}),this.attachListener(this,"mouseup",function(a){a.data.getTarget().is("input","textarea")&&a.data.preventDefault()}));CKEDITOR.env.webkit&&this.attachListener(a,"key",function(b){if(a.readOnly)return!0;var d=b.data.domEvent.getKey();if(d in n&&(b=a.getSelection(),0!==b.getRanges().length)){var d=8==d,c=b.getRanges()[0];b=c.startPath();if(c.collapsed)a:{var e=b.block;if(e&&c[d?"checkStartOfBlock":
"checkEndOfBlock"]()&&c.moveToClosestEditablePosition(e,!d)&&c.collapsed){if(c.startContainer.type==CKEDITOR.NODE_ELEMENT){var g=c.startContainer.getChild(c.startOffset-(d?1:0));if(g&&g.type==CKEDITOR.NODE_ELEMENT&&g.is("hr")){a.fire("saveSnapshot");g.remove();b=!0;break a}}c=c.startPath().block;if(!c||c&&c.contains(e))b=void 0;else{a.fire("saveSnapshot");var f;(f=(d?c:e).getBogus())&&f.remove();f=a.getSelection();g=f.createBookmarks();(d?e:c).moveChildren(d?c:e,!1);b.lastElement.mergeSiblings();
m(e,c,!d);f.selectBookmarks(g);b=!0}}else b=!1}else d=c,f=b.block,c=d.endPath().block,f&&c&&!f.equals(c)?(a.fire("saveSnapshot"),(e=f.getBogus())&&e.remove(),d.enlarge(CKEDITOR.ENLARGE_INLINE),d.deleteContents(),c.getParent()&&(c.moveChildren(f,!1),b.lastElement.mergeSiblings(),m(f,c,!0)),d=a.getSelection().getRanges()[0],d.collapse(1),d.optimize(),""===d.startContainer.getHtml()&&d.startContainer.appendBogus(),d.select(),b=!0):b=!1;if(!b)return;a.getSelection().scrollIntoView();a.fire("saveSnapshot");
return!1}},this,null,100)}}},_:{detach:function(){this.editor.setData(this.editor.getData(),0,1);this.clearListeners();this.restoreAttrs();var a;if(a=this.removeCustomData("classes"))for(;a.length;)this.removeClass(a.pop());if(!this.is("textarea")){a=this.getDocument();var b=a.getHead();if(b.getCustomData("stylesheet")){var d=a.getCustomData("stylesheet_ref");--d?a.setCustomData("stylesheet_ref",d):(a.removeCustomData("stylesheet_ref"),b.removeCustomData("stylesheet").remove())}}this.editor.fire("contentDomUnload");
delete this.editor}}});CKEDITOR.editor.prototype.editable=function(a){var b=this._.editable;if(b&&a)return 0;arguments.length&&(b=this._.editable=a?a instanceof CKEDITOR.editable?a:new CKEDITOR.editable(this,a):(b&&b.detach(),null));return b};CKEDITOR.on("instanceLoaded",function(b){var d=b.editor;d.on("insertElement",function(a){a=a.data;a.type==CKEDITOR.NODE_ELEMENT&&(a.is("input")||a.is("textarea"))&&("false"!=a.getAttribute("contentEditable")&&a.data("cke-editable",a.hasAttribute("contenteditable")?
"true":"1"),a.setAttribute("contentEditable",!1))});d.on("selectionChange",function(b){if(!d.readOnly){var c=d.getSelection();c&&!c.isLocked&&(c=d.checkDirty(),d.fire("lockSnapshot"),a(b),d.fire("unlockSnapshot"),!c&&d.resetDirty())}})});CKEDITOR.on("instanceCreated",function(a){var b=a.editor;b.on("mode",function(){var a=b.editable();if(a&&a.isInline()){var d=b.title;a.changeAttr("role","textbox");a.changeAttr("aria-label",d);d&&a.changeAttr("title",d);var c=b.fire("ariaEditorHelpLabel",{}).label;
if(c&&(d=this.ui.space(this.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?"top":"contents"))){var e=CKEDITOR.tools.getNextId(),c=CKEDITOR.dom.element.createFromHtml('\x3cspan id\x3d"'+e+'" class\x3d"cke_voice_label"\x3e'+c+"\x3c/span\x3e");d.append(c);a.changeAttr("aria-describedby",e)}}})});CKEDITOR.addCss(".cke_editable{cursor:text}.cke_editable img,.cke_editable input,.cke_editable textarea{cursor:default}");g=CKEDITOR.dom.walker.whitespaces(!0);n=CKEDITOR.dom.walker.bookmark(!1,!0);p=CKEDITOR.dom.walker.empty();
q=CKEDITOR.dom.walker.bogus();y=/(^|<body\b[^>]*>)\s*<(p|div|address|h\d|center|pre)[^>]*>\s*(?:<br[^>]*>|&nbsp;|\u00A0|&#160;)?\s*(:?<\/\2>)?\s*(?=$|<\/body>)/gi;v=function(){function a(b){return b.type==CKEDITOR.NODE_ELEMENT}function b(d,c){var e,g,f,m,h=[],k=c.range.startContainer;e=c.range.startPath();for(var k=l[k.getName()],n=0,t=d.getChildren(),p=t.count(),r=-1,w=-1,D=0,x=e.contains(l.$list);n<p;++n)e=t.getItem(n),a(e)?(f=e.getName(),x&&f in CKEDITOR.dtd.$list?h=h.concat(b(e,c)):(m=!!k[f],
"br"!=f||!e.data("cke-eol")||n&&n!=p-1||(D=(g=n?h[n-1].node:t.getItem(n+1))&&(!a(g)||!g.is("br")),g=g&&a(g)&&l.$block[g.getName()]),-1!=r||m||(r=n),m||(w=n),h.push({isElement:1,isLineBreak:D,isBlock:e.isBlockBoundary(),hasBlockSibling:g,node:e,name:f,allowed:m}),g=D=0)):h.push({isElement:0,node:e,allowed:1});-1<r&&(h[r].firstNotAllowed=1);-1<w&&(h[w].lastNotAllowed=1);return h}function d(b,c){var e=[],g=b.getChildren(),f=g.count(),m,h=0,k=l[c],n=!b.is(l.$inline)||b.is("br");for(n&&e.push(" ");h<f;h++)m=
g.getItem(h),a(m)&&!m.is(k)?e=e.concat(d(m,c)):e.push(m);n&&e.push(" ");return e}function c(b){return a(b.startContainer)&&b.startContainer.getChild(b.startOffset-1)}function g(b){return b&&a(b)&&(b.is(l.$removeEmpty)||b.is("a")&&!b.isBlockBoundary())}function m(b,d,c,e){var g=b.clone(),f,h;g.setEndAt(d,CKEDITOR.POSITION_BEFORE_END);(f=(new CKEDITOR.dom.walker(g)).next())&&a(f)&&n[f.getName()]&&(h=f.getPrevious())&&a(h)&&!h.getParent().equals(b.startContainer)&&c.contains(h)&&e.contains(f)&&f.isIdentical(h)&&
(f.moveChildren(h),f.remove(),m(b,d,c,e))}function h(b,d){function c(b,d){if(d.isBlock&&d.isElement&&!d.node.is("br")&&a(b)&&b.is("br"))return b.remove(),1}var e=d.endContainer.getChild(d.endOffset),g=d.endContainer.getChild(d.endOffset-1);e&&c(e,b[b.length-1]);g&&c(g,b[0])&&(d.setEnd(d.endContainer,d.endOffset-1),d.collapse())}var l=CKEDITOR.dtd,n={p:1,div:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1,ul:1,ol:1,li:1,pre:1,dl:1,blockquote:1},t={p:1,div:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1},p=CKEDITOR.tools.extend({},
l.$inline);delete p.br;return function(n,F,r,w){var v=n.editor,y=!1;"unfiltered_html"==F&&(F="html",y=!0);if(!w.checkReadOnly()){var q=(new CKEDITOR.dom.elementPath(w.startContainer,w.root)).blockLimit||w.root;n={type:F,dontFilter:y,editable:n,editor:v,range:w,blockLimit:q,mergeCandidates:[],zombies:[]};F=n.range;w=n.mergeCandidates;var z,I;"text"==n.type&&F.shrink(CKEDITOR.SHRINK_ELEMENT,!0,!1)&&(z=CKEDITOR.dom.element.createFromHtml("\x3cspan\x3e\x26nbsp;\x3c/span\x3e",F.document),F.insertNode(z),
F.setStartAfter(z));y=new CKEDITOR.dom.elementPath(F.startContainer);n.endPath=q=new CKEDITOR.dom.elementPath(F.endContainer);if(!F.collapsed){var v=q.block||q.blockLimit,da=F.getCommonAncestor();v&&!v.equals(da)&&!v.contains(da)&&F.checkEndOfBlock()&&n.zombies.push(v);F.deleteContents()}for(;(I=c(F))&&a(I)&&I.isBlockBoundary()&&y.contains(I);)F.moveToPosition(I,CKEDITOR.POSITION_BEFORE_END);m(F,n.blockLimit,y,q);z&&(F.setEndBefore(z),F.collapse(),z.remove());z=F.startPath();if(v=z.contains(g,!1,
1))F.splitElement(v),n.inlineStylesRoot=v,n.inlineStylesPeak=z.lastElement;z=F.createBookmark();(v=z.startNode.getPrevious(e))&&a(v)&&g(v)&&w.push(v);(v=z.startNode.getNext(e))&&a(v)&&g(v)&&w.push(v);for(v=z.startNode;(v=v.getParent())&&g(v);)w.push(v);F.moveToBookmark(z);if(z=r){z=n.range;if("text"==n.type&&n.inlineStylesRoot){I=n.inlineStylesPeak;F=I.getDocument().createText("{cke-peak}");for(w=n.inlineStylesRoot.getParent();!I.equals(w);)F=F.appendTo(I.clone()),I=I.getParent();r=F.getOuterHtml().split("{cke-peak}").join(r)}I=
n.blockLimit.getName();if(/^\s+|\s+$/.test(r)&&"span"in CKEDITOR.dtd[I]){var O='\x3cspan data-cke-marker\x3d"1"\x3e\x26nbsp;\x3c/span\x3e';r=O+r+O}r=n.editor.dataProcessor.toHtml(r,{context:null,fixForBody:!1,protectedWhitespaces:!!O,dontFilter:n.dontFilter,filter:n.editor.activeFilter,enterMode:n.editor.activeEnterMode});I=z.document.createElement("body");I.setHtml(r);O&&(I.getFirst().remove(),I.getLast().remove());if((O=z.startPath().block)&&(1!=O.getChildCount()||!O.getBogus()))a:{var P;if(1==
I.getChildCount()&&a(P=I.getFirst())&&P.is(t)&&!P.hasAttribute("contenteditable")){O=P.getElementsByTag("*");z=0;for(w=O.count();z<w;z++)if(F=O.getItem(z),!F.is(p))break a;P.moveChildren(P.getParent(1));P.remove()}}n.dataWrapper=I;z=r}if(z){P=n.range;z=P.document;var L;I=n.blockLimit;w=0;var T,O=[],R,Y;r=v=0;var V,aa;F=P.startContainer;var y=n.endPath.elements[0],ba,q=y.getPosition(F),da=!!y.getCommonAncestor(F)&&q!=CKEDITOR.POSITION_IDENTICAL&&!(q&CKEDITOR.POSITION_CONTAINS+CKEDITOR.POSITION_IS_CONTAINED);
F=b(n.dataWrapper,n);for(h(F,P);w<F.length;w++){q=F[w];if(L=q.isLineBreak){L=P;V=I;var X=void 0,ca=void 0;q.hasBlockSibling?L=1:(X=L.startContainer.getAscendant(l.$block,1))&&X.is({div:1,p:1})?(ca=X.getPosition(V),ca==CKEDITOR.POSITION_IDENTICAL||ca==CKEDITOR.POSITION_CONTAINS?L=0:(V=L.splitElement(X),L.moveToPosition(V,CKEDITOR.POSITION_AFTER_START),L=1)):L=0}if(L)r=0<w;else{L=P.startPath();!q.isBlock&&k(n.editor,L.block,L.blockLimit)&&(Y=f(n.editor))&&(Y=z.createElement(Y),Y.appendBogus(),P.insertNode(Y),
CKEDITOR.env.needsBrFiller&&(T=Y.getBogus())&&T.remove(),P.moveToPosition(Y,CKEDITOR.POSITION_BEFORE_END));if((L=P.startPath().block)&&!L.equals(R)){if(T=L.getBogus())T.remove(),O.push(L);R=L}q.firstNotAllowed&&(v=1);if(v&&q.isElement){L=P.startContainer;for(V=null;L&&!l[L.getName()][q.name];){if(L.equals(I)){L=null;break}V=L;L=L.getParent()}if(L)V&&(aa=P.splitElement(V),n.zombies.push(aa),n.zombies.push(V));else{V=I.getName();ba=!w;L=w==F.length-1;V=d(q.node,V);for(var X=[],ca=V.length,ea=0,ia=void 0,
ja=0,fa=-1;ea<ca;ea++)ia=V[ea]," "==ia?(ja||ba&&!ea||(X.push(new CKEDITOR.dom.text(" ")),fa=X.length),ja=1):(X.push(ia),ja=0);L&&fa==X.length&&X.pop();ba=X}}if(ba){for(;L=ba.pop();)P.insertNode(L);ba=0}else P.insertNode(q.node);q.lastNotAllowed&&w<F.length-1&&((aa=da?y:aa)&&P.setEndAt(aa,CKEDITOR.POSITION_AFTER_START),v=0);P.collapse()}}1!=F.length?T=!1:(T=F[0],T=T.isElement&&"false"==T.node.getAttribute("contenteditable"));T&&(r=!0,L=F[0].node,P.setStartAt(L,CKEDITOR.POSITION_BEFORE_START),P.setEndAt(L,
CKEDITOR.POSITION_AFTER_END));n.dontMoveCaret=r;n.bogusNeededBlocks=O}T=n.range;var ga;aa=n.bogusNeededBlocks;for(ba=T.createBookmark();R=n.zombies.pop();)R.getParent()&&(Y=T.clone(),Y.moveToElementEditStart(R),Y.removeEmptyBlocksAtEnd());if(aa)for(;R=aa.pop();)CKEDITOR.env.needsBrFiller?R.appendBogus():R.append(T.document.createText(" "));for(;R=n.mergeCandidates.pop();)R.mergeSiblings();T.moveToBookmark(ba);if(!n.dontMoveCaret){for(R=c(T);R&&a(R)&&!R.is(l.$empty);){if(R.isBlockBoundary())T.moveToPosition(R,
CKEDITOR.POSITION_BEFORE_END);else{if(g(R)&&R.getHtml().match(/(\s|&nbsp;)$/g)){ga=null;break}ga=T.clone();ga.moveToPosition(R,CKEDITOR.POSITION_BEFORE_END)}R=R.getLast(e)}ga&&T.moveToRange(ga)}}}}();t=function(){function a(b){b=new CKEDITOR.dom.walker(b);b.guard=function(a,b){if(b)return!1;if(a.type==CKEDITOR.NODE_ELEMENT)return a.is(CKEDITOR.dtd.$tableContent)};b.evaluator=function(a){return a.type==CKEDITOR.NODE_ELEMENT};return b}function b(a,d,c){d=a.getDocument().createElement(d);a.append(d,
c);return d}function d(a){var b=a.count(),c;for(b;0<b--;)c=a.getItem(b),CKEDITOR.tools.trim(c.getHtml())||(c.appendBogus(),CKEDITOR.env.ie&&9>CKEDITOR.env.version&&c.getChildCount()&&c.getFirst().remove())}return function(c){var e=c.startContainer,g=e.getAscendant("table",1),f=!1;d(g.getElementsByTag("td"));d(g.getElementsByTag("th"));g=c.clone();g.setStart(e,0);g=a(g).lastBackward();g||(g=c.clone(),g.setEndAt(e,CKEDITOR.POSITION_BEFORE_END),g=a(g).lastForward(),f=!0);g||(g=e);g.is("table")?(c.setStartAt(g,
CKEDITOR.POSITION_BEFORE_START),c.collapse(!0),g.remove()):(g.is({tbody:1,thead:1,tfoot:1})&&(g=b(g,"tr",f)),g.is("tr")&&(g=b(g,g.getParent().is("thead")?"th":"td",f)),(e=g.getBogus())&&e.remove(),c.moveToPosition(g,f?CKEDITOR.POSITION_AFTER_START:CKEDITOR.POSITION_BEFORE_END))}}();r=function(){function a(b){b=new CKEDITOR.dom.walker(b);b.guard=function(a,b){if(b)return!1;if(a.type==CKEDITOR.NODE_ELEMENT)return a.is(CKEDITOR.dtd.$list)||a.is(CKEDITOR.dtd.$listItem)};b.evaluator=function(a){return a.type==
CKEDITOR.NODE_ELEMENT&&a.is(CKEDITOR.dtd.$listItem)};return b}return function(b){var d=b.startContainer,c=!1,e;e=b.clone();e.setStart(d,0);e=a(e).lastBackward();e||(e=b.clone(),e.setEndAt(d,CKEDITOR.POSITION_BEFORE_END),e=a(e).lastForward(),c=!0);e||(e=d);e.is(CKEDITOR.dtd.$list)?(b.setStartAt(e,CKEDITOR.POSITION_BEFORE_START),b.collapse(!0),e.remove()):((d=e.getBogus())&&d.remove(),b.moveToPosition(e,c?CKEDITOR.POSITION_AFTER_START:CKEDITOR.POSITION_BEFORE_END),b.select())}}();w={eol:{detect:function(a,
b){var d=a.range,c=d.clone(),e=d.clone(),g=new CKEDITOR.dom.elementPath(d.startContainer,b),f=new CKEDITOR.dom.elementPath(d.endContainer,b);c.collapse(1);e.collapse();g.block&&c.checkBoundaryOfElement(g.block,CKEDITOR.END)&&(d.setStartAfter(g.block),a.prependEolBr=1);f.block&&e.checkBoundaryOfElement(f.block,CKEDITOR.START)&&(d.setEndBefore(f.block),a.appendEolBr=1)},fix:function(a,b){var d=b.getDocument(),c;a.appendEolBr&&(c=this.createEolBr(d),a.fragment.append(c));!a.prependEolBr||c&&!c.getPrevious()||
a.fragment.append(this.createEolBr(d),1)},createEolBr:function(a){return a.createElement("br",{attributes:{"data-cke-eol":1}})}},bogus:{exclude:function(a){var b=a.range.getBoundaryNodes(),d=b.startNode,b=b.endNode;!b||!q(b)||d&&d.equals(b)||a.range.setEndBefore(b)}},tree:{rebuild:function(a,b){var d=a.range,c=d.getCommonAncestor(),e=new CKEDITOR.dom.elementPath(c,b),g=new CKEDITOR.dom.elementPath(d.startContainer,b),d=new CKEDITOR.dom.elementPath(d.endContainer,b),f;c.type==CKEDITOR.NODE_TEXT&&(c=
c.getParent());if(e.blockLimit.is({tr:1,table:1})){var m=e.contains("table").getParent();f=function(a){return!a.equals(m)}}else if(e.block&&e.block.is(CKEDITOR.dtd.$listItem)&&(g=g.contains(CKEDITOR.dtd.$list),d=d.contains(CKEDITOR.dtd.$list),!g.equals(d))){var h=e.contains(CKEDITOR.dtd.$list).getParent();f=function(a){return!a.equals(h)}}f||(f=function(a){return!a.equals(e.block)&&!a.equals(e.blockLimit)});this.rebuildFragment(a,b,c,f)},rebuildFragment:function(a,b,d,c){for(var e;d&&!d.equals(b)&&
c(d);)e=d.clone(0,1),a.fragment.appendTo(e),a.fragment=e,d=d.getParent()}},cell:{shrink:function(a){a=a.range;var b=a.startContainer,d=a.endContainer,c=a.startOffset,e=a.endOffset;b.type==CKEDITOR.NODE_ELEMENT&&b.equals(d)&&b.is("tr")&&++c==e&&a.shrink(CKEDITOR.SHRINK_TEXT)}}};z=function(){function a(b,d){var c=b.getParent();if(c.is(CKEDITOR.dtd.$inline))b[d?"insertBefore":"insertAfter"](c)}function b(d,c,e){a(c);a(e,1);for(var g;g=e.getNext();)g.insertAfter(c),c=g;p(d)&&d.remove()}function d(a,b){var c=
new CKEDITOR.dom.range(a);c.setStartAfter(b.startNode);c.setEndBefore(b.endNode);return c}return{list:{detectMerge:function(a,b){var c=d(b,a.bookmark),e=c.startPath(),g=c.endPath(),f=e.contains(CKEDITOR.dtd.$list),m=g.contains(CKEDITOR.dtd.$list);a.mergeList=f&&m&&f.getParent().equals(m.getParent())&&!f.equals(m);a.mergeListItems=e.block&&g.block&&e.block.is(CKEDITOR.dtd.$listItem)&&g.block.is(CKEDITOR.dtd.$listItem);if(a.mergeList||a.mergeListItems)c=c.clone(),c.setStartBefore(a.bookmark.startNode),
c.setEndAfter(a.bookmark.endNode),a.mergeListBookmark=c.createBookmark()},merge:function(a,d){if(a.mergeListBookmark){var c=a.mergeListBookmark.startNode,e=a.mergeListBookmark.endNode,g=new CKEDITOR.dom.elementPath(c,d),f=new CKEDITOR.dom.elementPath(e,d);if(a.mergeList){var m=g.contains(CKEDITOR.dtd.$list),h=f.contains(CKEDITOR.dtd.$list);m.equals(h)||(h.moveChildren(m),h.remove())}a.mergeListItems&&(g=g.contains(CKEDITOR.dtd.$listItem),f=f.contains(CKEDITOR.dtd.$listItem),g.equals(f)||b(f,c,e));
c.remove();e.remove()}}},block:{detectMerge:function(a,b){if(!a.tableContentsRanges&&!a.mergeListBookmark){var d=new CKEDITOR.dom.range(b);d.setStartBefore(a.bookmark.startNode);d.setEndAfter(a.bookmark.endNode);a.mergeBlockBookmark=d.createBookmark()}},merge:function(a,d){if(a.mergeBlockBookmark&&!a.purgeTableBookmark){var c=a.mergeBlockBookmark.startNode,e=a.mergeBlockBookmark.endNode,g=new CKEDITOR.dom.elementPath(c,d),f=new CKEDITOR.dom.elementPath(e,d),g=g.block,f=f.block;g&&f&&!g.equals(f)&&
b(f,c,e);c.remove();e.remove()}}},table:function(){function a(d){var e=[],g,f=new CKEDITOR.dom.walker(d),m=d.startPath().contains(c),h=d.endPath().contains(c),k={};f.guard=function(a,f){if(a.type==CKEDITOR.NODE_ELEMENT){var l="visited_"+(f?"out":"in");if(a.getCustomData(l))return;CKEDITOR.dom.element.setMarker(k,a,l,1)}if(f&&m&&a.equals(m))g=d.clone(),g.setEndAt(m,CKEDITOR.POSITION_BEFORE_END),e.push(g);else if(!f&&h&&a.equals(h))g=d.clone(),g.setStartAt(h,CKEDITOR.POSITION_AFTER_START),e.push(g);
else{if(l=!f)l=a.type==CKEDITOR.NODE_ELEMENT&&a.is(c)&&(!m||b(a,m))&&(!h||b(a,h));l&&(g=d.clone(),g.selectNodeContents(a),e.push(g))}};f.lastForward();CKEDITOR.dom.element.clearAllMarkers(k);return e}function b(a,d){var c=CKEDITOR.POSITION_CONTAINS+CKEDITOR.POSITION_IS_CONTAINED,e=a.getPosition(d);return e===CKEDITOR.POSITION_IDENTICAL?!1:0===(e&c)}var c={td:1,th:1,caption:1};return{detectPurge:function(a){var b=a.range,d=b.clone();d.enlarge(CKEDITOR.ENLARGE_ELEMENT);var d=new CKEDITOR.dom.walker(d),
e=0;d.evaluator=function(a){a.type==CKEDITOR.NODE_ELEMENT&&a.is(c)&&++e};d.checkForward();if(1<e){var d=b.startPath().contains("table"),g=b.endPath().contains("table");d&&g&&b.checkBoundaryOfElement(d,CKEDITOR.START)&&b.checkBoundaryOfElement(g,CKEDITOR.END)&&(b=a.range.clone(),b.setStartBefore(d),b.setEndAfter(g),a.purgeTableBookmark=b.createBookmark())}},detectRanges:function(e,g){var f=d(g,e.bookmark),m=f.clone(),h,k,l=f.getCommonAncestor();l.is(CKEDITOR.dtd.$tableContent)&&!l.is(c)&&(l=l.getAscendant("table",
!0));k=l;l=new CKEDITOR.dom.elementPath(f.startContainer,k);k=new CKEDITOR.dom.elementPath(f.endContainer,k);l=l.contains("table");k=k.contains("table");if(l||k)l&&k&&b(l,k)?(e.tableSurroundingRange=m,m.setStartAt(l,CKEDITOR.POSITION_AFTER_END),m.setEndAt(k,CKEDITOR.POSITION_BEFORE_START),m=f.clone(),m.setEndAt(l,CKEDITOR.POSITION_AFTER_END),h=f.clone(),h.setStartAt(k,CKEDITOR.POSITION_BEFORE_START),h=a(m).concat(a(h))):l?k||(e.tableSurroundingRange=m,m.setStartAt(l,CKEDITOR.POSITION_AFTER_END),f.setEndAt(l,
CKEDITOR.POSITION_AFTER_END)):(e.tableSurroundingRange=m,m.setEndAt(k,CKEDITOR.POSITION_BEFORE_START),f.setStartAt(k,CKEDITOR.POSITION_AFTER_START)),e.tableContentsRanges=h?h:a(f)},deleteRanges:function(a){for(var b;b=a.tableContentsRanges.pop();)b.extractContents(),p(b.startContainer)&&b.startContainer.appendBogus();a.tableSurroundingRange&&a.tableSurroundingRange.extractContents()},purge:function(a){if(a.purgeTableBookmark){var b=a.doc,d=a.range.clone(),b=b.createElement("p");b.insertBefore(a.purgeTableBookmark.startNode);
d.moveToBookmark(a.purgeTableBookmark);d.deleteContents();a.range.moveToPosition(b,CKEDITOR.POSITION_AFTER_START)}}}}(),detectExtractMerge:function(a){return!(a.range.startPath().contains(CKEDITOR.dtd.$listItem)&&a.range.endPath().contains(CKEDITOR.dtd.$listItem))},fixUneditableRangePosition:function(a){a.startContainer.getDtd()["#"]||a.moveToClosestEditablePosition(null,!0)},autoParagraph:function(a,b){var d=b.startPath(),c;k(a,d.block,d.blockLimit)&&(c=f(a))&&(c=b.document.createElement(c),c.appendBogus(),
b.insertNode(c),b.moveToPosition(c,CKEDITOR.POSITION_AFTER_START))}}}()}(),function(){function a(a,b){if(0===a.length)return!1;var d,c;if((d=!b&&1===a.length)&&!(d=a[0].collapsed)){var e=a[0];d=e.startContainer.getAscendant({td:1,th:1},!0);var g=e.endContainer.getAscendant({td:1,th:1},!0);c=CKEDITOR.tools.trim;d&&d.equals(g)&&!d.findOne("td, th, tr, tbody, table")?(e=e.cloneContents(),d=e.getFirst()?c(e.getFirst().getText())!==c(d.getText()):!0):d=!1}if(d)return!1;for(c=0;c<a.length;c++)if(d=a[c]._getTableElement(),
!d)return!1;return!0}function c(a){function b(a){a=a.find("td, th");var d=[],c;for(c=0;c<a.count();c++)d.push(a.getItem(c));return d}var d=[],c,e;for(e=0;e<a.length;e++)c=a[e]._getTableElement(),c.is&&c.is({td:1,th:1})?d.push(c):d=d.concat(b(c));return d}function b(a){a=c(a);var b="",d=[],e,g;for(g=0;g<a.length;g++)e&&!e.equals(a[g].getAscendant("tr"))?(b+=d.join("\t")+"\n",e=a[g].getAscendant("tr"),d=[]):0===g&&(e=a[g].getAscendant("tr")),d.push(a[g].getText());return b+=d.join("\t")}function e(a){var d=
this.root.editor,c=d.getSelection(1);this.reset();z=!0;c.root.once("selectionchange",function(a){a.cancel()},null,null,0);c.selectRanges([a[0]]);c=this._.cache;c.ranges=new CKEDITOR.dom.rangeList(a);c.type=CKEDITOR.SELECTION_TEXT;c.selectedElement=a[0]._getTableElement();c.selectedText=b(a);c.nativeSel=null;this.isFake=1;this.rev=t++;d._.fakeSelection=this;z=!1;this.root.fire("selectionchange")}function h(){var b=this._.fakeSelection,d;if(b){d=this.getSelection(1);var c;if(!(c=!d)&&(c=!d.isHidden())){c=
b;var e=d.getRanges(),g=c.getRanges(),f=e.length&&e[0]._getTableElement()&&e[0]._getTableElement().getAscendant("table",!0),m=g.length&&g[0]._getTableElement()&&g[0]._getTableElement().getAscendant("table",!0),h=1===e.length&&e[0]._getTableElement()&&e[0]._getTableElement().is("table"),k=1===g.length&&g[0]._getTableElement()&&g[0]._getTableElement().is("table"),l=1===e.length&&e[0].collapsed,g=a(e,!!CKEDITOR.env.webkit)&&a(g);f=f&&m?f.equals(m)||m.contains(f):!1;f&&(l||g)?(h&&!k&&c.selectRanges(e),
c=!0):c=!1;c=!c}c&&(b.reset(),b=0)}if(!b&&(b=d||this.getSelection(1),!b||b.getType()==CKEDITOR.SELECTION_NONE))return;this.fire("selectionCheck",b);d=this.elementPath();d.compare(this._.selectionPreviousPath)||(c=this._.selectionPreviousPath&&this._.selectionPreviousPath.blockLimit.equals(d.blockLimit),CKEDITOR.env.webkit&&!c&&(this._.previousActive=this.document.getActive()),this._.selectionPreviousPath=d,this.fire("selectionChange",{selection:b,path:d}))}function l(){B=!0;u||(k.call(this),u=CKEDITOR.tools.setTimeout(k,
200,this))}function k(){u=null;B&&(CKEDITOR.tools.setTimeout(h,0,this),B=!1)}function f(a){return C(a)||a.type==CKEDITOR.NODE_ELEMENT&&!a.is(CKEDITOR.dtd.$empty)?!0:!1}function d(a){function b(d,c){return d&&d.type!=CKEDITOR.NODE_TEXT?a.clone()["moveToElementEdit"+(c?"End":"Start")](d):!1}if(!(a.root instanceof CKEDITOR.editable))return!1;var d=a.startContainer,c=a.getPreviousNode(f,null,d),e=a.getNextNode(f,null,d);return b(c)||b(e,1)||!(c||e||d.type==CKEDITOR.NODE_ELEMENT&&d.isBlockBoundary()&&
d.getBogus())?!0:!1}function m(a){g(a,!1);var b=a.getDocument().createText(r);a.setCustomData("cke-fillingChar",b);return b}function g(a,b){var d=a&&a.removeCustomData("cke-fillingChar");if(d){if(!1!==b){var c=a.getDocument().getSelection().getNative(),e=c&&"None"!=c.type&&c.getRangeAt(0),g=r.length;if(d.getLength()>g&&e&&e.intersectsNode(d.$)){var f=[{node:c.anchorNode,offset:c.anchorOffset},{node:c.focusNode,offset:c.focusOffset}];c.anchorNode==d.$&&c.anchorOffset>g&&(f[0].offset-=g);c.focusNode==
d.$&&c.focusOffset>g&&(f[1].offset-=g)}}d.setText(n(d.getText(),1));f&&(d=a.getDocument().$,c=d.getSelection(),d=d.createRange(),d.setStart(f[0].node,f[0].offset),d.collapse(!0),c.removeAllRanges(),c.addRange(d),c.extend(f[1].node,f[1].offset))}}function n(a,b){return b?a.replace(w,function(a,b){return b?" ":""}):a.replace(r,"")}function p(a,b){var d=CKEDITOR.dom.element.createFromHtml('\x3cdiv data-cke-hidden-sel\x3d"1" data-cke-temp\x3d"1" style\x3d"'+(CKEDITOR.env.ie&&14>CKEDITOR.env.version?"display:none":
"position:fixed;top:0;left:-1000px")+'"\x3e'+(b||"\x26nbsp;")+"\x3c/div\x3e",a.document);a.fire("lockSnapshot");a.editable().append(d);var c=a.getSelection(1),e=a.createRange(),g=c.root.on("selectionchange",function(a){a.cancel()},null,null,0);e.setStartAt(d,CKEDITOR.POSITION_AFTER_START);e.setEndAt(d,CKEDITOR.POSITION_BEFORE_END);c.selectRanges([e]);g.removeListener();a.fire("unlockSnapshot");a._.hiddenSelectionContainer=d}function q(a){var b={37:1,39:1,8:1,46:1};return function(d){var c=d.data.getKeystroke();
if(b[c]){var e=a.getSelection().getRanges(),g=e[0];1==e.length&&g.collapsed&&(c=g[38>c?"getPreviousEditableNode":"getNextEditableNode"]())&&c.type==CKEDITOR.NODE_ELEMENT&&"false"==c.getAttribute("contenteditable")&&(a.getSelection().fake(c),d.data.preventDefault(),d.cancel())}}}function y(a){for(var b=0;b<a.length;b++){var d=a[b];d.getCommonAncestor().isReadOnly()&&a.splice(b,1);if(!d.collapsed){if(d.startContainer.isReadOnly())for(var c=d.startContainer,e;c&&!((e=c.type==CKEDITOR.NODE_ELEMENT)&&
c.is("body")||!c.isReadOnly());)e&&"false"==c.getAttribute("contentEditable")&&d.setStartAfter(c),c=c.getParent();c=d.startContainer;e=d.endContainer;var g=d.startOffset,f=d.endOffset,m=d.clone();c&&c.type==CKEDITOR.NODE_TEXT&&(g>=c.getLength()?m.setStartAfter(c):m.setStartBefore(c));e&&e.type==CKEDITOR.NODE_TEXT&&(f?m.setEndAfter(e):m.setEndBefore(e));c=new CKEDITOR.dom.walker(m);c.evaluator=function(c){if(c.type==CKEDITOR.NODE_ELEMENT&&c.isReadOnly()){var e=d.clone();d.setEndBefore(c);d.collapsed&&
a.splice(b--,1);c.getPosition(m.endContainer)&CKEDITOR.POSITION_CONTAINS||(e.setStartAfter(c),e.collapsed||a.splice(b+1,0,e));return!0}return!1};c.next()}}return a}var v="function"!=typeof window.getSelection,t=1,r=CKEDITOR.tools.repeat("​",7),w=new RegExp(r+"( )?","g"),z,u,B,C=CKEDITOR.dom.walker.invisible(1),x=function(){function a(b){return function(a){var d=a.editor.createRange();d.moveToClosestEditablePosition(a.selected,b)&&a.editor.getSelection().selectRanges([d]);return!1}}function b(a){return function(b){var d=
b.editor,c=d.createRange(),e;(e=c.moveToClosestEditablePosition(b.selected,a))||(e=c.moveToClosestEditablePosition(b.selected,!a));e&&d.getSelection().selectRanges([c]);d.fire("saveSnapshot");b.selected.remove();e||(c.moveToElementEditablePosition(d.editable()),d.getSelection().selectRanges([c]));d.fire("saveSnapshot");return!1}}var d=a(),c=a(1);return{37:d,38:d,39:c,40:c,8:b(),46:b(1)}}();CKEDITOR.on("instanceCreated",function(a){function b(){var a=d.getSelection();a&&a.removeAllRanges()}var d=a.editor;
d.on("contentDom",function(){function a(){p=new CKEDITOR.dom.selection(d.getSelection());p.lock()}function b(){f.removeListener("mouseup",b);n.removeListener("mouseup",b);var a=CKEDITOR.document.$.selection,d=a.createRange();"None"!=a.type&&d.parentElement()&&d.parentElement().ownerDocument==e.$&&d.select()}function c(a){if(CKEDITOR.env.ie){var b=(a=a.getRanges()[0])?a.startContainer.getAscendant(function(a){return a.type==CKEDITOR.NODE_ELEMENT&&("false"==a.getAttribute("contenteditable")||"true"==
a.getAttribute("contenteditable"))},!0):null;return a&&"false"==b.getAttribute("contenteditable")&&b}}var e=d.document,f=CKEDITOR.document,m=d.editable(),k=e.getBody(),n=e.getDocumentElement(),t=m.isInline(),r,p;CKEDITOR.env.gecko&&m.attachListener(m,"focus",function(a){a.removeListener();0!==r&&(a=d.getSelection().getNative())&&a.isCollapsed&&a.anchorNode==m.$&&(a=d.createRange(),a.moveToElementEditStart(m),a.select())},null,null,-2);m.attachListener(m,CKEDITOR.env.webkit?"DOMFocusIn":"focus",function(){r&&
CKEDITOR.env.webkit&&(r=d._.previousActive&&d._.previousActive.equals(e.getActive()))&&null!=d._.previousScrollTop&&d._.previousScrollTop!=m.$.scrollTop&&(m.$.scrollTop=d._.previousScrollTop);d.unlockSelection(r);r=0},null,null,-1);m.attachListener(m,"mousedown",function(){r=0});if(CKEDITOR.env.ie||t)v?m.attachListener(m,"beforedeactivate",a,null,null,-1):m.attachListener(d,"selectionCheck",a,null,null,-1),m.attachListener(m,CKEDITOR.env.webkit?"DOMFocusOut":"blur",function(){d.lockSelection(p);r=
1},null,null,-1),m.attachListener(m,"mousedown",function(){r=0});if(CKEDITOR.env.ie&&!t){var w;m.attachListener(m,"mousedown",function(a){2==a.data.$.button&&((a=d.document.getSelection())&&a.getType()!=CKEDITOR.SELECTION_NONE||(w=d.window.getScrollPosition()))});m.attachListener(m,"mouseup",function(a){2==a.data.$.button&&w&&(d.document.$.documentElement.scrollLeft=w.x,d.document.$.documentElement.scrollTop=w.y);w=null});if("BackCompat"!=e.$.compatMode){if(CKEDITOR.env.ie7Compat||CKEDITOR.env.ie6Compat){var u,
y;n.on("mousedown",function(a){function b(a){a=a.data.$;if(u){var d=k.$.createTextRange();try{d.moveToPoint(a.clientX,a.clientY)}catch(c){}u.setEndPoint(0>y.compareEndPoints("StartToStart",d)?"EndToEnd":"StartToStart",d);u.select()}}function d(){n.removeListener("mousemove",b);f.removeListener("mouseup",d);n.removeListener("mouseup",d);u.select()}a=a.data;if(a.getTarget().is("html")&&a.$.y<n.$.clientHeight&&a.$.x<n.$.clientWidth){u=k.$.createTextRange();try{u.moveToPoint(a.$.clientX,a.$.clientY)}catch(c){}y=
u.duplicate();n.on("mousemove",b);f.on("mouseup",d);n.on("mouseup",d)}})}if(7<CKEDITOR.env.version&&11>CKEDITOR.env.version)n.on("mousedown",function(a){a.data.getTarget().is("html")&&(f.on("mouseup",b),n.on("mouseup",b))})}}m.attachListener(m,"selectionchange",h,d);m.attachListener(m,"keyup",l,d);m.attachListener(m,"keydown",function(a){var b=this.getSelection(1);c(b)&&(b.selectElement(c(b)),a.data.preventDefault())},d);m.attachListener(m,CKEDITOR.env.webkit?"DOMFocusIn":"focus",function(){d.forceNextSelectionCheck();
d.selectionChange(1)});if(t&&(CKEDITOR.env.webkit||CKEDITOR.env.gecko)){var z;m.attachListener(m,"mousedown",function(){z=1});m.attachListener(e.getDocumentElement(),"mouseup",function(){z&&l.call(d);z=0})}else m.attachListener(CKEDITOR.env.ie?m:e.getDocumentElement(),"mouseup",l,d);CKEDITOR.env.webkit&&m.attachListener(e,"keydown",function(a){switch(a.data.getKey()){case 13:case 33:case 34:case 35:case 36:case 37:case 39:case 8:case 45:case 46:m.hasFocus&&g(m)}},null,null,-1);m.attachListener(m,
"keydown",q(d),null,null,-1)});d.on("setData",function(){d.unlockSelection();CKEDITOR.env.webkit&&b()});d.on("contentDomUnload",function(){d.unlockSelection()});if(CKEDITOR.env.ie9Compat)d.on("beforeDestroy",b,null,null,9);d.on("dataReady",function(){delete d._.fakeSelection;delete d._.hiddenSelectionContainer;d.selectionChange(1)});d.on("loadSnapshot",function(){var a=CKEDITOR.dom.walker.nodeType(CKEDITOR.NODE_ELEMENT),b=d.editable().getLast(a);b&&b.hasAttribute("data-cke-hidden-sel")&&(b.remove(),
CKEDITOR.env.gecko&&(a=d.editable().getFirst(a))&&a.is("br")&&a.getAttribute("_moz_editor_bogus_node")&&a.remove())},null,null,100);d.on("key",function(a){if("wysiwyg"==d.mode){var b=d.getSelection();if(b.isFake){var c=x[a.data.keyCode];if(c)return c({editor:d,selected:b.getSelectedElement(),selection:b,keyEvent:a})}}})});if(CKEDITOR.env.webkit)CKEDITOR.on("instanceReady",function(a){var b=a.editor;b.on("selectionChange",function(){var a=b.editable(),d=a.getCustomData("cke-fillingChar");d&&(d.getCustomData("ready")?
(g(a),a.editor.fire("selectionCheck")):d.setCustomData("ready",1))},null,null,-1);b.on("beforeSetMode",function(){g(b.editable())},null,null,-1);b.on("getSnapshot",function(a){a.data&&(a.data=n(a.data))},b,null,20);b.on("toDataFormat",function(a){a.data.dataValue=n(a.data.dataValue)},null,null,0)});CKEDITOR.editor.prototype.selectionChange=function(a){(a?h:l).call(this)};CKEDITOR.editor.prototype.getSelection=function(a){return!this._.savedSelection&&!this._.fakeSelection||a?(a=this.editable())&&
"wysiwyg"==this.mode?new CKEDITOR.dom.selection(a):null:this._.savedSelection||this._.fakeSelection};CKEDITOR.editor.prototype.lockSelection=function(a){a=a||this.getSelection(1);return a.getType()!=CKEDITOR.SELECTION_NONE?(!a.isLocked&&a.lock(),this._.savedSelection=a,!0):!1};CKEDITOR.editor.prototype.unlockSelection=function(a){var b=this._.savedSelection;return b?(b.unlock(a),delete this._.savedSelection,!0):!1};CKEDITOR.editor.prototype.forceNextSelectionCheck=function(){delete this._.selectionPreviousPath};
CKEDITOR.dom.document.prototype.getSelection=function(){return new CKEDITOR.dom.selection(this)};CKEDITOR.dom.range.prototype.select=function(){var a=this.root instanceof CKEDITOR.editable?this.root.editor.getSelection():new CKEDITOR.dom.selection(this.root);a.selectRanges([this]);return a};CKEDITOR.SELECTION_NONE=1;CKEDITOR.SELECTION_TEXT=2;CKEDITOR.SELECTION_ELEMENT=3;CKEDITOR.dom.selection=function(a){if(a instanceof CKEDITOR.dom.selection){var b=a;a=a.root}var d=a instanceof CKEDITOR.dom.element;
this.rev=b?b.rev:t++;this.document=a instanceof CKEDITOR.dom.document?a:a.getDocument();this.root=d?a:this.document.getBody();this.isLocked=0;this._={cache:{}};if(b)return CKEDITOR.tools.extend(this._.cache,b._.cache),this.isFake=b.isFake,this.isLocked=b.isLocked,this;a=this.getNative();var c,e;if(a)if(a.getRangeAt)c=(e=a.rangeCount&&a.getRangeAt(0))&&new CKEDITOR.dom.node(e.commonAncestorContainer);else{try{e=a.createRange()}catch(g){}c=e&&CKEDITOR.dom.element.get(e.item&&e.item(0)||e.parentElement())}if(!c||
c.type!=CKEDITOR.NODE_ELEMENT&&c.type!=CKEDITOR.NODE_TEXT||!this.root.equals(c)&&!this.root.contains(c))this._.cache.type=CKEDITOR.SELECTION_NONE,this._.cache.startElement=null,this._.cache.selectedElement=null,this._.cache.selectedText="",this._.cache.ranges=new CKEDITOR.dom.rangeList;return this};var A={img:1,hr:1,li:1,table:1,tr:1,td:1,th:1,embed:1,object:1,ol:1,ul:1,a:1,input:1,form:1,select:1,textarea:1,button:1,fieldset:1,thead:1,tfoot:1};CKEDITOR.tools.extend(CKEDITOR.dom.selection,{_removeFillingCharSequenceString:n,
_createFillingCharSequenceNode:m,FILLING_CHAR_SEQUENCE:r});CKEDITOR.dom.selection.prototype={getNative:function(){return void 0!==this._.cache.nativeSel?this._.cache.nativeSel:this._.cache.nativeSel=v?this.document.$.selection:this.document.getWindow().$.getSelection()},getType:v?function(){var a=this._.cache;if(a.type)return a.type;var b=CKEDITOR.SELECTION_NONE;try{var d=this.getNative(),c=d.type;"Text"==c&&(b=CKEDITOR.SELECTION_TEXT);"Control"==c&&(b=CKEDITOR.SELECTION_ELEMENT);d.createRange().parentElement()&&
(b=CKEDITOR.SELECTION_TEXT)}catch(e){}return a.type=b}:function(){var a=this._.cache;if(a.type)return a.type;var b=CKEDITOR.SELECTION_TEXT,d=this.getNative();if(!d||!d.rangeCount)b=CKEDITOR.SELECTION_NONE;else if(1==d.rangeCount){var d=d.getRangeAt(0),c=d.startContainer;c==d.endContainer&&1==c.nodeType&&1==d.endOffset-d.startOffset&&A[c.childNodes[d.startOffset].nodeName.toLowerCase()]&&(b=CKEDITOR.SELECTION_ELEMENT)}return a.type=b},getRanges:function(){var a=v?function(){function a(b){return(new CKEDITOR.dom.node(b)).getIndex()}
var b=function(b,d){b=b.duplicate();b.collapse(d);var c=b.parentElement();if(!c.hasChildNodes())return{container:c,offset:0};for(var e=c.children,g,f,m=b.duplicate(),h=0,k=e.length-1,l=-1,n,t;h<=k;)if(l=Math.floor((h+k)/2),g=e[l],m.moveToElementText(g),n=m.compareEndPoints("StartToStart",b),0<n)k=l-1;else if(0>n)h=l+1;else return{container:c,offset:a(g)};if(-1==l||l==e.length-1&&0>n){m.moveToElementText(c);m.setEndPoint("StartToStart",b);m=m.text.replace(/(\r\n|\r)/g,"\n").length;e=c.childNodes;if(!m)return g=
e[e.length-1],g.nodeType!=CKEDITOR.NODE_TEXT?{container:c,offset:e.length}:{container:g,offset:g.nodeValue.length};for(c=e.length;0<m&&0<c;)f=e[--c],f.nodeType==CKEDITOR.NODE_TEXT&&(t=f,m-=f.nodeValue.length);return{container:t,offset:-m}}m.collapse(0<n?!0:!1);m.setEndPoint(0<n?"StartToStart":"EndToStart",b);m=m.text.replace(/(\r\n|\r)/g,"\n").length;if(!m)return{container:c,offset:a(g)+(0<n?0:1)};for(;0<m;)try{f=g[0<n?"previousSibling":"nextSibling"],f.nodeType==CKEDITOR.NODE_TEXT&&(m-=f.nodeValue.length,
t=f),g=f}catch(r){return{container:c,offset:a(g)}}return{container:t,offset:0<n?-m:t.nodeValue.length+m}};return function(){var a=this.getNative(),d=a&&a.createRange(),c=this.getType();if(!a)return[];if(c==CKEDITOR.SELECTION_TEXT)return a=new CKEDITOR.dom.range(this.root),c=b(d,!0),a.setStart(new CKEDITOR.dom.node(c.container),c.offset),c=b(d),a.setEnd(new CKEDITOR.dom.node(c.container),c.offset),a.endContainer.getPosition(a.startContainer)&CKEDITOR.POSITION_PRECEDING&&a.endOffset<=a.startContainer.getIndex()&&
a.collapse(),[a];if(c==CKEDITOR.SELECTION_ELEMENT){for(var c=[],e=0;e<d.length;e++){for(var g=d.item(e),f=g.parentNode,m=0,a=new CKEDITOR.dom.range(this.root);m<f.childNodes.length&&f.childNodes[m]!=g;m++);a.setStart(new CKEDITOR.dom.node(f),m);a.setEnd(new CKEDITOR.dom.node(f),m+1);c.push(a)}return c}return[]}}():function(){var a=[],b,d=this.getNative();if(!d)return a;for(var c=0;c<d.rangeCount;c++){var e=d.getRangeAt(c);b=new CKEDITOR.dom.range(this.root);b.setStart(new CKEDITOR.dom.node(e.startContainer),
e.startOffset);b.setEnd(new CKEDITOR.dom.node(e.endContainer),e.endOffset);a.push(b)}return a};return function(b){var d=this._.cache,c=d.ranges;c||(d.ranges=c=new CKEDITOR.dom.rangeList(a.call(this)));return b?y(new CKEDITOR.dom.rangeList(c.slice())):c}}(),getStartElement:function(){var a=this._.cache;if(void 0!==a.startElement)return a.startElement;var b;switch(this.getType()){case CKEDITOR.SELECTION_ELEMENT:return this.getSelectedElement();case CKEDITOR.SELECTION_TEXT:var d=this.getRanges()[0];
if(d){if(d.collapsed)b=d.startContainer,b.type!=CKEDITOR.NODE_ELEMENT&&(b=b.getParent());else{for(d.optimize();b=d.startContainer,d.startOffset==(b.getChildCount?b.getChildCount():b.getLength())&&!b.isBlockBoundary();)d.setStartAfter(b);b=d.startContainer;if(b.type!=CKEDITOR.NODE_ELEMENT)return b.getParent();if((b=b.getChild(d.startOffset))&&b.type==CKEDITOR.NODE_ELEMENT)for(d=b.getFirst();d&&d.type==CKEDITOR.NODE_ELEMENT;)b=d,d=d.getFirst();else b=d.startContainer}b=b.$}}return a.startElement=b?
new CKEDITOR.dom.element(b):null},getSelectedElement:function(){var a=this._.cache;if(void 0!==a.selectedElement)return a.selectedElement;var b=this,d=CKEDITOR.tools.tryThese(function(){return b.getNative().createRange().item(0)},function(){for(var a=b.getRanges()[0].clone(),d,c,e=2;e&&!((d=a.getEnclosedNode())&&d.type==CKEDITOR.NODE_ELEMENT&&A[d.getName()]&&(c=d));e--)a.shrink(CKEDITOR.SHRINK_ELEMENT);return c&&c.$});return a.selectedElement=d?new CKEDITOR.dom.element(d):null},getSelectedText:function(){var a=
this._.cache;if(void 0!==a.selectedText)return a.selectedText;var b=this.getNative(),b=v?"Control"==b.type?"":b.createRange().text:b.toString();return a.selectedText=b},lock:function(){this.getRanges();this.getStartElement();this.getSelectedElement();this.getSelectedText();this._.cache.nativeSel=null;this.isLocked=1},unlock:function(b){if(this.isLocked){if(b)var d=this.getSelectedElement(),c=this.getRanges(),g=this.isFake;this.isLocked=0;this.reset();b&&(b=d||c[0]&&c[0].getCommonAncestor())&&b.getAscendant("body",
1)&&(a(c)?e.call(this,c):g?this.fake(d):d?this.selectElement(d):this.selectRanges(c))}},reset:function(){this._.cache={};this.isFake=0;var a=this.root.editor;if(a&&a._.fakeSelection)if(this.rev==a._.fakeSelection.rev){delete a._.fakeSelection;var b=a._.hiddenSelectionContainer;if(b){var d=a.checkDirty();a.fire("lockSnapshot");b.remove();a.fire("unlockSnapshot");!d&&a.resetDirty()}delete a._.hiddenSelectionContainer}else CKEDITOR.warn("selection-fake-reset");this.rev=t++},selectElement:function(a){var b=
new CKEDITOR.dom.range(this.root);b.setStartBefore(a);b.setEndAfter(a);this.selectRanges([b])},selectRanges:function(b){var c=this.root.editor,f=c&&c._.hiddenSelectionContainer;this.reset();if(f)for(var f=this.root,h,k=0;k<b.length;++k)h=b[k],h.endContainer.equals(f)&&(h.endOffset=Math.min(h.endOffset,f.getChildCount()));if(b.length)if(this.isLocked){var l=CKEDITOR.document.getActive();this.unlock();this.selectRanges(b);this.lock();l&&!l.equals(this.root)&&l.focus()}else{var n;a:{var t,r;if(1==b.length&&
!(r=b[0]).collapsed&&(n=r.getEnclosedNode())&&n.type==CKEDITOR.NODE_ELEMENT&&(r=r.clone(),r.shrink(CKEDITOR.SHRINK_ELEMENT,!0),(t=r.getEnclosedNode())&&t.type==CKEDITOR.NODE_ELEMENT&&(n=t),"false"==n.getAttribute("contenteditable")))break a;n=void 0}if(n)this.fake(n);else if(c&&c.plugins.tableselection&&CKEDITOR.plugins.tableselection.isSupportedEnvironment&&a(b)&&!z)e.call(this,b);else{if(v){t=CKEDITOR.dom.walker.whitespaces(!0);n=/\ufeff|\u00a0/;r={table:1,tbody:1,tr:1};1<b.length&&(c=b[b.length-
1],b[0].setEnd(c.endContainer,c.endOffset));c=b[0];b=c.collapsed;var p,w,u;if((f=c.getEnclosedNode())&&f.type==CKEDITOR.NODE_ELEMENT&&f.getName()in A&&(!f.is("a")||!f.getText()))try{u=f.$.createControlRange();u.addElement(f.$);u.select();return}catch(y){}if(c.startContainer.type==CKEDITOR.NODE_ELEMENT&&c.startContainer.getName()in r||c.endContainer.type==CKEDITOR.NODE_ELEMENT&&c.endContainer.getName()in r)c.shrink(CKEDITOR.NODE_ELEMENT,!0),b=c.collapsed;u=c.createBookmark();r=u.startNode;b||(l=u.endNode);
u=c.document.$.body.createTextRange();u.moveToElementText(r.$);u.moveStart("character",1);l?(n=c.document.$.body.createTextRange(),n.moveToElementText(l.$),u.setEndPoint("EndToEnd",n),u.moveEnd("character",-1)):(p=r.getNext(t),w=r.hasAscendant("pre"),p=!(p&&p.getText&&p.getText().match(n))&&(w||!r.hasPrevious()||r.getPrevious().is&&r.getPrevious().is("br")),w=c.document.createElement("span"),w.setHtml("\x26#65279;"),w.insertBefore(r),p&&c.document.createText("﻿").insertBefore(r));c.setStartBefore(r);
r.remove();b?(p?(u.moveStart("character",-1),u.select(),c.document.$.selection.clear()):u.select(),c.moveToPosition(w,CKEDITOR.POSITION_BEFORE_START),w.remove()):(c.setEndBefore(l),l.remove(),u.select())}else{l=this.getNative();if(!l)return;this.removeAllRanges();for(u=0;u<b.length;u++){if(u<b.length-1&&(p=b[u],w=b[u+1],n=p.clone(),n.setStart(p.endContainer,p.endOffset),n.setEnd(w.startContainer,w.startOffset),!n.collapsed&&(n.shrink(CKEDITOR.NODE_ELEMENT,!0),c=n.getCommonAncestor(),n=n.getEnclosedNode(),
c.isReadOnly()||n&&n.isReadOnly()))){w.setStart(p.startContainer,p.startOffset);b.splice(u--,1);continue}c=b[u];w=this.document.$.createRange();c.collapsed&&CKEDITOR.env.webkit&&d(c)&&(n=m(this.root),c.insertNode(n),(p=n.getNext())&&!n.getPrevious()&&p.type==CKEDITOR.NODE_ELEMENT&&"br"==p.getName()?(g(this.root),c.moveToPosition(p,CKEDITOR.POSITION_BEFORE_START)):c.moveToPosition(n,CKEDITOR.POSITION_AFTER_END));w.setStart(c.startContainer.$,c.startOffset);try{w.setEnd(c.endContainer.$,c.endOffset)}catch(q){if(0<=
q.toString().indexOf("NS_ERROR_ILLEGAL_VALUE"))c.collapse(1),w.setEnd(c.endContainer.$,c.endOffset);else throw q;}l.addRange(w)}}this.reset();this.root.fire("selectionchange")}}},fake:function(a,b){var d=this.root.editor;void 0===b&&a.hasAttribute("aria-label")&&(b=a.getAttribute("aria-label"));this.reset();p(d,b);var c=this._.cache,e=new CKEDITOR.dom.range(this.root);e.setStartBefore(a);e.setEndAfter(a);c.ranges=new CKEDITOR.dom.rangeList(e);c.selectedElement=c.startElement=a;c.type=CKEDITOR.SELECTION_ELEMENT;
c.selectedText=c.nativeSel=null;this.isFake=1;this.rev=t++;d._.fakeSelection=this;this.root.fire("selectionchange")},isHidden:function(){var a=this.getCommonAncestor();a&&a.type==CKEDITOR.NODE_TEXT&&(a=a.getParent());return!(!a||!a.data("cke-hidden-sel"))},isInTable:function(b){return a(this.getRanges(),b)},createBookmarks:function(a){a=this.getRanges().createBookmarks(a);this.isFake&&(a.isFake=1);return a},createBookmarks2:function(a){a=this.getRanges().createBookmarks2(a);this.isFake&&(a.isFake=
1);return a},selectBookmarks:function(b){for(var d=[],c,e=0;e<b.length;e++){var g=new CKEDITOR.dom.range(this.root);g.moveToBookmark(b[e]);d.push(g)}b.isFake&&(c=a(d)?d[0]._getTableElement():d[0].getEnclosedNode(),c&&c.type==CKEDITOR.NODE_ELEMENT||(CKEDITOR.warn("selection-not-fake"),b.isFake=0));b.isFake&&!a(d)?this.fake(c):this.selectRanges(d);return this},getCommonAncestor:function(){var a=this.getRanges();return a.length?a[0].startContainer.getCommonAncestor(a[a.length-1].endContainer):null},
scrollIntoView:function(){this.type!=CKEDITOR.SELECTION_NONE&&this.getRanges()[0].scrollIntoView()},removeAllRanges:function(){if(this.getType()!=CKEDITOR.SELECTION_NONE){var a=this.getNative();try{a&&a[v?"empty":"removeAllRanges"]()}catch(b){}this.reset()}}}}(),"use strict",CKEDITOR.STYLE_BLOCK=1,CKEDITOR.STYLE_INLINE=2,CKEDITOR.STYLE_OBJECT=3,function(){function a(a,b){for(var d,c;(a=a.getParent())&&!a.equals(b);)if(a.getAttribute("data-nostyle"))d=a;else if(!c){var e=a.getAttribute("contentEditable");
"false"==e?d=a:"true"==e&&(c=1)}return d}function c(a,b,d,c){return(a.getPosition(b)|c)==c&&(!d.childRule||d.childRule(a))}function b(d){var e=d.document;if(d.collapsed)e=r(this,e),d.insertNode(e),d.moveToPosition(e,CKEDITOR.POSITION_BEFORE_END);else{var g=this.element,f=this._.definition,m,k=f.ignoreReadonly,l=k||f.includeReadonly;null==l&&(l=d.root.getCustomData("cke_includeReadonly"));var n=CKEDITOR.dtd[g];n||(m=!0,n=CKEDITOR.dtd.span);d.enlarge(CKEDITOR.ENLARGE_INLINE,1);d.trim();var t=d.createBookmark(),
p=t.startNode,w=t.endNode,u=p,v;if(!k){var q=d.getCommonAncestor(),k=a(p,q),q=a(w,q);k&&(u=k.getNextSourceNode(!0));q&&(w=q)}for(u.getPosition(w)==CKEDITOR.POSITION_FOLLOWING&&(u=0);u;){k=!1;if(u.equals(w))u=null,k=!0;else{var z=u.type==CKEDITOR.NODE_ELEMENT?u.getName():null,q=z&&"false"==u.getAttribute("contentEditable"),x=z&&u.getAttribute("data-nostyle");if(z&&u.data("cke-bookmark")){u=u.getNextSourceNode(!0);continue}if(q&&l&&CKEDITOR.dtd.$block[z])for(var B=u,A=h(B),C=void 0,D=A.length,ea=0,
B=D&&new CKEDITOR.dom.range(B.getDocument());ea<D;++ea){var C=A[ea],H=CKEDITOR.filter.instances[C.data("cke-filter")];if(H?H.check(this):1)B.selectNodeContents(C),b.call(this,B)}A=z?!n[z]||x?0:q&&!l?0:c(u,w,f,K):1;if(A)if(C=u.getParent(),A=f,D=g,ea=m,!C||!(C.getDtd()||CKEDITOR.dtd.span)[D]&&!ea||A.parentRule&&!A.parentRule(C))k=!0;else{if(v||z&&CKEDITOR.dtd.$removeEmpty[z]&&(u.getPosition(w)|K)!=K||(v=d.clone(),v.setStartBefore(u)),z=u.type,z==CKEDITOR.NODE_TEXT||q||z==CKEDITOR.NODE_ELEMENT&&!u.getChildCount()){for(var z=
u,G;(k=!z.getNext(I))&&(G=z.getParent(),n[G.getName()])&&c(G,p,f,J);)z=G;v.setEndAfter(z)}}else k=!0;u=u.getNextSourceNode(x||q)}if(k&&v&&!v.collapsed){for(var k=r(this,e),q=k.hasAttributes(),x=v.getCommonAncestor(),z={},A={},C={},D={},fa,E,ha;k&&x;){if(x.getName()==g){for(fa in f.attributes)!D[fa]&&(ha=x.getAttribute(E))&&(k.getAttribute(fa)==ha?A[fa]=1:D[fa]=1);for(E in f.styles)!C[E]&&(ha=x.getStyle(E))&&(k.getStyle(E)==ha?z[E]=1:C[E]=1)}x=x.getParent()}for(fa in A)k.removeAttribute(fa);for(E in z)k.removeStyle(E);
q&&!k.hasAttributes()&&(k=null);k?(v.extractContents().appendTo(k),v.insertNode(k),y.call(this,k),k.mergeSiblings(),CKEDITOR.env.ie||k.$.normalize()):(k=new CKEDITOR.dom.element("span"),v.extractContents().appendTo(k),v.insertNode(k),y.call(this,k),k.remove(!0));v=null}}d.moveToBookmark(t);d.shrink(CKEDITOR.SHRINK_TEXT);d.shrink(CKEDITOR.NODE_ELEMENT,!0)}}function e(a){function b(){for(var a=new CKEDITOR.dom.elementPath(c.getParent()),d=new CKEDITOR.dom.elementPath(l.getParent()),e=null,g=null,f=
0;f<a.elements.length;f++){var m=a.elements[f];if(m==a.block||m==a.blockLimit)break;n.checkElementRemovable(m,!0)&&(e=m)}for(f=0;f<d.elements.length;f++){m=d.elements[f];if(m==d.block||m==d.blockLimit)break;n.checkElementRemovable(m,!0)&&(g=m)}g&&l.breakParent(g);e&&c.breakParent(e)}a.enlarge(CKEDITOR.ENLARGE_INLINE,1);var d=a.createBookmark(),c=d.startNode,e=this._.definition.alwaysRemoveElement;if(a.collapsed){for(var g=new CKEDITOR.dom.elementPath(c.getParent(),a.root),f,m=0,h;m<g.elements.length&&
(h=g.elements[m])&&h!=g.block&&h!=g.blockLimit;m++)if(this.checkElementRemovable(h)){var k;!e&&a.collapsed&&(a.checkBoundaryOfElement(h,CKEDITOR.END)||(k=a.checkBoundaryOfElement(h,CKEDITOR.START)))?(f=h,f.match=k?"start":"end"):(h.mergeSiblings(),h.is(this.element)?q.call(this,h):v(h,u(this)[h.getName()]))}if(f){e=c;for(m=0;;m++){h=g.elements[m];if(h.equals(f))break;else if(h.match)continue;else h=h.clone();h.append(e);e=h}e["start"==f.match?"insertBefore":"insertAfter"](f)}}else{var l=d.endNode,
n=this;b();for(g=c;!g.equals(l);)f=g.getNextSourceNode(),g.type==CKEDITOR.NODE_ELEMENT&&this.checkElementRemovable(g)&&(g.getName()==this.element?q.call(this,g):v(g,u(this)[g.getName()]),f.type==CKEDITOR.NODE_ELEMENT&&f.contains(c)&&(b(),f=c.getNext())),g=f}a.moveToBookmark(d);a.shrink(CKEDITOR.NODE_ELEMENT,!0)}function h(a){var b=[];a.forEach(function(a){if("true"==a.getAttribute("contenteditable"))return b.push(a),!1},CKEDITOR.NODE_ELEMENT,!0);return b}function l(a){var b=a.getEnclosedNode()||a.getCommonAncestor(!1,
!0);(a=(new CKEDITOR.dom.elementPath(b,a.root)).contains(this.element,1))&&!a.isReadOnly()&&w(a,this)}function k(a){var b=a.getCommonAncestor(!0,!0);if(a=(new CKEDITOR.dom.elementPath(b,a.root)).contains(this.element,1)){var b=this._.definition,d=b.attributes;if(d)for(var c in d)a.removeAttribute(c,d[c]);if(b.styles)for(var e in b.styles)b.styles.hasOwnProperty(e)&&a.removeStyle(e)}}function f(a){var b=a.createBookmark(!0),d=a.createIterator();d.enforceRealBlocks=!0;this._.enterMode&&(d.enlargeBr=
this._.enterMode!=CKEDITOR.ENTER_BR);for(var c,e=a.document,g;c=d.getNextParagraph();)!c.isReadOnly()&&(d.activeFilter?d.activeFilter.check(this):1)&&(g=r(this,e,c),m(c,g));a.moveToBookmark(b)}function d(a){var b=a.createBookmark(1),d=a.createIterator();d.enforceRealBlocks=!0;d.enlargeBr=this._.enterMode!=CKEDITOR.ENTER_BR;for(var c,e;c=d.getNextParagraph();)this.checkElementRemovable(c)&&(c.is("pre")?((e=this._.enterMode==CKEDITOR.ENTER_BR?null:a.document.createElement(this._.enterMode==CKEDITOR.ENTER_P?
"p":"div"))&&c.copyAttributes(e),m(c,e)):q.call(this,c));a.moveToBookmark(b)}function m(a,b){var d=!b;d&&(b=a.getDocument().createElement("div"),a.copyAttributes(b));var c=b&&b.is("pre"),e=a.is("pre"),f=!c&&e;if(c&&!e){e=b;(f=a.getBogus())&&f.remove();f=a.getHtml();f=n(f,/(?:^[ \t\n\r]+)|(?:[ \t\n\r]+$)/g,"");f=f.replace(/[ \t\r\n]*(<br[^>]*>)[ \t\r\n]*/gi,"$1");f=f.replace(/([ \t\n\r]+|&nbsp;)/g," ");f=f.replace(/<br\b[^>]*>/gi,"\n");if(CKEDITOR.env.ie){var m=a.getDocument().createElement("div");
m.append(e);e.$.outerHTML="\x3cpre\x3e"+f+"\x3c/pre\x3e";e.copyAttributes(m.getFirst());e=m.getFirst().remove()}else e.setHtml(f);b=e}else f?b=p(d?[a.getHtml()]:g(a),b):a.moveChildren(b);b.replace(a);if(c){var d=b,h;(h=d.getPrevious(G))&&h.type==CKEDITOR.NODE_ELEMENT&&h.is("pre")&&(c=n(h.getHtml(),/\n$/,"")+"\n\n"+n(d.getHtml(),/^\n/,""),CKEDITOR.env.ie?d.$.outerHTML="\x3cpre\x3e"+c+"\x3c/pre\x3e":d.setHtml(c),h.remove())}else d&&t(b)}function g(a){var b=[];n(a.getOuterHtml(),/(\S\s*)\n(?:\s|(<span[^>]+data-cke-bookmark.*?\/span>))*\n(?!$)/gi,
function(a,b,d){return b+"\x3c/pre\x3e"+d+"\x3cpre\x3e"}).replace(/<pre\b.*?>([\s\S]*?)<\/pre>/gi,function(a,d){b.push(d)});return b}function n(a,b,d){var c="",e="";a=a.replace(/(^<span[^>]+data-cke-bookmark.*?\/span>)|(<span[^>]+data-cke-bookmark.*?\/span>$)/gi,function(a,b,d){b&&(c=b);d&&(e=d);return""});return c+a.replace(b,d)+e}function p(a,b){var d;1<a.length&&(d=new CKEDITOR.dom.documentFragment(b.getDocument()));for(var c=0;c<a.length;c++){var e=a[c],e=e.replace(/(\r\n|\r)/g,"\n"),e=n(e,/^[ \t]*\n/,
""),e=n(e,/\n$/,""),e=n(e,/^[ \t]+|[ \t]+$/g,function(a,b){return 1==a.length?"\x26nbsp;":b?" "+CKEDITOR.tools.repeat("\x26nbsp;",a.length-1):CKEDITOR.tools.repeat("\x26nbsp;",a.length-1)+" "}),e=e.replace(/\n/g,"\x3cbr\x3e"),e=e.replace(/[ \t]{2,}/g,function(a){return CKEDITOR.tools.repeat("\x26nbsp;",a.length-1)+" "});if(d){var g=b.clone();g.setHtml(e);d.append(g)}else b.setHtml(e)}return d||b}function q(a,b){var d=this._.definition,c=d.attributes,d=d.styles,e=u(this)[a.getName()],g=CKEDITOR.tools.isEmpty(c)&&
CKEDITOR.tools.isEmpty(d),f;for(f in c)if("class"!=f&&!this._.definition.fullMatch||a.getAttribute(f)==B(f,c[f]))b&&"data-"==f.slice(0,5)||(g=a.hasAttribute(f),a.removeAttribute(f));for(var m in d)this._.definition.fullMatch&&a.getStyle(m)!=B(m,d[m],!0)||(g=g||!!a.getStyle(m),a.removeStyle(m));v(a,e,A[a.getName()]);g&&(this._.definition.alwaysRemoveElement?t(a,1):!CKEDITOR.dtd.$block[a.getName()]||this._.enterMode==CKEDITOR.ENTER_BR&&!a.hasAttributes()?t(a):a.renameNode(this._.enterMode==CKEDITOR.ENTER_P?
"p":"div"))}function y(a){for(var b=u(this),d=a.getElementsByTag(this.element),c,e=d.count();0<=--e;)c=d.getItem(e),c.isReadOnly()||q.call(this,c,!0);for(var g in b)if(g!=this.element)for(d=a.getElementsByTag(g),e=d.count()-1;0<=e;e--)c=d.getItem(e),c.isReadOnly()||v(c,b[g])}function v(a,b,d){if(b=b&&b.attributes)for(var c=0;c<b.length;c++){var e=b[c][0],g;if(g=a.getAttribute(e)){var f=b[c][1];(null===f||f.test&&f.test(g)||"string"==typeof f&&g==f)&&a.removeAttribute(e)}}d||t(a)}function t(a,b){if(!a.hasAttributes()||
b)if(CKEDITOR.dtd.$block[a.getName()]){var d=a.getPrevious(G),c=a.getNext(G);!d||d.type!=CKEDITOR.NODE_TEXT&&d.isBlockBoundary({br:1})||a.append("br",1);!c||c.type!=CKEDITOR.NODE_TEXT&&c.isBlockBoundary({br:1})||a.append("br");a.remove(!0)}else d=a.getFirst(),c=a.getLast(),a.remove(!0),d&&(d.type==CKEDITOR.NODE_ELEMENT&&d.mergeSiblings(),c&&!d.equals(c)&&c.type==CKEDITOR.NODE_ELEMENT&&c.mergeSiblings())}function r(a,b,d){var c;c=a.element;"*"==c&&(c="span");c=new CKEDITOR.dom.element(c,b);d&&d.copyAttributes(c);
c=w(c,a);b.getCustomData("doc_processing_style")&&c.hasAttribute("id")?c.removeAttribute("id"):b.setCustomData("doc_processing_style",1);return c}function w(a,b){var d=b._.definition,c=d.attributes,d=CKEDITOR.style.getStyleText(d);if(c)for(var e in c)a.setAttribute(e,c[e]);d&&a.setAttribute("style",d);return a}function z(a,b){for(var d in a)a[d]=a[d].replace(E,function(a,d){return b[d]})}function u(a){if(a._.overrides)return a._.overrides;var b=a._.overrides={},d=a._.definition.overrides;if(d){CKEDITOR.tools.isArray(d)||
(d=[d]);for(var c=0;c<d.length;c++){var e=d[c],g,f;"string"==typeof e?g=e.toLowerCase():(g=e.element?e.element.toLowerCase():a.element,f=e.attributes);e=b[g]||(b[g]={});if(f){var e=e.attributes=e.attributes||[],m;for(m in f)e.push([m.toLowerCase(),f[m]])}}}return b}function B(a,b,d){var c=new CKEDITOR.dom.element("span");c[d?"setStyle":"setAttribute"](a,b);return c[d?"getStyle":"getAttribute"](a)}function C(a,b){function d(a,b){return"font-family"==b.toLowerCase()?a.replace(/["']/g,""):a}"string"==
typeof a&&(a=CKEDITOR.tools.parseCssText(a));"string"==typeof b&&(b=CKEDITOR.tools.parseCssText(b,!0));for(var c in a)if(!(c in b)||d(b[c],c)!=d(a[c],c)&&"inherit"!=a[c]&&"inherit"!=b[c])return!1;return!0}function x(a,b,d){var c=a.document,e=a.getRanges();b=b?this.removeFromRange:this.applyToRange;var g,f;if(a.isFake&&a.isInTable())for(g=[],f=0;f<e.length;f++)g.push(e[f].clone());for(var m=e.createIterator();f=m.getNextRange();)b.call(this,f,d);a.selectRanges(g||e);c.removeCustomData("doc_processing_style")}
var A={address:1,div:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1,p:1,pre:1,section:1,header:1,footer:1,nav:1,article:1,aside:1,figure:1,dialog:1,hgroup:1,time:1,meter:1,menu:1,command:1,keygen:1,output:1,progress:1,details:1,datagrid:1,datalist:1},D={a:1,blockquote:1,embed:1,hr:1,img:1,li:1,object:1,ol:1,table:1,td:1,tr:1,th:1,ul:1,dl:1,dt:1,dd:1,form:1,audio:1,video:1},H=/\s*(?:;\s*|$)/,E=/#\((.+?)\)/g,I=CKEDITOR.dom.walker.bookmark(0,1),G=CKEDITOR.dom.walker.whitespaces(1);CKEDITOR.style=function(a,b){if("string"==
typeof a.type)return new CKEDITOR.style.customHandlers[a.type](a);var d=a.attributes;d&&d.style&&(a.styles=CKEDITOR.tools.extend({},a.styles,CKEDITOR.tools.parseCssText(d.style)),delete d.style);b&&(a=CKEDITOR.tools.clone(a),z(a.attributes,b),z(a.styles,b));d=this.element=a.element?"string"==typeof a.element?a.element.toLowerCase():a.element:"*";this.type=a.type||(A[d]?CKEDITOR.STYLE_BLOCK:D[d]?CKEDITOR.STYLE_OBJECT:CKEDITOR.STYLE_INLINE);"object"==typeof this.element&&(this.type=CKEDITOR.STYLE_OBJECT);
this._={definition:a}};CKEDITOR.style.prototype={apply:function(a){if(a instanceof CKEDITOR.dom.document)return x.call(this,a.getSelection());if(this.checkApplicable(a.elementPath(),a)){var b=this._.enterMode;b||(this._.enterMode=a.activeEnterMode);x.call(this,a.getSelection(),0,a);this._.enterMode=b}},remove:function(a){if(a instanceof CKEDITOR.dom.document)return x.call(this,a.getSelection(),1);if(this.checkApplicable(a.elementPath(),a)){var b=this._.enterMode;b||(this._.enterMode=a.activeEnterMode);
x.call(this,a.getSelection(),1,a);this._.enterMode=b}},applyToRange:function(a){this.applyToRange=this.type==CKEDITOR.STYLE_INLINE?b:this.type==CKEDITOR.STYLE_BLOCK?f:this.type==CKEDITOR.STYLE_OBJECT?l:null;return this.applyToRange(a)},removeFromRange:function(a){this.removeFromRange=this.type==CKEDITOR.STYLE_INLINE?e:this.type==CKEDITOR.STYLE_BLOCK?d:this.type==CKEDITOR.STYLE_OBJECT?k:null;return this.removeFromRange(a)},applyToObject:function(a){w(a,this)},checkActive:function(a,b){switch(this.type){case CKEDITOR.STYLE_BLOCK:return this.checkElementRemovable(a.block||
a.blockLimit,!0,b);case CKEDITOR.STYLE_OBJECT:case CKEDITOR.STYLE_INLINE:for(var d=a.elements,c=0,e;c<d.length;c++)if(e=d[c],this.type!=CKEDITOR.STYLE_INLINE||e!=a.block&&e!=a.blockLimit){if(this.type==CKEDITOR.STYLE_OBJECT){var g=e.getName();if(!("string"==typeof this.element?g==this.element:g in this.element))continue}if(this.checkElementRemovable(e,!0,b))return!0}}return!1},checkApplicable:function(a,b,d){b&&b instanceof CKEDITOR.filter&&(d=b);if(d&&!d.check(this))return!1;switch(this.type){case CKEDITOR.STYLE_OBJECT:return!!a.contains(this.element);
case CKEDITOR.STYLE_BLOCK:return!!a.blockLimit.getDtd()[this.element]}return!0},checkElementMatch:function(a,b){var d=this._.definition;if(!a||!d.ignoreReadonly&&a.isReadOnly())return!1;var c=a.getName();if("string"==typeof this.element?c==this.element:c in this.element){if(!b&&!a.hasAttributes())return!0;if(c=d._AC)d=c;else{var c={},e=0,g=d.attributes;if(g)for(var f in g)e++,c[f]=g[f];if(f=CKEDITOR.style.getStyleText(d))c.style||e++,c.style=f;c._length=e;d=d._AC=c}if(d._length){for(var m in d)if("_length"!=
m)if(c=a.getAttribute(m)||"","style"==m?C(d[m],c):d[m]==c){if(!b)return!0}else if(b)return!1;if(b)return!0}else return!0}return!1},checkElementRemovable:function(a,b,d){if(this.checkElementMatch(a,b,d))return!0;if(b=u(this)[a.getName()]){var c;if(!(b=b.attributes))return!0;for(d=0;d<b.length;d++)if(c=b[d][0],c=a.getAttribute(c)){var e=b[d][1];if(null===e)return!0;if("string"==typeof e){if(c==e)return!0}else if(e.test(c))return!0}}return!1},buildPreview:function(a){var b=this._.definition,d=[],c=b.element;
"bdo"==c&&(c="span");var d=["\x3c",c],e=b.attributes;if(e)for(var g in e)d.push(" ",g,'\x3d"',e[g],'"');(e=CKEDITOR.style.getStyleText(b))&&d.push(' style\x3d"',e,'"');d.push("\x3e",a||b.name,"\x3c/",c,"\x3e");return d.join("")},getDefinition:function(){return this._.definition}};CKEDITOR.style.getStyleText=function(a){var b=a._ST;if(b)return b;var b=a.styles,d=a.attributes&&a.attributes.style||"",c="";d.length&&(d=d.replace(H,";"));for(var e in b){var g=b[e],f=(e+":"+g).replace(H,";");"inherit"==
g?c+=f:d+=f}d.length&&(d=CKEDITOR.tools.normalizeCssText(d,!0));return a._ST=d+c};CKEDITOR.style.customHandlers={};CKEDITOR.style.addCustomHandler=function(a){var b=function(a){this._={definition:a};this.setup&&this.setup(a)};b.prototype=CKEDITOR.tools.extend(CKEDITOR.tools.prototypedCopy(CKEDITOR.style.prototype),{assignedTo:CKEDITOR.STYLE_OBJECT},a,!0);return this.customHandlers[a.type]=b};var K=CKEDITOR.POSITION_PRECEDING|CKEDITOR.POSITION_IDENTICAL|CKEDITOR.POSITION_IS_CONTAINED,J=CKEDITOR.POSITION_FOLLOWING|
CKEDITOR.POSITION_IDENTICAL|CKEDITOR.POSITION_IS_CONTAINED}(),CKEDITOR.styleCommand=function(a,c){this.requiredContent=this.allowedContent=this.style=a;CKEDITOR.tools.extend(this,c,!0)},CKEDITOR.styleCommand.prototype.exec=function(a){a.focus();this.state==CKEDITOR.TRISTATE_OFF?a.applyStyle(this.style):this.state==CKEDITOR.TRISTATE_ON&&a.removeStyle(this.style)},CKEDITOR.stylesSet=new CKEDITOR.resourceManager("","stylesSet"),CKEDITOR.addStylesSet=CKEDITOR.tools.bind(CKEDITOR.stylesSet.add,CKEDITOR.stylesSet),
CKEDITOR.loadStylesSet=function(a,c,b){CKEDITOR.stylesSet.addExternal(a,c,"");CKEDITOR.stylesSet.load(a,b)},CKEDITOR.tools.extend(CKEDITOR.editor.prototype,{attachStyleStateChange:function(a,c){var b=this._.styleStateChangeCallbacks;b||(b=this._.styleStateChangeCallbacks=[],this.on("selectionChange",function(a){for(var c=0;c<b.length;c++){var l=b[c],k=l.style.checkActive(a.data.path,this)?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF;l.fn.call(this,k)}}));b.push({style:a,fn:c})},applyStyle:function(a){a.apply(this)},
removeStyle:function(a){a.remove(this)},getStylesSet:function(a){if(this._.stylesDefinitions)a(this._.stylesDefinitions);else{var c=this,b=c.config.stylesCombo_stylesSet||c.config.stylesSet;if(!1===b)a(null);else if(b instanceof Array)c._.stylesDefinitions=b,a(b);else{b||(b="default");var b=b.split(":"),e=b[0];CKEDITOR.stylesSet.addExternal(e,b[1]?b.slice(1).join(":"):CKEDITOR.getUrl("styles.js"),"");CKEDITOR.stylesSet.load(e,function(b){c._.stylesDefinitions=b[e];a(c._.stylesDefinitions)})}}}}),
CKEDITOR.dom.comment=function(a,c){"string"==typeof a&&(a=(c?c.$:document).createComment(a));CKEDITOR.dom.domObject.call(this,a)},CKEDITOR.dom.comment.prototype=new CKEDITOR.dom.node,CKEDITOR.tools.extend(CKEDITOR.dom.comment.prototype,{type:CKEDITOR.NODE_COMMENT,getOuterHtml:function(){return"\x3c!--"+this.$.nodeValue+"--\x3e"}}),"use strict",function(){var a={},c={},b;for(b in CKEDITOR.dtd.$blockLimit)b in CKEDITOR.dtd.$list||(a[b]=1);for(b in CKEDITOR.dtd.$block)b in CKEDITOR.dtd.$blockLimit||
b in CKEDITOR.dtd.$empty||(c[b]=1);CKEDITOR.dom.elementPath=function(b,h){var l=null,k=null,f=[],d=b,m;h=h||b.getDocument().getBody();d||(d=h);do if(d.type==CKEDITOR.NODE_ELEMENT){f.push(d);if(!this.lastElement&&(this.lastElement=d,d.is(CKEDITOR.dtd.$object)||"false"==d.getAttribute("contenteditable")))continue;if(d.equals(h))break;if(!k&&(m=d.getName(),"true"==d.getAttribute("contenteditable")?k=d:!l&&c[m]&&(l=d),a[m])){if(m=!l&&"div"==m){a:{m=d.getChildren();for(var g=0,n=m.count();g<n;g++){var p=
m.getItem(g);if(p.type==CKEDITOR.NODE_ELEMENT&&CKEDITOR.dtd.$block[p.getName()]){m=!0;break a}}m=!1}m=!m}m?l=d:k=d}}while(d=d.getParent());k||(k=h);this.block=l;this.blockLimit=k;this.root=h;this.elements=f}}(),CKEDITOR.dom.elementPath.prototype={compare:function(a){var c=this.elements;a=a&&a.elements;if(!a||c.length!=a.length)return!1;for(var b=0;b<c.length;b++)if(!c[b].equals(a[b]))return!1;return!0},contains:function(a,c,b){var e=0,h;"string"==typeof a&&(h=function(b){return b.getName()==a});a instanceof
CKEDITOR.dom.element?h=function(b){return b.equals(a)}:CKEDITOR.tools.isArray(a)?h=function(b){return-1<CKEDITOR.tools.indexOf(a,b.getName())}:"function"==typeof a?h=a:"object"==typeof a&&(h=function(b){return b.getName()in a});var l=this.elements,k=l.length;c&&(b?e+=1:--k);b&&(l=Array.prototype.slice.call(l,0),l.reverse());for(;e<k;e++)if(h(l[e]))return l[e];return null},isContextFor:function(a){var c;return a in CKEDITOR.dtd.$block?(c=this.contains(CKEDITOR.dtd.$intermediate)||this.root.equals(this.block)&&
this.block||this.blockLimit,!!c.getDtd()[a]):!0},direction:function(){return(this.block||this.blockLimit||this.root).getDirection(1)}},CKEDITOR.dom.text=function(a,c){"string"==typeof a&&(a=(c?c.$:document).createTextNode(a));this.$=a},CKEDITOR.dom.text.prototype=new CKEDITOR.dom.node,CKEDITOR.tools.extend(CKEDITOR.dom.text.prototype,{type:CKEDITOR.NODE_TEXT,getLength:function(){return this.$.nodeValue.length},getText:function(){return this.$.nodeValue},setText:function(a){this.$.nodeValue=a},split:function(a){var c=
this.$.parentNode,b=c.childNodes.length,e=this.getLength(),h=this.getDocument(),l=new CKEDITOR.dom.text(this.$.splitText(a),h);c.childNodes.length==b&&(a>=e?(l=h.createText(""),l.insertAfter(this)):(a=h.createText(""),a.insertAfter(l),a.remove()));return l},substring:function(a,c){return"number"!=typeof c?this.$.nodeValue.substr(a):this.$.nodeValue.substring(a,c)}}),function(){function a(a,c,h){var l=a.serializable,k=c[h?"endContainer":"startContainer"],f=h?"endOffset":"startOffset",d=l?c.document.getById(a.startNode):
a.startNode;a=l?c.document.getById(a.endNode):a.endNode;k.equals(d.getPrevious())?(c.startOffset=c.startOffset-k.getLength()-a.getPrevious().getLength(),k=a.getNext()):k.equals(a.getPrevious())&&(c.startOffset-=k.getLength(),k=a.getNext());k.equals(d.getParent())&&c[f]++;k.equals(a.getParent())&&c[f]++;c[h?"endContainer":"startContainer"]=k;return c}CKEDITOR.dom.rangeList=function(a){if(a instanceof CKEDITOR.dom.rangeList)return a;a?a instanceof CKEDITOR.dom.range&&(a=[a]):a=[];return CKEDITOR.tools.extend(a,
c)};var c={createIterator:function(){var a=this,c=CKEDITOR.dom.walker.bookmark(),h=[],l;return{getNextRange:function(k){l=void 0===l?0:l+1;var f=a[l];if(f&&1<a.length){if(!l)for(var d=a.length-1;0<=d;d--)h.unshift(a[d].createBookmark(!0));if(k)for(var m=0;a[l+m+1];){var g=f.document;k=0;d=g.getById(h[m].endNode);for(g=g.getById(h[m+1].startNode);;){d=d.getNextSourceNode(!1);if(g.equals(d))k=1;else if(c(d)||d.type==CKEDITOR.NODE_ELEMENT&&d.isBlockBoundary())continue;break}if(!k)break;m++}for(f.moveToBookmark(h.shift());m--;)d=
a[++l],d.moveToBookmark(h.shift()),f.setEnd(d.endContainer,d.endOffset)}return f}}},createBookmarks:function(b){for(var c=[],h,l=0;l<this.length;l++){c.push(h=this[l].createBookmark(b,!0));for(var k=l+1;k<this.length;k++)this[k]=a(h,this[k]),this[k]=a(h,this[k],!0)}return c},createBookmarks2:function(a){for(var c=[],h=0;h<this.length;h++)c.push(this[h].createBookmark2(a));return c},moveToBookmarks:function(a){for(var c=0;c<this.length;c++)this[c].moveToBookmark(a[c])}}}(),function(){function a(){return CKEDITOR.getUrl(CKEDITOR.skinName.split(",")[1]||
"skins/"+CKEDITOR.skinName.split(",")[0]+"/")}function c(b){var d=CKEDITOR.skin["ua_"+b],c=CKEDITOR.env;if(d)for(var d=d.split(",").sort(function(a,b){return a>b?-1:1}),e=0,f;e<d.length;e++)if(f=d[e],c.ie&&(f.replace(/^ie/,"")==c.version||c.quirks&&"iequirks"==f)&&(f="ie"),c[f]){b+="_"+d[e];break}return CKEDITOR.getUrl(a()+b+".css")}function b(a,b){l[a]||(CKEDITOR.document.appendStyleSheet(c(a)),l[a]=1);b&&b()}function e(a){var b=a.getById(k);b||(b=a.getHead().append("style"),b.setAttribute("id",
k),b.setAttribute("type","text/css"));return b}function h(a,b,d){var c,e,f;if(CKEDITOR.env.webkit)for(b=b.split("}").slice(0,-1),e=0;e<b.length;e++)b[e]=b[e].split("{");for(var h=0;h<a.length;h++)if(CKEDITOR.env.webkit)for(e=0;e<b.length;e++){f=b[e][1];for(c=0;c<d.length;c++)f=f.replace(d[c][0],d[c][1]);a[h].$.sheet.addRule(b[e][0],f)}else{f=b;for(c=0;c<d.length;c++)f=f.replace(d[c][0],d[c][1]);CKEDITOR.env.ie&&11>CKEDITOR.env.version?a[h].$.styleSheet.cssText+=f:a[h].$.innerHTML+=f}}var l={};CKEDITOR.skin=
{path:a,loadPart:function(d,c){CKEDITOR.skin.name!=CKEDITOR.skinName.split(",")[0]?CKEDITOR.scriptLoader.load(CKEDITOR.getUrl(a()+"skin.js"),function(){b(d,c)}):b(d,c)},getPath:function(a){return CKEDITOR.getUrl(c(a))},icons:{},addIcon:function(a,b,d,c){a=a.toLowerCase();this.icons[a]||(this.icons[a]={path:b,offset:d||0,bgsize:c||"16px"})},getIconStyle:function(a,b,d,c,e){var f;a&&(a=a.toLowerCase(),b&&(f=this.icons[a+"-rtl"]),f||(f=this.icons[a]));a=d||f&&f.path||"";c=c||f&&f.offset;e=e||f&&f.bgsize||
"16px";a&&(a=a.replace(/'/g,"\\'"));return a&&"background-image:url('"+CKEDITOR.getUrl(a)+"');background-position:0 "+c+"px;background-size:"+e+";"}};CKEDITOR.tools.extend(CKEDITOR.editor.prototype,{getUiColor:function(){return this.uiColor},setUiColor:function(a){var b=e(CKEDITOR.document);return(this.setUiColor=function(a){this.uiColor=a;var c=CKEDITOR.skin.chameleon,e="",m="";"function"==typeof c&&(e=c(this,"editor"),m=c(this,"panel"));a=[[d,a]];h([b],e,a);h(f,m,a)}).call(this,a)}});var k="cke_ui_color",
f=[],d=/\$color/g;CKEDITOR.on("instanceLoaded",function(a){if(!CKEDITOR.env.ie||!CKEDITOR.env.quirks){var b=a.editor;a=function(a){a=(a.data[0]||a.data).element.getElementsByTag("iframe").getItem(0).getFrameDocument();if(!a.getById("cke_ui_color")){a=e(a);f.push(a);var c=b.getUiColor();c&&h([a],CKEDITOR.skin.chameleon(b,"panel"),[[d,c]])}};b.on("panelShow",a);b.on("menuShow",a);b.config.uiColor&&b.setUiColor(b.config.uiColor)}})}(),function(){if(CKEDITOR.env.webkit)CKEDITOR.env.hc=!1;else{var a=CKEDITOR.dom.element.createFromHtml('\x3cdiv style\x3d"width:0;height:0;position:absolute;left:-10000px;border:1px solid;border-color:red blue"\x3e\x3c/div\x3e',
CKEDITOR.document);a.appendTo(CKEDITOR.document.getHead());try{var c=a.getComputedStyle("border-top-color"),b=a.getComputedStyle("border-right-color");CKEDITOR.env.hc=!(!c||c!=b)}catch(e){CKEDITOR.env.hc=!1}a.remove()}CKEDITOR.env.hc&&(CKEDITOR.env.cssClass+=" cke_hc");CKEDITOR.document.appendStyleText(".cke{visibility:hidden;}");CKEDITOR.status="loaded";CKEDITOR.fireOnce("loaded");if(a=CKEDITOR._.pending)for(delete CKEDITOR._.pending,c=0;c<a.length;c++)CKEDITOR.editor.prototype.constructor.apply(a[c][0],
a[c][1]),CKEDITOR.add(a[c][0])}(),CKEDITOR.skin.name="moono-lisa",CKEDITOR.skin.ua_editor="ie,iequirks,ie8,gecko",CKEDITOR.skin.ua_dialog="ie,iequirks,ie8",CKEDITOR.skin.chameleon=function(){var a=function(){return function(a,c){for(var h=a.match(/[^#]./g),l=0;3>l;l++){var k=l,f;f=parseInt(h[l],16);f=("0"+(0>c?0|f*(1+c):0|f+(255-f)*c).toString(16)).slice(-2);h[k]=f}return"#"+h.join("")}}(),c={editor:new CKEDITOR.template("{id}.cke_chrome [border-color:{defaultBorder};] {id} .cke_top [ background-color:{defaultBackground};border-bottom-color:{defaultBorder};] {id} .cke_bottom [background-color:{defaultBackground};border-top-color:{defaultBorder};] {id} .cke_resizer [border-right-color:{ckeResizer}] {id} .cke_dialog_title [background-color:{defaultBackground};border-bottom-color:{defaultBorder};] {id} .cke_dialog_footer [background-color:{defaultBackground};outline-color:{defaultBorder};] {id} .cke_dialog_tab [background-color:{dialogTab};border-color:{defaultBorder};] {id} .cke_dialog_tab:hover [background-color:{lightBackground};] {id} .cke_dialog_contents [border-top-color:{defaultBorder};] {id} .cke_dialog_tab_selected, {id} .cke_dialog_tab_selected:hover [background:{dialogTabSelected};border-bottom-color:{dialogTabSelectedBorder};] {id} .cke_dialog_body [background:{dialogBody};border-color:{defaultBorder};] {id} a.cke_button_off:hover,{id} a.cke_button_off:focus,{id} a.cke_button_off:active [background-color:{darkBackground};border-color:{toolbarElementsBorder};] {id} .cke_button_on [background-color:{ckeButtonOn};border-color:{toolbarElementsBorder};] {id} .cke_toolbar_separator,{id} .cke_toolgroup a.cke_button:last-child:after,{id} .cke_toolgroup a.cke_button.cke_button_disabled:hover:last-child:after [background-color: {toolbarElementsBorder};border-color: {toolbarElementsBorder};] {id} a.cke_combo_button:hover,{id} a.cke_combo_button:focus,{id} .cke_combo_on a.cke_combo_button [border-color:{toolbarElementsBorder};background-color:{darkBackground};] {id} .cke_combo:after [border-color:{toolbarElementsBorder};] {id} .cke_path_item [color:{elementsPathColor};] {id} a.cke_path_item:hover,{id} a.cke_path_item:focus,{id} a.cke_path_item:active [background-color:{darkBackground};] {id}.cke_panel [border-color:{defaultBorder};] "),
panel:new CKEDITOR.template(".cke_panel_grouptitle [background-color:{lightBackground};border-color:{defaultBorder};] .cke_menubutton_icon [background-color:{menubuttonIcon};] .cke_menubutton:hover,.cke_menubutton:focus,.cke_menubutton:active [background-color:{menubuttonHover};] .cke_menubutton:hover .cke_menubutton_icon, .cke_menubutton:focus .cke_menubutton_icon, .cke_menubutton:active .cke_menubutton_icon [background-color:{menubuttonIconHover};] .cke_menubutton_disabled:hover .cke_menubutton_icon,.cke_menubutton_disabled:focus .cke_menubutton_icon,.cke_menubutton_disabled:active .cke_menubutton_icon [background-color:{menubuttonIcon};] .cke_menuseparator [background-color:{menubuttonIcon};] a:hover.cke_colorbox, a:active.cke_colorbox [border-color:{defaultBorder};] a:hover.cke_colorauto, a:hover.cke_colormore, a:active.cke_colorauto, a:active.cke_colormore [background-color:{ckeColorauto};border-color:{defaultBorder};] ")};
return function(b,e){var h=a(b.uiColor,.4),h={id:"."+b.id,defaultBorder:a(h,-.2),toolbarElementsBorder:a(h,-.25),defaultBackground:h,lightBackground:a(h,.8),darkBackground:a(h,-.15),ckeButtonOn:a(h,.4),ckeResizer:a(h,-.4),ckeColorauto:a(h,.8),dialogBody:a(h,.7),dialogTab:a(h,.65),dialogTabSelected:"#FFF",dialogTabSelectedBorder:"#FFF",elementsPathColor:a(h,-.6),menubuttonHover:a(h,.1),menubuttonIcon:a(h,.5),menubuttonIconHover:a(h,.3)};return c[e].output(h).replace(/\[/g,"{").replace(/\]/g,"}")}}(),
CKEDITOR.plugins.add("dialogui",{onLoad:function(){var a=function(a){this._||(this._={});this._["default"]=this._.initValue=a["default"]||"";this._.required=a.required||!1;for(var b=[this._],c=1;c<arguments.length;c++)b.push(arguments[c]);b.push(!0);CKEDITOR.tools.extend.apply(CKEDITOR.tools,b);return this._},c={build:function(a,b,c){return new CKEDITOR.ui.dialog.textInput(a,b,c)}},b={build:function(a,b,c){return new CKEDITOR.ui.dialog[b.type](a,b,c)}},e={isChanged:function(){return this.getValue()!=
this.getInitValue()},reset:function(a){this.setValue(this.getInitValue(),a)},setInitValue:function(){this._.initValue=this.getValue()},resetInitValue:function(){this._.initValue=this._["default"]},getInitValue:function(){return this._.initValue}},h=CKEDITOR.tools.extend({},CKEDITOR.ui.dialog.uiElement.prototype.eventProcessors,{onChange:function(a,b){this._.domOnChangeRegistered||(a.on("load",function(){this.getInputElement().on("change",function(){a.parts.dialog.isVisible()&&this.fire("change",{value:this.getValue()})},
this)},this),this._.domOnChangeRegistered=!0);this.on("change",b)}},!0),l=/^on([A-Z]\w+)/,k=function(a){for(var b in a)(l.test(b)||"title"==b||"type"==b)&&delete a[b];return a},f=function(a){a=a.data.getKeystroke();a==CKEDITOR.SHIFT+CKEDITOR.ALT+36?this.setDirectionMarker("ltr"):a==CKEDITOR.SHIFT+CKEDITOR.ALT+35&&this.setDirectionMarker("rtl")};CKEDITOR.tools.extend(CKEDITOR.ui.dialog,{labeledElement:function(b,c,e,f){if(!(4>arguments.length)){var h=a.call(this,c);h.labelId=CKEDITOR.tools.getNextId()+
"_label";this._.children=[];var k={role:c.role||"presentation"};c.includeLabel&&(k["aria-labelledby"]=h.labelId);CKEDITOR.ui.dialog.uiElement.call(this,b,c,e,"div",null,k,function(){var a=[],e=c.required?" cke_required":"";"horizontal"!=c.labelLayout?a.push('\x3clabel class\x3d"cke_dialog_ui_labeled_label'+e+'" ',' id\x3d"'+h.labelId+'"',h.inputId?' for\x3d"'+h.inputId+'"':"",(c.labelStyle?' style\x3d"'+c.labelStyle+'"':"")+"\x3e",c.label,"\x3c/label\x3e",'\x3cdiv class\x3d"cke_dialog_ui_labeled_content"',
c.controlStyle?' style\x3d"'+c.controlStyle+'"':"",' role\x3d"presentation"\x3e',f.call(this,b,c),"\x3c/div\x3e"):(e={type:"hbox",widths:c.widths,padding:0,children:[{type:"html",html:'\x3clabel class\x3d"cke_dialog_ui_labeled_label'+e+'" id\x3d"'+h.labelId+'" for\x3d"'+h.inputId+'"'+(c.labelStyle?' style\x3d"'+c.labelStyle+'"':"")+"\x3e"+CKEDITOR.tools.htmlEncode(c.label)+"\x3c/label\x3e"},{type:"html",html:'\x3cspan class\x3d"cke_dialog_ui_labeled_content"'+(c.controlStyle?' style\x3d"'+c.controlStyle+
'"':"")+"\x3e"+f.call(this,b,c)+"\x3c/span\x3e"}]},CKEDITOR.dialog._.uiElementBuilders.hbox.build(b,e,a));return a.join("")})}},textInput:function(b,c,e){if(!(3>arguments.length)){a.call(this,c);var h=this._.inputId=CKEDITOR.tools.getNextId()+"_textInput",k={"class":"cke_dialog_ui_input_"+c.type,id:h,type:c.type};c.validate&&(this.validate=c.validate);c.maxLength&&(k.maxlength=c.maxLength);c.size&&(k.size=c.size);c.inputStyle&&(k.style=c.inputStyle);var l=this,y=!1;b.on("load",function(){l.getInputElement().on("keydown",
function(a){13==a.data.getKeystroke()&&(y=!0)});l.getInputElement().on("keyup",function(a){13==a.data.getKeystroke()&&y&&(b.getButton("ok")&&setTimeout(function(){b.getButton("ok").click()},0),y=!1);l.bidi&&f.call(l,a)},null,null,1E3)});CKEDITOR.ui.dialog.labeledElement.call(this,b,c,e,function(){var a=['\x3cdiv class\x3d"cke_dialog_ui_input_',c.type,'" role\x3d"presentation"'];c.width&&a.push('style\x3d"width:'+c.width+'" ');a.push("\x3e\x3cinput ");k["aria-labelledby"]=this._.labelId;this._.required&&
(k["aria-required"]=this._.required);for(var b in k)a.push(b+'\x3d"'+k[b]+'" ');a.push(" /\x3e\x3c/div\x3e");return a.join("")})}},textarea:function(b,c,e){if(!(3>arguments.length)){a.call(this,c);var h=this,k=this._.inputId=CKEDITOR.tools.getNextId()+"_textarea",l={};c.validate&&(this.validate=c.validate);l.rows=c.rows||5;l.cols=c.cols||20;l["class"]="cke_dialog_ui_input_textarea "+(c["class"]||"");"undefined"!=typeof c.inputStyle&&(l.style=c.inputStyle);c.dir&&(l.dir=c.dir);if(h.bidi)b.on("load",
function(){h.getInputElement().on("keyup",f)},h);CKEDITOR.ui.dialog.labeledElement.call(this,b,c,e,function(){l["aria-labelledby"]=this._.labelId;this._.required&&(l["aria-required"]=this._.required);var a=['\x3cdiv class\x3d"cke_dialog_ui_input_textarea" role\x3d"presentation"\x3e\x3ctextarea id\x3d"',k,'" '],b;for(b in l)a.push(b+'\x3d"'+CKEDITOR.tools.htmlEncode(l[b])+'" ');a.push("\x3e",CKEDITOR.tools.htmlEncode(h._["default"]),"\x3c/textarea\x3e\x3c/div\x3e");return a.join("")})}},checkbox:function(b,
c,e){if(!(3>arguments.length)){var f=a.call(this,c,{"default":!!c["default"]});c.validate&&(this.validate=c.validate);CKEDITOR.ui.dialog.uiElement.call(this,b,c,e,"span",null,null,function(){var a=CKEDITOR.tools.extend({},c,{id:c.id?c.id+"_checkbox":CKEDITOR.tools.getNextId()+"_checkbox"},!0),e=[],g=CKEDITOR.tools.getNextId()+"_label",h={"class":"cke_dialog_ui_checkbox_input",type:"checkbox","aria-labelledby":g};k(a);c["default"]&&(h.checked="checked");"undefined"!=typeof a.inputStyle&&(a.style=a.inputStyle);
f.checkbox=new CKEDITOR.ui.dialog.uiElement(b,a,e,"input",null,h);e.push(' \x3clabel id\x3d"',g,'" for\x3d"',h.id,'"'+(c.labelStyle?' style\x3d"'+c.labelStyle+'"':"")+"\x3e",CKEDITOR.tools.htmlEncode(c.label),"\x3c/label\x3e");return e.join("")})}},radio:function(b,c,e){if(!(3>arguments.length)){a.call(this,c);this._["default"]||(this._["default"]=this._.initValue=c.items[0][1]);c.validate&&(this.validate=c.validate);var f=[],h=this;c.role="radiogroup";c.includeLabel=!0;CKEDITOR.ui.dialog.labeledElement.call(this,
b,c,e,function(){for(var a=[],e=[],g=(c.id?c.id:CKEDITOR.tools.getNextId())+"_radio",l=0;l<c.items.length;l++){var r=c.items[l],w=void 0!==r[2]?r[2]:r[0],z=void 0!==r[1]?r[1]:r[0],u=CKEDITOR.tools.getNextId()+"_radio_input",B=u+"_label",u=CKEDITOR.tools.extend({},c,{id:u,title:null,type:null},!0),w=CKEDITOR.tools.extend({},u,{title:w},!0),C={type:"radio","class":"cke_dialog_ui_radio_input",name:g,value:z,"aria-labelledby":B},x=[];h._["default"]==z&&(C.checked="checked");k(u);k(w);"undefined"!=typeof u.inputStyle&&
(u.style=u.inputStyle);u.keyboardFocusable=!0;f.push(new CKEDITOR.ui.dialog.uiElement(b,u,x,"input",null,C));x.push(" ");new CKEDITOR.ui.dialog.uiElement(b,w,x,"label",null,{id:B,"for":C.id},r[0]);a.push(x.join(""))}new CKEDITOR.ui.dialog.hbox(b,f,a,e);return e.join("")});this._.children=f}},button:function(b,c,e){if(arguments.length){"function"==typeof c&&(c=c(b.getParentEditor()));a.call(this,c,{disabled:c.disabled||!1});CKEDITOR.event.implementOn(this);var f=this;b.on("load",function(){var a=this.getElement();
(function(){a.on("click",function(a){f.click();a.data.preventDefault()});a.on("keydown",function(a){a.data.getKeystroke()in{32:1}&&(f.click(),a.data.preventDefault())})})();a.unselectable()},this);var h=CKEDITOR.tools.extend({},c);delete h.style;var k=CKEDITOR.tools.getNextId()+"_label";CKEDITOR.ui.dialog.uiElement.call(this,b,h,e,"a",null,{style:c.style,href:"javascript:void(0)",title:c.label,hidefocus:"true","class":c["class"],role:"button","aria-labelledby":k},'\x3cspan id\x3d"'+k+'" class\x3d"cke_dialog_ui_button"\x3e'+
CKEDITOR.tools.htmlEncode(c.label)+"\x3c/span\x3e")}},select:function(b,c,e){if(!(3>arguments.length)){var f=a.call(this,c);c.validate&&(this.validate=c.validate);f.inputId=CKEDITOR.tools.getNextId()+"_select";CKEDITOR.ui.dialog.labeledElement.call(this,b,c,e,function(){var a=CKEDITOR.tools.extend({},c,{id:c.id?c.id+"_select":CKEDITOR.tools.getNextId()+"_select"},!0),e=[],g=[],h={id:f.inputId,"class":"cke_dialog_ui_input_select","aria-labelledby":this._.labelId};e.push('\x3cdiv class\x3d"cke_dialog_ui_input_',
c.type,'" role\x3d"presentation"');c.width&&e.push('style\x3d"width:'+c.width+'" ');e.push("\x3e");void 0!==c.size&&(h.size=c.size);void 0!==c.multiple&&(h.multiple=c.multiple);k(a);for(var l=0,r;l<c.items.length&&(r=c.items[l]);l++)g.push('\x3coption value\x3d"',CKEDITOR.tools.htmlEncode(void 0!==r[1]?r[1]:r[0]).replace(/"/g,"\x26quot;"),'" /\x3e ',CKEDITOR.tools.htmlEncode(r[0]));"undefined"!=typeof a.inputStyle&&(a.style=a.inputStyle);f.select=new CKEDITOR.ui.dialog.uiElement(b,a,e,"select",null,
h,g.join(""));e.push("\x3c/div\x3e");return e.join("")})}},file:function(b,c,e){if(!(3>arguments.length)){void 0===c["default"]&&(c["default"]="");var f=CKEDITOR.tools.extend(a.call(this,c),{definition:c,buttons:[]});c.validate&&(this.validate=c.validate);b.on("load",function(){CKEDITOR.document.getById(f.frameId).getParent().addClass("cke_dialog_ui_input_file")});CKEDITOR.ui.dialog.labeledElement.call(this,b,c,e,function(){f.frameId=CKEDITOR.tools.getNextId()+"_fileInput";var a=['\x3ciframe frameborder\x3d"0" allowtransparency\x3d"0" class\x3d"cke_dialog_ui_input_file" role\x3d"presentation" id\x3d"',
f.frameId,'" title\x3d"',c.label,'" src\x3d"javascript:void('];a.push(CKEDITOR.env.ie?"(function(){"+encodeURIComponent("document.open();("+CKEDITOR.tools.fixDomain+")();document.close();")+"})()":"0");a.push(')"\x3e\x3c/iframe\x3e');return a.join("")})}},fileButton:function(b,c,e){var f=this;if(!(3>arguments.length)){a.call(this,c);c.validate&&(this.validate=c.validate);var h=CKEDITOR.tools.extend({},c),k=h.onClick;h.className=(h.className?h.className+" ":"")+"cke_dialog_ui_button";h.onClick=function(a){var e=
c["for"];k&&!1===k.call(this,a)||(b.getContentElement(e[0],e[1]).submit(),this.disable())};b.on("load",function(){b.getContentElement(c["for"][0],c["for"][1])._.buttons.push(f)});CKEDITOR.ui.dialog.button.call(this,b,h,e)}},html:function(){var a=/^\s*<[\w:]+\s+([^>]*)?>/,b=/^(\s*<[\w:]+(?:\s+[^>]*)?)((?:.|\r|\n)+)$/,c=/\/$/;return function(e,f,h){if(!(3>arguments.length)){var k=[],l=f.html;"\x3c"!=l.charAt(0)&&(l="\x3cspan\x3e"+l+"\x3c/span\x3e");var t=f.focus;if(t){var r=this.focus;this.focus=function(){("function"==
typeof t?t:r).call(this);this.fire("focus")};f.isFocusable&&(this.isFocusable=this.isFocusable);this.keyboardFocusable=!0}CKEDITOR.ui.dialog.uiElement.call(this,e,f,k,"span",null,null,"");k=k.join("").match(a);l=l.match(b)||["","",""];c.test(l[1])&&(l[1]=l[1].slice(0,-1),l[2]="/"+l[2]);h.push([l[1]," ",k[1]||"",l[2]].join(""))}}}(),fieldset:function(a,b,c,e,f){var h=f.label;this._={children:b};CKEDITOR.ui.dialog.uiElement.call(this,a,f,e,"fieldset",null,null,function(){var a=[];h&&a.push("\x3clegend"+
(f.labelStyle?' style\x3d"'+f.labelStyle+'"':"")+"\x3e"+h+"\x3c/legend\x3e");for(var b=0;b<c.length;b++)a.push(c[b]);return a.join("")})}},!0);CKEDITOR.ui.dialog.html.prototype=new CKEDITOR.ui.dialog.uiElement;CKEDITOR.ui.dialog.labeledElement.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.uiElement,{setLabel:function(a){var b=CKEDITOR.document.getById(this._.labelId);1>b.getChildCount()?(new CKEDITOR.dom.text(a,CKEDITOR.document)).appendTo(b):b.getChild(0).$.nodeValue=a;return this},getLabel:function(){var a=
CKEDITOR.document.getById(this._.labelId);return!a||1>a.getChildCount()?"":a.getChild(0).getText()},eventProcessors:h},!0);CKEDITOR.ui.dialog.button.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.uiElement,{click:function(){return this._.disabled?!1:this.fire("click",{dialog:this._.dialog})},enable:function(){this._.disabled=!1;var a=this.getElement();a&&a.removeClass("cke_disabled")},disable:function(){this._.disabled=!0;this.getElement().addClass("cke_disabled")},isVisible:function(){return this.getElement().getFirst().isVisible()},
isEnabled:function(){return!this._.disabled},eventProcessors:CKEDITOR.tools.extend({},CKEDITOR.ui.dialog.uiElement.prototype.eventProcessors,{onClick:function(a,b){this.on("click",function(){b.apply(this,arguments)})}},!0),accessKeyUp:function(){this.click()},accessKeyDown:function(){this.focus()},keyboardFocusable:!0},!0);CKEDITOR.ui.dialog.textInput.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.labeledElement,{getInputElement:function(){return CKEDITOR.document.getById(this._.inputId)},
focus:function(){var a=this.selectParentTab();setTimeout(function(){var b=a.getInputElement();b&&b.$.focus()},0)},select:function(){var a=this.selectParentTab();setTimeout(function(){var b=a.getInputElement();b&&(b.$.focus(),b.$.select())},0)},accessKeyUp:function(){this.select()},setValue:function(a){if(this.bidi){var b=a&&a.charAt(0);(b="‪"==b?"ltr":"‫"==b?"rtl":null)&&(a=a.slice(1));this.setDirectionMarker(b)}a||(a="");return CKEDITOR.ui.dialog.uiElement.prototype.setValue.apply(this,arguments)},
getValue:function(){var a=CKEDITOR.ui.dialog.uiElement.prototype.getValue.call(this);if(this.bidi&&a){var b=this.getDirectionMarker();b&&(a=("ltr"==b?"‪":"‫")+a)}return a},setDirectionMarker:function(a){var b=this.getInputElement();a?b.setAttributes({dir:a,"data-cke-dir-marker":a}):this.getDirectionMarker()&&b.removeAttributes(["dir","data-cke-dir-marker"])},getDirectionMarker:function(){return this.getInputElement().data("cke-dir-marker")},keyboardFocusable:!0},e,!0);CKEDITOR.ui.dialog.textarea.prototype=
new CKEDITOR.ui.dialog.textInput;CKEDITOR.ui.dialog.select.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.labeledElement,{getInputElement:function(){return this._.select.getElement()},add:function(a,b,c){var e=new CKEDITOR.dom.element("option",this.getDialog().getParentEditor().document),f=this.getInputElement().$;e.$.text=a;e.$.value=void 0===b||null===b?a:b;void 0===c||null===c?CKEDITOR.env.ie?f.add(e.$):f.add(e.$,null):f.add(e.$,c);return this},remove:function(a){this.getInputElement().$.remove(a);
return this},clear:function(){for(var a=this.getInputElement().$;0<a.length;)a.remove(0);return this},keyboardFocusable:!0},e,!0);CKEDITOR.ui.dialog.checkbox.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.uiElement,{getInputElement:function(){return this._.checkbox.getElement()},setValue:function(a,b){this.getInputElement().$.checked=a;!b&&this.fire("change",{value:a})},getValue:function(){return this.getInputElement().$.checked},accessKeyUp:function(){this.setValue(!this.getValue())},eventProcessors:{onChange:function(a,
b){if(!CKEDITOR.env.ie||8<CKEDITOR.env.version)return h.onChange.apply(this,arguments);a.on("load",function(){var a=this._.checkbox.getElement();a.on("propertychange",function(b){b=b.data.$;"checked"==b.propertyName&&this.fire("change",{value:a.$.checked})},this)},this);this.on("change",b);return null}},keyboardFocusable:!0},e,!0);CKEDITOR.ui.dialog.radio.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.uiElement,{setValue:function(a,b){for(var c=this._.children,e,f=0;f<c.length&&(e=c[f]);f++)e.getElement().$.checked=
e.getValue()==a;!b&&this.fire("change",{value:a})},getValue:function(){for(var a=this._.children,b=0;b<a.length;b++)if(a[b].getElement().$.checked)return a[b].getValue();return null},accessKeyUp:function(){var a=this._.children,b;for(b=0;b<a.length;b++)if(a[b].getElement().$.checked){a[b].getElement().focus();return}a[0].getElement().focus()},eventProcessors:{onChange:function(a,b){if(!CKEDITOR.env.ie||8<CKEDITOR.env.version)return h.onChange.apply(this,arguments);a.on("load",function(){for(var a=
this._.children,b=this,d=0;d<a.length;d++)a[d].getElement().on("propertychange",function(a){a=a.data.$;"checked"==a.propertyName&&this.$.checked&&b.fire("change",{value:this.getAttribute("value")})})},this);this.on("change",b);return null}}},e,!0);CKEDITOR.ui.dialog.file.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.labeledElement,e,{getInputElement:function(){var a=CKEDITOR.document.getById(this._.frameId).getFrameDocument();return 0<a.$.forms.length?new CKEDITOR.dom.element(a.$.forms[0].elements[0]):
this.getElement()},submit:function(){this.getInputElement().getParent().$.submit();return this},getAction:function(){return this.getInputElement().getParent().$.action},registerEvents:function(a){var b=/^on([A-Z]\w+)/,c,e=function(a,b,d,c){a.on("formLoaded",function(){a.getInputElement().on(d,c,a)})},f;for(f in a)if(c=f.match(b))this.eventProcessors[f]?this.eventProcessors[f].call(this,this._.dialog,a[f]):e(this,this._.dialog,c[1].toLowerCase(),a[f]);return this},reset:function(){function a(){c.$.open();
var d="";e.size&&(d=e.size-(CKEDITOR.env.ie?7:0));var w=b.frameId+"_input";c.$.write(['\x3chtml dir\x3d"'+l+'" lang\x3d"'+t+'"\x3e\x3chead\x3e\x3ctitle\x3e\x3c/title\x3e\x3c/head\x3e\x3cbody style\x3d"margin: 0; overflow: hidden; background: transparent;"\x3e','\x3cform enctype\x3d"multipart/form-data" method\x3d"POST" dir\x3d"'+l+'" lang\x3d"'+t+'" action\x3d"',CKEDITOR.tools.htmlEncode(e.action),'"\x3e\x3clabel id\x3d"',b.labelId,'" for\x3d"',w,'" style\x3d"display:none"\x3e',CKEDITOR.tools.htmlEncode(e.label),
'\x3c/label\x3e\x3cinput style\x3d"width:100%" id\x3d"',w,'" aria-labelledby\x3d"',b.labelId,'" type\x3d"file" name\x3d"',CKEDITOR.tools.htmlEncode(e.id||"cke_upload"),'" size\x3d"',CKEDITOR.tools.htmlEncode(0<d?d:""),'" /\x3e\x3c/form\x3e\x3c/body\x3e\x3c/html\x3e\x3cscript\x3e',CKEDITOR.env.ie?"("+CKEDITOR.tools.fixDomain+")();":"","window.parent.CKEDITOR.tools.callFunction("+h+");","window.onbeforeunload \x3d function() {window.parent.CKEDITOR.tools.callFunction("+k+")}","\x3c/script\x3e"].join(""));
c.$.close();for(d=0;d<f.length;d++)f[d].enable()}var b=this._,c=CKEDITOR.document.getById(b.frameId).getFrameDocument(),e=b.definition,f=b.buttons,h=this.formLoadedNumber,k=this.formUnloadNumber,l=b.dialog._.editor.lang.dir,t=b.dialog._.editor.langCode;h||(h=this.formLoadedNumber=CKEDITOR.tools.addFunction(function(){this.fire("formLoaded")},this),k=this.formUnloadNumber=CKEDITOR.tools.addFunction(function(){this.getInputElement().clearCustomData()},this),this.getDialog()._.editor.on("destroy",function(){CKEDITOR.tools.removeFunction(h);
CKEDITOR.tools.removeFunction(k)}));CKEDITOR.env.gecko?setTimeout(a,500):a()},getValue:function(){return this.getInputElement().$.value||""},setInitValue:function(){this._.initValue=""},eventProcessors:{onChange:function(a,b){this._.domOnChangeRegistered||(this.on("formLoaded",function(){this.getInputElement().on("change",function(){this.fire("change",{value:this.getValue()})},this)},this),this._.domOnChangeRegistered=!0);this.on("change",b)}},keyboardFocusable:!0},!0);CKEDITOR.ui.dialog.fileButton.prototype=
new CKEDITOR.ui.dialog.button;CKEDITOR.ui.dialog.fieldset.prototype=CKEDITOR.tools.clone(CKEDITOR.ui.dialog.hbox.prototype);CKEDITOR.dialog.addUIElement("text",c);CKEDITOR.dialog.addUIElement("password",c);CKEDITOR.dialog.addUIElement("textarea",b);CKEDITOR.dialog.addUIElement("checkbox",b);CKEDITOR.dialog.addUIElement("radio",b);CKEDITOR.dialog.addUIElement("button",b);CKEDITOR.dialog.addUIElement("select",b);CKEDITOR.dialog.addUIElement("file",b);CKEDITOR.dialog.addUIElement("fileButton",b);CKEDITOR.dialog.addUIElement("html",
b);CKEDITOR.dialog.addUIElement("fieldset",{build:function(a,b,c){for(var e=b.children,f,h=[],k=[],l=0;l<e.length&&(f=e[l]);l++){var t=[];h.push(t);k.push(CKEDITOR.dialog._.uiElementBuilders[f.type].build(a,f,t))}return new CKEDITOR.ui.dialog[b.type](a,k,h,c,b)}})}}),CKEDITOR.DIALOG_RESIZE_NONE=0,CKEDITOR.DIALOG_RESIZE_WIDTH=1,CKEDITOR.DIALOG_RESIZE_HEIGHT=2,CKEDITOR.DIALOG_RESIZE_BOTH=3,CKEDITOR.DIALOG_STATE_IDLE=1,CKEDITOR.DIALOG_STATE_BUSY=2,function(){function a(){for(var a=this._.tabIdList.length,
b=CKEDITOR.tools.indexOf(this._.tabIdList,this._.currentTabId)+a,d=b-1;d>b-a;d--)if(this._.tabs[this._.tabIdList[d%a]][0].$.offsetHeight)return this._.tabIdList[d%a];return null}function c(){for(var a=this._.tabIdList.length,b=CKEDITOR.tools.indexOf(this._.tabIdList,this._.currentTabId),d=b+1;d<b+a;d++)if(this._.tabs[this._.tabIdList[d%a]][0].$.offsetHeight)return this._.tabIdList[d%a];return null}function b(a,b){for(var d=a.$.getElementsByTagName("input"),c=0,e=d.length;c<e;c++){var g=new CKEDITOR.dom.element(d[c]);
"text"==g.getAttribute("type").toLowerCase()&&(b?(g.setAttribute("value",g.getCustomData("fake_value")||""),g.removeCustomData("fake_value")):(g.setCustomData("fake_value",g.getAttribute("value")),g.setAttribute("value","")))}}function e(a,b){var d=this.getInputElement();d&&(a?d.removeAttribute("aria-invalid"):d.setAttribute("aria-invalid",!0));a||(this.select?this.select():this.focus());b&&alert(b);this.fire("validated",{valid:a,msg:b})}function h(){var a=this.getInputElement();a&&a.removeAttribute("aria-invalid")}
function l(a){var b=CKEDITOR.dom.element.createFromHtml(CKEDITOR.addTemplate("dialog",v).output({id:CKEDITOR.tools.getNextNumber(),editorId:a.id,langDir:a.lang.dir,langCode:a.langCode,editorDialogClass:"cke_editor_"+a.name.replace(/\./g,"\\.")+"_dialog",closeTitle:a.lang.common.close,hidpi:CKEDITOR.env.hidpi?"cke_hidpi":""})),d=b.getChild([0,0,0,0,0]),c=d.getChild(0),e=d.getChild(1);a.plugins.clipboard&&CKEDITOR.plugins.clipboard.preventDefaultDropOnElement(d);!CKEDITOR.env.ie||CKEDITOR.env.quirks||
CKEDITOR.env.edge||(a="javascript:void(function(){"+encodeURIComponent("document.open();("+CKEDITOR.tools.fixDomain+")();document.close();")+"}())",CKEDITOR.dom.element.createFromHtml('\x3ciframe frameBorder\x3d"0" class\x3d"cke_iframe_shim" src\x3d"'+a+'" tabIndex\x3d"-1"\x3e\x3c/iframe\x3e').appendTo(d.getParent()));c.unselectable();e.unselectable();return{element:b,parts:{dialog:b.getChild(0),title:c,close:e,tabs:d.getChild(2),contents:d.getChild([3,0,0,0]),footer:d.getChild([3,0,1,0])}}}function k(a,
b,d){this.element=b;this.focusIndex=d;this.tabIndex=0;this.isFocusable=function(){return!b.getAttribute("disabled")&&b.isVisible()};this.focus=function(){a._.currentFocusIndex=this.focusIndex;this.element.focus()};b.on("keydown",function(a){a.data.getKeystroke()in{32:1,13:1}&&this.fire("click")});b.on("focus",function(){this.fire("mouseover")});b.on("blur",function(){this.fire("mouseout")})}function f(a){function b(){a.layout()}var d=CKEDITOR.document.getWindow();d.on("resize",b);a.on("hide",function(){d.removeListener("resize",
b)})}function d(a,b){this._={dialog:a};CKEDITOR.tools.extend(this,b)}function m(a){function b(d){var m=a.getSize(),k=CKEDITOR.document.getWindow().getViewPaneSize(),l=d.data.$.screenX,n=d.data.$.screenY,r=l-c.x,t=n-c.y;c={x:l,y:n};e.x+=r;e.y+=t;a.move(e.x+h[3]<f?-h[3]:e.x-h[1]>k.width-m.width-f?k.width-m.width+("rtl"==g.lang.dir?0:h[1]):e.x,e.y+h[0]<f?-h[0]:e.y-h[2]>k.height-m.height-f?k.height-m.height+h[2]:e.y,1);d.data.preventDefault()}function d(){CKEDITOR.document.removeListener("mousemove",
b);CKEDITOR.document.removeListener("mouseup",d);if(CKEDITOR.env.ie6Compat){var a=x.getChild(0).getFrameDocument();a.removeListener("mousemove",b);a.removeListener("mouseup",d)}}var c=null,e=null,g=a.getParentEditor(),f=g.config.dialog_magnetDistance,h=CKEDITOR.skin.margins||[0,0,0,0];"undefined"==typeof f&&(f=20);a.parts.title.on("mousedown",function(g){c={x:g.data.$.screenX,y:g.data.$.screenY};CKEDITOR.document.on("mousemove",b);CKEDITOR.document.on("mouseup",d);e=a.getPosition();if(CKEDITOR.env.ie6Compat){var f=
x.getChild(0).getFrameDocument();f.on("mousemove",b);f.on("mouseup",d)}g.data.preventDefault()},a)}function g(a){function b(d){var n="rtl"==g.lang.dir,r=l.width,t=l.height,w=r+(d.data.$.screenX-k.x)*(n?-1:1)*(a._.moved?1:2),u=t+(d.data.$.screenY-k.y)*(a._.moved?1:2),p=a._.element.getFirst(),p=n&&p.getComputedStyle("right"),z=a.getPosition();z.y+u>m.height&&(u=m.height-z.y);(n?p:z.x)+w>m.width&&(w=m.width-(n?p:z.x));if(e==CKEDITOR.DIALOG_RESIZE_WIDTH||e==CKEDITOR.DIALOG_RESIZE_BOTH)r=Math.max(c.minWidth||
0,w-f);if(e==CKEDITOR.DIALOG_RESIZE_HEIGHT||e==CKEDITOR.DIALOG_RESIZE_BOTH)t=Math.max(c.minHeight||0,u-h);a.resize(r,t);a._.moved||a.layout();d.data.preventDefault()}function d(){CKEDITOR.document.removeListener("mouseup",d);CKEDITOR.document.removeListener("mousemove",b);n&&(n.remove(),n=null);if(CKEDITOR.env.ie6Compat){var a=x.getChild(0).getFrameDocument();a.removeListener("mouseup",d);a.removeListener("mousemove",b)}}var c=a.definition,e=c.resizable;if(e!=CKEDITOR.DIALOG_RESIZE_NONE){var g=a.getParentEditor(),
f,h,m,k,l,n,r=CKEDITOR.tools.addFunction(function(c){l=a.getSize();var e=a.parts.contents;e.$.getElementsByTagName("iframe").length&&(n=CKEDITOR.dom.element.createFromHtml('\x3cdiv class\x3d"cke_dialog_resize_cover" style\x3d"height: 100%; position: absolute; width: 100%;"\x3e\x3c/div\x3e'),e.append(n));h=l.height-a.parts.contents.getSize("height",!(CKEDITOR.env.gecko||CKEDITOR.env.ie&&CKEDITOR.env.quirks));f=l.width-a.parts.contents.getSize("width",1);k={x:c.screenX,y:c.screenY};m=CKEDITOR.document.getWindow().getViewPaneSize();
CKEDITOR.document.on("mousemove",b);CKEDITOR.document.on("mouseup",d);CKEDITOR.env.ie6Compat&&(e=x.getChild(0).getFrameDocument(),e.on("mousemove",b),e.on("mouseup",d));c.preventDefault&&c.preventDefault()});a.on("load",function(){var b="";e==CKEDITOR.DIALOG_RESIZE_WIDTH?b=" cke_resizer_horizontal":e==CKEDITOR.DIALOG_RESIZE_HEIGHT&&(b=" cke_resizer_vertical");b=CKEDITOR.dom.element.createFromHtml('\x3cdiv class\x3d"cke_resizer'+b+" cke_resizer_"+g.lang.dir+'" title\x3d"'+CKEDITOR.tools.htmlEncode(g.lang.common.resize)+
'" onmousedown\x3d"CKEDITOR.tools.callFunction('+r+', event )"\x3e'+("ltr"==g.lang.dir?"◢":"◣")+"\x3c/div\x3e");a.parts.footer.append(b,1)});g.on("destroy",function(){CKEDITOR.tools.removeFunction(r)})}}function n(a){a.data.preventDefault(1)}function p(a){var b=CKEDITOR.document.getWindow(),d=a.config,c=CKEDITOR.skinName||a.config.skin,e=d.dialog_backgroundCoverColor||("moono-lisa"==c?"black":"white"),c=d.dialog_backgroundCoverOpacity,g=d.baseFloatZIndex,d=CKEDITOR.tools.genKey(e,c,g),f=C[d];f?f.show():
(g=['\x3cdiv tabIndex\x3d"-1" style\x3d"position: ',CKEDITOR.env.ie6Compat?"absolute":"fixed","; z-index: ",g,"; top: 0px; left: 0px; ",CKEDITOR.env.ie6Compat?"":"background-color: "+e,'" class\x3d"cke_dialog_background_cover"\x3e'],CKEDITOR.env.ie6Compat&&(e="\x3chtml\x3e\x3cbody style\x3d\\'background-color:"+e+";\\'\x3e\x3c/body\x3e\x3c/html\x3e",g.push('\x3ciframe hidefocus\x3d"true" frameborder\x3d"0" id\x3d"cke_dialog_background_iframe" src\x3d"javascript:'),g.push("void((function(){"+encodeURIComponent("document.open();("+
CKEDITOR.tools.fixDomain+")();document.write( '"+e+"' );document.close();")+"})())"),g.push('" style\x3d"position:absolute;left:0;top:0;width:100%;height: 100%;filter: progid:DXImageTransform.Microsoft.Alpha(opacity\x3d0)"\x3e\x3c/iframe\x3e')),g.push("\x3c/div\x3e"),f=CKEDITOR.dom.element.createFromHtml(g.join("")),f.setOpacity(void 0!==c?c:.5),f.on("keydown",n),f.on("keypress",n),f.on("keyup",n),f.appendTo(CKEDITOR.document.getBody()),C[d]=f);a.focusManager.add(f);x=f;a=function(){var a=b.getViewPaneSize();
f.setStyles({width:a.width+"px",height:a.height+"px"})};var h=function(){var a=b.getScrollPosition(),d=CKEDITOR.dialog._.currentTop;f.setStyles({left:a.x+"px",top:a.y+"px"});if(d){do a=d.getPosition(),d.move(a.x,a.y);while(d=d._.parentDialog)}};B=a;b.on("resize",a);a();CKEDITOR.env.mac&&CKEDITOR.env.webkit||f.focus();if(CKEDITOR.env.ie6Compat){var m=function(){h();arguments.callee.prevScrollHandler.apply(this,arguments)};b.$.setTimeout(function(){m.prevScrollHandler=window.onscroll||function(){};
window.onscroll=m},0);h()}}function q(a){x&&(a.focusManager.remove(x),a=CKEDITOR.document.getWindow(),x.hide(),a.removeListener("resize",B),CKEDITOR.env.ie6Compat&&a.$.setTimeout(function(){window.onscroll=window.onscroll&&window.onscroll.prevScrollHandler||null},0),B=null)}var y=CKEDITOR.tools.cssLength,v='\x3cdiv class\x3d"cke_reset_all {editorId} {editorDialogClass} {hidpi}" dir\x3d"{langDir}" lang\x3d"{langCode}" role\x3d"dialog" aria-labelledby\x3d"cke_dialog_title_{id}"\x3e\x3ctable class\x3d"cke_dialog '+
CKEDITOR.env.cssClass+' cke_{langDir}" style\x3d"position:absolute" role\x3d"presentation"\x3e\x3ctr\x3e\x3ctd role\x3d"presentation"\x3e\x3cdiv class\x3d"cke_dialog_body" role\x3d"presentation"\x3e\x3cdiv id\x3d"cke_dialog_title_{id}" class\x3d"cke_dialog_title" role\x3d"presentation"\x3e\x3c/div\x3e\x3ca id\x3d"cke_dialog_close_button_{id}" class\x3d"cke_dialog_close_button" href\x3d"javascript:void(0)" title\x3d"{closeTitle}" role\x3d"button"\x3e\x3cspan class\x3d"cke_label"\x3eX\x3c/span\x3e\x3c/a\x3e\x3cdiv id\x3d"cke_dialog_tabs_{id}" class\x3d"cke_dialog_tabs" role\x3d"tablist"\x3e\x3c/div\x3e\x3ctable class\x3d"cke_dialog_contents" role\x3d"presentation"\x3e\x3ctr\x3e\x3ctd id\x3d"cke_dialog_contents_{id}" class\x3d"cke_dialog_contents_body" role\x3d"presentation"\x3e\x3c/td\x3e\x3c/tr\x3e\x3ctr\x3e\x3ctd id\x3d"cke_dialog_footer_{id}" class\x3d"cke_dialog_footer" role\x3d"presentation"\x3e\x3c/td\x3e\x3c/tr\x3e\x3c/table\x3e\x3c/div\x3e\x3c/td\x3e\x3c/tr\x3e\x3c/table\x3e\x3c/div\x3e';
CKEDITOR.dialog=function(b,d){function f(){var a=A._.focusList;a.sort(function(a,b){return a.tabIndex!=b.tabIndex?b.tabIndex-a.tabIndex:a.focusIndex-b.focusIndex});for(var b=a.length,d=0;d<b;d++)a[d].focusIndex=d}function k(a){var b=A._.focusList;a=a||0;if(!(1>b.length)){var d=A._.currentFocusIndex;A._.tabBarMode&&0>a&&(d=0);try{b[d].getInputElement().$.blur()}catch(c){}var e=d,g=1<A._.pageCount;do{e+=a;if(g&&!A._.tabBarMode&&(e==b.length||-1==e)){A._.tabBarMode=!0;A._.tabs[A._.currentTabId][0].focus();
A._.currentFocusIndex=-1;return}e=(e+b.length)%b.length;if(e==d)break}while(a&&!b[e].isFocusable());b[e].focus();"text"==b[e].type&&b[e].select()}}function n(d){if(A==CKEDITOR.dialog._.currentTop){var e=d.data.getKeystroke(),g="rtl"==b.lang.dir,f=[37,38,39,40];q=x=0;if(9==e||e==CKEDITOR.SHIFT+9)k(e==CKEDITOR.SHIFT+9?-1:1),q=1;else if(e==CKEDITOR.ALT+121&&!A._.tabBarMode&&1<A.getPageCount())A._.tabBarMode=!0,A._.tabs[A._.currentTabId][0].focus(),A._.currentFocusIndex=-1,q=1;else if(-1!=CKEDITOR.tools.indexOf(f,
e)&&A._.tabBarMode)e=-1!=CKEDITOR.tools.indexOf([g?39:37,38],e)?a.call(A):c.call(A),A.selectPage(e),A._.tabs[e][0].focus(),q=1;else if(13!=e&&32!=e||!A._.tabBarMode)if(13==e)e=d.data.getTarget(),e.is("a","button","select","textarea")||e.is("input")&&"button"==e.$.type||((e=this.getButton("ok"))&&CKEDITOR.tools.setTimeout(e.click,0,e),q=1),x=1;else if(27==e)(e=this.getButton("cancel"))?CKEDITOR.tools.setTimeout(e.click,0,e):!1!==this.fire("cancel",{hide:!0}).hide&&this.hide(),x=1;else return;else this.selectPage(this._.currentTabId),
this._.tabBarMode=!1,this._.currentFocusIndex=-1,k(1),q=1;r(d)}}function r(a){q?a.data.preventDefault(1):x&&a.data.stopPropagation()}var w=CKEDITOR.dialog._.dialogDefinitions[d],p=CKEDITOR.tools.clone(t),z=b.config.dialog_buttonsOrder||"OS",v=b.lang.dir,y={},q,x;("OS"==z&&CKEDITOR.env.mac||"rtl"==z&&"ltr"==v||"ltr"==z&&"rtl"==v)&&p.buttons.reverse();w=CKEDITOR.tools.extend(w(b),p);w=CKEDITOR.tools.clone(w);w=new u(this,w);p=l(b);this._={editor:b,element:p.element,name:d,contentSize:{width:0,height:0},
size:{width:0,height:0},contents:{},buttons:{},accessKeyMap:{},tabs:{},tabIdList:[],currentTabId:null,currentTabIndex:null,pageCount:0,lastTab:null,tabBarMode:!1,focusList:[],currentFocusIndex:0,hasFocus:!1};this.parts=p.parts;CKEDITOR.tools.setTimeout(function(){b.fire("ariaWidget",this.parts.contents)},0,this);p={position:CKEDITOR.env.ie6Compat?"absolute":"fixed",top:0,visibility:"hidden"};p["rtl"==v?"right":"left"]=0;this.parts.dialog.setStyles(p);CKEDITOR.event.call(this);this.definition=w=CKEDITOR.fire("dialogDefinition",
{name:d,definition:w},b).definition;if(!("removeDialogTabs"in b._)&&b.config.removeDialogTabs){p=b.config.removeDialogTabs.split(";");for(v=0;v<p.length;v++)if(z=p[v].split(":"),2==z.length){var B=z[0];y[B]||(y[B]=[]);y[B].push(z[1])}b._.removeDialogTabs=y}if(b._.removeDialogTabs&&(y=b._.removeDialogTabs[d]))for(v=0;v<y.length;v++)w.removeContents(y[v]);if(w.onLoad)this.on("load",w.onLoad);if(w.onShow)this.on("show",w.onShow);if(w.onHide)this.on("hide",w.onHide);if(w.onOk)this.on("ok",function(a){b.fire("saveSnapshot");
setTimeout(function(){b.fire("saveSnapshot")},0);!1===w.onOk.call(this,a)&&(a.data.hide=!1)});this.state=CKEDITOR.DIALOG_STATE_IDLE;if(w.onCancel)this.on("cancel",function(a){!1===w.onCancel.call(this,a)&&(a.data.hide=!1)});var A=this,C=function(a){var b=A._.contents,d=!1,c;for(c in b)for(var e in b[c])if(d=a.call(this,b[c][e]))return};this.on("ok",function(a){C(function(b){if(b.validate){var d=b.validate(this),c="string"==typeof d||!1===d;c&&(a.data.hide=!1,a.stop());e.call(b,!c,"string"==typeof d?
d:void 0);return c}})},this,null,0);this.on("cancel",function(a){C(function(d){if(d.isChanged())return b.config.dialog_noConfirmCancel||confirm(b.lang.common.confirmCancel)||(a.data.hide=!1),!0})},this,null,0);this.parts.close.on("click",function(a){!1!==this.fire("cancel",{hide:!0}).hide&&this.hide();a.data.preventDefault()},this);this.changeFocus=k;var D=this._.element;b.focusManager.add(D,1);this.on("show",function(){D.on("keydown",n,this);if(CKEDITOR.env.gecko)D.on("keypress",r,this)});this.on("hide",
function(){D.removeListener("keydown",n);CKEDITOR.env.gecko&&D.removeListener("keypress",r);C(function(a){h.apply(a)})});this.on("iframeAdded",function(a){(new CKEDITOR.dom.document(a.data.iframe.$.contentWindow.document)).on("keydown",n,this,null,0)});this.on("show",function(){f();var a=1<A._.pageCount;b.config.dialog_startupFocusTab&&a?(A._.tabBarMode=!0,A._.tabs[A._.currentTabId][0].focus(),A._.currentFocusIndex=-1):this._.hasFocus||(this._.currentFocusIndex=a?-1:this._.focusList.length-1,w.onFocus?
(a=w.onFocus.call(this))&&a.focus():k(1))},this,null,4294967295);if(CKEDITOR.env.ie6Compat)this.on("load",function(){var a=this.getElement(),b=a.getFirst();b.remove();b.appendTo(a)},this);m(this);g(this);(new CKEDITOR.dom.text(w.title,CKEDITOR.document)).appendTo(this.parts.title);for(v=0;v<w.contents.length;v++)(y=w.contents[v])&&this.addPage(y);this.parts.tabs.on("click",function(a){var b=a.data.getTarget();b.hasClass("cke_dialog_tab")&&(b=b.$.id,this.selectPage(b.substring(4,b.lastIndexOf("_"))),
this._.tabBarMode&&(this._.tabBarMode=!1,this._.currentFocusIndex=-1,k(1)),a.data.preventDefault())},this);v=[];y=CKEDITOR.dialog._.uiElementBuilders.hbox.build(this,{type:"hbox",className:"cke_dialog_footer_buttons",widths:[],children:w.buttons},v).getChild();this.parts.footer.setHtml(v.join(""));for(v=0;v<y.length;v++)this._.buttons[y[v].id]=y[v]};CKEDITOR.dialog.prototype={destroy:function(){this.hide();this._.element.remove()},resize:function(){return function(a,b){this._.contentSize&&this._.contentSize.width==
a&&this._.contentSize.height==b||(CKEDITOR.dialog.fire("resize",{dialog:this,width:a,height:b},this._.editor),this.fire("resize",{width:a,height:b},this._.editor),this.parts.contents.setStyles({width:a+"px",height:b+"px"}),"rtl"==this._.editor.lang.dir&&this._.position&&(this._.position.x=CKEDITOR.document.getWindow().getViewPaneSize().width-this._.contentSize.width-parseInt(this._.element.getFirst().getStyle("right"),10)),this._.contentSize={width:a,height:b})}}(),getSize:function(){var a=this._.element.getFirst();
return{width:a.$.offsetWidth||0,height:a.$.offsetHeight||0}},move:function(a,b,d){var c=this._.element.getFirst(),e="rtl"==this._.editor.lang.dir,g="fixed"==c.getComputedStyle("position");CKEDITOR.env.ie&&c.setStyle("zoom","100%");g&&this._.position&&this._.position.x==a&&this._.position.y==b||(this._.position={x:a,y:b},g||(g=CKEDITOR.document.getWindow().getScrollPosition(),a+=g.x,b+=g.y),e&&(g=this.getSize(),a=CKEDITOR.document.getWindow().getViewPaneSize().width-g.width-a),b={top:(0<b?b:0)+"px"},
b[e?"right":"left"]=(0<a?a:0)+"px",c.setStyles(b),d&&(this._.moved=1))},getPosition:function(){return CKEDITOR.tools.extend({},this._.position)},show:function(){var a=this._.element,b=this.definition;a.getParent()&&a.getParent().equals(CKEDITOR.document.getBody())?a.setStyle("display","block"):a.appendTo(CKEDITOR.document.getBody());this.resize(this._.contentSize&&this._.contentSize.width||b.width||b.minWidth,this._.contentSize&&this._.contentSize.height||b.height||b.minHeight);this.reset();this.selectPage(this.definition.contents[0].id);
null===CKEDITOR.dialog._.currentZIndex&&(CKEDITOR.dialog._.currentZIndex=this._.editor.config.baseFloatZIndex);this._.element.getFirst().setStyle("z-index",CKEDITOR.dialog._.currentZIndex+=10);null===CKEDITOR.dialog._.currentTop?(CKEDITOR.dialog._.currentTop=this,this._.parentDialog=null,p(this._.editor)):(this._.parentDialog=CKEDITOR.dialog._.currentTop,this._.parentDialog.getElement().getFirst().$.style.zIndex-=Math.floor(this._.editor.config.baseFloatZIndex/2),CKEDITOR.dialog._.currentTop=this);
a.on("keydown",D);a.on("keyup",H);this._.hasFocus=!1;for(var d in b.contents)if(b.contents[d]){var a=b.contents[d],c=this._.tabs[a.id],e=a.requiredContent,g=0;if(c){for(var h in this._.contents[a.id]){var m=this._.contents[a.id][h];"hbox"!=m.type&&"vbox"!=m.type&&m.getInputElement()&&(m.requiredContent&&!this._.editor.activeFilter.check(m.requiredContent)?m.disable():(m.enable(),g++))}!g||e&&!this._.editor.activeFilter.check(e)?c[0].addClass("cke_dialog_tab_disabled"):c[0].removeClass("cke_dialog_tab_disabled")}}CKEDITOR.tools.setTimeout(function(){this.layout();
f(this);this.parts.dialog.setStyle("visibility","");this.fireOnce("load",{});CKEDITOR.ui.fire("ready",this);this.fire("show",{});this._.editor.fire("dialogShow",this);this._.parentDialog||this._.editor.focusManager.lock();this.foreach(function(a){a.setInitValue&&a.setInitValue()})},100,this)},layout:function(){var a=this.parts.dialog,b=this.getSize(),d=CKEDITOR.document.getWindow().getViewPaneSize(),c=(d.width-b.width)/2,e=(d.height-b.height)/2;CKEDITOR.env.ie6Compat||(b.height+(0<e?e:0)>d.height||
b.width+(0<c?c:0)>d.width?a.setStyle("position","absolute"):a.setStyle("position","fixed"));this.move(this._.moved?this._.position.x:c,this._.moved?this._.position.y:e)},foreach:function(a){for(var b in this._.contents)for(var d in this._.contents[b])a.call(this,this._.contents[b][d]);return this},reset:function(){var a=function(a){a.reset&&a.reset(1)};return function(){this.foreach(a);return this}}(),setupContent:function(){var a=arguments;this.foreach(function(b){b.setup&&b.setup.apply(b,a)})},
commitContent:function(){var a=arguments;this.foreach(function(b){CKEDITOR.env.ie&&this._.currentFocusIndex==b.focusIndex&&b.getInputElement().$.blur();b.commit&&b.commit.apply(b,a)})},hide:function(){if(this.parts.dialog.isVisible()){this.fire("hide",{});this._.editor.fire("dialogHide",this);this.selectPage(this._.tabIdList[0]);var a=this._.element;a.setStyle("display","none");this.parts.dialog.setStyle("visibility","hidden");for(I(this);CKEDITOR.dialog._.currentTop!=this;)CKEDITOR.dialog._.currentTop.hide();
if(this._.parentDialog){var b=this._.parentDialog.getElement().getFirst();b.setStyle("z-index",parseInt(b.$.style.zIndex,10)+Math.floor(this._.editor.config.baseFloatZIndex/2))}else q(this._.editor);if(CKEDITOR.dialog._.currentTop=this._.parentDialog)CKEDITOR.dialog._.currentZIndex-=10;else{CKEDITOR.dialog._.currentZIndex=null;a.removeListener("keydown",D);a.removeListener("keyup",H);var d=this._.editor;d.focus();setTimeout(function(){d.focusManager.unlock();CKEDITOR.env.iOS&&d.window.focus()},0)}delete this._.parentDialog;
this.foreach(function(a){a.resetInitValue&&a.resetInitValue()});this.setState(CKEDITOR.DIALOG_STATE_IDLE)}},addPage:function(a){if(!a.requiredContent||this._.editor.filter.check(a.requiredContent)){for(var b=[],d=a.label?' title\x3d"'+CKEDITOR.tools.htmlEncode(a.label)+'"':"",c=CKEDITOR.dialog._.uiElementBuilders.vbox.build(this,{type:"vbox",className:"cke_dialog_page_contents",children:a.elements,expand:!!a.expand,padding:a.padding,style:a.style||"width: 100%;"},b),e=this._.contents[a.id]={},g=c.getChild(),
f=0;c=g.shift();)c.notAllowed||"hbox"==c.type||"vbox"==c.type||f++,e[c.id]=c,"function"==typeof c.getChild&&g.push.apply(g,c.getChild());f||(a.hidden=!0);b=CKEDITOR.dom.element.createFromHtml(b.join(""));b.setAttribute("role","tabpanel");c=CKEDITOR.env;e="cke_"+a.id+"_"+CKEDITOR.tools.getNextNumber();d=CKEDITOR.dom.element.createFromHtml(['\x3ca class\x3d"cke_dialog_tab"',0<this._.pageCount?" cke_last":"cke_first",d,a.hidden?' style\x3d"display:none"':"",' id\x3d"',e,'"',c.gecko&&!c.hc?"":' href\x3d"javascript:void(0)"',
' tabIndex\x3d"-1" hidefocus\x3d"true" role\x3d"tab"\x3e',a.label,"\x3c/a\x3e"].join(""));b.setAttribute("aria-labelledby",e);this._.tabs[a.id]=[d,b];this._.tabIdList.push(a.id);!a.hidden&&this._.pageCount++;this._.lastTab=d;this.updateStyle();b.setAttribute("name",a.id);b.appendTo(this.parts.contents);d.unselectable();this.parts.tabs.append(d);a.accessKey&&(E(this,this,"CTRL+"+a.accessKey,K,G),this._.accessKeyMap["CTRL+"+a.accessKey]=a.id)}},selectPage:function(a){if(this._.currentTabId!=a&&!this._.tabs[a][0].hasClass("cke_dialog_tab_disabled")&&
!1!==this.fire("selectPage",{page:a,currentPage:this._.currentTabId})){for(var d in this._.tabs){var c=this._.tabs[d][0],e=this._.tabs[d][1];d!=a&&(c.removeClass("cke_dialog_tab_selected"),e.hide());e.setAttribute("aria-hidden",d!=a)}var g=this._.tabs[a];g[0].addClass("cke_dialog_tab_selected");CKEDITOR.env.ie6Compat||CKEDITOR.env.ie7Compat?(b(g[1]),g[1].show(),setTimeout(function(){b(g[1],1)},0)):g[1].show();this._.currentTabId=a;this._.currentTabIndex=CKEDITOR.tools.indexOf(this._.tabIdList,a)}},
updateStyle:function(){this.parts.dialog[(1===this._.pageCount?"add":"remove")+"Class"]("cke_single_page")},hidePage:function(b){var d=this._.tabs[b]&&this._.tabs[b][0];d&&1!=this._.pageCount&&d.isVisible()&&(b==this._.currentTabId&&this.selectPage(a.call(this)),d.hide(),this._.pageCount--,this.updateStyle())},showPage:function(a){if(a=this._.tabs[a]&&this._.tabs[a][0])a.show(),this._.pageCount++,this.updateStyle()},getElement:function(){return this._.element},getName:function(){return this._.name},
getContentElement:function(a,b){var d=this._.contents[a];return d&&d[b]},getValueOf:function(a,b){return this.getContentElement(a,b).getValue()},setValueOf:function(a,b,d){return this.getContentElement(a,b).setValue(d)},getButton:function(a){return this._.buttons[a]},click:function(a){return this._.buttons[a].click()},disableButton:function(a){return this._.buttons[a].disable()},enableButton:function(a){return this._.buttons[a].enable()},getPageCount:function(){return this._.pageCount},getParentEditor:function(){return this._.editor},
getSelectedElement:function(){return this.getParentEditor().getSelection().getSelectedElement()},addFocusable:function(a,b){if("undefined"==typeof b)b=this._.focusList.length,this._.focusList.push(new k(this,a,b));else{this._.focusList.splice(b,0,new k(this,a,b));for(var d=b+1;d<this._.focusList.length;d++)this._.focusList[d].focusIndex++}},setState:function(a){if(this.state!=a){this.state=a;if(a==CKEDITOR.DIALOG_STATE_BUSY){if(!this.parts.spinner){var b=this.getParentEditor().lang.dir,d={attributes:{"class":"cke_dialog_spinner"},
styles:{"float":"rtl"==b?"right":"left"}};d.styles["margin-"+("rtl"==b?"left":"right")]="8px";this.parts.spinner=CKEDITOR.document.createElement("div",d);this.parts.spinner.setHtml("\x26#8987;");this.parts.spinner.appendTo(this.parts.title,1)}this.parts.spinner.show();this.getButton("ok").disable()}else a==CKEDITOR.DIALOG_STATE_IDLE&&(this.parts.spinner&&this.parts.spinner.hide(),this.getButton("ok").enable());this.fire("state",a)}}};CKEDITOR.tools.extend(CKEDITOR.dialog,{add:function(a,b){this._.dialogDefinitions[a]&&
"function"!=typeof b||(this._.dialogDefinitions[a]=b)},exists:function(a){return!!this._.dialogDefinitions[a]},getCurrent:function(){return CKEDITOR.dialog._.currentTop},isTabEnabled:function(a,b,d){a=a.config.removeDialogTabs;return!(a&&a.match(new RegExp("(?:^|;)"+b+":"+d+"(?:$|;)","i")))},okButton:function(){var a=function(a,b){b=b||{};return CKEDITOR.tools.extend({id:"ok",type:"button",label:a.lang.common.ok,"class":"cke_dialog_ui_button_ok",onClick:function(a){a=a.data.dialog;!1!==a.fire("ok",
{hide:!0}).hide&&a.hide()}},b,!0)};a.type="button";a.override=function(b){return CKEDITOR.tools.extend(function(d){return a(d,b)},{type:"button"},!0)};return a}(),cancelButton:function(){var a=function(a,b){b=b||{};return CKEDITOR.tools.extend({id:"cancel",type:"button",label:a.lang.common.cancel,"class":"cke_dialog_ui_button_cancel",onClick:function(a){a=a.data.dialog;!1!==a.fire("cancel",{hide:!0}).hide&&a.hide()}},b,!0)};a.type="button";a.override=function(b){return CKEDITOR.tools.extend(function(d){return a(d,
b)},{type:"button"},!0)};return a}(),addUIElement:function(a,b){this._.uiElementBuilders[a]=b}});CKEDITOR.dialog._={uiElementBuilders:{},dialogDefinitions:{},currentTop:null,currentZIndex:null};CKEDITOR.event.implementOn(CKEDITOR.dialog);CKEDITOR.event.implementOn(CKEDITOR.dialog.prototype);var t={resizable:CKEDITOR.DIALOG_RESIZE_BOTH,minWidth:600,minHeight:400,buttons:[CKEDITOR.dialog.okButton,CKEDITOR.dialog.cancelButton]},r=function(a,b,d){for(var c=0,e;e=a[c];c++)if(e.id==b||d&&e[d]&&(e=r(e[d],
b,d)))return e;return null},w=function(a,b,d,c,e){if(d){for(var g=0,f;f=a[g];g++){if(f.id==d)return a.splice(g,0,b),b;if(c&&f[c]&&(f=w(f[c],b,d,c,!0)))return f}if(e)return null}a.push(b);return b},z=function(a,b,d){for(var c=0,e;e=a[c];c++){if(e.id==b)return a.splice(c,1);if(d&&e[d]&&(e=z(e[d],b,d)))return e}return null},u=function(a,b){this.dialog=a;for(var c=b.contents,e=0,g;g=c[e];e++)c[e]=g&&new d(a,g);CKEDITOR.tools.extend(this,b)};u.prototype={getContents:function(a){return r(this.contents,
a)},getButton:function(a){return r(this.buttons,a)},addContents:function(a,b){return w(this.contents,a,b)},addButton:function(a,b){return w(this.buttons,a,b)},removeContents:function(a){z(this.contents,a)},removeButton:function(a){z(this.buttons,a)}};d.prototype={get:function(a){return r(this.elements,a,"children")},add:function(a,b){return w(this.elements,a,b,"children")},remove:function(a){z(this.elements,a,"children")}};var B,C={},x,A={},D=function(a){var b=a.data.$.ctrlKey||a.data.$.metaKey,d=
a.data.$.altKey,c=a.data.$.shiftKey,e=String.fromCharCode(a.data.$.keyCode);(b=A[(b?"CTRL+":"")+(d?"ALT+":"")+(c?"SHIFT+":"")+e])&&b.length&&(b=b[b.length-1],b.keydown&&b.keydown.call(b.uiElement,b.dialog,b.key),a.data.preventDefault())},H=function(a){var b=a.data.$.ctrlKey||a.data.$.metaKey,d=a.data.$.altKey,c=a.data.$.shiftKey,e=String.fromCharCode(a.data.$.keyCode);(b=A[(b?"CTRL+":"")+(d?"ALT+":"")+(c?"SHIFT+":"")+e])&&b.length&&(b=b[b.length-1],b.keyup&&(b.keyup.call(b.uiElement,b.dialog,b.key),
a.data.preventDefault()))},E=function(a,b,d,c,e){(A[d]||(A[d]=[])).push({uiElement:a,dialog:b,key:d,keyup:e||a.accessKeyUp,keydown:c||a.accessKeyDown})},I=function(a){for(var b in A){for(var d=A[b],c=d.length-1;0<=c;c--)d[c].dialog!=a&&d[c].uiElement!=a||d.splice(c,1);0===d.length&&delete A[b]}},G=function(a,b){a._.accessKeyMap[b]&&a.selectPage(a._.accessKeyMap[b])},K=function(){};(function(){CKEDITOR.ui.dialog={uiElement:function(a,b,d,c,e,g,f){if(!(4>arguments.length)){var h=(c.call?c(b):c)||"div",
m=["\x3c",h," "],k=(e&&e.call?e(b):e)||{},l=(g&&g.call?g(b):g)||{},n=(f&&f.call?f.call(this,a,b):f)||"",r=this.domId=l.id||CKEDITOR.tools.getNextId()+"_uiElement";b.requiredContent&&!a.getParentEditor().filter.check(b.requiredContent)&&(k.display="none",this.notAllowed=!0);l.id=r;var w={};b.type&&(w["cke_dialog_ui_"+b.type]=1);b.className&&(w[b.className]=1);b.disabled&&(w.cke_disabled=1);for(var t=l["class"]&&l["class"].split?l["class"].split(" "):[],r=0;r<t.length;r++)t[r]&&(w[t[r]]=1);t=[];for(r in w)t.push(r);
l["class"]=t.join(" ");b.title&&(l.title=b.title);w=(b.style||"").split(";");b.align&&(t=b.align,k["margin-left"]="left"==t?0:"auto",k["margin-right"]="right"==t?0:"auto");for(r in k)w.push(r+":"+k[r]);b.hidden&&w.push("display:none");for(r=w.length-1;0<=r;r--)""===w[r]&&w.splice(r,1);0<w.length&&(l.style=(l.style?l.style+"; ":"")+w.join("; "));for(r in l)m.push(r+'\x3d"'+CKEDITOR.tools.htmlEncode(l[r])+'" ');m.push("\x3e",n,"\x3c/",h,"\x3e");d.push(m.join(""));(this._||(this._={})).dialog=a;"boolean"==
typeof b.isChanged&&(this.isChanged=function(){return b.isChanged});"function"==typeof b.isChanged&&(this.isChanged=b.isChanged);"function"==typeof b.setValue&&(this.setValue=CKEDITOR.tools.override(this.setValue,function(a){return function(d){a.call(this,b.setValue.call(this,d))}}));"function"==typeof b.getValue&&(this.getValue=CKEDITOR.tools.override(this.getValue,function(a){return function(){return b.getValue.call(this,a.call(this))}}));CKEDITOR.event.implementOn(this);this.registerEvents(b);
this.accessKeyUp&&this.accessKeyDown&&b.accessKey&&E(this,a,"CTRL+"+b.accessKey);var u=this;a.on("load",function(){var b=u.getInputElement();if(b){var d=u.type in{checkbox:1,ratio:1}&&CKEDITOR.env.ie&&8>CKEDITOR.env.version?"cke_dialog_ui_focused":"";b.on("focus",function(){a._.tabBarMode=!1;a._.hasFocus=!0;u.fire("focus");d&&this.addClass(d)});b.on("blur",function(){u.fire("blur");d&&this.removeClass(d)})}});CKEDITOR.tools.extend(this,b);this.keyboardFocusable&&(this.tabIndex=b.tabIndex||0,this.focusIndex=
a._.focusList.push(this)-1,this.on("focus",function(){a._.currentFocusIndex=u.focusIndex}))}},hbox:function(a,b,d,c,e){if(!(4>arguments.length)){this._||(this._={});var g=this._.children=b,f=e&&e.widths||null,h=e&&e.height||null,m,k={role:"presentation"};e&&e.align&&(k.align=e.align);CKEDITOR.ui.dialog.uiElement.call(this,a,e||{type:"hbox"},c,"table",{},k,function(){var a=['\x3ctbody\x3e\x3ctr class\x3d"cke_dialog_ui_hbox"\x3e'];for(m=0;m<d.length;m++){var b="cke_dialog_ui_hbox_child",c=[];0===m&&
(b="cke_dialog_ui_hbox_first");m==d.length-1&&(b="cke_dialog_ui_hbox_last");a.push('\x3ctd class\x3d"',b,'" role\x3d"presentation" ');f?f[m]&&c.push("width:"+y(f[m])):c.push("width:"+Math.floor(100/d.length)+"%");h&&c.push("height:"+y(h));e&&void 0!==e.padding&&c.push("padding:"+y(e.padding));CKEDITOR.env.ie&&CKEDITOR.env.quirks&&g[m].align&&c.push("text-align:"+g[m].align);0<c.length&&a.push('style\x3d"'+c.join("; ")+'" ');a.push("\x3e",d[m],"\x3c/td\x3e")}a.push("\x3c/tr\x3e\x3c/tbody\x3e");return a.join("")})}},
vbox:function(a,b,d,c,e){if(!(3>arguments.length)){this._||(this._={});var g=this._.children=b,f=e&&e.width||null,h=e&&e.heights||null;CKEDITOR.ui.dialog.uiElement.call(this,a,e||{type:"vbox"},c,"div",null,{role:"presentation"},function(){var b=['\x3ctable role\x3d"presentation" cellspacing\x3d"0" border\x3d"0" '];b.push('style\x3d"');e&&e.expand&&b.push("height:100%;");b.push("width:"+y(f||"100%"),";");CKEDITOR.env.webkit&&b.push("float:none;");b.push('"');b.push('align\x3d"',CKEDITOR.tools.htmlEncode(e&&
e.align||("ltr"==a.getParentEditor().lang.dir?"left":"right")),'" ');b.push("\x3e\x3ctbody\x3e");for(var c=0;c<d.length;c++){var m=[];b.push('\x3ctr\x3e\x3ctd role\x3d"presentation" ');f&&m.push("width:"+y(f||"100%"));h?m.push("height:"+y(h[c])):e&&e.expand&&m.push("height:"+Math.floor(100/d.length)+"%");e&&void 0!==e.padding&&m.push("padding:"+y(e.padding));CKEDITOR.env.ie&&CKEDITOR.env.quirks&&g[c].align&&m.push("text-align:"+g[c].align);0<m.length&&b.push('style\x3d"',m.join("; "),'" ');b.push(' class\x3d"cke_dialog_ui_vbox_child"\x3e',
d[c],"\x3c/td\x3e\x3c/tr\x3e")}b.push("\x3c/tbody\x3e\x3c/table\x3e");return b.join("")})}}}})();CKEDITOR.ui.dialog.uiElement.prototype={getElement:function(){return CKEDITOR.document.getById(this.domId)},getInputElement:function(){return this.getElement()},getDialog:function(){return this._.dialog},setValue:function(a,b){this.getInputElement().setValue(a);!b&&this.fire("change",{value:a});return this},getValue:function(){return this.getInputElement().getValue()},isChanged:function(){return!1},selectParentTab:function(){for(var a=
this.getInputElement();(a=a.getParent())&&-1==a.$.className.search("cke_dialog_page_contents"););if(!a)return this;a=a.getAttribute("name");this._.dialog._.currentTabId!=a&&this._.dialog.selectPage(a);return this},focus:function(){this.selectParentTab().getInputElement().focus();return this},registerEvents:function(a){var b=/^on([A-Z]\w+)/,d,c=function(a,b,d,c){b.on("load",function(){a.getInputElement().on(d,c,a)})},e;for(e in a)if(d=e.match(b))this.eventProcessors[e]?this.eventProcessors[e].call(this,
this._.dialog,a[e]):c(this,this._.dialog,d[1].toLowerCase(),a[e]);return this},eventProcessors:{onLoad:function(a,b){a.on("load",b,this)},onShow:function(a,b){a.on("show",b,this)},onHide:function(a,b){a.on("hide",b,this)}},accessKeyDown:function(){this.focus()},accessKeyUp:function(){},disable:function(){var a=this.getElement();this.getInputElement().setAttribute("disabled","true");a.addClass("cke_disabled")},enable:function(){var a=this.getElement();this.getInputElement().removeAttribute("disabled");
a.removeClass("cke_disabled")},isEnabled:function(){return!this.getElement().hasClass("cke_disabled")},isVisible:function(){return this.getInputElement().isVisible()},isFocusable:function(){return this.isEnabled()&&this.isVisible()?!0:!1}};CKEDITOR.ui.dialog.hbox.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.uiElement,{getChild:function(a){if(1>arguments.length)return this._.children.concat();a.splice||(a=[a]);return 2>a.length?this._.children[a[0]]:this._.children[a[0]]&&this._.children[a[0]].getChild?
this._.children[a[0]].getChild(a.slice(1,a.length)):null}},!0);CKEDITOR.ui.dialog.vbox.prototype=new CKEDITOR.ui.dialog.hbox;(function(){var a={build:function(a,b,d){for(var c=b.children,e,g=[],f=[],h=0;h<c.length&&(e=c[h]);h++){var m=[];g.push(m);f.push(CKEDITOR.dialog._.uiElementBuilders[e.type].build(a,e,m))}return new CKEDITOR.ui.dialog[b.type](a,f,g,d,b)}};CKEDITOR.dialog.addUIElement("hbox",a);CKEDITOR.dialog.addUIElement("vbox",a)})();CKEDITOR.dialogCommand=function(a,b){this.dialogName=a;
CKEDITOR.tools.extend(this,b,!0)};CKEDITOR.dialogCommand.prototype={exec:function(a){a.openDialog(this.dialogName)},canUndo:!1,editorFocus:1};(function(){var a=/^([a]|[^a])+$/,b=/^\d*$/,d=/^\d*(?:\.\d+)?$/,c=/^(((\d*(\.\d+))|(\d*))(px|\%)?)?$/,e=/^(((\d*(\.\d+))|(\d*))(px|em|ex|in|cm|mm|pt|pc|\%)?)?$/i,g=/^(\s*[\w-]+\s*:\s*[^:;]+(?:;|$))*$/;CKEDITOR.VALIDATE_OR=1;CKEDITOR.VALIDATE_AND=2;CKEDITOR.dialog.validate={functions:function(){var a=arguments;return function(){var b=this&&this.getValue?this.getValue():
a[0],d,c=CKEDITOR.VALIDATE_AND,e=[],g;for(g=0;g<a.length;g++)if("function"==typeof a[g])e.push(a[g]);else break;g<a.length&&"string"==typeof a[g]&&(d=a[g],g++);g<a.length&&"number"==typeof a[g]&&(c=a[g]);var f=c==CKEDITOR.VALIDATE_AND?!0:!1;for(g=0;g<e.length;g++)f=c==CKEDITOR.VALIDATE_AND?f&&e[g](b):f||e[g](b);return f?!0:d}},regex:function(a,b){return function(d){d=this&&this.getValue?this.getValue():d;return a.test(d)?!0:b}},notEmpty:function(b){return this.regex(a,b)},integer:function(a){return this.regex(b,
a)},number:function(a){return this.regex(d,a)},cssLength:function(a){return this.functions(function(a){return e.test(CKEDITOR.tools.trim(a))},a)},htmlLength:function(a){return this.functions(function(a){return c.test(CKEDITOR.tools.trim(a))},a)},inlineStyle:function(a){return this.functions(function(a){return g.test(CKEDITOR.tools.trim(a))},a)},equals:function(a,b){return this.functions(function(b){return b==a},b)},notEqual:function(a,b){return this.functions(function(b){return b!=a},b)}};CKEDITOR.on("instanceDestroyed",
function(a){if(CKEDITOR.tools.isEmpty(CKEDITOR.instances)){for(var b;b=CKEDITOR.dialog._.currentTop;)b.hide();for(var d in C)C[d].remove();C={}}a=a.editor._.storedDialogs;for(var c in a)a[c].destroy()})})();CKEDITOR.tools.extend(CKEDITOR.editor.prototype,{openDialog:function(a,b){var d=null,c=CKEDITOR.dialog._.dialogDefinitions[a];null===CKEDITOR.dialog._.currentTop&&p(this);if("function"==typeof c)d=this._.storedDialogs||(this._.storedDialogs={}),d=d[a]||(d[a]=new CKEDITOR.dialog(this,a)),b&&b.call(d,
d),d.show();else{if("failed"==c)throw q(this),Error('[CKEDITOR.dialog.openDialog] Dialog "'+a+'" failed when loading definition.');"string"==typeof c&&CKEDITOR.scriptLoader.load(CKEDITOR.getUrl(c),function(){"function"!=typeof CKEDITOR.dialog._.dialogDefinitions[a]&&(CKEDITOR.dialog._.dialogDefinitions[a]="failed");this.openDialog(a,b)},this,0,1)}CKEDITOR.skin.loadPart("dialog");return d}})}(),CKEDITOR.plugins.add("dialog",{requires:"dialogui",init:function(a){a.on("doubleclick",function(c){c.data.dialog&&
a.openDialog(c.data.dialog)},null,null,999)}}),function(){CKEDITOR.plugins.add("a11yhelp",{requires:"dialog",availableLangs:{af:1,ar:1,az:1,bg:1,ca:1,cs:1,cy:1,da:1,de:1,"de-ch":1,el:1,en:1,"en-gb":1,eo:1,es:1,"es-mx":1,et:1,eu:1,fa:1,fi:1,fo:1,fr:1,"fr-ca":1,gl:1,gu:1,he:1,hi:1,hr:1,hu:1,id:1,it:1,ja:1,km:1,ko:1,ku:1,lt:1,lv:1,mk:1,mn:1,nb:1,nl:1,no:1,oc:1,pl:1,pt:1,"pt-br":1,ro:1,ru:1,si:1,sk:1,sl:1,sq:1,sr:1,"sr-latn":1,sv:1,th:1,tr:1,tt:1,ug:1,uk:1,vi:1,zh:1,"zh-cn":1},init:function(a){var c=
this;a.addCommand("a11yHelp",{exec:function(){var b=a.langCode,b=c.availableLangs[b]?b:c.availableLangs[b.replace(/-.*/,"")]?b.replace(/-.*/,""):"en";CKEDITOR.scriptLoader.load(CKEDITOR.getUrl(c.path+"dialogs/lang/"+b+".js"),function(){a.lang.a11yhelp=c.langEntries[b];a.openDialog("a11yHelp")})},modes:{wysiwyg:1,source:1},readOnly:1,canUndo:!1});a.setKeystroke(CKEDITOR.ALT+48,"a11yHelp");CKEDITOR.dialog.add("a11yHelp",this.path+"dialogs/a11yhelp.js");a.on("ariaEditorHelpLabel",function(b){b.data.label=
a.lang.common.editorHelp})}})}(),CKEDITOR.plugins.add("about",{requires:"dialog",init:function(a){var c=a.addCommand("about",new CKEDITOR.dialogCommand("about"));c.modes={wysiwyg:1,source:1};c.canUndo=!1;c.readOnly=1;a.ui.addButton&&a.ui.addButton("About",{label:a.lang.about.title,command:"about",toolbar:"about"});CKEDITOR.dialog.add("about",this.path+"dialogs/about.js")}}),CKEDITOR.plugins.add("basicstyles",{init:function(a){var c=0,b=function(b,f,d,h){if(h){h=new CKEDITOR.style(h);var g=e[d];g.unshift(h);
a.attachStyleStateChange(h,function(b){!a.readOnly&&a.getCommand(d).setState(b)});a.addCommand(d,new CKEDITOR.styleCommand(h,{contentForms:g}));a.ui.addButton&&a.ui.addButton(b,{label:f,command:d,toolbar:"basicstyles,"+(c+=10)})}},e={bold:["strong","b",["span",function(a){a=a.styles["font-weight"];return"bold"==a||700<=+a}]],italic:["em","i",["span",function(a){return"italic"==a.styles["font-style"]}]],underline:["u",["span",function(a){return"underline"==a.styles["text-decoration"]}]],strike:["s",
"strike",["span",function(a){return"line-through"==a.styles["text-decoration"]}]],subscript:["sub"],superscript:["sup"]},h=a.config,l=a.lang.basicstyles;b("Bold",l.bold,"bold",h.coreStyles_bold);b("Italic",l.italic,"italic",h.coreStyles_italic);b("Underline",l.underline,"underline",h.coreStyles_underline);b("Strike",l.strike,"strike",h.coreStyles_strike);b("Subscript",l.subscript,"subscript",h.coreStyles_subscript);b("Superscript",l.superscript,"superscript",h.coreStyles_superscript);a.setKeystroke([[CKEDITOR.CTRL+
66,"bold"],[CKEDITOR.CTRL+73,"italic"],[CKEDITOR.CTRL+85,"underline"]])}}),CKEDITOR.config.coreStyles_bold={element:"strong",overrides:"b"},CKEDITOR.config.coreStyles_italic={element:"em",overrides:"i"},CKEDITOR.config.coreStyles_underline={element:"u"},CKEDITOR.config.coreStyles_strike={element:"s",overrides:"strike"},CKEDITOR.config.coreStyles_subscript={element:"sub"},CKEDITOR.config.coreStyles_superscript={element:"sup"},function(){function a(a,b,d,c){if(!a.isReadOnly()&&!a.equals(d.editable())){CKEDITOR.dom.element.setMarker(c,
a,"bidi_processed",1);c=a;for(var e=d.editable();(c=c.getParent())&&!c.equals(e);)if(c.getCustomData("bidi_processed")){a.removeStyle("direction");a.removeAttribute("dir");return}c="useComputedState"in d.config?d.config.useComputedState:1;(c?a.getComputedStyle("direction"):a.getStyle("direction")||a.hasAttribute("dir"))!=b&&(a.removeStyle("direction"),c?(a.removeAttribute("dir"),b!=a.getComputedStyle("direction")&&a.setAttribute("dir",b)):a.setAttribute("dir",b),d.forceNextSelectionCheck())}}function c(a,
b,d){var c=a.getCommonAncestor(!1,!0);a=a.clone();a.enlarge(d==CKEDITOR.ENTER_BR?CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS:CKEDITOR.ENLARGE_BLOCK_CONTENTS);if(a.checkBoundaryOfElement(c,CKEDITOR.START)&&a.checkBoundaryOfElement(c,CKEDITOR.END)){for(var e;c&&c.type==CKEDITOR.NODE_ELEMENT&&(e=c.getParent())&&1==e.getChildCount()&&!(c.getName()in b);)c=e;return c.type==CKEDITOR.NODE_ELEMENT&&c.getName()in b&&c}}function b(b){return{context:"p",allowedContent:{"h1 h2 h3 h4 h5 h6 table ul ol blockquote div tr p div li td":{propertiesOnly:!0,
attributes:"dir"}},requiredContent:"p[dir]",refresh:function(a,b){var d=a.config.useComputedState,c,d=void 0===d||d;if(!d){c=b.lastElement;for(var e=a.editable();c&&!(c.getName()in k||c.equals(e));){var g=c.getParent();if(!g)break;c=g}}c=c||b.block||b.blockLimit;c.equals(a.editable())&&(e=a.getSelection().getRanges()[0].getEnclosedNode())&&e.type==CKEDITOR.NODE_ELEMENT&&(c=e);c&&(d=d?c.getComputedStyle("direction"):c.getStyle("direction")||c.getAttribute("dir"),a.getCommand("bidirtl").setState("rtl"==
d?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF),a.getCommand("bidiltr").setState("ltr"==d?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF));d=(b.block||b.blockLimit||a.editable()).getDirection(1);d!=(a._.selDir||a.lang.dir)&&(a._.selDir=d,a.fire("contentDirChanged",d))},exec:function(d){var e=d.getSelection(),f=d.config.enterMode,m=e.getRanges();if(m&&m.length){for(var k={},t=e.createBookmarks(),m=m.createIterator(),r,w=0;r=m.getNextRange(1);){var z=r.getEnclosedNode();z&&(!z||z.type==CKEDITOR.NODE_ELEMENT&&
z.getName()in l)||(z=c(r,h,f));z&&a(z,b,d,k);var u=new CKEDITOR.dom.walker(r),B=t[w].startNode,C=t[w++].endNode;u.evaluator=function(a){var b=f==CKEDITOR.ENTER_P?"p":"div",d;if(d=(a?a.type==CKEDITOR.NODE_ELEMENT:!1)&&a.getName()in h){if(b=a.is(b))b=(b=a.getParent())?b.type==CKEDITOR.NODE_ELEMENT:!1;d=!(b&&a.getParent().is("blockquote"))}return!!(d&&a.getPosition(B)&CKEDITOR.POSITION_FOLLOWING&&(a.getPosition(C)&CKEDITOR.POSITION_PRECEDING+CKEDITOR.POSITION_CONTAINS)==CKEDITOR.POSITION_PRECEDING)};
for(;z=u.next();)a(z,b,d,k);r=r.createIterator();for(r.enlargeBr=f!=CKEDITOR.ENTER_BR;z=r.getNextParagraph(f==CKEDITOR.ENTER_P?"p":"div");)a(z,b,d,k)}CKEDITOR.dom.element.clearAllMarkers(k);d.forceNextSelectionCheck();e.selectBookmarks(t);d.focus()}}}}function e(a){var b=a==f.setAttribute,d=a==f.removeAttribute,c=/\bdirection\s*:\s*(.*?)\s*(:?$|;)/;return function(e,f){if(!this.isReadOnly()){var h;if(h=e==(b||d?"dir":"direction")||"style"==e&&(d||c.test(f))){a:{h=this;for(var m=h.getDocument().getBody().getParent();h;){if(h.equals(m)){h=
!1;break a}h=h.getParent()}h=!0}h=!h}if(h&&(h=this.getDirection(1),m=a.apply(this,arguments),h!=this.getDirection(1)))return this.getDocument().fire("dirChanged",this),m}return a.apply(this,arguments)}}var h={table:1,ul:1,ol:1,blockquote:1,div:1},l={},k={};CKEDITOR.tools.extend(l,h,{tr:1,p:1,div:1,li:1});CKEDITOR.tools.extend(k,l,{td:1});CKEDITOR.plugins.add("bidi",{init:function(a){function d(b,c,e,f,h){a.addCommand(e,new CKEDITOR.command(a,f));a.ui.addButton&&a.ui.addButton(b,{label:c,command:e,
toolbar:"bidi,"+h})}if(!a.blockless){var c=a.lang.bidi;d("BidiLtr",c.ltr,"bidiltr",b("ltr"),10);d("BidiRtl",c.rtl,"bidirtl",b("rtl"),20);a.on("contentDom",function(){a.document.on("dirChanged",function(b){a.fire("dirChanged",{node:b.data,dir:b.data.getDirection(1)})})});a.on("contentDirChanged",function(b){b=(a.lang.dir!=b.data?"add":"remove")+"Class";var d=a.ui.space(a.config.toolbarLocation);if(d)d[b]("cke_mixed_dir_content")})}}});for(var f=CKEDITOR.dom.element.prototype,d=["setStyle","removeStyle",
"setAttribute","removeAttribute"],m=0;m<d.length;m++)f[d[m]]=CKEDITOR.tools.override(f[d[m]],e)}(),function(){var a={exec:function(a){var b=a.getCommand("blockquote").state,e=a.getSelection(),h=e&&e.getRanges()[0];if(h){var l=e.createBookmarks();if(CKEDITOR.env.ie){var k=l[0].startNode,f=l[0].endNode,d;if(k&&"blockquote"==k.getParent().getName())for(d=k;d=d.getNext();)if(d.type==CKEDITOR.NODE_ELEMENT&&d.isBlockBoundary()){k.move(d,!0);break}if(f&&"blockquote"==f.getParent().getName())for(d=f;d=d.getPrevious();)if(d.type==
CKEDITOR.NODE_ELEMENT&&d.isBlockBoundary()){f.move(d);break}}var m=h.createIterator();m.enlargeBr=a.config.enterMode!=CKEDITOR.ENTER_BR;if(b==CKEDITOR.TRISTATE_OFF){for(k=[];b=m.getNextParagraph();)k.push(b);1>k.length&&(b=a.document.createElement(a.config.enterMode==CKEDITOR.ENTER_P?"p":"div"),f=l.shift(),h.insertNode(b),b.append(new CKEDITOR.dom.text("﻿",a.document)),h.moveToBookmark(f),h.selectNodeContents(b),h.collapse(!0),f=h.createBookmark(),k.push(b),l.unshift(f));d=k[0].getParent();h=[];for(f=
0;f<k.length;f++)b=k[f],d=d.getCommonAncestor(b.getParent());for(b={table:1,tbody:1,tr:1,ol:1,ul:1};b[d.getName()];)d=d.getParent();for(f=null;0<k.length;){for(b=k.shift();!b.getParent().equals(d);)b=b.getParent();b.equals(f)||h.push(b);f=b}for(;0<h.length;)if(b=h.shift(),"blockquote"==b.getName()){for(f=new CKEDITOR.dom.documentFragment(a.document);b.getFirst();)f.append(b.getFirst().remove()),k.push(f.getLast());f.replace(b)}else k.push(b);h=a.document.createElement("blockquote");for(h.insertBefore(k[0]);0<
k.length;)b=k.shift(),h.append(b)}else if(b==CKEDITOR.TRISTATE_ON){f=[];for(d={};b=m.getNextParagraph();){for(k=h=null;b.getParent();){if("blockquote"==b.getParent().getName()){h=b.getParent();k=b;break}b=b.getParent()}h&&k&&!k.getCustomData("blockquote_moveout")&&(f.push(k),CKEDITOR.dom.element.setMarker(d,k,"blockquote_moveout",!0))}CKEDITOR.dom.element.clearAllMarkers(d);b=[];k=[];for(d={};0<f.length;)m=f.shift(),h=m.getParent(),m.getPrevious()?m.getNext()?(m.breakParent(m.getParent()),k.push(m.getNext())):
m.remove().insertAfter(h):m.remove().insertBefore(h),h.getCustomData("blockquote_processed")||(k.push(h),CKEDITOR.dom.element.setMarker(d,h,"blockquote_processed",!0)),b.push(m);CKEDITOR.dom.element.clearAllMarkers(d);for(f=k.length-1;0<=f;f--){h=k[f];a:{d=h;for(var m=0,g=d.getChildCount(),n=void 0;m<g&&(n=d.getChild(m));m++)if(n.type==CKEDITOR.NODE_ELEMENT&&n.isBlockBoundary()){d=!1;break a}d=!0}d&&h.remove()}if(a.config.enterMode==CKEDITOR.ENTER_BR)for(h=!0;b.length;)if(m=b.shift(),"div"==m.getName()){f=
new CKEDITOR.dom.documentFragment(a.document);!h||!m.getPrevious()||m.getPrevious().type==CKEDITOR.NODE_ELEMENT&&m.getPrevious().isBlockBoundary()||f.append(a.document.createElement("br"));for(h=m.getNext()&&!(m.getNext().type==CKEDITOR.NODE_ELEMENT&&m.getNext().isBlockBoundary());m.getFirst();)m.getFirst().remove().appendTo(f);h&&f.append(a.document.createElement("br"));f.replace(m);h=!1}}e.selectBookmarks(l);a.focus()}},refresh:function(a,b){this.setState(a.elementPath(b.block||b.blockLimit).contains("blockquote",
1)?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF)},context:"blockquote",allowedContent:"blockquote",requiredContent:"blockquote"};CKEDITOR.plugins.add("blockquote",{init:function(c){c.blockless||(c.addCommand("blockquote",a),c.ui.addButton&&c.ui.addButton("Blockquote",{label:c.lang.blockquote.toolbar,command:"blockquote",toolbar:"blocks,10"}))}})}(),"use strict",CKEDITOR.plugins.add("notification",{init:function(a){function c(a){var c=new CKEDITOR.dom.element("div");c.setStyles({position:"fixed","margin-left":"-9999px"});
c.setAttributes({"aria-live":"assertive","aria-atomic":"true"});c.setText(a);CKEDITOR.document.getBody().append(c);setTimeout(function(){c.remove()},100)}a._.notificationArea=new la(a);a.showNotification=function(b,c,h){var l,k;"progress"==c?l=h:k=h;b=new CKEDITOR.plugins.notification(a,{message:b,type:c,progress:l,duration:k});b.show();return b};a.on("key",function(b){if(27==b.data.keyCode){var e=a._.notificationArea.notifications;e.length&&(c(a.lang.notification.closed),e[e.length-1].hide(),b.cancel())}})}}),
ka.prototype={show:function(){!1!==this.editor.fire("notificationShow",{notification:this})&&(this.area.add(this),this._hideAfterTimeout())},update:function(a){var c=!0;!1===this.editor.fire("notificationUpdate",{notification:this,options:a})&&(c=!1);var b=this.element,e=b.findOne(".cke_notification_message"),h=b.findOne(".cke_notification_progress"),l=a.type;b.removeAttribute("role");a.progress&&"progress"!=this.type&&(l="progress");l&&(b.removeClass(this._getClass()),b.removeAttribute("aria-label"),
this.type=l,b.addClass(this._getClass()),b.setAttribute("aria-label",this.type),"progress"!=this.type||h?"progress"!=this.type&&h&&h.remove():(h=this._createProgressElement(),h.insertBefore(e)));void 0!==a.message&&(this.message=a.message,e.setHtml(this.message));void 0!==a.progress&&(this.progress=a.progress,h&&h.setStyle("width",this._getPercentageProgress()));c&&a.important&&(b.setAttribute("role","alert"),this.isVisible()||this.area.add(this));this.duration=a.duration;this._hideAfterTimeout()},
hide:function(){!1!==this.editor.fire("notificationHide",{notification:this})&&this.area.remove(this)},isVisible:function(){return 0<=CKEDITOR.tools.indexOf(this.area.notifications,this)},_createElement:function(){var a=this,c,b,e=this.editor.lang.common.close;c=new CKEDITOR.dom.element("div");c.addClass("cke_notification");c.addClass(this._getClass());c.setAttributes({id:this.id,role:"alert","aria-label":this.type});"progress"==this.type&&c.append(this._createProgressElement());b=new CKEDITOR.dom.element("p");
b.addClass("cke_notification_message");b.setHtml(this.message);c.append(b);b=CKEDITOR.dom.element.createFromHtml('\x3ca class\x3d"cke_notification_close" href\x3d"javascript:void(0)" title\x3d"'+e+'" role\x3d"button" tabindex\x3d"-1"\x3e\x3cspan class\x3d"cke_label"\x3eX\x3c/span\x3e\x3c/a\x3e');c.append(b);b.on("click",function(){a.editor.focus();a.hide()});return c},_getClass:function(){return"progress"==this.type?"cke_notification_info":"cke_notification_"+this.type},_createProgressElement:function(){var a=
new CKEDITOR.dom.element("span");a.addClass("cke_notification_progress");a.setStyle("width",this._getPercentageProgress());return a},_getPercentageProgress:function(){return Math.round(100*(this.progress||0))+"%"},_hideAfterTimeout:function(){var a=this,c;this._hideTimeoutId&&clearTimeout(this._hideTimeoutId);if("number"==typeof this.duration)c=this.duration;else if("info"==this.type||"success"==this.type)c="number"==typeof this.editor.config.notification_duration?this.editor.config.notification_duration:
5E3;c&&(a._hideTimeoutId=setTimeout(function(){a.hide()},c))}},la.prototype={add:function(a){this.notifications.push(a);this.element.append(a.element);1==this.element.getChildCount()&&(CKEDITOR.document.getBody().append(this.element),this._attachListeners());this._layout()},remove:function(a){var c=CKEDITOR.tools.indexOf(this.notifications,a);0>c||(this.notifications.splice(c,1),a.element.remove(),this.element.getChildCount()||(this._removeListeners(),this.element.remove()))},_createElement:function(){var a=
this.editor,c=a.config,b=new CKEDITOR.dom.element("div");b.addClass("cke_notifications_area");b.setAttribute("id","cke_notifications_area_"+a.name);b.setStyle("z-index",c.baseFloatZIndex-2);return b},_attachListeners:function(){var a=CKEDITOR.document.getWindow(),c=this.editor;a.on("scroll",this._uiBuffer.input);a.on("resize",this._uiBuffer.input);c.on("change",this._changeBuffer.input);c.on("floatingSpaceLayout",this._layout,this,null,20);c.on("blur",this._layout,this,null,20)},_removeListeners:function(){var a=
CKEDITOR.document.getWindow(),c=this.editor;a.removeListener("scroll",this._uiBuffer.input);a.removeListener("resize",this._uiBuffer.input);c.removeListener("change",this._changeBuffer.input);c.removeListener("floatingSpaceLayout",this._layout);c.removeListener("blur",this._layout)},_layout:function(){function a(){c.setStyle("left",v(t+e.width-m-g))}var c=this.element,b=this.editor,e=b.ui.contentsElement.getClientRect(),h=b.ui.contentsElement.getDocumentPosition(),l,k,f=c.getClientRect(),d,m=this._notificationWidth,
g=this._notificationMargin;d=CKEDITOR.document.getWindow();var n=d.getScrollPosition(),p=d.getViewPaneSize(),q=CKEDITOR.document.getBody(),y=q.getDocumentPosition(),v=CKEDITOR.tools.cssLength;m&&g||(d=this.element.getChild(0),m=this._notificationWidth=d.getClientRect().width,g=this._notificationMargin=parseInt(d.getComputedStyle("margin-left"),10)+parseInt(d.getComputedStyle("margin-right"),10));b.toolbar&&(l=b.ui.space("top"),k=l.getClientRect());l&&l.isVisible()&&k.bottom>e.top&&k.bottom<e.bottom-
f.height?c.setStyles({position:"fixed",top:v(k.bottom)}):0<e.top?c.setStyles({position:"absolute",top:v(h.y)}):h.y+e.height-f.height>n.y?c.setStyles({position:"fixed",top:0}):c.setStyles({position:"absolute",top:v(h.y+e.height-f.height)});var t="fixed"==c.getStyle("position")?e.left:"static"!=q.getComputedStyle("position")?h.x-y.x:h.x;e.width<m+g?h.x+m+g>n.x+p.width?a():c.setStyle("left",v(t)):h.x+m+g>n.x+p.width?c.setStyle("left",v(t)):h.x+e.width/2+m/2+g>n.x+p.width?c.setStyle("left",v(t-h.x+n.x+
p.width-m-g)):0>e.left+e.width-m-g?a():0>e.left+e.width/2-m/2?c.setStyle("left",v(t-h.x+n.x)):c.setStyle("left",v(t+e.width/2-m/2-g/2))}},CKEDITOR.plugins.notification=ka,function(){var a='\x3ca id\x3d"{id}" class\x3d"cke_button cke_button__{name} cke_button_{state} {cls}"'+(CKEDITOR.env.gecko&&!CKEDITOR.env.hc?"":" href\x3d\"javascript:void('{titleJs}')\"")+' title\x3d"{title}" tabindex\x3d"-1" hidefocus\x3d"true" role\x3d"button" aria-labelledby\x3d"{id}_label" aria-describedby\x3d"{id}_description" aria-haspopup\x3d"{hasArrow}" aria-disabled\x3d"{ariaDisabled}"';
CKEDITOR.env.gecko&&CKEDITOR.env.mac&&(a+=' onkeypress\x3d"return false;"');CKEDITOR.env.gecko&&(a+=' onblur\x3d"this.style.cssText \x3d this.style.cssText;"');var a=a+(' onkeydown\x3d"return CKEDITOR.tools.callFunction({keydownFn},event);" onfocus\x3d"return CKEDITOR.tools.callFunction({focusFn},event);" '+(CKEDITOR.env.ie?'onclick\x3d"return false;" onmouseup':"onclick")+'\x3d"CKEDITOR.tools.callFunction({clickFn},this);return false;"\x3e\x3cspan class\x3d"cke_button_icon cke_button__{iconName}_icon" style\x3d"{style}"'),
a=a+'\x3e\x26nbsp;\x3c/span\x3e\x3cspan id\x3d"{id}_label" class\x3d"cke_button_label cke_button__{name}_label" aria-hidden\x3d"false"\x3e{label}\x3c/span\x3e\x3cspan id\x3d"{id}_description" class\x3d"cke_button_label" aria-hidden\x3d"false"\x3e{ariaShortcut}\x3c/span\x3e{arrowHtml}\x3c/a\x3e',c=CKEDITOR.addTemplate("buttonArrow",'\x3cspan class\x3d"cke_button_arrow"\x3e'+(CKEDITOR.env.hc?"\x26#9660;":"")+"\x3c/span\x3e"),b=CKEDITOR.addTemplate("button",a);CKEDITOR.plugins.add("button",{beforeInit:function(a){a.ui.addHandler(CKEDITOR.UI_BUTTON,
CKEDITOR.ui.button.handler)}});CKEDITOR.UI_BUTTON="button";CKEDITOR.ui.button=function(a){CKEDITOR.tools.extend(this,a,{title:a.label,click:a.click||function(b){b.execCommand(a.command)}});this._={}};CKEDITOR.ui.button.handler={create:function(a){return new CKEDITOR.ui.button(a)}};CKEDITOR.ui.button.prototype={render:function(a,h){function l(){var b=a.mode;b&&(b=this.modes[b]?void 0!==r[b]?r[b]:CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,b=a.readOnly&&!this.readOnly?CKEDITOR.TRISTATE_DISABLED:
b,this.setState(b),this.refresh&&this.refresh())}var k=CKEDITOR.env,f=this._.id=CKEDITOR.tools.getNextId(),d="",m=this.command,g,n,p;this._.editor=a;var q={id:f,button:this,editor:a,focus:function(){CKEDITOR.document.getById(f).focus()},execute:function(){this.button.click(a)},attach:function(a){this.button.attach(a)}},y=CKEDITOR.tools.addFunction(function(a){if(q.onkey)return a=new CKEDITOR.dom.event(a),!1!==q.onkey(q,a.getKeystroke())}),v=CKEDITOR.tools.addFunction(function(a){var b;q.onfocus&&
(b=!1!==q.onfocus(q,new CKEDITOR.dom.event(a)));return b}),t=0;q.clickFn=g=CKEDITOR.tools.addFunction(function(){t&&(a.unlockSelection(1),t=0);q.execute();k.iOS&&a.focus()});if(this.modes){var r={};a.on("beforeModeUnload",function(){a.mode&&this._.state!=CKEDITOR.TRISTATE_DISABLED&&(r[a.mode]=this._.state)},this);a.on("activeFilterChange",l,this);a.on("mode",l,this);!this.readOnly&&a.on("readOnly",l,this)}else m&&(m=a.getCommand(m))&&(m.on("state",function(){this.setState(m.state)},this),d+=m.state==
CKEDITOR.TRISTATE_ON?"on":m.state==CKEDITOR.TRISTATE_DISABLED?"disabled":"off");if(this.directional)a.on("contentDirChanged",function(b){var d=CKEDITOR.document.getById(this._.id),c=d.getFirst();b=b.data;b!=a.lang.dir?d.addClass("cke_"+b):d.removeClass("cke_ltr").removeClass("cke_rtl");c.setAttribute("style",CKEDITOR.skin.getIconStyle(w,"rtl"==b,this.icon,this.iconOffset))},this);m?(n=a.getCommandKeystroke(m))&&(p=CKEDITOR.tools.keystrokeToString(a.lang.common.keyboard,n)):d+="off";var w=n=this.name||
this.command;this.icon&&!/\./.test(this.icon)&&(w=this.icon,this.icon=null);d={id:f,name:n,iconName:w,label:this.label,cls:this.className||"",state:d,ariaDisabled:"disabled"==d?"true":"false",title:this.title+(p?" ("+p.display+")":""),ariaShortcut:p?a.lang.common.keyboardShortcut+" "+p.aria:"",titleJs:k.gecko&&!k.hc?"":(this.title||"").replace("'",""),hasArrow:this.hasArrow?"true":"false",keydownFn:y,focusFn:v,clickFn:g,style:CKEDITOR.skin.getIconStyle(w,"rtl"==a.lang.dir,this.icon,this.iconOffset),
arrowHtml:this.hasArrow?c.output():""};b.output(d,h);if(this.onRender)this.onRender();return q},setState:function(a){if(this._.state==a)return!1;this._.state=a;var b=CKEDITOR.document.getById(this._.id);return b?(b.setState(a,"cke_button"),a==CKEDITOR.TRISTATE_DISABLED?b.setAttribute("aria-disabled",!0):b.removeAttribute("aria-disabled"),this.hasArrow?(a=a==CKEDITOR.TRISTATE_ON?this._.editor.lang.button.selectedLabel.replace(/%1/g,this.label):this.label,CKEDITOR.document.getById(this._.id+"_label").setText(a)):
a==CKEDITOR.TRISTATE_ON?b.setAttribute("aria-pressed",!0):b.removeAttribute("aria-pressed"),!0):!1},getState:function(){return this._.state},toFeature:function(a){if(this._.feature)return this._.feature;var b=this;this.allowedContent||this.requiredContent||!this.command||(b=a.getCommand(this.command)||b);return this._.feature=b}};CKEDITOR.ui.prototype.addButton=function(a,b){this.add(a,CKEDITOR.UI_BUTTON,b)}}(),function(){function a(a){function b(){for(var d=e(),g=CKEDITOR.tools.clone(a.config.toolbarGroups)||
c(a),m=0;m<g.length;m++){var l=g[m];if("/"!=l){"string"==typeof l&&(l=g[m]={name:l});var v,t=l.groups;if(t)for(var r=0;r<t.length;r++)v=t[r],(v=d[v])&&f(l,v);(v=d[l.name])&&f(l,v)}}return g}function e(){var b={},d,c,g;for(d in a.ui.items)c=a.ui.items[d],g=c.toolbar||"others",g=g.split(","),c=g[0],g=parseInt(g[1]||-1,10),b[c]||(b[c]=[]),b[c].push({name:d,order:g});for(c in b)b[c]=b[c].sort(function(a,b){return a.order==b.order?0:0>b.order?-1:0>a.order?1:a.order<b.order?-1:1});return b}function f(b,
d){if(d.length){b.items?b.items.push(a.ui.create("-")):b.items=[];for(var c;c=d.shift();)c="string"==typeof c?c:c.name,m&&-1!=CKEDITOR.tools.indexOf(m,c)||(c=a.ui.create(c))&&a.addFeature(c)&&b.items.push(c)}}function d(a){var b=[],d,c,e;for(d=0;d<a.length;++d)c=a[d],e={},"/"==c?b.push(c):CKEDITOR.tools.isArray(c)?(f(e,CKEDITOR.tools.clone(c)),b.push(e)):c.items&&(f(e,CKEDITOR.tools.clone(c.items)),e.name=c.name,b.push(e));return b}var m=a.config.removeButtons,m=m&&m.split(","),g=a.config.toolbar;
"string"==typeof g&&(g=a.config["toolbar_"+g]);return a.toolbar=g?d(g):b()}function c(a){return a._.toolbarGroups||(a._.toolbarGroups=[{name:"document",groups:["mode","document","doctools"]},{name:"clipboard",groups:["clipboard","undo"]},{name:"editing",groups:["find","selection","spellchecker"]},{name:"forms"},"/",{name:"basicstyles",groups:["basicstyles","cleanup"]},{name:"paragraph",groups:["list","indent","blocks","align","bidi"]},{name:"links"},{name:"insert"},"/",{name:"styles"},{name:"colors"},
{name:"tools"},{name:"others"},{name:"about"}])}var b=function(){this.toolbars=[];this.focusCommandExecuted=!1};b.prototype.focus=function(){for(var a=0,b;b=this.toolbars[a++];)for(var c=0,e;e=b.items[c++];)if(e.focus){e.focus();return}};var e={modes:{wysiwyg:1,source:1},readOnly:1,exec:function(a){a.toolbox&&(a.toolbox.focusCommandExecuted=!0,CKEDITOR.env.ie||CKEDITOR.env.air?setTimeout(function(){a.toolbox.focus()},100):a.toolbox.focus())}};CKEDITOR.plugins.add("toolbar",{requires:"button",init:function(c){var l,
k=function(a,b){var e,g="rtl"==c.lang.dir,n=c.config.toolbarGroupCycling,p=g?37:39,g=g?39:37,n=void 0===n||n;switch(b){case 9:case CKEDITOR.SHIFT+9:for(;!e||!e.items.length;)if(e=9==b?(e?e.next:a.toolbar.next)||c.toolbox.toolbars[0]:(e?e.previous:a.toolbar.previous)||c.toolbox.toolbars[c.toolbox.toolbars.length-1],e.items.length)for(a=e.items[l?e.items.length-1:0];a&&!a.focus;)(a=l?a.previous:a.next)||(e=0);a&&a.focus();return!1;case p:e=a;do e=e.next,!e&&n&&(e=a.toolbar.items[0]);while(e&&!e.focus);
e?e.focus():k(a,9);return!1;case 40:return a.button&&a.button.hasArrow?a.execute():k(a,40==b?p:g),!1;case g:case 38:e=a;do e=e.previous,!e&&n&&(e=a.toolbar.items[a.toolbar.items.length-1]);while(e&&!e.focus);e?e.focus():(l=1,k(a,CKEDITOR.SHIFT+9),l=0);return!1;case 27:return c.focus(),!1;case 13:case 32:return a.execute(),!1}return!0};c.on("uiSpace",function(e){if(e.data.space==c.config.toolbarLocation){e.removeListener();c.toolbox=new b;var d=CKEDITOR.tools.getNextId(),m=['\x3cspan id\x3d"',d,'" class\x3d"cke_voice_label"\x3e',
c.lang.toolbar.toolbars,"\x3c/span\x3e",'\x3cspan id\x3d"'+c.ui.spaceId("toolbox")+'" class\x3d"cke_toolbox" role\x3d"group" aria-labelledby\x3d"',d,'" onmousedown\x3d"return false;"\x3e'],d=!1!==c.config.toolbarStartupExpanded,g,l;c.config.toolbarCanCollapse&&c.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE&&m.push('\x3cspan class\x3d"cke_toolbox_main"'+(d?"\x3e":' style\x3d"display:none"\x3e'));for(var p=c.toolbox.toolbars,q=a(c),y=q.length,v=0;v<y;v++){var t,r=0,w,z=q[v],u="/"!==z&&("/"===q[v+1]||v==
y-1),B;if(z)if(g&&(m.push("\x3c/span\x3e"),l=g=0),"/"===z)m.push('\x3cspan class\x3d"cke_toolbar_break"\x3e\x3c/span\x3e');else{B=z.items||z;for(var C=0;C<B.length;C++){var x=B[C],A;if(x){var D=function(a){a=a.render(c,m);H=r.items.push(a)-1;0<H&&(a.previous=r.items[H-1],a.previous.next=a);a.toolbar=r;a.onkey=k;a.onfocus=function(){c.toolbox.focusCommandExecuted||c.focus()}};if(x.type==CKEDITOR.UI_SEPARATOR)l=g&&x;else{A=!1!==x.canGroup;if(!r){t=CKEDITOR.tools.getNextId();r={id:t,items:[]};w=z.name&&
(c.lang.toolbar.toolbarGroups[z.name]||z.name);m.push('\x3cspan id\x3d"',t,'" class\x3d"cke_toolbar'+(u?' cke_toolbar_last"':'"'),w?' aria-labelledby\x3d"'+t+'_label"':"",' role\x3d"toolbar"\x3e');w&&m.push('\x3cspan id\x3d"',t,'_label" class\x3d"cke_voice_label"\x3e',w,"\x3c/span\x3e");m.push('\x3cspan class\x3d"cke_toolbar_start"\x3e\x3c/span\x3e');var H=p.push(r)-1;0<H&&(r.previous=p[H-1],r.previous.next=r)}A?g||(m.push('\x3cspan class\x3d"cke_toolgroup" role\x3d"presentation"\x3e'),g=1):g&&(m.push("\x3c/span\x3e"),
g=0);l&&(D(l),l=0);D(x)}}}g&&(m.push("\x3c/span\x3e"),l=g=0);r&&m.push('\x3cspan class\x3d"cke_toolbar_end"\x3e\x3c/span\x3e\x3c/span\x3e')}}c.config.toolbarCanCollapse&&m.push("\x3c/span\x3e");if(c.config.toolbarCanCollapse&&c.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE){var E=CKEDITOR.tools.addFunction(function(){c.execCommand("toolbarCollapse")});c.on("destroy",function(){CKEDITOR.tools.removeFunction(E)});c.addCommand("toolbarCollapse",{readOnly:1,exec:function(a){var b=a.ui.space("toolbar_collapser"),
d=b.getPrevious(),c=a.ui.space("contents"),e=d.getParent(),g=parseInt(c.$.style.height,10),f=e.$.offsetHeight,h=b.hasClass("cke_toolbox_collapser_min");h?(d.show(),b.removeClass("cke_toolbox_collapser_min"),b.setAttribute("title",a.lang.toolbar.toolbarCollapse)):(d.hide(),b.addClass("cke_toolbox_collapser_min"),b.setAttribute("title",a.lang.toolbar.toolbarExpand));b.getFirst().setText(h?"▲":"◀");c.setStyle("height",g-(e.$.offsetHeight-f)+"px");a.fire("resize",{outerHeight:a.container.$.offsetHeight,
contentsHeight:c.$.offsetHeight,outerWidth:a.container.$.offsetWidth})},modes:{wysiwyg:1,source:1}});c.setKeystroke(CKEDITOR.ALT+(CKEDITOR.env.ie||CKEDITOR.env.webkit?189:109),"toolbarCollapse");m.push('\x3ca title\x3d"'+(d?c.lang.toolbar.toolbarCollapse:c.lang.toolbar.toolbarExpand)+'" id\x3d"'+c.ui.spaceId("toolbar_collapser")+'" tabIndex\x3d"-1" class\x3d"cke_toolbox_collapser');d||m.push(" cke_toolbox_collapser_min");m.push('" onclick\x3d"CKEDITOR.tools.callFunction('+E+')"\x3e','\x3cspan class\x3d"cke_arrow"\x3e\x26#9650;\x3c/span\x3e',
"\x3c/a\x3e")}m.push("\x3c/span\x3e");e.data.html+=m.join("")}});c.on("destroy",function(){if(this.toolbox){var a,b=0,c,e,h;for(a=this.toolbox.toolbars;b<a.length;b++)for(e=a[b].items,c=0;c<e.length;c++)h=e[c],h.clickFn&&CKEDITOR.tools.removeFunction(h.clickFn),h.keyDownFn&&CKEDITOR.tools.removeFunction(h.keyDownFn)}});c.on("uiReady",function(){var a=c.ui.space("toolbox");a&&c.focusManager.add(a,1)});c.addCommand("toolbarFocus",e);c.setKeystroke(CKEDITOR.ALT+121,"toolbarFocus");c.ui.add("-",CKEDITOR.UI_SEPARATOR,
{});c.ui.addHandler(CKEDITOR.UI_SEPARATOR,{create:function(){return{render:function(a,b){b.push('\x3cspan class\x3d"cke_toolbar_separator" role\x3d"separator"\x3e\x3c/span\x3e');return{}}}}})}});CKEDITOR.ui.prototype.addToolbarGroup=function(a,b,e){var f=c(this.editor),d=0===b,m={name:a};if(e){if(e=CKEDITOR.tools.search(f,function(a){return a.name==e})){!e.groups&&(e.groups=[]);if(b&&(b=CKEDITOR.tools.indexOf(e.groups,b),0<=b)){e.groups.splice(b+1,0,a);return}d?e.groups.splice(0,0,a):e.groups.push(a);
return}b=null}b&&(b=CKEDITOR.tools.indexOf(f,function(a){return a.name==b}));d?f.splice(0,0,a):"number"==typeof b?f.splice(b+1,0,m):f.push(a)}}(),CKEDITOR.UI_SEPARATOR="separator",CKEDITOR.config.toolbarLocation="top","use strict",function(){function a(a,b,d){b.type||(b.type="auto");if(d&&!1===a.fire("beforePaste",b)||!b.dataValue&&b.dataTransfer.isEmpty())return!1;b.dataValue||(b.dataValue="");if(CKEDITOR.env.gecko&&"drop"==b.method&&a.toolbox)a.once("afterPaste",function(){a.toolbox.focus()});return a.fire("paste",
b)}function c(b){function d(){var a=b.editable();if(CKEDITOR.plugins.clipboard.isCustomCopyCutSupported){var c=function(a){b.readOnly&&"cut"==a.name||A.initPasteDataTransfer(a,b);a.data.preventDefault()};a.on("copy",c);a.on("cut",c);a.on("cut",function(){b.readOnly||b.extractSelectedHtml()},null,null,999)}a.on(A.mainPasteEvent,function(a){"beforepaste"==A.mainPasteEvent&&D||B(a)});"beforepaste"==A.mainPasteEvent&&(a.on("paste",function(a){H||(f(),a.data.preventDefault(),B(a),m("paste"))}),a.on("contextmenu",
h,null,null,0),a.on("beforepaste",function(a){!a.data||a.data.$.ctrlKey||a.data.$.shiftKey||h()},null,null,0));a.on("beforecut",function(){!D&&k(b)});var e;a.attachListener(CKEDITOR.env.ie?a:b.document.getDocumentElement(),"mouseup",function(){e=setTimeout(function(){C()},0)});b.on("destroy",function(){clearTimeout(e)});a.on("keyup",C)}function c(a){return{type:a,canUndo:"cut"==a,startDisabled:!0,fakeKeystroke:"cut"==a?CKEDITOR.CTRL+88:CKEDITOR.CTRL+67,exec:function(){"cut"==this.type&&k();var a;
var d=this.type;if(CKEDITOR.env.ie)a=m(d);else try{a=b.document.$.execCommand(d,!1,null)}catch(c){a=!1}a||b.showNotification(b.lang.clipboard[this.type+"Error"]);return a}}}function e(){return{canUndo:!1,async:!0,fakeKeystroke:CKEDITOR.CTRL+86,exec:function(b,d){function c(d,f){f="undefined"!==typeof f?f:!0;d?(d.method="paste",d.dataTransfer||(d.dataTransfer=A.initPasteDataTransfer()),a(b,d,f)):g&&b.showNotification(m,"info",b.config.clipboard_notificationDuration);b.fire("afterCommandExec",{name:"paste",
command:e,returnValue:!!d})}d="undefined"!==typeof d&&null!==d?d:{};var e=this,g="undefined"!==typeof d.notification?d.notification:!0,f=d.type,h=CKEDITOR.tools.keystrokeToString(b.lang.common.keyboard,b.getCommandKeystroke(this)),m="string"===typeof g?g:b.lang.clipboard.pasteNotification.replace(/%1/,'\x3ckbd aria-label\x3d"'+h.aria+'"\x3e'+h.display+"\x3c/kbd\x3e"),h="string"===typeof d?d:d.dataValue;f?b._.nextPasteType=f:delete b._.nextPasteType;"string"===typeof h?c({dataValue:h}):b.getClipboardData(c)}}}
function f(){H=1;setTimeout(function(){H=0},100)}function h(){D=1;setTimeout(function(){D=0},10)}function m(a){var d=b.document,c=d.getBody(),e=!1,f=function(){e=!0};c.on(a,f);7<CKEDITOR.env.version?d.$.execCommand(a):d.$.selection.createRange().execCommand(a);c.removeListener(a,f);return e}function k(){if(CKEDITOR.env.ie&&!CKEDITOR.env.quirks){var a=b.getSelection(),d,c,e;a.getType()==CKEDITOR.SELECTION_ELEMENT&&(d=a.getSelectedElement())&&(c=a.getRanges()[0],e=b.document.createText(""),e.insertBefore(d),
c.setStartBefore(e),c.setEndAfter(d),a.selectRanges([c]),setTimeout(function(){d.getParent()&&(e.remove(),a.selectElement(d))},0))}}function l(a,d){var c=b.document,e=b.editable(),f=function(a){a.cancel()},h;if(!c.getById("cke_pastebin")){var m=b.getSelection(),k=m.createBookmarks();CKEDITOR.env.ie&&m.root.fire("selectionchange");var n=new CKEDITOR.dom.element(!CKEDITOR.env.webkit&&!e.is("body")||CKEDITOR.env.ie?"div":"body",c);n.setAttributes({id:"cke_pastebin","data-cke-temp":"1"});var r=0,c=c.getWindow();
CKEDITOR.env.webkit?(e.append(n),n.addClass("cke_editable"),e.is("body")||(r="static"!=e.getComputedStyle("position")?e:CKEDITOR.dom.element.get(e.$.offsetParent),r=r.getDocumentPosition().y)):e.getAscendant(CKEDITOR.env.ie?"body":"html",1).append(n);n.setStyles({position:"absolute",top:c.getScrollPosition().y-r+10+"px",width:"1px",height:Math.max(1,c.getViewPaneSize().height-20)+"px",overflow:"hidden",margin:0,padding:0});CKEDITOR.env.safari&&n.setStyles(CKEDITOR.tools.cssVendorPrefix("user-select",
"text"));(r=n.getParent().isReadOnly())?(n.setOpacity(0),n.setAttribute("contenteditable",!0)):n.setStyle("ltr"==b.config.contentsLangDirection?"left":"right","-10000px");b.on("selectionChange",f,null,null,0);if(CKEDITOR.env.webkit||CKEDITOR.env.gecko)h=e.once("blur",f,null,null,-100);r&&n.focus();r=new CKEDITOR.dom.range(n);r.selectNodeContents(n);var w=r.select();CKEDITOR.env.ie&&(h=e.once("blur",function(){b.lockSelection(w)}));var t=CKEDITOR.document.getWindow().getScrollPosition().y;setTimeout(function(){CKEDITOR.env.webkit&&
(CKEDITOR.document.getBody().$.scrollTop=t);h&&h.removeListener();CKEDITOR.env.ie&&e.focus();m.selectBookmarks(k);n.remove();var a;CKEDITOR.env.webkit&&(a=n.getFirst())&&a.is&&a.hasClass("Apple-style-span")&&(n=a);b.removeListener("selectionChange",f);d(n.getHtml())},0)}}function z(){if("paste"==A.mainPasteEvent)return b.fire("beforePaste",{type:"auto",method:"paste"}),!1;b.focus();f();var a=b.focusManager;a.lock();if(b.editable().fire(A.mainPasteEvent)&&!m("paste"))return a.unlock(),!1;a.unlock();
return!0}function u(a){if("wysiwyg"==b.mode)switch(a.data.keyCode){case CKEDITOR.CTRL+86:case CKEDITOR.SHIFT+45:a=b.editable();f();"paste"==A.mainPasteEvent&&a.fire("beforepaste");break;case CKEDITOR.CTRL+88:case CKEDITOR.SHIFT+46:b.fire("saveSnapshot"),setTimeout(function(){b.fire("saveSnapshot")},50)}}function B(d){var c={type:"auto",method:"paste",dataTransfer:A.initPasteDataTransfer(d)};c.dataTransfer.cacheData();var e=!1!==b.fire("beforePaste",c);e&&A.canClipboardApiBeTrusted(c.dataTransfer,
b)?(d.data.preventDefault(),setTimeout(function(){a(b,c)},0)):l(d,function(d){c.dataValue=d.replace(/<span[^>]+data-cke-bookmark[^<]*?<\/span>/ig,"");e&&a(b,c)})}function C(){if("wysiwyg"==b.mode){var a=x("paste");b.getCommand("cut").setState(x("cut"));b.getCommand("copy").setState(x("copy"));b.getCommand("paste").setState(a);b.fire("pasteState",a)}}function x(a){if(E&&a in{paste:1,cut:1})return CKEDITOR.TRISTATE_DISABLED;if("paste"==a)return CKEDITOR.TRISTATE_OFF;a=b.getSelection();var d=a.getRanges();
return a.getType()==CKEDITOR.SELECTION_NONE||1==d.length&&d[0].collapsed?CKEDITOR.TRISTATE_DISABLED:CKEDITOR.TRISTATE_OFF}var A=CKEDITOR.plugins.clipboard,D=0,H=0,E=0;(function(){b.on("key",u);b.on("contentDom",d);b.on("selectionChange",function(a){E=a.data.selection.getRanges()[0].checkReadOnly();C()});b.contextMenu&&b.contextMenu.addListener(function(a,b){E=b.getRanges()[0].checkReadOnly();return{cut:x("cut"),copy:x("copy"),paste:x("paste")}})})();(function(){function a(d,c,e,f,h){var m=b.lang.clipboard[c];
b.addCommand(c,e);b.ui.addButton&&b.ui.addButton(d,{label:m,command:c,toolbar:"clipboard,"+f});b.addMenuItems&&b.addMenuItem(c,{label:m,command:c,group:"clipboard",order:h})}a("Cut","cut",c("cut"),10,1);a("Copy","copy",c("copy"),20,4);a("Paste","paste",e(),30,8)})();b.getClipboardData=function(a,d){function c(a){a.removeListener();a.cancel();d(a.data)}d||(d=a,a=null);b.on("paste",c,null,null,0);!1===z()&&(b.removeListener("paste",c),d(null))}}function b(a){if(CKEDITOR.env.webkit){if(!a.match(/^[^<]*$/g)&&
!a.match(/^(<div><br( ?\/)?><\/div>|<div>[^<]*<\/div>)*$/gi))return"html"}else if(CKEDITOR.env.ie){if(!a.match(/^([^<]|<br( ?\/)?>)*$/gi)&&!a.match(/^(<p>([^<]|<br( ?\/)?>)*<\/p>|(\r\n))*$/gi))return"html"}else if(CKEDITOR.env.gecko){if(!a.match(/^([^<]|<br( ?\/)?>)*$/gi))return"html"}else return"html";return"htmlifiedtext"}function e(a,b){function d(a){return CKEDITOR.tools.repeat("\x3c/p\x3e\x3cp\x3e",~~(a/2))+(1==a%2?"\x3cbr\x3e":"")}b=b.replace(/\s+/g," ").replace(/> +</g,"\x3e\x3c").replace(/<br ?\/>/gi,
"\x3cbr\x3e");b=b.replace(/<\/?[A-Z]+>/g,function(a){return a.toLowerCase()});if(b.match(/^[^<]$/))return b;CKEDITOR.env.webkit&&-1<b.indexOf("\x3cdiv\x3e")&&(b=b.replace(/^(<div>(<br>|)<\/div>)(?!$|(<div>(<br>|)<\/div>))/g,"\x3cbr\x3e").replace(/^(<div>(<br>|)<\/div>){2}(?!$)/g,"\x3cdiv\x3e\x3c/div\x3e"),b.match(/<div>(<br>|)<\/div>/)&&(b="\x3cp\x3e"+b.replace(/(<div>(<br>|)<\/div>)+/g,function(a){return d(a.split("\x3c/div\x3e\x3cdiv\x3e").length+1)})+"\x3c/p\x3e"),b=b.replace(/<\/div><div>/g,"\x3cbr\x3e"),
b=b.replace(/<\/?div>/g,""));CKEDITOR.env.gecko&&a.enterMode!=CKEDITOR.ENTER_BR&&(CKEDITOR.env.gecko&&(b=b.replace(/^<br><br>$/,"\x3cbr\x3e")),-1<b.indexOf("\x3cbr\x3e\x3cbr\x3e")&&(b="\x3cp\x3e"+b.replace(/(<br>){2,}/g,function(a){return d(a.length/4)})+"\x3c/p\x3e"));return k(a,b)}function h(){function a(){var b={},d;for(d in CKEDITOR.dtd)"$"!=d.charAt(0)&&"div"!=d&&"span"!=d&&(b[d]=1);return b}var b={};return{get:function(d){return"plain-text"==d?b.plainText||(b.plainText=new CKEDITOR.filter("br")):
"semantic-content"==d?((d=b.semanticContent)||(d=new CKEDITOR.filter,d.allow({$1:{elements:a(),attributes:!0,styles:!1,classes:!1}}),d=b.semanticContent=d),d):d?new CKEDITOR.filter(d):null}}}function l(a,b,d){b=CKEDITOR.htmlParser.fragment.fromHtml(b);var c=new CKEDITOR.htmlParser.basicWriter;d.applyTo(b,!0,!1,a.activeEnterMode);b.writeHtml(c);return c.getHtml()}function k(a,b){a.enterMode==CKEDITOR.ENTER_BR?b=b.replace(/(<\/p><p>)+/g,function(a){return CKEDITOR.tools.repeat("\x3cbr\x3e",a.length/
7*2)}).replace(/<\/?p>/g,""):a.enterMode==CKEDITOR.ENTER_DIV&&(b=b.replace(/<(\/)?p>/g,"\x3c$1div\x3e"));return b}function f(a){a.data.preventDefault();a.data.$.dataTransfer.dropEffect="none"}function d(b){var d=CKEDITOR.plugins.clipboard;b.on("contentDom",function(){function c(d,e,f){e.select();a(b,{dataTransfer:f,method:"drop"},1);f.sourceEditor.fire("saveSnapshot");f.sourceEditor.editable().extractHtmlFromRange(d);f.sourceEditor.getSelection().selectRanges([d]);f.sourceEditor.fire("saveSnapshot")}
function e(c,f){c.select();a(b,{dataTransfer:f,method:"drop"},1);d.resetDragDataTransfer()}function f(a,d,c){var e={$:a.data.$,target:a.data.getTarget()};d&&(e.dragRange=d);c&&(e.dropRange=c);!1===b.fire(a.name,e)&&a.data.preventDefault()}function h(a){a.type!=CKEDITOR.NODE_ELEMENT&&(a=a.getParent());return a.getChildCount()}var m=b.editable(),k=CKEDITOR.plugins.clipboard.getDropTarget(b),l=b.ui.space("top"),z=b.ui.space("bottom");d.preventDefaultDropOnElement(l);d.preventDefaultDropOnElement(z);
m.attachListener(k,"dragstart",f);m.attachListener(b,"dragstart",d.resetDragDataTransfer,d,null,1);m.attachListener(b,"dragstart",function(a){d.initDragDataTransfer(a,b)},null,null,2);m.attachListener(b,"dragstart",function(){var a=d.dragRange=b.getSelection().getRanges()[0];CKEDITOR.env.ie&&10>CKEDITOR.env.version&&(d.dragStartContainerChildCount=a?h(a.startContainer):null,d.dragEndContainerChildCount=a?h(a.endContainer):null)},null,null,100);m.attachListener(k,"dragend",f);m.attachListener(b,"dragend",
d.initDragDataTransfer,d,null,1);m.attachListener(b,"dragend",d.resetDragDataTransfer,d,null,100);m.attachListener(k,"dragover",function(a){if(CKEDITOR.env.edge)a.data.preventDefault();else{var b=a.data.getTarget();b&&b.is&&b.is("html")?a.data.preventDefault():CKEDITOR.env.ie&&CKEDITOR.plugins.clipboard.isFileApiSupported&&a.data.$.dataTransfer.types.contains("Files")&&a.data.preventDefault()}});m.attachListener(k,"drop",function(a){if(!a.data.$.defaultPrevented){a.data.preventDefault();var c=a.data.getTarget();
if(!c.isReadOnly()||c.type==CKEDITOR.NODE_ELEMENT&&c.is("html")){var c=d.getRangeAtDropPosition(a,b),e=d.dragRange;c&&f(a,e,c)}}},null,null,9999);m.attachListener(b,"drop",d.initDragDataTransfer,d,null,1);m.attachListener(b,"drop",function(a){if(a=a.data){var f=a.dropRange,h=a.dragRange,m=a.dataTransfer;m.getTransferType(b)==CKEDITOR.DATA_TRANSFER_INTERNAL?setTimeout(function(){d.internalDrop(h,f,m,b)},0):m.getTransferType(b)==CKEDITOR.DATA_TRANSFER_CROSS_EDITORS?c(h,f,m):e(f,m)}},null,null,9999)})}
CKEDITOR.plugins.add("clipboard",{requires:"notification,toolbar",init:function(a){var f,m=h();a.config.forcePasteAsPlainText?f="plain-text":a.config.pasteFilter?f=a.config.pasteFilter:!CKEDITOR.env.webkit||"pasteFilter"in a.config||(f="semantic-content");a.pasteFilter=m.get(f);c(a);d(a);if(CKEDITOR.env.gecko){var k=["image/png","image/jpeg","image/gif"],y;a.on("paste",function(b){var d=b.data,c=d.dataTransfer;if(!d.dataValue&&"paste"==d.method&&c&&1==c.getFilesCount()&&y!=c.id&&(c=c.getFile(0),-1!=
CKEDITOR.tools.indexOf(k,c.type))){var e=new FileReader;e.addEventListener("load",function(){b.data.dataValue='\x3cimg src\x3d"'+e.result+'" /\x3e';a.fire("paste",b.data)},!1);e.addEventListener("abort",function(){a.fire("paste",b.data)},!1);e.addEventListener("error",function(){a.fire("paste",b.data)},!1);e.readAsDataURL(c);y=d.dataTransfer.id;b.stop()}},null,null,1)}a.on("paste",function(b){b.data.dataTransfer||(b.data.dataTransfer=new CKEDITOR.plugins.clipboard.dataTransfer);if(!b.data.dataValue){var d=
b.data.dataTransfer,c=d.getData("text/html");if(c)b.data.dataValue=c,b.data.type="html";else if(c=d.getData("text/plain"))b.data.dataValue=a.editable().transformPlainTextToHtml(c),b.data.type="text"}},null,null,1);a.on("paste",function(a){var b=a.data.dataValue,d=CKEDITOR.dtd.$block;-1<b.indexOf("Apple-")&&(b=b.replace(/<span class="Apple-converted-space">&nbsp;<\/span>/gi," "),"html"!=a.data.type&&(b=b.replace(/<span class="Apple-tab-span"[^>]*>([^<]*)<\/span>/gi,function(a,b){return b.replace(/\t/g,
"\x26nbsp;\x26nbsp; \x26nbsp;")})),-1<b.indexOf('\x3cbr class\x3d"Apple-interchange-newline"\x3e')&&(a.data.startsWithEOL=1,a.data.preSniffing="html",b=b.replace(/<br class="Apple-interchange-newline">/,"")),b=b.replace(/(<[^>]+) class="Apple-[^"]*"/gi,"$1"));if(b.match(/^<[^<]+cke_(editable|contents)/i)){var c,e,f=new CKEDITOR.dom.element("div");for(f.setHtml(b);1==f.getChildCount()&&(c=f.getFirst())&&c.type==CKEDITOR.NODE_ELEMENT&&(c.hasClass("cke_editable")||c.hasClass("cke_contents"));)f=e=c;
e&&(b=e.getHtml().replace(/<br>$/i,""))}CKEDITOR.env.ie?b=b.replace(/^&nbsp;(?: |\r\n)?<(\w+)/g,function(b,c){return c.toLowerCase()in d?(a.data.preSniffing="html","\x3c"+c):b}):CKEDITOR.env.webkit?b=b.replace(/<\/(\w+)><div><br><\/div>$/,function(b,c){return c in d?(a.data.endsWithEOL=1,"\x3c/"+c+"\x3e"):b}):CKEDITOR.env.gecko&&(b=b.replace(/(\s)<br>$/,"$1"));a.data.dataValue=b},null,null,3);a.on("paste",function(d){d=d.data;var c=a._.nextPasteType||d.type,f=d.dataValue,h,k=a.config.clipboard_defaultContentType||
"html",n=d.dataTransfer.getTransferType(a);h="html"==c||"html"==d.preSniffing?"html":b(f);delete a._.nextPasteType;"htmlifiedtext"==h&&(f=e(a.config,f));"text"==c&&"html"==h?f=l(a,f,m.get("plain-text")):n==CKEDITOR.DATA_TRANSFER_EXTERNAL&&a.pasteFilter&&!d.dontFilter&&(f=l(a,f,a.pasteFilter));d.startsWithEOL&&(f='\x3cbr data-cke-eol\x3d"1"\x3e'+f);d.endsWithEOL&&(f+='\x3cbr data-cke-eol\x3d"1"\x3e');"auto"==c&&(c="html"==h||"html"==k?"html":"text");d.type=c;d.dataValue=f;delete d.preSniffing;delete d.startsWithEOL;
delete d.endsWithEOL},null,null,6);a.on("paste",function(b){b=b.data;b.dataValue&&(a.insertHtml(b.dataValue,b.type,b.range),setTimeout(function(){a.fire("afterPaste")},0))},null,null,1E3)}});CKEDITOR.plugins.clipboard={isCustomCopyCutSupported:!CKEDITOR.env.ie&&!CKEDITOR.env.iOS,isCustomDataTypesSupported:!CKEDITOR.env.ie,isFileApiSupported:!CKEDITOR.env.ie||9<CKEDITOR.env.version,mainPasteEvent:CKEDITOR.env.ie&&!CKEDITOR.env.edge?"beforepaste":"paste",canClipboardApiBeTrusted:function(a,b){return a.getTransferType(b)!=
CKEDITOR.DATA_TRANSFER_EXTERNAL||CKEDITOR.env.chrome&&!a.isEmpty()||CKEDITOR.env.gecko&&(a.getData("text/html")||a.getFilesCount())||CKEDITOR.env.safari&&603<=CKEDITOR.env.version&&!CKEDITOR.env.iOS?!0:!1},getDropTarget:function(a){var b=a.editable();return CKEDITOR.env.ie&&9>CKEDITOR.env.version||b.isInline()?b:a.document},fixSplitNodesAfterDrop:function(a,b,d,c){function e(a,d,c){var f=a;f.type==CKEDITOR.NODE_TEXT&&(f=a.getParent());if(f.equals(d)&&c!=d.getChildCount())return a=b.startContainer.getChild(b.startOffset-
1),d=b.startContainer.getChild(b.startOffset),a&&a.type==CKEDITOR.NODE_TEXT&&d&&d.type==CKEDITOR.NODE_TEXT&&(c=a.getLength(),a.setText(a.getText()+d.getText()),d.remove(),b.setStart(a,c),b.collapse(!0)),!0}var f=b.startContainer;"number"==typeof c&&"number"==typeof d&&f.type==CKEDITOR.NODE_ELEMENT&&(e(a.startContainer,f,d)||e(a.endContainer,f,c))},isDropRangeAffectedByDragRange:function(a,b){var d=b.startContainer,c=b.endOffset;return a.endContainer.equals(d)&&a.endOffset<=c||a.startContainer.getParent().equals(d)&&
a.startContainer.getIndex()<c||a.endContainer.getParent().equals(d)&&a.endContainer.getIndex()<c?!0:!1},internalDrop:function(b,d,c,e){var f=CKEDITOR.plugins.clipboard,h=e.editable(),m,k;e.fire("saveSnapshot");e.fire("lockSnapshot",{dontUpdate:1});CKEDITOR.env.ie&&10>CKEDITOR.env.version&&this.fixSplitNodesAfterDrop(b,d,f.dragStartContainerChildCount,f.dragEndContainerChildCount);(k=this.isDropRangeAffectedByDragRange(b,d))||(m=b.createBookmark(!1));f=d.clone().createBookmark(!1);k&&(m=b.createBookmark(!1));
b=m.startNode;d=m.endNode;k=f.startNode;d&&b.getPosition(k)&CKEDITOR.POSITION_PRECEDING&&d.getPosition(k)&CKEDITOR.POSITION_FOLLOWING&&k.insertBefore(b);b=e.createRange();b.moveToBookmark(m);h.extractHtmlFromRange(b,1);d=e.createRange();d.moveToBookmark(f);a(e,{dataTransfer:c,method:"drop",range:d},1);e.fire("unlockSnapshot")},getRangeAtDropPosition:function(a,b){var d=a.data.$,c=d.clientX,e=d.clientY,f=b.getSelection(!0).getRanges()[0],h=b.createRange();if(a.data.testRange)return a.data.testRange;
if(document.caretRangeFromPoint&&b.document.$.caretRangeFromPoint(c,e))d=b.document.$.caretRangeFromPoint(c,e),h.setStart(CKEDITOR.dom.node(d.startContainer),d.startOffset),h.collapse(!0);else if(d.rangeParent)h.setStart(CKEDITOR.dom.node(d.rangeParent),d.rangeOffset),h.collapse(!0);else{if(CKEDITOR.env.ie&&8<CKEDITOR.env.version&&f&&b.editable().hasFocus)return f;if(document.body.createTextRange){b.focus();d=b.document.getBody().$.createTextRange();try{for(var m=!1,k=0;20>k&&!m;k++){if(!m)try{d.moveToPoint(c,
e-k),m=!0}catch(l){}if(!m)try{d.moveToPoint(c,e+k),m=!0}catch(u){}}if(m){var B="cke-temp-"+(new Date).getTime();d.pasteHTML('\x3cspan id\x3d"'+B+'"\x3e​\x3c/span\x3e');var C=b.document.getById(B);h.moveToPosition(C,CKEDITOR.POSITION_BEFORE_START);C.remove()}else{var x=b.document.$.elementFromPoint(c,e),A=new CKEDITOR.dom.element(x),D;if(A.equals(b.editable())||"html"==A.getName())return f&&f.startContainer&&!f.startContainer.equals(b.editable())?f:null;D=A.getClientRect();c<D.left?h.setStartAt(A,
CKEDITOR.POSITION_AFTER_START):h.setStartAt(A,CKEDITOR.POSITION_BEFORE_END);h.collapse(!0)}}catch(H){return null}}else return null}return h},initDragDataTransfer:function(a,b){var d=a.data.$?a.data.$.dataTransfer:null,c=new this.dataTransfer(d,b);d?this.dragData&&c.id==this.dragData.id?c=this.dragData:this.dragData=c:this.dragData?c=this.dragData:this.dragData=c;a.data.dataTransfer=c},resetDragDataTransfer:function(){this.dragData=null},initPasteDataTransfer:function(a,b){if(this.isCustomCopyCutSupported){if(a&&
a.data&&a.data.$){var d=new this.dataTransfer(a.data.$.clipboardData,b);this.copyCutData&&d.id==this.copyCutData.id?(d=this.copyCutData,d.$=a.data.$.clipboardData):this.copyCutData=d;return d}return new this.dataTransfer(null,b)}return new this.dataTransfer(CKEDITOR.env.edge&&a&&a.data.$&&a.data.$.clipboardData||null,b)},preventDefaultDropOnElement:function(a){a&&a.on("dragover",f)}};var m=CKEDITOR.plugins.clipboard.isCustomDataTypesSupported?"cke/id":"Text";CKEDITOR.plugins.clipboard.dataTransfer=
function(a,b){a&&(this.$=a);this._={metaRegExp:/^<meta.*?>/i,bodyRegExp:/<body(?:[\s\S]*?)>([\s\S]*)<\/body>/i,fragmentRegExp:/\x3c!--(?:Start|End)Fragment--\x3e/g,data:{},files:[],normalizeType:function(a){a=a.toLowerCase();return"text"==a||"text/plain"==a?"Text":"url"==a?"URL":a}};this.id=this.getData(m);this.id||(this.id="Text"==m?"":"cke-"+CKEDITOR.tools.getUniqueId());if("Text"!=m)try{this.$.setData(m,this.id)}catch(d){}b&&(this.sourceEditor=b,this.setData("text/html",b.getSelectedHtml(1)),"Text"==
m||this.getData("text/plain")||this.setData("text/plain",b.getSelection().getSelectedText()))};CKEDITOR.DATA_TRANSFER_INTERNAL=1;CKEDITOR.DATA_TRANSFER_CROSS_EDITORS=2;CKEDITOR.DATA_TRANSFER_EXTERNAL=3;CKEDITOR.plugins.clipboard.dataTransfer.prototype={getData:function(a,b){a=this._.normalizeType(a);var d=this._.data[a],c;if(void 0===d||null===d||""===d)try{d=this.$.getData(a)}catch(e){}if(void 0===d||null===d||""===d)d="";"text/html"!=a||b?"Text"==a&&CKEDITOR.env.gecko&&this.getFilesCount()&&"file://"==
d.substring(0,7)&&(d=""):(d=d.replace(this._.metaRegExp,""),(c=this._.bodyRegExp.exec(d))&&c.length&&(d=c[1],d=d.replace(this._.fragmentRegExp,"")));"string"===typeof d&&(c=d.indexOf("\x3c/html\x3e"),d=-1!==c?d.substring(0,c+7):d);return d},setData:function(a,b){a=this._.normalizeType(a);this._.data[a]=b;if(CKEDITOR.plugins.clipboard.isCustomDataTypesSupported||"URL"==a||"Text"==a){"Text"==m&&"Text"==a&&(this.id=b);try{this.$.setData(a,b)}catch(d){}}},getTransferType:function(a){return this.sourceEditor?
this.sourceEditor==a?CKEDITOR.DATA_TRANSFER_INTERNAL:CKEDITOR.DATA_TRANSFER_CROSS_EDITORS:CKEDITOR.DATA_TRANSFER_EXTERNAL},cacheData:function(){function a(d){d=b._.normalizeType(d);var c=b.getData(d,!0);c&&(b._.data[d]=c)}if(this.$){var b=this,d,c;if(CKEDITOR.plugins.clipboard.isCustomDataTypesSupported){if(this.$.types)for(d=0;d<this.$.types.length;d++)a(this.$.types[d])}else a("Text"),a("URL");c=this._getImageFromClipboard();if(this.$&&this.$.files||c){this._.files=[];if(this.$.files&&this.$.files.length)for(d=
0;d<this.$.files.length;d++)this._.files.push(this.$.files[d]);0===this._.files.length&&c&&this._.files.push(c)}}},getFilesCount:function(){return this._.files.length?this._.files.length:this.$&&this.$.files&&this.$.files.length?this.$.files.length:this._getImageFromClipboard()?1:0},getFile:function(a){return this._.files.length?this._.files[a]:this.$&&this.$.files&&this.$.files.length?this.$.files[a]:0===a?this._getImageFromClipboard():void 0},isEmpty:function(){var a={},b;if(this.getFilesCount())return!1;
for(b in this._.data)a[b]=1;if(this.$)if(CKEDITOR.plugins.clipboard.isCustomDataTypesSupported){if(this.$.types)for(var d=0;d<this.$.types.length;d++)a[this.$.types[d]]=1}else a.Text=1,a.URL=1;"Text"!=m&&(a[m]=0);for(b in a)if(a[b]&&""!==this.getData(b))return!1;return!0},_getImageFromClipboard:function(){var a;if(this.$&&this.$.items&&this.$.items[0])try{if((a=this.$.items[0].getAsFile())&&a.type)return a}catch(b){}}}}(),CKEDITOR.config.clipboard_notificationDuration=1E4,CKEDITOR.plugins.add("panelbutton",
{requires:"button",onLoad:function(){function a(a){var b=this._;b.state!=CKEDITOR.TRISTATE_DISABLED&&(this.createPanel(a),b.on?b.panel.hide():b.panel.showBlock(this._.id,this.document.getById(this._.id),4))}CKEDITOR.ui.panelButton=CKEDITOR.tools.createClass({base:CKEDITOR.ui.button,$:function(c){var b=c.panel||{};delete c.panel;this.base(c);this.document=b.parent&&b.parent.getDocument()||CKEDITOR.document;b.block={attributes:b.attributes};this.hasArrow=b.toolbarRelated=!0;this.click=a;this._={panelDefinition:b}},
statics:{handler:{create:function(a){return new CKEDITOR.ui.panelButton(a)}}},proto:{createPanel:function(a){var b=this._;if(!b.panel){var e=this._.panelDefinition,h=this._.panelDefinition.block,l=e.parent||CKEDITOR.document.getBody(),k=this._.panel=new CKEDITOR.ui.floatPanel(a,l,e),e=k.addBlock(b.id,h),f=this;k.onShow=function(){f.className&&this.element.addClass(f.className+"_panel");f.setState(CKEDITOR.TRISTATE_ON);b.on=1;f.editorFocus&&a.focus();if(f.onOpen)f.onOpen()};k.onHide=function(d){f.className&&
this.element.getFirst().removeClass(f.className+"_panel");f.setState(f.modes&&f.modes[a.mode]?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED);b.on=0;if(!d&&f.onClose)f.onClose()};k.onEscape=function(){k.hide(1);f.document.getById(b.id).focus()};if(this.onBlock)this.onBlock(k,e);e.onHide=function(){b.on=0;f.setState(CKEDITOR.TRISTATE_OFF)}}}}})},beforeInit:function(a){a.ui.addHandler(CKEDITOR.UI_PANELBUTTON,CKEDITOR.ui.panelButton.handler)}}),CKEDITOR.UI_PANELBUTTON="panelbutton",function(){CKEDITOR.plugins.add("panel",
{beforeInit:function(a){a.ui.addHandler(CKEDITOR.UI_PANEL,CKEDITOR.ui.panel.handler)}});CKEDITOR.UI_PANEL="panel";CKEDITOR.ui.panel=function(a,b){b&&CKEDITOR.tools.extend(this,b);CKEDITOR.tools.extend(this,{className:"",css:[]});this.id=CKEDITOR.tools.getNextId();this.document=a;this.isFramed=this.forceIFrame||this.css.length;this._={blocks:{}}};CKEDITOR.ui.panel.handler={create:function(a){return new CKEDITOR.ui.panel(a)}};var a=CKEDITOR.addTemplate("panel",'\x3cdiv lang\x3d"{langCode}" id\x3d"{id}" dir\x3d{dir} class\x3d"cke cke_reset_all {editorId} cke_panel cke_panel {cls} cke_{dir}" style\x3d"z-index:{z-index}" role\x3d"presentation"\x3e{frame}\x3c/div\x3e'),
c=CKEDITOR.addTemplate("panel-frame",'\x3ciframe id\x3d"{id}" class\x3d"cke_panel_frame" role\x3d"presentation" frameborder\x3d"0" src\x3d"{src}"\x3e\x3c/iframe\x3e'),b=CKEDITOR.addTemplate("panel-frame-inner",'\x3c!DOCTYPE html\x3e\x3chtml class\x3d"cke_panel_container {env}" dir\x3d"{dir}" lang\x3d"{langCode}"\x3e\x3chead\x3e{css}\x3c/head\x3e\x3cbody class\x3d"cke_{dir}" style\x3d"margin:0;padding:0" onload\x3d"{onload}"\x3e\x3c/body\x3e\x3c/html\x3e');CKEDITOR.ui.panel.prototype={render:function(e,
h){this.getHolderElement=function(){var a=this._.holder;if(!a){if(this.isFramed){var a=this.document.getById(this.id+"_frame"),d=a.getParent(),a=a.getFrameDocument();CKEDITOR.env.iOS&&d.setStyles({overflow:"scroll","-webkit-overflow-scrolling":"touch"});d=CKEDITOR.tools.addFunction(CKEDITOR.tools.bind(function(){this.isLoaded=!0;if(this.onLoad)this.onLoad()},this));a.write(b.output(CKEDITOR.tools.extend({css:CKEDITOR.tools.buildStyleHtml(this.css),onload:"window.parent.CKEDITOR.tools.callFunction("+
d+");"},l)));a.getWindow().$.CKEDITOR=CKEDITOR;a.on("keydown",function(a){var b=a.data.getKeystroke(),d=this.document.getById(this.id).getAttribute("dir");this._.onKeyDown&&!1===this._.onKeyDown(b)?a.data.preventDefault():(27==b||b==("rtl"==d?39:37))&&this.onEscape&&!1===this.onEscape(b)&&a.data.preventDefault()},this);a=a.getBody();a.unselectable();CKEDITOR.env.air&&CKEDITOR.tools.callFunction(d)}else a=this.document.getById(this.id);this._.holder=a}return a};var l={editorId:e.id,id:this.id,langCode:e.langCode,
dir:e.lang.dir,cls:this.className,frame:"",env:CKEDITOR.env.cssClass,"z-index":e.config.baseFloatZIndex+1};if(this.isFramed){var k=CKEDITOR.env.air?"javascript:void(0)":CKEDITOR.env.ie?"javascript:void(function(){"+encodeURIComponent("document.open();("+CKEDITOR.tools.fixDomain+")();document.close();")+"}())":"";l.frame=c.output({id:this.id+"_frame",src:k})}k=a.output(l);h&&h.push(k);return k},addBlock:function(a,b){b=this._.blocks[a]=b instanceof CKEDITOR.ui.panel.block?b:new CKEDITOR.ui.panel.block(this.getHolderElement(),
b);this._.currentBlock||this.showBlock(a);return b},getBlock:function(a){return this._.blocks[a]},showBlock:function(a){a=this._.blocks[a];var b=this._.currentBlock,c=!this.forceIFrame||CKEDITOR.env.ie?this._.holder:this.document.getById(this.id+"_frame");b&&b.hide();this._.currentBlock=a;CKEDITOR.fire("ariaWidget",c);a._.focusIndex=-1;this._.onKeyDown=a.onKeyDown&&CKEDITOR.tools.bind(a.onKeyDown,a);a.show();return a},destroy:function(){this.element&&this.element.remove()}};CKEDITOR.ui.panel.block=
CKEDITOR.tools.createClass({$:function(a,b){this.element=a.append(a.getDocument().createElement("div",{attributes:{tabindex:-1,"class":"cke_panel_block"},styles:{display:"none"}}));b&&CKEDITOR.tools.extend(this,b);this.element.setAttributes({role:this.attributes.role||"presentation","aria-label":this.attributes["aria-label"],title:this.attributes.title||this.attributes["aria-label"]});this.keys={};this._.focusIndex=-1;this.element.disableContextMenu()},_:{markItem:function(a){-1!=a&&(a=this.element.getElementsByTag("a").getItem(this._.focusIndex=
a),CKEDITOR.env.webkit&&a.getDocument().getWindow().focus(),a.focus(),this.onMark&&this.onMark(a))},markFirstDisplayed:function(a){for(var b=function(a){return a.type==CKEDITOR.NODE_ELEMENT&&"none"==a.getStyle("display")},c=this._.getItems(),k,f,d=c.count()-1;0<=d;d--)if(k=c.getItem(d),k.getAscendant(b)||(f=k,this._.focusIndex=d),"true"==k.getAttribute("aria-selected")){f=k;this._.focusIndex=d;break}f&&(a&&a(),CKEDITOR.env.webkit&&f.getDocument().getWindow().focus(),f.focus(),this.onMark&&this.onMark(f))},
getItems:function(){return this.element.getElementsByTag("a")}},proto:{show:function(){this.element.setStyle("display","")},hide:function(){this.onHide&&!0===this.onHide.call(this)||this.element.setStyle("display","none")},onKeyDown:function(a,b){var c=this.keys[a];switch(c){case "next":for(var k=this._.focusIndex,c=this.element.getElementsByTag("a"),f;f=c.getItem(++k);)if(f.getAttribute("_cke_focus")&&f.$.offsetWidth){this._.focusIndex=k;f.focus();break}return f||b?!1:(this._.focusIndex=-1,this.onKeyDown(a,
1));case "prev":k=this._.focusIndex;for(c=this.element.getElementsByTag("a");0<k&&(f=c.getItem(--k));){if(f.getAttribute("_cke_focus")&&f.$.offsetWidth){this._.focusIndex=k;f.focus();break}f=null}return f||b?!1:(this._.focusIndex=c.count(),this.onKeyDown(a,1));case "click":case "mouseup":return k=this._.focusIndex,(f=0<=k&&this.element.getElementsByTag("a").getItem(k))&&(f.$[c]?f.$[c]():f.$["on"+c]()),!1}return!0}}})}(),CKEDITOR.plugins.add("floatpanel",{requires:"panel"}),function(){function a(a,
e,h,l,k){k=CKEDITOR.tools.genKey(e.getUniqueId(),h.getUniqueId(),a.lang.dir,a.uiColor||"",l.css||"",k||"");var f=c[k];f||(f=c[k]=new CKEDITOR.ui.panel(e,l),f.element=h.append(CKEDITOR.dom.element.createFromHtml(f.render(a),e)),f.element.setStyles({display:"none",position:"absolute"}));return f}var c={};CKEDITOR.ui.floatPanel=CKEDITOR.tools.createClass({$:function(b,c,h,l){function k(){g.hide()}h.forceIFrame=1;h.toolbarRelated&&b.elementMode==CKEDITOR.ELEMENT_MODE_INLINE&&(c=CKEDITOR.document.getById("cke_"+
b.name));var f=c.getDocument();l=a(b,f,c,h,l||0);var d=l.element,m=d.getFirst(),g=this;d.disableContextMenu();this.element=d;this._={editor:b,panel:l,parentElement:c,definition:h,document:f,iframe:m,children:[],dir:b.lang.dir,showBlockParams:null};b.on("mode",k);b.on("resize",k);f.getWindow().on("resize",function(){this.reposition()},this)},proto:{addBlock:function(a,c){return this._.panel.addBlock(a,c)},addListBlock:function(a,c){return this._.panel.addListBlock(a,c)},getBlock:function(a){return this._.panel.getBlock(a)},
showBlock:function(a,c,h,l,k,f){var d=this._.panel,m=d.showBlock(a);this._.showBlockParams=[].slice.call(arguments);this.allowBlur(!1);var g=this._.editor.editable();this._.returnFocus=g.hasFocus?g:new CKEDITOR.dom.element(CKEDITOR.document.$.activeElement);this._.hideTimeout=0;var n=this.element,g=this._.iframe,g=CKEDITOR.env.ie&&!CKEDITOR.env.edge?g:new CKEDITOR.dom.window(g.$.contentWindow),p=n.getDocument(),q=this._.parentElement.getPositionedAncestor(),y=c.getDocumentPosition(p),p=q?q.getDocumentPosition(p):
{x:0,y:0},v="rtl"==this._.dir,t=y.x+(l||0)-p.x,r=y.y+(k||0)-p.y;!v||1!=h&&4!=h?v||2!=h&&3!=h||(t+=c.$.offsetWidth-1):t+=c.$.offsetWidth;if(3==h||4==h)r+=c.$.offsetHeight-1;this._.panel._.offsetParentId=c.getId();n.setStyles({top:r+"px",left:0,display:""});n.setOpacity(0);n.getFirst().removeStyle("width");this._.editor.focusManager.add(g);this._.blurSet||(CKEDITOR.event.useCapture=!0,g.on("blur",function(a){function b(){delete this._.returnFocus;this.hide()}this.allowBlur()&&a.data.getPhase()==CKEDITOR.EVENT_PHASE_AT_TARGET&&
this.visible&&!this._.activeChild&&(CKEDITOR.env.iOS?this._.hideTimeout||(this._.hideTimeout=CKEDITOR.tools.setTimeout(b,0,this)):b.call(this))},this),g.on("focus",function(){this._.focused=!0;this.hideChild();this.allowBlur(!0)},this),CKEDITOR.env.iOS&&(g.on("touchstart",function(){clearTimeout(this._.hideTimeout)},this),g.on("touchend",function(){this._.hideTimeout=0;this.focus()},this)),CKEDITOR.event.useCapture=!1,this._.blurSet=1);d.onEscape=CKEDITOR.tools.bind(function(a){if(this.onEscape&&
!1===this.onEscape(a))return!1},this);CKEDITOR.tools.setTimeout(function(){var a=CKEDITOR.tools.bind(function(){var a=n;a.removeStyle("width");if(m.autoSize){var b=m.element.getDocument(),b=(CKEDITOR.env.webkit||CKEDITOR.env.edge?m.element:b.getBody()).$.scrollWidth;CKEDITOR.env.ie&&CKEDITOR.env.quirks&&0<b&&(b+=(a.$.offsetWidth||0)-(a.$.clientWidth||0)+3);a.setStyle("width",b+10+"px");b=m.element.$.scrollHeight;CKEDITOR.env.ie&&CKEDITOR.env.quirks&&0<b&&(b+=(a.$.offsetHeight||0)-(a.$.clientHeight||
0)+3);a.setStyle("height",b+"px");d._.currentBlock.element.setStyle("display","none").removeStyle("display")}else a.removeStyle("height");v&&(t-=n.$.offsetWidth);n.setStyle("left",t+"px");var b=d.element.getWindow(),a=n.$.getBoundingClientRect(),b=b.getViewPaneSize(),c=a.width||a.right-a.left,e=a.height||a.bottom-a.top,g=v?a.right:b.width-a.left,h=v?b.width-a.right:a.left;v?g<c&&(t=h>c?t+c:b.width>c?t-a.left:t-a.right+b.width):g<c&&(t=h>c?t-c:b.width>c?t-a.right+b.width:t-a.left);c=a.top;b.height-
a.top<e&&(r=c>e?r-e:b.height>e?r-a.bottom+b.height:r-a.top);CKEDITOR.env.ie&&(b=a=new CKEDITOR.dom.element(n.$.offsetParent),"html"==b.getName()&&(b=b.getDocument().getBody()),"rtl"==b.getComputedStyle("direction")&&(t=CKEDITOR.env.ie8Compat?t-2*n.getDocument().getDocumentElement().$.scrollLeft:t-(a.$.scrollWidth-a.$.clientWidth)));var a=n.getFirst(),k;(k=a.getCustomData("activePanel"))&&k.onHide&&k.onHide.call(this,1);a.setCustomData("activePanel",this);n.setStyles({top:r+"px",left:t+"px"});n.setOpacity(1);
f&&f()},this);d.isLoaded?a():d.onLoad=a;CKEDITOR.tools.setTimeout(function(){var a=CKEDITOR.env.webkit&&CKEDITOR.document.getWindow().getScrollPosition().y;this.focus();m.element.focus();CKEDITOR.env.webkit&&(CKEDITOR.document.getBody().$.scrollTop=a);this.allowBlur(!0);CKEDITOR.env.ie?CKEDITOR.tools.setTimeout(function(){m.markFirstDisplayed?m.markFirstDisplayed():m._.markFirstDisplayed()},0):m.markFirstDisplayed?m.markFirstDisplayed():m._.markFirstDisplayed();this._.editor.fire("panelShow",this)},
0,this)},CKEDITOR.env.air?200:0,this);this.visible=1;this.onShow&&this.onShow.call(this)},reposition:function(){var a=this._.showBlockParams;this.visible&&this._.showBlockParams&&(this.hide(),this.showBlock.apply(this,a))},focus:function(){if(CKEDITOR.env.webkit){var a=CKEDITOR.document.getActive();a&&!a.equals(this._.iframe)&&a.$.blur()}(this._.lastFocused||this._.iframe.getFrameDocument().getWindow()).focus()},blur:function(){var a=this._.iframe.getFrameDocument().getActive();a&&a.is("a")&&(this._.lastFocused=
a)},hide:function(a){if(this.visible&&(!this.onHide||!0!==this.onHide.call(this))){this.hideChild();CKEDITOR.env.gecko&&this._.iframe.getFrameDocument().$.activeElement.blur();this.element.setStyle("display","none");this.visible=0;this.element.getFirst().removeCustomData("activePanel");if(a=a&&this._.returnFocus)CKEDITOR.env.webkit&&a.type&&a.getWindow().$.focus(),a.focus();delete this._.lastFocused;this._.showBlockParams=null;this._.editor.fire("panelHide",this)}},allowBlur:function(a){var c=this._.panel;
void 0!==a&&(c.allowBlur=a);return c.allowBlur},showAsChild:function(a,c,h,l,k,f){if(this._.activeChild!=a||a._.panel._.offsetParentId!=h.getId())this.hideChild(),a.onHide=CKEDITOR.tools.bind(function(){CKEDITOR.tools.setTimeout(function(){this._.focused||this.hide()},0,this)},this),this._.activeChild=a,this._.focused=!1,a.showBlock(c,h,l,k,f),this.blur(),(CKEDITOR.env.ie7Compat||CKEDITOR.env.ie6Compat)&&setTimeout(function(){a.element.getChild(0).$.style.cssText+=""},100)},hideChild:function(a){var c=
this._.activeChild;c&&(delete c.onHide,delete this._.activeChild,c.hide(),a&&this.focus())}}});CKEDITOR.on("instanceDestroyed",function(){var a=CKEDITOR.tools.isEmpty(CKEDITOR.instances),e;for(e in c){var h=c[e];a?h.destroy():h.element.hide()}a&&(c={})})}(),CKEDITOR.plugins.add("colorbutton",{requires:"panelbutton,floatpanel",init:function(a){function c(d,c,e,f,q){var y=new CKEDITOR.style(l["colorButton_"+c+"Style"]),v=CKEDITOR.tools.getNextId()+"_colorBox",t;q=q||{};a.ui.add(d,CKEDITOR.UI_PANELBUTTON,
{label:e,title:e,modes:{wysiwyg:1},editorFocus:0,toolbar:"colors,"+f,allowedContent:y,requiredContent:y,contentTransformations:q.contentTransformations,panel:{css:CKEDITOR.skin.getPath("editor"),attributes:{role:"listbox","aria-label":k.panelTitle}},onBlock:function(d,e){t=e;e.autoSize=!0;e.element.addClass("cke_colorblock");e.element.setHtml(b(d,c,v));e.element.getDocument().getBody().setStyle("overflow","hidden");CKEDITOR.ui.fire("ready",this);var f=e.keys,h="rtl"==a.lang.dir;f[h?37:39]="next";
f[40]="next";f[9]="next";f[h?39:37]="prev";f[38]="prev";f[CKEDITOR.SHIFT+9]="prev";f[32]="click"},refresh:function(){a.activeFilter.check(y)||this.setState(CKEDITOR.TRISTATE_DISABLED)},onOpen:function(){var b=a.getSelection(),d=b&&b.getStartElement(),e=a.elementPath(d);if(e){d=e.block||e.blockLimit||a.document.getBody();do e=d&&d.getComputedStyle("back"==c?"background-color":"color")||"transparent";while("back"==c&&"transparent"==e&&d&&(d=d.getParent()));e&&"transparent"!=e||(e="#ffffff");!1!==l.colorButton_enableAutomatic&&
this._.panel._.iframe.getFrameDocument().getById(v).setStyle("background-color",e);if(d=b&&b.getRanges()[0]){for(var b=new CKEDITOR.dom.walker(d),f=d.collapsed?d.startContainer:b.next(),d="";f;){f.type===CKEDITOR.NODE_TEXT&&(f=f.getParent());f=h(f.getComputedStyle("back"==c?"background-color":"color"));d=d||f;if(d!==f){d="";break}f=b.next()}b=d;d=t._.getItems();for(f=0;f<d.count();f++){var m=d.getItem(f);m.removeAttribute("aria-selected");b&&b==h(m.getAttribute("data-value"))&&m.setAttribute("aria-selected",
!0)}}return e}}})}function b(b,d,c){b=[];var f=l.colorButton_colors.split(","),h=l.colorButton_colorsPerRow||6,y=a.plugins.colordialog&&!1!==l.colorButton_enableMore,v=f.length+(y?2:1),t=CKEDITOR.tools.addFunction(function(b,d){function c(b){a.removeStyle(new CKEDITOR.style(l["colorButton_"+d+"Style"],{color:"inherit"}));var f=l["colorButton_"+d+"Style"];f.childRule="back"==d?function(a){return e(a)}:function(a){return!(a.is("a")||a.getElementsByTag("a").count())||e(a)};a.focus();a.applyStyle(new CKEDITOR.style(f,
{color:b}));a.fire("saveSnapshot")}a.focus();a.fire("saveSnapshot");if("?"==b)a.getColorFromDialog(function(a){if(a)return c(a)});else return c(b)});!1!==l.colorButton_enableAutomatic&&b.push('\x3ca class\x3d"cke_colorauto" _cke_focus\x3d1 hidefocus\x3dtrue title\x3d"',k.auto,'" onclick\x3d"CKEDITOR.tools.callFunction(',t,",null,'",d,"');return false;\" href\x3d\"javascript:void('",k.auto,'\')" role\x3d"option" aria-posinset\x3d"1" aria-setsize\x3d"',v,'"\x3e\x3ctable role\x3d"presentation" cellspacing\x3d0 cellpadding\x3d0 width\x3d"100%"\x3e\x3ctr\x3e\x3ctd colspan\x3d"'+
h+'" align\x3d"center"\x3e\x3cspan class\x3d"cke_colorbox" id\x3d"',c,'"\x3e\x3c/span\x3e',k.auto,"\x3c/td\x3e\x3c/tr\x3e\x3c/table\x3e\x3c/a\x3e");b.push('\x3ctable role\x3d"presentation" cellspacing\x3d0 cellpadding\x3d0 width\x3d"100%"\x3e');for(c=0;c<f.length;c++){0===c%h&&b.push("\x3c/tr\x3e\x3ctr\x3e");var r=f[c].split("/"),w=r[0],z=r[1]||w;r[1]||(w="#"+w.replace(/^(.)(.)(.)$/,"$1$1$2$2$3$3"));r=a.lang.colorbutton.colors[z]||z;b.push('\x3ctd\x3e\x3ca class\x3d"cke_colorbox" _cke_focus\x3d1 hidefocus\x3dtrue title\x3d"',
r,'" onclick\x3d"CKEDITOR.tools.callFunction(',t,",'",w,"','",d,"'); return false;\" href\x3d\"javascript:void('",r,'\')" data-value\x3d"'+z+'" role\x3d"option" aria-posinset\x3d"',c+2,'" aria-setsize\x3d"',v,'"\x3e\x3cspan class\x3d"cke_colorbox" style\x3d"background-color:#',z,'"\x3e\x3c/span\x3e\x3c/a\x3e\x3c/td\x3e')}y&&b.push('\x3c/tr\x3e\x3ctr\x3e\x3ctd colspan\x3d"'+h+'" align\x3d"center"\x3e\x3ca class\x3d"cke_colormore" _cke_focus\x3d1 hidefocus\x3dtrue title\x3d"',k.more,'" onclick\x3d"CKEDITOR.tools.callFunction(',
t,",'?','",d,"');return false;\" href\x3d\"javascript:void('",k.more,"')\"",' role\x3d"option" aria-posinset\x3d"',v,'" aria-setsize\x3d"',v,'"\x3e',k.more,"\x3c/a\x3e\x3c/td\x3e");b.push("\x3c/tr\x3e\x3c/table\x3e");return b.join("")}function e(a){return"false"==a.getAttribute("contentEditable")||a.getAttribute("data-nostyle")}function h(a){return CKEDITOR.tools.convertRgbToHex(a||"").replace(/#/,"").toLowerCase()}var l=a.config,k=a.lang.colorbutton;if(!CKEDITOR.env.hc){c("TextColor","fore",k.textColorTitle,
10,{contentTransformations:[[{element:"font",check:"span{color}",left:function(a){return!!a.attributes.color},right:function(a){a.name="span";a.attributes.color&&(a.styles.color=a.attributes.color);delete a.attributes.color}}]]});var f={},d=a.config.colorButton_normalizeBackground;if(void 0===d||d)f.contentTransformations=[[{element:"span",left:function(a){var b=CKEDITOR.tools;if("span"!=a.name||!a.styles||!a.styles.background)return!1;a=b.style.parse.background(a.styles.background);return a.color&&
1===b.objectKeys(a).length},right:function(b){var d=(new CKEDITOR.style(a.config.colorButton_backStyle,{color:b.styles.background})).getDefinition();b.name=d.element;b.styles=d.styles;b.attributes=d.attributes||{};return b}}]];c("BGColor","back",k.bgColorTitle,20,f)}}}),CKEDITOR.config.colorButton_colors="1ABC9C,2ECC71,3498DB,9B59B6,4E5F70,F1C40F,16A085,27AE60,2980B9,8E44AD,2C3E50,F39C12,E67E22,E74C3C,ECF0F1,95A5A6,DDD,FFF,D35400,C0392B,BDC3C7,7F8C8D,999,000",CKEDITOR.config.colorButton_foreStyle=
{element:"span",styles:{color:"#(color)"},overrides:[{element:"font",attributes:{color:null}}]},CKEDITOR.config.colorButton_backStyle={element:"span",styles:{"background-color":"#(color)"}},CKEDITOR.plugins.colordialog={requires:"dialog",init:function(a){var c=new CKEDITOR.dialogCommand("colordialog");c.editorFocus=!1;a.addCommand("colordialog",c);CKEDITOR.dialog.add("colordialog",this.path+"dialogs/colordialog.js");a.getColorFromDialog=function(b,c){var h=function(a){this.removeListener("ok",h);
this.removeListener("cancel",h);a="ok"==a.name?this.getValueOf("picker","selectedColor"):null;b.call(c,a)},l=function(a){a.on("ok",h);a.on("cancel",h)};a.execCommand("colordialog");if(a._.storedDialogs&&a._.storedDialogs.colordialog)l(a._.storedDialogs.colordialog);else CKEDITOR.on("dialogDefinition",function(a){if("colordialog"==a.data.name){var b=a.data.definition;a.removeListener();b.onLoad=CKEDITOR.tools.override(b.onLoad,function(a){return function(){l(this);b.onLoad=a;"function"==typeof a&&
a.call(this)}})}})}}},CKEDITOR.plugins.add("colordialog",CKEDITOR.plugins.colordialog),function(){function a(a){var b=(a=a.data)&&a.$;return a&&b?CKEDITOR.env.ie&&9>CKEDITOR.env.version?1===b.button:0===b.button:!1}function c(a,b,d,c){var e=new CKEDITOR.dom.walker(a);if(a=a.startContainer.getAscendant(b,!0)||a.endContainer.getAscendant(b,!0))if(d(a),c)return;for(;a=e.next();)if(a=a.getAscendant(b,!0))if(d(a),c)break}function b(a,b){var d={ul:"ol",ol:"ul"};return-1!==h(b,function(b){return b.element===
a||b.element===d[a]})}function e(a){this.styles=null;this.sticky=!1;this.editor=a;this.filter=new CKEDITOR.filter(a.config.copyFormatting_allowRules);!0===a.config.copyFormatting_allowRules&&(this.filter.disabled=!0);a.config.copyFormatting_disallowRules&&this.filter.disallow(a.config.copyFormatting_disallowRules)}var h=CKEDITOR.tools.indexOf,l=!1;CKEDITOR.plugins.add("copyformatting",{lang:"az,de,en,it,ja,nb,nl,oc,pl,pt-br,ru,sv,tr,zh,zh-cn",icons:"copyformatting",hidpi:!0,init:function(c){var e=
CKEDITOR.plugins.copyformatting;e._addScreenReaderContainer();l||(CKEDITOR.document.appendStyleSheet(this.path+"styles/copyformatting.css"),l=!0);c.addContentsCss&&c.addContentsCss(this.path+"styles/copyformatting.css");c.copyFormatting=new e.state(c);c.addCommand("copyFormatting",e.commands.copyFormatting);c.addCommand("applyFormatting",e.commands.applyFormatting);c.ui.addButton("CopyFormatting",{label:c.lang.copyformatting.label,command:"copyFormatting",toolbar:"cleanup,0"});c.on("contentDom",function(){var b=
c.editable(),e=b.isInline()?b:c.document,f=c.ui.get("CopyFormatting");b.attachListener(e,"mouseup",function(b){a(b)&&c.execCommand("applyFormatting")});b.attachListener(CKEDITOR.document,"mouseup",function(e){var f=c.getCommand("copyFormatting");a(e)&&f.state===CKEDITOR.TRISTATE_ON&&!b.contains(e.data.getTarget())&&c.execCommand("copyFormatting")});f&&(e=CKEDITOR.document.getById(f._.id),b.attachListener(e,"dblclick",function(){c.execCommand("copyFormatting",{sticky:!0})}),b.attachListener(e,"mouseup",
function(a){a.data.stopPropagation()}))});c.config.copyFormatting_keystrokeCopy&&c.setKeystroke(c.config.copyFormatting_keystrokeCopy,"copyFormatting");c.on("key",function(a){var b=c.getCommand("copyFormatting");a=a.data.domEvent;a.getKeystroke&&27===a.getKeystroke()&&b.state===CKEDITOR.TRISTATE_ON&&c.execCommand("copyFormatting")});c.copyFormatting.on("extractFormatting",function(a){var b=a.data.element;if(b.contains(c.editable())||b.equals(c.editable()))return a.cancel();b=e._convertElementToStyleDef(b);
if(!c.copyFormatting.filter.check(new CKEDITOR.style(b),!0,!0))return a.cancel();a.data.styleDef=b});c.copyFormatting.on("applyFormatting",function(a){if(!a.data.preventFormatStripping){var m=a.data.range,g=e._extractStylesFromRange(c,m),l=e._determineContext(m),p,q;if(c.copyFormatting._isContextAllowed(l))for(q=0;q<g.length;q++)l=g[q],p=m.createBookmark(),-1===h(e.preservedElements,l.element)?CKEDITOR.env.webkit&&!CKEDITOR.env.chrome?g[q].removeFromRange(a.data.range,a.editor):g[q].remove(a.editor):
b(l.element,a.data.styles)&&e._removeStylesFromElementInRange(m,l.element),m.moveToBookmark(p)}});c.copyFormatting.on("applyFormatting",function(a){var b=CKEDITOR.plugins.copyformatting,e=b._determineContext(a.data.range);"list"===e&&c.copyFormatting._isContextAllowed("list")?b._applyStylesToListContext(a.editor,a.data.range,a.data.styles):"table"===e&&c.copyFormatting._isContextAllowed("table")?b._applyStylesToTableContext(a.editor,a.data.range,a.data.styles):c.copyFormatting._isContextAllowed("text")&&
b._applyStylesToTextContext(a.editor,a.data.range,a.data.styles)},null,null,999)}});e.prototype._isContextAllowed=function(a){var b=this.editor.config.copyFormatting_allowedContexts;return!0===b||-1!==h(b,a)};CKEDITOR.event.implementOn(e.prototype);CKEDITOR.plugins.copyformatting={state:e,inlineBoundary:"h1 h2 h3 h4 h5 h6 p div".split(" "),excludedAttributes:["id","style","href","data-cke-saved-href","dir"],elementsForInlineTransform:["li"],excludedElementsFromInlineTransform:["table","thead","tbody",
"ul","ol"],excludedAttributesFromInlineTransform:["value","type"],preservedElements:"ul ol li td th tr thead tbody table".split(" "),breakOnElements:["ul","ol","table"],_initialKeystrokePasteCommand:null,commands:{copyFormatting:{exec:function(a,b){var d=CKEDITOR.plugins.copyformatting,c=a.copyFormatting,e=b?"keystrokeHandler"==b.from:!1,h=b?b.sticky||e:!1,l=d._getCursorContainer(a),q=CKEDITOR.document.getDocumentElement();if(this.state===CKEDITOR.TRISTATE_ON)return c.styles=null,c.sticky=!1,l.removeClass("cke_copyformatting_active"),
q.removeClass("cke_copyformatting_disabled"),q.removeClass("cke_copyformatting_tableresize_cursor"),d._putScreenReaderMessage(a,"canceled"),d._detachPasteKeystrokeHandler(a),this.setState(CKEDITOR.TRISTATE_OFF);c.styles=d._extractStylesFromElement(a,a.elementPath().lastElement);this.setState(CKEDITOR.TRISTATE_ON);e||(l.addClass("cke_copyformatting_active"),q.addClass("cke_copyformatting_tableresize_cursor"),a.config.copyFormatting_outerCursor&&q.addClass("cke_copyformatting_disabled"));c.sticky=h;
d._putScreenReaderMessage(a,"copied");d._attachPasteKeystrokeHandler(a)}},applyFormatting:{editorFocus:!1,exec:function(a,b){var d=a.getCommand("copyFormatting"),c=b?"keystrokeHandler"==b.from:!1,e=CKEDITOR.plugins.copyformatting,h=a.copyFormatting,l=e._getCursorContainer(a),q=CKEDITOR.document.getDocumentElement();if(c||d.state===CKEDITOR.TRISTATE_ON){if(c&&!h.styles)return e._putScreenReaderMessage(a,"failed"),e._detachPasteKeystrokeHandler(a),!1;c=e._applyFormat(a,h.styles);h.sticky||(h.styles=
null,l.removeClass("cke_copyformatting_active"),q.removeClass("cke_copyformatting_disabled"),q.removeClass("cke_copyformatting_tableresize_cursor"),d.setState(CKEDITOR.TRISTATE_OFF),e._detachPasteKeystrokeHandler(a));e._putScreenReaderMessage(a,c?"applied":"canceled")}}}},_getCursorContainer:function(a){return a.elementMode===CKEDITOR.ELEMENT_MODE_INLINE?a.editable():a.editable().getParent()},_convertElementToStyleDef:function(a){var b=CKEDITOR.tools,d=a.getAttributes(CKEDITOR.plugins.copyformatting.excludedAttributes),
b=b.parseCssText(a.getAttribute("style"),!0,!0);return{element:a.getName(),type:CKEDITOR.STYLE_INLINE,attributes:d,styles:b}},_extractStylesFromElement:function(a,b){var d={},c=[];do if(b.type===CKEDITOR.NODE_ELEMENT&&!b.hasAttribute("data-cke-bookmark")&&(d.element=b,a.copyFormatting.fire("extractFormatting",d,a)&&d.styleDef&&c.push(new CKEDITOR.style(d.styleDef)),b.getName&&-1!==h(CKEDITOR.plugins.copyformatting.breakOnElements,b.getName())))break;while((b=b.getParent())&&b.type===CKEDITOR.NODE_ELEMENT);
return c},_extractStylesFromRange:function(a,b){for(var d=[],c=new CKEDITOR.dom.walker(b),e;e=c.next();)d=d.concat(CKEDITOR.plugins.copyformatting._extractStylesFromElement(a,e));return d},_removeStylesFromElementInRange:function(a,b){for(var d=-1!==h(["ol","ul","table"],b),c=new CKEDITOR.dom.walker(a),e;e=c.next();)if(e=e.getAscendant(b,!0))if(e.removeAttributes(e.getAttributes()),d)break},_getSelectedWordOffset:function(a){function b(a,d){return a[d?"getPrevious":"getNext"](function(a){return a.type!==
CKEDITOR.NODE_COMMENT})}function d(a){return a.type==CKEDITOR.NODE_ELEMENT?(a=a.getHtml().replace(/<span.*?>&nbsp;<\/span>/g,""),a.replace(/<.*?>/g,"")):a.getText()}function c(a,e){var g=a,k=/\s/g,l="p br ol ul li td th div caption body".split(" "),n=!1,v=!1,x,p;do{for(x=b(g,e);!x&&g.getParent();){g=g.getParent();if(-1!==h(l,g.getName())){v=n=!0;break}x=b(g,e)}if(x&&x.getName&&-1!==h(l,x.getName())){n=!0;break}g=x}while(g&&g.getStyle&&("none"==g.getStyle("display")||!g.getText()));for(g||(g=a);g.type!==
CKEDITOR.NODE_TEXT;)g=!n||e||v?g.getChild(0):g.getChild(g.getChildCount()-1);for(l=d(g);null!=(v=k.exec(l))&&(p=v.index,e););if("number"!==typeof p&&!n)return c(g,e);if(n)e?p=0:(k=/([\.\b]*$)/,p=(v=k.exec(l))?v.index:l.length);else if(e&&(p+=1,p>l.length))return c(g);return{node:g,offset:p}}var e=/\b\w+\b/ig,l,p,q,y,v;q=y=v=a.startContainer;for(l=d(q);null!=(p=e.exec(l));)if(p.index+p[0].length>=a.startOffset)return a=p.index,e=p.index+p[0].length,0===p.index&&(p=c(q,!0),y=p.node,a=p.offset),e>=l.length&&
(l=c(q),v=l.node,e=l.offset),{startNode:y,startOffset:a,endNode:v,endOffset:e};return null},_filterStyles:function(a){var b=CKEDITOR.tools.isEmpty,d=[],c,e;for(e=0;e<a.length;e++)c=a[e]._.definition,-1!==CKEDITOR.tools.indexOf(CKEDITOR.plugins.copyformatting.inlineBoundary,c.element)&&(c.element=a[e].element="span"),"span"===c.element&&b(c.attributes)&&b(c.styles)||d.push(a[e]);return d},_determineContext:function(a){function b(d){var c=new CKEDITOR.dom.walker(a),e;if(a.startContainer.getAscendant(d,
!0)||a.endContainer.getAscendant(d,!0))return!0;for(;e=c.next();)if(e.getAscendant(d,!0))return!0}return b({ul:1,ol:1})?"list":b("table")?"table":"text"},_applyStylesToTextContext:function(a,b,d){var c=CKEDITOR.plugins.copyformatting,e=c.excludedAttributesFromInlineTransform,l,p;CKEDITOR.env.webkit&&!CKEDITOR.env.chrome&&a.getSelection().selectRanges([b]);for(l=0;l<d.length;l++)if(b=d[l],-1===h(c.excludedElementsFromInlineTransform,b.element)){if(-1!==h(c.elementsForInlineTransform,b.element))for(b.element=
b._.definition.element="span",p=0;p<e.length;p++)b._.definition.attributes[e[p]]&&delete b._.definition.attributes[e[p]];b.apply(a)}},_applyStylesToListContext:function(a,b,d){var e,g,h;for(h=0;h<d.length;h++)e=d[h],g=b.createBookmark(),"ol"===e.element||"ul"===e.element?c(b,{ul:1,ol:1},function(a){var b=e;a.getName()!==b.element&&a.renameNode(b.element);b.applyToObject(a)},!0):"li"===e.element?c(b,"li",function(a){e.applyToObject(a)}):CKEDITOR.plugins.copyformatting._applyStylesToTextContext(a,b,
[e]),b.moveToBookmark(g)},_applyStylesToTableContext:function(a,b,d){function e(a,b){a.getName()!==b.element&&(b=b.getDefinition(),b.element=a.getName(),b=new CKEDITOR.style(b));b.applyToObject(a)}var g,l,p;for(p=0;p<d.length;p++)g=d[p],l=b.createBookmark(),-1!==h(["table","tr"],g.element)?c(b,g.element,function(a){g.applyToObject(a)}):-1!==h(["td","th"],g.element)?c(b,{td:1,th:1},function(a){e(a,g)}):-1!==h(["thead","tbody"],g.element)?c(b,{thead:1,tbody:1},function(a){e(a,g)}):CKEDITOR.plugins.copyformatting._applyStylesToTextContext(a,
b,[g]),b.moveToBookmark(l)},_applyFormat:function(a,b){var d=a.getSelection().getRanges()[0],c=CKEDITOR.plugins.copyformatting,e,h;if(!d)return!1;if(d.collapsed){h=a.getSelection().createBookmarks();if(!(e=c._getSelectedWordOffset(d)))return;d=a.createRange();d.setStart(e.startNode,e.startOffset);d.setEnd(e.endNode,e.endOffset);d.select()}b=c._filterStyles(b);if(!a.copyFormatting.fire("applyFormatting",{styles:b,range:d,preventFormatStripping:!1},a))return!1;h&&a.getSelection().selectBookmarks(h);
return!0},_putScreenReaderMessage:function(a,b){var d=this._getScreenReaderContainer();d&&d.setText(a.lang.copyformatting.notification[b])},_addScreenReaderContainer:function(){if(this._getScreenReaderContainer())return this._getScreenReaderContainer();if(!CKEDITOR.env.ie6Compat&&!CKEDITOR.env.ie7Compat)return CKEDITOR.document.getBody().append(CKEDITOR.dom.element.createFromHtml('\x3cdiv class\x3d"cke_screen_reader_only cke_copyformatting_notification"\x3e\x3cdiv aria-live\x3d"polite"\x3e\x3c/div\x3e\x3c/div\x3e')).getChild(0)},
_getScreenReaderContainer:function(){if(!CKEDITOR.env.ie6Compat&&!CKEDITOR.env.ie7Compat)return CKEDITOR.document.getBody().findOne(".cke_copyformatting_notification div[aria-live]")},_attachPasteKeystrokeHandler:function(a){var b=a.config.copyFormatting_keystrokePaste;b&&(this._initialKeystrokePasteCommand=a.keystrokeHandler.keystrokes[b],a.setKeystroke(b,"applyFormatting"))},_detachPasteKeystrokeHandler:function(a){var b=a.config.copyFormatting_keystrokePaste;b&&a.setKeystroke(b,this._initialKeystrokePasteCommand||
!1)}};CKEDITOR.config.copyFormatting_outerCursor=!0;CKEDITOR.config.copyFormatting_allowRules="b s u i em strong span p div td th ol ul li(*)[*]{*}";CKEDITOR.config.copyFormatting_disallowRules="*[data-cke-widget*,data-widget*,data-cke-realelement](cke_widget*)";CKEDITOR.config.copyFormatting_allowedContexts=!0;CKEDITOR.config.copyFormatting_keystrokeCopy=CKEDITOR.CTRL+CKEDITOR.SHIFT+67;CKEDITOR.config.copyFormatting_keystrokePaste=CKEDITOR.CTRL+CKEDITOR.SHIFT+86}(),CKEDITOR.plugins.add("menu",{requires:"floatpanel",
beforeInit:function(a){for(var c=a.config.menu_groups.split(","),b=a._.menuGroups={},e=a._.menuItems={},h=0;h<c.length;h++)b[c[h]]=h+1;a.addMenuGroup=function(a,c){b[a]=c||100};a.addMenuItem=function(a,c){b[c.group]&&(e[a]=new CKEDITOR.menuItem(this,a,c))};a.addMenuItems=function(a){for(var b in a)this.addMenuItem(b,a[b])};a.getMenuItem=function(a){return e[a]};a.removeMenuItem=function(a){delete e[a]}}}),function(){function a(a){a.sort(function(a,b){return a.group<b.group?-1:a.group>b.group?1:a.order<
b.order?-1:a.order>b.order?1:0})}var c='\x3cspan class\x3d"cke_menuitem"\x3e\x3ca id\x3d"{id}" class\x3d"cke_menubutton cke_menubutton__{name} cke_menubutton_{state} {cls}" href\x3d"{href}" title\x3d"{title}" tabindex\x3d"-1" _cke_focus\x3d1 hidefocus\x3d"true" role\x3d"{role}" aria-label\x3d"{label}" aria-describedby\x3d"{id}_description" aria-haspopup\x3d"{hasPopup}" aria-disabled\x3d"{disabled}" {ariaChecked} draggable\x3d"false"';CKEDITOR.env.gecko&&CKEDITOR.env.mac&&(c+=' onkeypress\x3d"return false;"');
CKEDITOR.env.gecko&&(c+=' onblur\x3d"this.style.cssText \x3d this.style.cssText;" ondragstart\x3d"return false;"');var c=c+(' onmouseover\x3d"CKEDITOR.tools.callFunction({hoverFn},{index});" onmouseout\x3d"CKEDITOR.tools.callFunction({moveOutFn},{index});" '+(CKEDITOR.env.ie?'onclick\x3d"return false;" onmouseup':"onclick")+'\x3d"CKEDITOR.tools.callFunction({clickFn},{index}); return false;"\x3e'),b=CKEDITOR.addTemplate("menuItem",c+'\x3cspan class\x3d"cke_menubutton_inner"\x3e\x3cspan class\x3d"cke_menubutton_icon"\x3e\x3cspan class\x3d"cke_button_icon cke_button__{iconName}_icon" style\x3d"{iconStyle}"\x3e\x3c/span\x3e\x3c/span\x3e\x3cspan class\x3d"cke_menubutton_label"\x3e{label}\x3c/span\x3e{shortcutHtml}{arrowHtml}\x3c/span\x3e\x3c/a\x3e\x3cspan id\x3d"{id}_description" class\x3d"cke_voice_label" aria-hidden\x3d"false"\x3e{ariaShortcut}\x3c/span\x3e\x3c/span\x3e'),
e=CKEDITOR.addTemplate("menuArrow",'\x3cspan class\x3d"cke_menuarrow"\x3e\x3cspan\x3e{label}\x3c/span\x3e\x3c/span\x3e'),h=CKEDITOR.addTemplate("menuShortcut",'\x3cspan class\x3d"cke_menubutton_label cke_menubutton_shortcut"\x3e{shortcut}\x3c/span\x3e');CKEDITOR.menu=CKEDITOR.tools.createClass({$:function(a,b){b=this._.definition=b||{};this.id=CKEDITOR.tools.getNextId();this.editor=a;this.items=[];this._.listeners=[];this._.level=b.level||1;var c=CKEDITOR.tools.extend({},b.panel,{css:[CKEDITOR.skin.getPath("editor")],
level:this._.level-1,block:{}}),d=c.block.attributes=c.attributes||{};!d.role&&(d.role="menu");this._.panelDefinition=c},_:{onShow:function(){var a=this.editor.getSelection(),b=a&&a.getStartElement(),c=this.editor.elementPath(),d=this._.listeners;this.removeAll();for(var e=0;e<d.length;e++){var g=d[e](b,a,c);if(g)for(var h in g){var p=this.editor.getMenuItem(h);!p||p.command&&!this.editor.getCommand(p.command).state||(p.state=g[h],this.add(p))}}},onClick:function(a){this.hide();if(a.onClick)a.onClick();
else a.command&&this.editor.execCommand(a.command)},onEscape:function(a){var b=this.parent;b?b._.panel.hideChild(1):27==a&&this.hide(1);return!1},onHide:function(){this.onHide&&this.onHide()},showSubMenu:function(a){var b=this._.subMenu,c=this.items[a];if(c=c.getItems&&c.getItems()){b?b.removeAll():(b=this._.subMenu=new CKEDITOR.menu(this.editor,CKEDITOR.tools.extend({},this._.definition,{level:this._.level+1},!0)),b.parent=this,b._.onClick=CKEDITOR.tools.bind(this._.onClick,this));for(var d in c){var e=
this.editor.getMenuItem(d);e&&(e.state=c[d],b.add(e))}var g=this._.panel.getBlock(this.id).element.getDocument().getById(this.id+String(a));setTimeout(function(){b.show(g,2)},0)}else this._.panel.hideChild(1)}},proto:{add:function(a){a.order||(a.order=this.items.length);this.items.push(a)},removeAll:function(){this.items=[]},show:function(b,c,e,d){if(!this.parent&&(this._.onShow(),!this.items.length))return;c=c||("rtl"==this.editor.lang.dir?2:1);var h=this.items,g=this.editor,n=this._.panel,p=this._.element;
if(!n){n=this._.panel=new CKEDITOR.ui.floatPanel(this.editor,CKEDITOR.document.getBody(),this._.panelDefinition,this._.level);n.onEscape=CKEDITOR.tools.bind(function(a){if(!1===this._.onEscape(a))return!1},this);n.onShow=function(){n._.panel.getHolderElement().getParent().addClass("cke").addClass("cke_reset_all")};n.onHide=CKEDITOR.tools.bind(function(){this._.onHide&&this._.onHide()},this);p=n.addBlock(this.id,this._.panelDefinition.block);p.autoSize=!0;var q=p.keys;q[40]="next";q[9]="next";q[38]=
"prev";q[CKEDITOR.SHIFT+9]="prev";q["rtl"==g.lang.dir?37:39]=CKEDITOR.env.ie?"mouseup":"click";q[32]=CKEDITOR.env.ie?"mouseup":"click";CKEDITOR.env.ie&&(q[13]="mouseup");p=this._.element=p.element;q=p.getDocument();q.getBody().setStyle("overflow","hidden");q.getElementsByTag("html").getItem(0).setStyle("overflow","hidden");this._.itemOverFn=CKEDITOR.tools.addFunction(function(a){clearTimeout(this._.showSubTimeout);this._.showSubTimeout=CKEDITOR.tools.setTimeout(this._.showSubMenu,g.config.menu_subMenuDelay||
400,this,[a])},this);this._.itemOutFn=CKEDITOR.tools.addFunction(function(){clearTimeout(this._.showSubTimeout)},this);this._.itemClickFn=CKEDITOR.tools.addFunction(function(a){var b=this.items[a];if(b.state==CKEDITOR.TRISTATE_DISABLED)this.hide(1);else if(b.getItems)this._.showSubMenu(a);else this._.onClick(b)},this)}a(h);for(var q=g.elementPath(),q=['\x3cdiv class\x3d"cke_menu'+(q&&q.direction()!=g.lang.dir?" cke_mixed_dir_content":"")+'" role\x3d"presentation"\x3e'],y=h.length,v=y&&h[0].group,
t=0;t<y;t++){var r=h[t];v!=r.group&&(q.push('\x3cdiv class\x3d"cke_menuseparator" role\x3d"separator"\x3e\x3c/div\x3e'),v=r.group);r.render(this,t,q)}q.push("\x3c/div\x3e");p.setHtml(q.join(""));CKEDITOR.ui.fire("ready",this);this.parent?this.parent._.panel.showAsChild(n,this.id,b,c,e,d):n.showBlock(this.id,b,c,e,d);g.fire("menuShow",[n])},addListener:function(a){this._.listeners.push(a)},hide:function(a){this._.onHide&&this._.onHide();this._.panel&&this._.panel.hide(a)}}});CKEDITOR.menuItem=CKEDITOR.tools.createClass({$:function(a,
b,c){CKEDITOR.tools.extend(this,c,{order:0,className:"cke_menubutton__"+b});this.group=a._.menuGroups[this.group];this.editor=a;this.name=b},proto:{render:function(a,c,f){var d=a.id+String(c),m="undefined"==typeof this.state?CKEDITOR.TRISTATE_OFF:this.state,g="",n=this.editor,p,q,y=m==CKEDITOR.TRISTATE_ON?"on":m==CKEDITOR.TRISTATE_DISABLED?"disabled":"off";this.role in{menuitemcheckbox:1,menuitemradio:1}&&(g=' aria-checked\x3d"'+(m==CKEDITOR.TRISTATE_ON?"true":"false")+'"');var v=this.getItems,t=
"\x26#"+("rtl"==this.editor.lang.dir?"9668":"9658")+";",r=this.name;this.icon&&!/\./.test(this.icon)&&(r=this.icon);this.command&&(p=n.getCommand(this.command),(p=n.getCommandKeystroke(p))&&(q=CKEDITOR.tools.keystrokeToString(n.lang.common.keyboard,p)));a={id:d,name:this.name,iconName:r,label:this.label,cls:this.className||"",state:y,hasPopup:v?"true":"false",disabled:m==CKEDITOR.TRISTATE_DISABLED,title:this.label+(q?" ("+q.display+")":""),ariaShortcut:q?n.lang.common.keyboardShortcut+" "+q.aria:
"",href:"javascript:void('"+(this.label||"").replace("'")+"')",hoverFn:a._.itemOverFn,moveOutFn:a._.itemOutFn,clickFn:a._.itemClickFn,index:c,iconStyle:CKEDITOR.skin.getIconStyle(r,"rtl"==this.editor.lang.dir,r==this.icon?null:this.icon,this.iconOffset),shortcutHtml:q?h.output({shortcut:q.display}):"",arrowHtml:v?e.output({label:t}):"",role:this.role?this.role:"menuitem",ariaChecked:g};b.output(a,f)}}})}(),CKEDITOR.config.menu_groups="clipboard,form,tablecell,tablecellproperties,tablerow,tablecolumn,table,anchor,link,image,flash,checkbox,radio,textfield,hiddenfield,imagebutton,button,select,textarea,div",
CKEDITOR.plugins.add("contextmenu",{requires:"menu",onLoad:function(){CKEDITOR.plugins.contextMenu=CKEDITOR.tools.createClass({base:CKEDITOR.menu,$:function(a){this.base.call(this,a,{panel:{className:"cke_menu_panel",attributes:{"aria-label":a.lang.contextmenu.options}}})},proto:{addTarget:function(a,c){a.on("contextmenu",function(a){a=a.data;var e=CKEDITOR.env.webkit?b:CKEDITOR.env.mac?a.$.metaKey:a.$.ctrlKey;if(!c||!e){a.preventDefault();if(CKEDITOR.env.mac&&CKEDITOR.env.webkit){var e=this.editor,
k=(new CKEDITOR.dom.elementPath(a.getTarget(),e.editable())).contains(function(a){return a.hasAttribute("contenteditable")},!0);k&&"false"==k.getAttribute("contenteditable")&&e.getSelection().fake(k)}var k=a.getTarget().getDocument(),f=a.getTarget().getDocument().getDocumentElement(),e=!k.equals(CKEDITOR.document),k=k.getWindow().getScrollPosition(),d=e?a.$.clientX:a.$.pageX||k.x+a.$.clientX,m=e?a.$.clientY:a.$.pageY||k.y+a.$.clientY;CKEDITOR.tools.setTimeout(function(){this.open(f,null,d,m)},CKEDITOR.env.ie?
200:0,this)}},this);if(CKEDITOR.env.webkit){var b,e=function(){b=0};a.on("keydown",function(a){b=CKEDITOR.env.mac?a.data.$.metaKey:a.data.$.ctrlKey});a.on("keyup",e);a.on("contextmenu",e)}},open:function(a,c,b,e){!1!==this.editor.config.enableContextMenu&&(this.editor.focus(),a=a||CKEDITOR.document.getDocumentElement(),this.editor.selectionChange(1),this.show(a,c,b,e))}}})},beforeInit:function(a){var c=a.contextMenu=new CKEDITOR.plugins.contextMenu(a);a.on("contentDom",function(){c.addTarget(a.editable(),
!1!==a.config.browserContextMenuOnCtrl)});a.addCommand("contextMenu",{exec:function(){a.contextMenu.open(a.document.getBody())}});a.setKeystroke(CKEDITOR.SHIFT+121,"contextMenu");a.setKeystroke(CKEDITOR.CTRL+CKEDITOR.SHIFT+121,"contextMenu")}}),function(){function a(a){var b=this.att;a=a&&a.hasAttribute(b)&&a.getAttribute(b)||"";void 0!==a&&this.setValue(a)}function c(){for(var a,b=0;b<arguments.length;b++)if(arguments[b]instanceof CKEDITOR.dom.element){a=arguments[b];break}if(a){var b=this.att,c=
this.getValue();c?a.setAttribute(b,c):a.removeAttribute(b,c)}}var b={id:1,dir:1,classes:1,styles:1};CKEDITOR.plugins.add("dialogadvtab",{requires:"dialog",allowedContent:function(a){a||(a=b);var c=[];a.id&&c.push("id");a.dir&&c.push("dir");var l="";c.length&&(l+="["+c.join(",")+"]");a.classes&&(l+="(*)");a.styles&&(l+="{*}");return l},createAdvancedTab:function(e,h,l){h||(h=b);var k=e.lang.common,f={id:"advanced",label:k.advancedTab,title:k.advancedTab,elements:[{type:"vbox",padding:1,children:[]}]},
d=[];if(h.id||h.dir)h.id&&d.push({id:"advId",att:"id",type:"text",requiredContent:l?l+"[id]":null,label:k.id,setup:a,commit:c}),h.dir&&d.push({id:"advLangDir",att:"dir",type:"select",requiredContent:l?l+"[dir]":null,label:k.langDir,"default":"",style:"width:100%",items:[[k.notSet,""],[k.langDirLTR,"ltr"],[k.langDirRTL,"rtl"]],setup:a,commit:c}),f.elements[0].children.push({type:"hbox",widths:["50%","50%"],children:[].concat(d)});if(h.styles||h.classes)d=[],h.styles&&d.push({id:"advStyles",att:"style",
type:"text",requiredContent:l?l+"{cke-xyz}":null,label:k.styles,"default":"",validate:CKEDITOR.dialog.validate.inlineStyle(k.invalidInlineStyle),onChange:function(){},getStyle:function(a,b){var d=this.getValue().match(new RegExp("(?:^|;)\\s*"+a+"\\s*:\\s*([^;]*)","i"));return d?d[1]:b},updateStyle:function(a,b){var d=this.getValue(),c=e.document.createElement("span");c.setAttribute("style",d);c.setStyle(a,b);d=CKEDITOR.tools.normalizeCssText(c.getAttribute("style"));this.setValue(d,1)},setup:a,commit:c}),
h.classes&&d.push({type:"hbox",widths:["45%","55%"],children:[{id:"advCSSClasses",att:"class",type:"text",requiredContent:l?l+"(cke-xyz)":null,label:k.cssClasses,"default":"",setup:a,commit:c}]}),f.elements[0].children.push({type:"hbox",widths:["50%","50%"],children:[].concat(d)});return f}})}(),function(){CKEDITOR.plugins.add("div",{requires:"dialog",init:function(a){if(!a.blockless){var c=a.lang.div,b="div(*)";CKEDITOR.dialog.isTabEnabled(a,"editdiv","advanced")&&(b+=";div[dir,id,lang,title]{*}");
a.addCommand("creatediv",new CKEDITOR.dialogCommand("creatediv",{allowedContent:b,requiredContent:"div",contextSensitive:!0,contentTransformations:[["div: alignmentToStyle"]],refresh:function(a,b){this.setState("div"in(a.config.div_wrapTable?b.root:b.blockLimit).getDtd()?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED)}}));a.addCommand("editdiv",new CKEDITOR.dialogCommand("editdiv",{requiredContent:"div"}));a.addCommand("removediv",{requiredContent:"div",exec:function(a){function b(d){(d=CKEDITOR.plugins.div.getSurroundDiv(a,
d))&&!d.data("cke-div-added")&&(m.push(d),d.data("cke-div-added"))}for(var c=a.getSelection(),k=c&&c.getRanges(),f,d=c.createBookmarks(),m=[],g=0;g<k.length;g++)f=k[g],f.collapsed?b(c.getStartElement()):(f=new CKEDITOR.dom.walker(f),f.evaluator=b,f.lastForward());for(g=0;g<m.length;g++)m[g].remove(!0);c.selectBookmarks(d)}});a.ui.addButton&&a.ui.addButton("CreateDiv",{label:c.toolbar,command:"creatediv",toolbar:"blocks,50"});a.addMenuItems&&(a.addMenuItems({editdiv:{label:c.edit,command:"editdiv",
group:"div",order:1},removediv:{label:c.remove,command:"removediv",group:"div",order:5}}),a.contextMenu&&a.contextMenu.addListener(function(b){return!b||b.isReadOnly()?null:CKEDITOR.plugins.div.getSurroundDiv(a)?{editdiv:CKEDITOR.TRISTATE_OFF,removediv:CKEDITOR.TRISTATE_OFF}:null}));CKEDITOR.dialog.add("creatediv",this.path+"dialogs/div.js");CKEDITOR.dialog.add("editdiv",this.path+"dialogs/div.js")}}});CKEDITOR.plugins.div={getSurroundDiv:function(a,c){var b=a.elementPath(c);return a.elementPath(b.blockLimit).contains(function(a){return a.is("div")&&
!a.isReadOnly()},1)}}}(),function(){function a(a,b){function k(b){b=g.list[b];var d;b.equals(a.editable())||"true"==b.getAttribute("contenteditable")?(d=a.createRange(),d.selectNodeContents(b),d=d.select()):(d=a.getSelection(),d.selectElement(b));CKEDITOR.env.ie&&a.fire("selectionChange",{selection:d,path:new CKEDITOR.dom.elementPath(b)});a.focus()}function f(){m&&m.setHtml('\x3cspan class\x3d"cke_path_empty"\x3e\x26nbsp;\x3c/span\x3e');delete g.list}var d=a.ui.spaceId("path"),m,g=a._.elementsPath,
n=g.idBase;b.html+='\x3cspan id\x3d"'+d+'_label" class\x3d"cke_voice_label"\x3e'+a.lang.elementspath.eleLabel+'\x3c/span\x3e\x3cspan id\x3d"'+d+'" class\x3d"cke_path" role\x3d"group" aria-labelledby\x3d"'+d+'_label"\x3e\x3cspan class\x3d"cke_path_empty"\x3e\x26nbsp;\x3c/span\x3e\x3c/span\x3e';a.on("uiReady",function(){var b=a.ui.space("path");b&&a.focusManager.add(b,1)});g.onClick=k;var p=CKEDITOR.tools.addFunction(k),q=CKEDITOR.tools.addFunction(function(b,d){var c=g.idBase,e;d=new CKEDITOR.dom.event(d);
e="rtl"==a.lang.dir;switch(d.getKeystroke()){case e?39:37:case 9:return(e=CKEDITOR.document.getById(c+(b+1)))||(e=CKEDITOR.document.getById(c+"0")),e.focus(),!1;case e?37:39:case CKEDITOR.SHIFT+9:return(e=CKEDITOR.document.getById(c+(b-1)))||(e=CKEDITOR.document.getById(c+(g.list.length-1))),e.focus(),!1;case 27:return a.focus(),!1;case 13:case 32:return k(b),!1}return!0});a.on("selectionChange",function(){for(var b=[],c=g.list=[],f=[],k=g.filters,l=!0,z=a.elementPath().elements,u,B=z.length;B--;){var C=
z[B],x=0;u=C.data("cke-display-name")?C.data("cke-display-name"):C.data("cke-real-element-type")?C.data("cke-real-element-type"):C.getName();(l=C.hasAttribute("contenteditable")?"true"==C.getAttribute("contenteditable"):l)||C.hasAttribute("contenteditable")||(x=1);for(var A=0;A<k.length;A++){var D=k[A](C,u);if(!1===D){x=1;break}u=D||u}x||(c.unshift(C),f.unshift(u))}c=c.length;for(k=0;k<c;k++)u=f[k],l=a.lang.elementspath.eleTitle.replace(/%1/,u),u=e.output({id:n+k,label:l,text:u,jsTitle:"javascript:void('"+
u+"')",index:k,keyDownFn:q,clickFn:p}),b.unshift(u);m||(m=CKEDITOR.document.getById(d));f=m;f.setHtml(b.join("")+'\x3cspan class\x3d"cke_path_empty"\x3e\x26nbsp;\x3c/span\x3e');a.fire("elementsPathUpdate",{space:f})});a.on("readOnly",f);a.on("contentDomUnload",f);a.addCommand("elementsPathFocus",c.toolbarFocus);a.setKeystroke(CKEDITOR.ALT+122,"elementsPathFocus")}var c={toolbarFocus:{editorFocus:!1,readOnly:1,exec:function(a){(a=CKEDITOR.document.getById(a._.elementsPath.idBase+"0"))&&a.focus(CKEDITOR.env.ie||
CKEDITOR.env.air)}}},b="";CKEDITOR.env.gecko&&CKEDITOR.env.mac&&(b+=' onkeypress\x3d"return false;"');CKEDITOR.env.gecko&&(b+=' onblur\x3d"this.style.cssText \x3d this.style.cssText;"');var e=CKEDITOR.addTemplate("pathItem",'\x3ca id\x3d"{id}" href\x3d"{jsTitle}" tabindex\x3d"-1" class\x3d"cke_path_item" title\x3d"{label}"'+b+' hidefocus\x3d"true"  onkeydown\x3d"return CKEDITOR.tools.callFunction({keyDownFn},{index}, event );" onclick\x3d"CKEDITOR.tools.callFunction({clickFn},{index}); return false;" role\x3d"button" aria-label\x3d"{label}"\x3e{text}\x3c/a\x3e');
CKEDITOR.plugins.add("elementspath",{init:function(b){b._.elementsPath={idBase:"cke_elementspath_"+CKEDITOR.tools.getNextNumber()+"_",filters:[]};b.on("uiSpace",function(c){"bottom"==c.data.space&&a(b,c.data)})}})}(),function(){function a(a,b,d){d=a.config.forceEnterMode||d;if("wysiwyg"==a.mode){b||(b=a.activeEnterMode);var c=a.elementPath();c&&!c.isContextFor("p")&&(b=CKEDITOR.ENTER_BR,d=1);a.fire("saveSnapshot");b==CKEDITOR.ENTER_BR?k(a,b,null,d):f(a,b,null,d);a.fire("saveSnapshot")}}function c(a){a=
a.getSelection().getRanges(!0);for(var b=a.length-1;0<b;b--)a[b].deleteContents();return a[0]}function b(a){var b=a.startContainer.getAscendant(function(a){return a.type==CKEDITOR.NODE_ELEMENT&&"true"==a.getAttribute("contenteditable")},!0);if(a.root.equals(b))return a;b=new CKEDITOR.dom.range(b);b.moveToRange(a);return b}CKEDITOR.plugins.add("enterkey",{init:function(b){b.addCommand("enter",{modes:{wysiwyg:1},editorFocus:!1,exec:function(b){a(b)}});b.addCommand("shiftEnter",{modes:{wysiwyg:1},editorFocus:!1,
exec:function(b){a(b,b.activeShiftEnterMode,1)}});b.setKeystroke([[13,"enter"],[CKEDITOR.SHIFT+13,"shiftEnter"]])}});var e=CKEDITOR.dom.walker.whitespaces(),h=CKEDITOR.dom.walker.bookmark();CKEDITOR.plugins.enterkey={enterBlock:function(a,f,l,p){if(l=l||c(a)){l=b(l);var q=l.document,y=l.checkStartOfBlock(),v=l.checkEndOfBlock(),t=a.elementPath(l.startContainer),r=t.block,w=f==CKEDITOR.ENTER_DIV?"div":"p",z;if(y&&v){if(r&&(r.is("li")||r.getParent().is("li"))){r.is("li")||(r=r.getParent());l=r.getParent();
z=l.getParent();p=!r.hasPrevious();var u=!r.hasNext(),w=a.getSelection(),B=w.createBookmarks(),y=r.getDirection(1),v=r.getAttribute("class"),C=r.getAttribute("style"),x=z.getDirection(1)!=y;a=a.enterMode!=CKEDITOR.ENTER_BR||x||C||v;if(z.is("li"))p||u?(p&&u&&l.remove(),r[u?"insertAfter":"insertBefore"](z)):r.breakParent(z);else{if(a)if(t.block.is("li")?(z=q.createElement(f==CKEDITOR.ENTER_P?"p":"div"),x&&z.setAttribute("dir",y),C&&z.setAttribute("style",C),v&&z.setAttribute("class",v),r.moveChildren(z)):
z=t.block,p||u)z[p?"insertBefore":"insertAfter"](l);else r.breakParent(l),z.insertAfter(l);else if(r.appendBogus(!0),p||u)for(;q=r[p?"getFirst":"getLast"]();)q[p?"insertBefore":"insertAfter"](l);else for(r.breakParent(l);q=r.getLast();)q.insertAfter(l);r.remove()}w.selectBookmarks(B);return}if(r&&r.getParent().is("blockquote")){r.breakParent(r.getParent());r.getPrevious().getFirst(CKEDITOR.dom.walker.invisible(1))||r.getPrevious().remove();r.getNext().getFirst(CKEDITOR.dom.walker.invisible(1))||r.getNext().remove();
l.moveToElementEditStart(r);l.select();return}}else if(r&&r.is("pre")&&!v){k(a,f,l,p);return}if(y=l.splitBlock(w)){f=y.previousBlock;r=y.nextBlock;t=y.wasStartOfBlock;a=y.wasEndOfBlock;r?(B=r.getParent(),B.is("li")&&(r.breakParent(B),r.move(r.getNext(),1))):f&&(B=f.getParent())&&B.is("li")&&(f.breakParent(B),B=f.getNext(),l.moveToElementEditStart(B),f.move(f.getPrevious()));if(t||a){if(f){if(f.is("li")||!d.test(f.getName())&&!f.is("pre"))z=f.clone()}else r&&(z=r.clone());z?p&&!z.is("li")&&z.renameNode(w):
B&&B.is("li")?z=B:(z=q.createElement(w),f&&(u=f.getDirection())&&z.setAttribute("dir",u));if(q=y.elementPath)for(p=0,w=q.elements.length;p<w;p++){B=q.elements[p];if(B.equals(q.block)||B.equals(q.blockLimit))break;CKEDITOR.dtd.$removeEmpty[B.getName()]&&(B=B.clone(),z.moveChildren(B),z.append(B))}z.appendBogus();z.getParent()||l.insertNode(z);z.is("li")&&z.removeAttribute("value");!CKEDITOR.env.ie||!t||a&&f.getChildCount()||(l.moveToElementEditStart(a?f:z),l.select());l.moveToElementEditStart(t&&!a?
r:z)}else r.is("li")&&(z=l.clone(),z.selectNodeContents(r),z=new CKEDITOR.dom.walker(z),z.evaluator=function(a){return!(h(a)||e(a)||a.type==CKEDITOR.NODE_ELEMENT&&a.getName()in CKEDITOR.dtd.$inline&&!(a.getName()in CKEDITOR.dtd.$empty))},(B=z.next())&&B.type==CKEDITOR.NODE_ELEMENT&&B.is("ul","ol")&&(CKEDITOR.env.needsBrFiller?q.createElement("br"):q.createText(" ")).insertBefore(B)),r&&l.moveToElementEditStart(r);l.select();l.scrollIntoView()}}},enterBr:function(a,b,e,h){if(e=e||c(a)){var l=e.document,
k=e.checkEndOfBlock(),v=new CKEDITOR.dom.elementPath(a.getSelection().getStartElement()),t=v.block,r=t&&v.block.getName();h||"li"!=r?(!h&&k&&d.test(r)?(k=t.getDirection())?(l=l.createElement("div"),l.setAttribute("dir",k),l.insertAfter(t),e.setStart(l,0)):(l.createElement("br").insertAfter(t),CKEDITOR.env.gecko&&l.createText("").insertAfter(t),e.setStartAt(t.getNext(),CKEDITOR.env.ie?CKEDITOR.POSITION_BEFORE_START:CKEDITOR.POSITION_AFTER_START)):(a="pre"==r&&CKEDITOR.env.ie&&8>CKEDITOR.env.version?
l.createText("\r"):l.createElement("br"),e.deleteContents(),e.insertNode(a),CKEDITOR.env.needsBrFiller?(l.createText("﻿").insertAfter(a),k&&(t||v.blockLimit).appendBogus(),a.getNext().$.nodeValue="",e.setStartAt(a.getNext(),CKEDITOR.POSITION_AFTER_START)):e.setStartAt(a,CKEDITOR.POSITION_AFTER_END)),e.collapse(!0),e.select(),e.scrollIntoView()):f(a,b,e,h)}}};var l=CKEDITOR.plugins.enterkey,k=l.enterBr,f=l.enterBlock,d=/^h[1-6]$/}(),function(){function a(a,b){var e={},h=[],l={nbsp:" ",shy:"­",gt:"\x3e",
lt:"\x3c",amp:"\x26",apos:"'",quot:'"'};a=a.replace(/\b(nbsp|shy|gt|lt|amp|apos|quot)(?:,|$)/g,function(a,d){var c=b?"\x26"+d+";":l[d];e[c]=b?l[d]:"\x26"+d+";";h.push(c);return""});if(!b&&a){a=a.split(",");var k=document.createElement("div"),f;k.innerHTML="\x26"+a.join(";\x26")+";";f=k.innerHTML;k=null;for(k=0;k<f.length;k++){var d=f.charAt(k);e[d]="\x26"+a[k]+";";h.push(d)}}e.regex=h.join(b?"|":"");return e}CKEDITOR.plugins.add("entities",{afterInit:function(c){function b(a){return d[a]}function e(a){return"force"!=
h.entities_processNumerical&&k[a]?k[a]:"\x26#"+a.charCodeAt(0)+";"}var h=c.config;if(c=(c=c.dataProcessor)&&c.htmlFilter){var l=[];!1!==h.basicEntities&&l.push("nbsp,gt,lt,amp");h.entities&&(l.length&&l.push("quot,iexcl,cent,pound,curren,yen,brvbar,sect,uml,copy,ordf,laquo,not,shy,reg,macr,deg,plusmn,sup2,sup3,acute,micro,para,middot,cedil,sup1,ordm,raquo,frac14,frac12,frac34,iquest,times,divide,fnof,bull,hellip,prime,Prime,oline,frasl,weierp,image,real,trade,alefsym,larr,uarr,rarr,darr,harr,crarr,lArr,uArr,rArr,dArr,hArr,forall,part,exist,empty,nabla,isin,notin,ni,prod,sum,minus,lowast,radic,prop,infin,ang,and,or,cap,cup,int,there4,sim,cong,asymp,ne,equiv,le,ge,sub,sup,nsub,sube,supe,oplus,otimes,perp,sdot,lceil,rceil,lfloor,rfloor,lang,rang,loz,spades,clubs,hearts,diams,circ,tilde,ensp,emsp,thinsp,zwnj,zwj,lrm,rlm,ndash,mdash,lsquo,rsquo,sbquo,ldquo,rdquo,bdquo,dagger,Dagger,permil,lsaquo,rsaquo,euro"),
h.entities_latin&&l.push("Agrave,Aacute,Acirc,Atilde,Auml,Aring,AElig,Ccedil,Egrave,Eacute,Ecirc,Euml,Igrave,Iacute,Icirc,Iuml,ETH,Ntilde,Ograve,Oacute,Ocirc,Otilde,Ouml,Oslash,Ugrave,Uacute,Ucirc,Uuml,Yacute,THORN,szlig,agrave,aacute,acirc,atilde,auml,aring,aelig,ccedil,egrave,eacute,ecirc,euml,igrave,iacute,icirc,iuml,eth,ntilde,ograve,oacute,ocirc,otilde,ouml,oslash,ugrave,uacute,ucirc,uuml,yacute,thorn,yuml,OElig,oelig,Scaron,scaron,Yuml"),h.entities_greek&&l.push("Alpha,Beta,Gamma,Delta,Epsilon,Zeta,Eta,Theta,Iota,Kappa,Lambda,Mu,Nu,Xi,Omicron,Pi,Rho,Sigma,Tau,Upsilon,Phi,Chi,Psi,Omega,alpha,beta,gamma,delta,epsilon,zeta,eta,theta,iota,kappa,lambda,mu,nu,xi,omicron,pi,rho,sigmaf,sigma,tau,upsilon,phi,chi,psi,omega,thetasym,upsih,piv"),
h.entities_additional&&l.push(h.entities_additional));var k=a(l.join(",")),f=k.regex?"["+k.regex+"]":"a^";delete k.regex;h.entities&&h.entities_processNumerical&&(f="[^ -~]|"+f);var f=new RegExp(f,"g"),d=a("nbsp,gt,lt,amp,shy",!0),m=new RegExp(d.regex,"g");c.addRules({text:function(a){return a.replace(m,b).replace(f,e)}},{applyToAll:!0,excludeNestedEditable:!0})}}})}(),CKEDITOR.config.basicEntities=!0,CKEDITOR.config.entities=!0,CKEDITOR.config.entities_latin=!0,CKEDITOR.config.entities_greek=!0,
CKEDITOR.config.entities_additional="#39",CKEDITOR.plugins.add("popup"),CKEDITOR.tools.extend(CKEDITOR.editor.prototype,{popup:function(a,c,b,e){c=c||"80%";b=b||"70%";"string"==typeof c&&1<c.length&&"%"==c.substr(c.length-1,1)&&(c=parseInt(window.screen.width*parseInt(c,10)/100,10));"string"==typeof b&&1<b.length&&"%"==b.substr(b.length-1,1)&&(b=parseInt(window.screen.height*parseInt(b,10)/100,10));640>c&&(c=640);420>b&&(b=420);var h=parseInt((window.screen.height-b)/2,10),l=parseInt((window.screen.width-
c)/2,10);e=(e||"location\x3dno,menubar\x3dno,toolbar\x3dno,dependent\x3dyes,minimizable\x3dno,modal\x3dyes,alwaysRaised\x3dyes,resizable\x3dyes,scrollbars\x3dyes")+",width\x3d"+c+",height\x3d"+b+",top\x3d"+h+",left\x3d"+l;var k=window.open("",null,e,!0);if(!k)return!1;try{-1==navigator.userAgent.toLowerCase().indexOf(" chrome/")&&(k.moveTo(l,h),k.resizeTo(c,b)),k.focus(),k.location.href=a}catch(f){window.open(a,null,e,!0)}return!0}}),function(){function a(a,b){var c=[];if(b)for(var e in b)c.push(e+
"\x3d"+encodeURIComponent(b[e]));else return a;return a+(-1!=a.indexOf("?")?"\x26":"?")+c.join("\x26")}function c(a){a+="";return a.charAt(0).toUpperCase()+a.substr(1)}function b(){var b=this.getDialog(),e=b.getParentEditor();e._.filebrowserSe=this;var f=e.config["filebrowser"+c(b.getName())+"WindowWidth"]||e.config.filebrowserWindowWidth||"80%",b=e.config["filebrowser"+c(b.getName())+"WindowHeight"]||e.config.filebrowserWindowHeight||"70%",h=this.filebrowser.params||{};h.CKEditor=e.name;h.CKEditorFuncNum=
e._.filebrowserFn;h.langCode||(h.langCode=e.langCode);h=a(this.filebrowser.url,h);e.popup(h,f,b,e.config.filebrowserWindowFeatures||e.config.fileBrowserWindowFeatures)}function e(){var a=this.getDialog();a.getParentEditor()._.filebrowserSe=this;return a.getContentElement(this["for"][0],this["for"][1]).getInputElement().$.value&&a.getContentElement(this["for"][0],this["for"][1]).getAction()?!0:!1}function h(b,c,e){var f=e.params||{};f.CKEditor=b.name;f.CKEditorFuncNum=b._.filebrowserFn;f.langCode||
(f.langCode=b.langCode);c.action=a(e.url,f);c.filebrowser=e}function l(a,f,g,k){if(k&&k.length)for(var p,q=k.length;q--;)if(p=k[q],"hbox"!=p.type&&"vbox"!=p.type&&"fieldset"!=p.type||l(a,f,g,p.children),p.filebrowser)if("string"==typeof p.filebrowser&&(p.filebrowser={action:"fileButton"==p.type?"QuickUpload":"Browse",target:p.filebrowser}),"Browse"==p.filebrowser.action){var y=p.filebrowser.url;void 0===y&&(y=a.config["filebrowser"+c(f)+"BrowseUrl"],void 0===y&&(y=a.config.filebrowserBrowseUrl));
y&&(p.onClick=b,p.filebrowser.url=y,p.hidden=!1)}else if("QuickUpload"==p.filebrowser.action&&p["for"]&&(y=p.filebrowser.url,void 0===y&&(y=a.config["filebrowser"+c(f)+"UploadUrl"],void 0===y&&(y=a.config.filebrowserUploadUrl)),y)){var v=p.onClick;p.onClick=function(a){var b=a.sender;if(v&&!1===v.call(b,a))return!1;if(e.call(b,a)){a=b.getDialog().getContentElement(this["for"][0],this["for"][1]).getInputElement();if(b=new CKEDITOR.dom.element(a.$.form))(a=b.$.elements.ckCsrfToken)?a=new CKEDITOR.dom.element(a):
(a=new CKEDITOR.dom.element("input"),a.setAttributes({name:"ckCsrfToken",type:"hidden"}),b.append(a)),a.setAttribute("value",CKEDITOR.tools.getCsrfToken());return!0}return!1};p.filebrowser.url=y;p.hidden=!1;h(a,g.getContents(p["for"][0]).get(p["for"][1]),p.filebrowser)}}function k(a,b,c){if(-1!==c.indexOf(";")){c=c.split(";");for(var e=0;e<c.length;e++)if(k(a,b,c[e]))return!0;return!1}return(a=a.getContents(b).get(c).filebrowser)&&a.url}function f(a,b){var c=this._.filebrowserSe.getDialog(),e=this._.filebrowserSe["for"],
f=this._.filebrowserSe.filebrowser.onSelect;e&&c.getContentElement(e[0],e[1]).reset();if("function"!=typeof b||!1!==b.call(this._.filebrowserSe))if(!f||!1!==f.call(this._.filebrowserSe,a,b))if("string"==typeof b&&b&&alert(b),a&&(e=this._.filebrowserSe,c=e.getDialog(),e=e.filebrowser.target||null))if(e=e.split(":"),f=c.getContentElement(e[0],e[1]))f.setValue(a),c.selectPage(e[0])}CKEDITOR.plugins.add("filebrowser",{requires:"popup",init:function(a){a._.filebrowserFn=CKEDITOR.tools.addFunction(f,a);
a.on("destroy",function(){CKEDITOR.tools.removeFunction(this._.filebrowserFn)})}});CKEDITOR.on("dialogDefinition",function(a){if(a.editor.plugins.filebrowser)for(var b=a.data.definition,c,e=0;e<b.contents.length;++e)if(c=b.contents[e])l(a.editor,a.data.name,b,c.elements),c.hidden&&c.filebrowser&&(c.hidden=!k(b,c.id,c.filebrowser))})}(),CKEDITOR.plugins.add("find",{requires:"dialog",init:function(a){var c=a.addCommand("find",new CKEDITOR.dialogCommand("find"));c.canUndo=!1;c.readOnly=1;a.addCommand("replace",
new CKEDITOR.dialogCommand("replace")).canUndo=!1;a.ui.addButton&&(a.ui.addButton("Find",{label:a.lang.find.find,command:"find",toolbar:"find,10"}),a.ui.addButton("Replace",{label:a.lang.find.replace,command:"replace",toolbar:"find,20"}));CKEDITOR.dialog.add("find",this.path+"dialogs/find.js");CKEDITOR.dialog.add("replace",this.path+"dialogs/find.js")}}),CKEDITOR.config.find_highlight={element:"span",styles:{"background-color":"#004",color:"#fff"}},function(){function a(a,b){var c=e.exec(a),d=e.exec(b);
if(c){if(!c[2]&&"px"==d[2])return d[1];if("px"==c[2]&&!d[2])return d[1]+"px"}return b}var c=CKEDITOR.htmlParser.cssStyle,b=CKEDITOR.tools.cssLength,e=/^((?:\d*(?:\.\d+))|(?:\d+))(.*)?$/i,h={elements:{$:function(b){var e=b.attributes;if((e=(e=(e=e&&e["data-cke-realelement"])&&new CKEDITOR.htmlParser.fragment.fromHtml(decodeURIComponent(e)))&&e.children[0])&&b.attributes["data-cke-resizable"]){var f=(new c(b)).rules;b=e.attributes;var d=f.width,f=f.height;d&&(b.width=a(b.width,d));f&&(b.height=a(b.height,
f))}return e}}};CKEDITOR.plugins.add("fakeobjects",{init:function(a){a.filter.allow("img[!data-cke-realelement,src,alt,title](*){*}","fakeobjects")},afterInit:function(a){(a=(a=a.dataProcessor)&&a.htmlFilter)&&a.addRules(h,{applyToAll:!0})}});CKEDITOR.editor.prototype.createFakeElement=function(a,e,f,d){var h=this.lang.fakeobjects,h=h[f]||h.unknown;e={"class":e,"data-cke-realelement":encodeURIComponent(a.getOuterHtml()),"data-cke-real-node-type":a.type,alt:h,title:h,align:a.getAttribute("align")||
""};CKEDITOR.env.hc||(e.src=CKEDITOR.tools.transparentImageData);f&&(e["data-cke-real-element-type"]=f);d&&(e["data-cke-resizable"]=d,f=new c,d=a.getAttribute("width"),a=a.getAttribute("height"),d&&(f.rules.width=b(d)),a&&(f.rules.height=b(a)),f.populate(e));return this.document.createElement("img",{attributes:e})};CKEDITOR.editor.prototype.createFakeParserElement=function(a,e,f,d){var h=this.lang.fakeobjects,h=h[f]||h.unknown,g;g=new CKEDITOR.htmlParser.basicWriter;a.writeHtml(g);g=g.getHtml();e=
{"class":e,"data-cke-realelement":encodeURIComponent(g),"data-cke-real-node-type":a.type,alt:h,title:h,align:a.attributes.align||""};CKEDITOR.env.hc||(e.src=CKEDITOR.tools.transparentImageData);f&&(e["data-cke-real-element-type"]=f);d&&(e["data-cke-resizable"]=d,d=a.attributes,a=new c,f=d.width,d=d.height,void 0!==f&&(a.rules.width=b(f)),void 0!==d&&(a.rules.height=b(d)),a.populate(e));return new CKEDITOR.htmlParser.element("img",e)};CKEDITOR.editor.prototype.restoreRealElement=function(b){if(b.data("cke-real-node-type")!=
CKEDITOR.NODE_ELEMENT)return null;var c=CKEDITOR.dom.element.createFromHtml(decodeURIComponent(b.data("cke-realelement")),this.document);if(b.data("cke-resizable")){var e=b.getStyle("width");b=b.getStyle("height");e&&c.setAttribute("width",a(c.getAttribute("width"),e));b&&c.setAttribute("height",a(c.getAttribute("height"),b))}return c}}(),function(){function a(a){a=a.attributes;return"application/x-shockwave-flash"==a.type||b.test(a.src||"")}function c(a,b){return a.createFakeParserElement(b,"cke_flash",
"flash",!0)}var b=/\.swf(?:$|\?)/i;CKEDITOR.plugins.add("flash",{requires:"dialog,fakeobjects",onLoad:function(){CKEDITOR.addCss("img.cke_flash{background-image: url("+CKEDITOR.getUrl(this.path+"images/placeholder.png")+");background-position: center center;background-repeat: no-repeat;border: 1px solid #a9a9a9;width: 80px;height: 80px;}")},init:function(a){var b="object[classid,codebase,height,hspace,vspace,width];param[name,value];embed[height,hspace,pluginspage,src,type,vspace,width]";CKEDITOR.dialog.isTabEnabled(a,
"flash","properties")&&(b+=";object[align]; embed[allowscriptaccess,quality,scale,wmode]");CKEDITOR.dialog.isTabEnabled(a,"flash","advanced")&&(b+=";object[id]{*}; embed[bgcolor]{*}(*)");a.addCommand("flash",new CKEDITOR.dialogCommand("flash",{allowedContent:b,requiredContent:"embed"}));a.ui.addButton&&a.ui.addButton("Flash",{label:a.lang.common.flash,command:"flash",toolbar:"insert,20"});CKEDITOR.dialog.add("flash",this.path+"dialogs/flash.js");a.addMenuItems&&a.addMenuItems({flash:{label:a.lang.flash.properties,
command:"flash",group:"flash"}});a.on("doubleclick",function(a){var b=a.data.element;b.is("img")&&"flash"==b.data("cke-real-element-type")&&(a.data.dialog="flash")});a.contextMenu&&a.contextMenu.addListener(function(a){if(a&&a.is("img")&&!a.isReadOnly()&&"flash"==a.data("cke-real-element-type"))return{flash:CKEDITOR.TRISTATE_OFF}})},afterInit:function(b){var h=b.dataProcessor;(h=h&&h.dataFilter)&&h.addRules({elements:{"cke:object":function(h){var k=h.attributes;if(!(k.classid&&String(k.classid).toLowerCase()||
a(h))){for(k=0;k<h.children.length;k++)if("cke:embed"==h.children[k].name){if(!a(h.children[k]))break;return c(b,h)}return null}return c(b,h)},"cke:embed":function(h){return a(h)?c(b,h):null}}},5)}})}(),CKEDITOR.tools.extend(CKEDITOR.config,{flashEmbedTagOnly:!1,flashAddEmbedTag:!0,flashConvertOnEdit:!1}),function(){function a(a){var h=a.config,l=a.fire("uiSpace",{space:"top",html:""}).html,k=function(){function f(a,c,e){d.setStyle(c,b(e));d.setStyle("position",a)}function g(a){var b=l.getDocumentPosition();
switch(a){case "top":f("absolute","top",b.y-w-B);break;case "pin":f("fixed","top",x);break;case "bottom":f("absolute","top",b.y+(t.height||t.bottom-t.top)+B)}m=a}var m,l,v,t,r,w,z,u=h.floatSpaceDockedOffsetX||0,B=h.floatSpaceDockedOffsetY||0,C=h.floatSpacePinnedOffsetX||0,x=h.floatSpacePinnedOffsetY||0;return function(f){if(l=a.editable()){var n=f&&"focus"==f.name;n&&d.show();a.fire("floatingSpaceLayout",{show:n});d.removeStyle("left");d.removeStyle("right");v=d.getClientRect();t=l.getClientRect();
r=c.getViewPaneSize();w=v.height;z="pageXOffset"in c.$?c.$.pageXOffset:CKEDITOR.document.$.documentElement.scrollLeft;m?(w+B<=t.top?g("top"):w+B>r.height-t.bottom?g("pin"):g("bottom"),f=r.width/2,f=h.floatSpacePreferRight?"right":0<t.left&&t.right<r.width&&t.width>v.width?"rtl"==h.contentsLangDirection?"right":"left":f-t.left>t.right-f?"left":"right",v.width>r.width?(f="left",n=0):(n="left"==f?0<t.left?t.left:0:t.right<r.width?r.width-t.right:0,n+v.width>r.width&&(f="left"==f?"right":"left",n=0)),
d.setStyle(f,b(("pin"==m?C:u)+n+("pin"==m?0:"left"==f?z:-z)))):(m="pin",g("pin"),k(f))}}}();if(l){var f=new CKEDITOR.template('\x3cdiv id\x3d"cke_{name}" class\x3d"cke {id} cke_reset_all cke_chrome cke_editor_{name} cke_float cke_{langDir} '+CKEDITOR.env.cssClass+'" dir\x3d"{langDir}" title\x3d"'+(CKEDITOR.env.gecko?" ":"")+'" lang\x3d"{langCode}" role\x3d"application" style\x3d"{style}"'+(a.title?' aria-labelledby\x3d"cke_{name}_arialbl"':" ")+"\x3e"+(a.title?'\x3cspan id\x3d"cke_{name}_arialbl" class\x3d"cke_voice_label"\x3e{voiceLabel}\x3c/span\x3e':
" ")+'\x3cdiv class\x3d"cke_inner"\x3e\x3cdiv id\x3d"{topId}" class\x3d"cke_top" role\x3d"presentation"\x3e{content}\x3c/div\x3e\x3c/div\x3e\x3c/div\x3e'),d=CKEDITOR.document.getBody().append(CKEDITOR.dom.element.createFromHtml(f.output({content:l,id:a.id,langDir:a.lang.dir,langCode:a.langCode,name:a.name,style:"display:none;z-index:"+(h.baseFloatZIndex-1),topId:a.ui.spaceId("top"),voiceLabel:a.title}))),m=CKEDITOR.tools.eventsBuffer(500,k),g=CKEDITOR.tools.eventsBuffer(100,k);d.unselectable();d.on("mousedown",
function(a){a=a.data;a.getTarget().hasAscendant("a",1)||a.preventDefault()});a.on("focus",function(b){k(b);a.on("change",m.input);c.on("scroll",g.input);c.on("resize",g.input)});a.on("blur",function(){d.hide();a.removeListener("change",m.input);c.removeListener("scroll",g.input);c.removeListener("resize",g.input)});a.on("destroy",function(){c.removeListener("scroll",g.input);c.removeListener("resize",g.input);d.clearCustomData();d.remove()});a.focusManager.hasFocus&&d.show();a.focusManager.add(d,
1)}}var c=CKEDITOR.document.getWindow(),b=CKEDITOR.tools.cssLength;CKEDITOR.plugins.add("floatingspace",{init:function(b){b.on("loaded",function(){a(this)},null,null,20)}})}(),CKEDITOR.plugins.add("listblock",{requires:"panel",onLoad:function(){var a=CKEDITOR.addTemplate("panel-list",'\x3cul role\x3d"presentation" class\x3d"cke_panel_list"\x3e{items}\x3c/ul\x3e'),c=CKEDITOR.addTemplate("panel-list-item",'\x3cli id\x3d"{id}" class\x3d"cke_panel_listItem" role\x3dpresentation\x3e\x3ca id\x3d"{id}_option" _cke_focus\x3d1 hidefocus\x3dtrue title\x3d"{title}" href\x3d"javascript:void(\'{val}\')"  {onclick}\x3d"CKEDITOR.tools.callFunction({clickFn},\'{val}\'); return false;" role\x3d"option"\x3e{text}\x3c/a\x3e\x3c/li\x3e'),
b=CKEDITOR.addTemplate("panel-list-group",'\x3ch1 id\x3d"{id}" class\x3d"cke_panel_grouptitle" role\x3d"presentation" \x3e{label}\x3c/h1\x3e'),e=/\'/g;CKEDITOR.ui.panel.prototype.addListBlock=function(a,b){return this.addBlock(a,new CKEDITOR.ui.listBlock(this.getHolderElement(),b))};CKEDITOR.ui.listBlock=CKEDITOR.tools.createClass({base:CKEDITOR.ui.panel.block,$:function(a,b){b=b||{};var c=b.attributes||(b.attributes={});(this.multiSelect=!!b.multiSelect)&&(c["aria-multiselectable"]=!0);!c.role&&
(c.role="listbox");this.base.apply(this,arguments);this.element.setAttribute("role",c.role);c=this.keys;c[40]="next";c[9]="next";c[38]="prev";c[CKEDITOR.SHIFT+9]="prev";c[32]=CKEDITOR.env.ie?"mouseup":"click";CKEDITOR.env.ie&&(c[13]="mouseup");this._.pendingHtml=[];this._.pendingList=[];this._.items={};this._.groups={}},_:{close:function(){if(this._.started){var b=a.output({items:this._.pendingList.join("")});this._.pendingList=[];this._.pendingHtml.push(b);delete this._.started}},getClick:function(){this._.click||
(this._.click=CKEDITOR.tools.addFunction(function(a){var b=this.toggle(a);if(this.onClick)this.onClick(a,b)},this));return this._.click}},proto:{add:function(a,b,k){var f=CKEDITOR.tools.getNextId();this._.started||(this._.started=1,this._.size=this._.size||0);this._.items[a]=f;var d;d=CKEDITOR.tools.htmlEncodeAttr(a).replace(e,"\\'");a={id:f,val:d,onclick:CKEDITOR.env.ie?'onclick\x3d"return false;" onmouseup':"onclick",clickFn:this._.getClick(),title:CKEDITOR.tools.htmlEncodeAttr(k||a),text:b||a};
this._.pendingList.push(c.output(a))},startGroup:function(a){this._.close();var c=CKEDITOR.tools.getNextId();this._.groups[a]=c;this._.pendingHtml.push(b.output({id:c,label:a}))},commit:function(){this._.close();this.element.appendHtml(this._.pendingHtml.join(""));delete this._.size;this._.pendingHtml=[]},toggle:function(a){var b=this.isMarked(a);b?this.unmark(a):this.mark(a);return!b},hideGroup:function(a){var b=(a=this.element.getDocument().getById(this._.groups[a]))&&a.getNext();a&&(a.setStyle("display",
"none"),b&&"ul"==b.getName()&&b.setStyle("display","none"))},hideItem:function(a){this.element.getDocument().getById(this._.items[a]).setStyle("display","none")},showAll:function(){var a=this._.items,b=this._.groups,c=this.element.getDocument(),e;for(e in a)c.getById(a[e]).setStyle("display","");for(var d in b)a=c.getById(b[d]),e=a.getNext(),a.setStyle("display",""),e&&"ul"==e.getName()&&e.setStyle("display","")},mark:function(a){this.multiSelect||this.unmarkAll();a=this._.items[a];var b=this.element.getDocument().getById(a);
b.addClass("cke_selected");this.element.getDocument().getById(a+"_option").setAttribute("aria-selected",!0);this.onMark&&this.onMark(b)},markFirstDisplayed:function(){var a=this;this._.markFirstDisplayed(function(){a.multiSelect||a.unmarkAll()})},unmark:function(a){var b=this.element.getDocument();a=this._.items[a];var c=b.getById(a);c.removeClass("cke_selected");b.getById(a+"_option").removeAttribute("aria-selected");this.onUnmark&&this.onUnmark(c)},unmarkAll:function(){var a=this._.items,b=this.element.getDocument(),
c;for(c in a){var e=a[c];b.getById(e).removeClass("cke_selected");b.getById(e+"_option").removeAttribute("aria-selected")}this.onUnmark&&this.onUnmark()},isMarked:function(a){return this.element.getDocument().getById(this._.items[a]).hasClass("cke_selected")},focus:function(a){this._.focusIndex=-1;var b=this.element.getElementsByTag("a"),c,e=-1;if(a)for(c=this.element.getDocument().getById(this._.items[a]).getFirst();a=b.getItem(++e);){if(a.equals(c)){this._.focusIndex=e;break}}else this.element.focus();
c&&setTimeout(function(){c.focus()},0)}}})}}),CKEDITOR.plugins.add("richcombo",{requires:"floatpanel,listblock,button",beforeInit:function(a){a.ui.addHandler(CKEDITOR.UI_RICHCOMBO,CKEDITOR.ui.richCombo.handler)}}),function(){var a='\x3cspan id\x3d"{id}" class\x3d"cke_combo cke_combo__{name} {cls}" role\x3d"presentation"\x3e\x3cspan id\x3d"{id}_label" class\x3d"cke_combo_label"\x3e{label}\x3c/span\x3e\x3ca class\x3d"cke_combo_button" title\x3d"{title}" tabindex\x3d"-1"'+(CKEDITOR.env.gecko&&!CKEDITOR.env.hc?
"":" href\x3d\"javascript:void('{titleJs}')\"")+' hidefocus\x3d"true" role\x3d"button" aria-labelledby\x3d"{id}_label" aria-haspopup\x3d"true"';CKEDITOR.env.gecko&&CKEDITOR.env.mac&&(a+=' onkeypress\x3d"return false;"');CKEDITOR.env.gecko&&(a+=' onblur\x3d"this.style.cssText \x3d this.style.cssText;"');var a=a+(' onkeydown\x3d"return CKEDITOR.tools.callFunction({keydownFn},event,this);" onfocus\x3d"return CKEDITOR.tools.callFunction({focusFn},event);" '+(CKEDITOR.env.ie?'onclick\x3d"return false;" onmouseup':
"onclick")+'\x3d"CKEDITOR.tools.callFunction({clickFn},this);return false;"\x3e\x3cspan id\x3d"{id}_text" class\x3d"cke_combo_text cke_combo_inlinelabel"\x3e{label}\x3c/span\x3e\x3cspan class\x3d"cke_combo_open"\x3e\x3cspan class\x3d"cke_combo_arrow"\x3e'+(CKEDITOR.env.hc?"\x26#9660;":CKEDITOR.env.air?"\x26nbsp;":"")+"\x3c/span\x3e\x3c/span\x3e\x3c/a\x3e\x3c/span\x3e"),c=CKEDITOR.addTemplate("combo",a);CKEDITOR.UI_RICHCOMBO="richcombo";CKEDITOR.ui.richCombo=CKEDITOR.tools.createClass({$:function(a){CKEDITOR.tools.extend(this,
a,{canGroup:!1,title:a.label,modes:{wysiwyg:1},editorFocus:1});a=this.panel||{};delete this.panel;this.id=CKEDITOR.tools.getNextNumber();this.document=a.parent&&a.parent.getDocument()||CKEDITOR.document;a.className="cke_combopanel";a.block={multiSelect:a.multiSelect,attributes:a.attributes};a.toolbarRelated=!0;this._={panelDefinition:a,items:{}}},proto:{renderHtml:function(a){var c=[];this.render(a,c);return c.join("")},render:function(a,e){function h(){if(this.getState()!=CKEDITOR.TRISTATE_ON){var d=
this.modes[a.mode]?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED;a.readOnly&&!this.readOnly&&(d=CKEDITOR.TRISTATE_DISABLED);this.setState(d);this.setValue("");d!=CKEDITOR.TRISTATE_DISABLED&&this.refresh&&this.refresh()}}var l=CKEDITOR.env,k="cke_"+this.id,f=CKEDITOR.tools.addFunction(function(d){p&&(a.unlockSelection(1),p=0);m.execute(d)},this),d=this,m={id:k,combo:this,focus:function(){CKEDITOR.document.getById(k).getChild(1).focus()},execute:function(c){var e=d._;if(e.state!=CKEDITOR.TRISTATE_DISABLED)if(d.createPanel(a),
e.on)e.panel.hide();else{d.commit();var f=d.getValue();f?e.list.mark(f):e.list.unmarkAll();e.panel.showBlock(d.id,new CKEDITOR.dom.element(c),4)}},clickFn:f};a.on("activeFilterChange",h,this);a.on("mode",h,this);a.on("selectionChange",h,this);!this.readOnly&&a.on("readOnly",h,this);var g=CKEDITOR.tools.addFunction(function(a,b){a=new CKEDITOR.dom.event(a);var d=a.getKeystroke();switch(d){case 13:case 32:case 40:CKEDITOR.tools.callFunction(f,b);break;default:m.onkey(m,d)}a.preventDefault()}),n=CKEDITOR.tools.addFunction(function(){m.onfocus&&
m.onfocus()}),p=0;m.keyDownFn=g;l={id:k,name:this.name||this.command,label:this.label,title:this.title,cls:this.className||"",titleJs:l.gecko&&!l.hc?"":(this.title||"").replace("'",""),keydownFn:g,focusFn:n,clickFn:f};c.output(l,e);if(this.onRender)this.onRender();return m},createPanel:function(a){if(!this._.panel){var c=this._.panelDefinition,h=this._.panelDefinition.block,l=c.parent||CKEDITOR.document.getBody(),k="cke_combopanel__"+this.name,f=new CKEDITOR.ui.floatPanel(a,l,c),c=f.addListBlock(this.id,
h),d=this;f.onShow=function(){this.element.addClass(k);d.setState(CKEDITOR.TRISTATE_ON);d._.on=1;d.editorFocus&&!a.focusManager.hasFocus&&a.focus();if(d.onOpen)d.onOpen()};f.onHide=function(c){this.element.removeClass(k);d.setState(d.modes&&d.modes[a.mode]?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED);d._.on=0;if(!c&&d.onClose)d.onClose()};f.onEscape=function(){f.hide(1)};c.onClick=function(a,b){d.onClick&&d.onClick.call(d,a,b);f.hide()};this._.panel=f;this._.list=c;f.getBlock(this.id).onHide=
function(){d._.on=0;d.setState(CKEDITOR.TRISTATE_OFF)};this.init&&this.init()}},setValue:function(a,c){this._.value=a;var h=this.document.getById("cke_"+this.id+"_text");h&&(a||c?h.removeClass("cke_combo_inlinelabel"):(c=this.label,h.addClass("cke_combo_inlinelabel")),h.setText("undefined"!=typeof c?c:a))},getValue:function(){return this._.value||""},unmarkAll:function(){this._.list.unmarkAll()},mark:function(a){this._.list.mark(a)},hideItem:function(a){this._.list.hideItem(a)},hideGroup:function(a){this._.list.hideGroup(a)},
showAll:function(){this._.list.showAll()},add:function(a,c,h){this._.items[a]=h||a;this._.list.add(a,c,h)},startGroup:function(a){this._.list.startGroup(a)},commit:function(){this._.committed||(this._.list.commit(),this._.committed=1,CKEDITOR.ui.fire("ready",this));this._.committed=1},setState:function(a){if(this._.state!=a){var c=this.document.getById("cke_"+this.id);c.setState(a,"cke_combo");a==CKEDITOR.TRISTATE_DISABLED?c.setAttribute("aria-disabled",!0):c.removeAttribute("aria-disabled");this._.state=
a}},getState:function(){return this._.state},enable:function(){this._.state==CKEDITOR.TRISTATE_DISABLED&&this.setState(this._.lastState)},disable:function(){this._.state!=CKEDITOR.TRISTATE_DISABLED&&(this._.lastState=this._.state,this.setState(CKEDITOR.TRISTATE_DISABLED))}},statics:{handler:{create:function(a){return new CKEDITOR.ui.richCombo(a)}}}});CKEDITOR.ui.prototype.addRichCombo=function(a,c){this.add(a,CKEDITOR.UI_RICHCOMBO,c)}}(),function(){function a(a,e,h,l,k,f,d,m){var g=a.config,n=new CKEDITOR.style(d),
p=k.split(";");k=[];for(var q={},y=0;y<p.length;y++){var v=p[y];if(v){var v=v.split("/"),t={},r=p[y]=v[0];t[h]=k[y]=v[1]||r;q[r]=new CKEDITOR.style(d,t);q[r]._.definition.name=r}else p.splice(y--,1)}a.ui.addRichCombo(e,{label:l.label,title:l.panelTitle,toolbar:"styles,"+m,allowedContent:n,requiredContent:n,contentTransformations:[[{element:"font",check:"span",left:function(a){return!!a.attributes.size||!!a.attributes.align||!!a.attributes.face},right:function(a){var b=" x-small small medium large x-large xx-large 48px".split(" ");
a.name="span";a.attributes.size&&(a.styles["font-size"]=b[a.attributes.size],delete a.attributes.size);a.attributes.align&&(a.styles["text-align"]=a.attributes.align,delete a.attributes.align);a.attributes.face&&(a.styles["font-family"]=a.attributes.face,delete a.attributes.face)}}]],panel:{css:[CKEDITOR.skin.getPath("editor")].concat(g.contentsCss),multiSelect:!1,attributes:{"aria-label":l.panelTitle}},init:function(){this.startGroup(l.panelTitle);for(var a=0;a<p.length;a++){var b=p[a];this.add(b,
q[b].buildPreview(),b)}},onClick:function(d){a.focus();a.fire("saveSnapshot");var e=this.getValue(),f=q[d];if(e&&d!=e){var g=q[e],h=a.getSelection().getRanges()[0];if(h.collapsed){var m=a.elementPath(),k=m.contains(function(a){return g.checkElementRemovable(a)});if(k){var l=h.checkBoundaryOfElement(k,CKEDITOR.START),r=h.checkBoundaryOfElement(k,CKEDITOR.END);if(l&&r){for(l=h.createBookmark();m=k.getFirst();)m.insertBefore(k);k.remove();h.moveToBookmark(l)}else l||r?h.moveToPosition(k,l?CKEDITOR.POSITION_BEFORE_START:
CKEDITOR.POSITION_AFTER_END):(h.splitElement(k),h.moveToPosition(k,CKEDITOR.POSITION_AFTER_END)),c(h,m.elements.slice(),k);a.getSelection().selectRanges([h])}}else a.removeStyle(g)}a[e==d?"removeStyle":"applyStyle"](f);a.fire("saveSnapshot")},onRender:function(){a.on("selectionChange",function(d){var c=this.getValue();d=d.data.path.elements;for(var e=0,g;e<d.length;e++){g=d[e];for(var h in q)if(q[h].checkElementMatch(g,!0,a)){h!=c&&this.setValue(h);return}}this.setValue("",f)},this)},refresh:function(){a.activeFilter.check(n)||
this.setState(CKEDITOR.TRISTATE_DISABLED)}})}function c(a,e,h){var l=e.pop();if(l){if(h)return c(a,e,l.equals(h)?null:h);h=l.clone();a.insertNode(h);a.moveToPosition(h,CKEDITOR.POSITION_AFTER_START);c(a,e)}}CKEDITOR.plugins.add("font",{requires:"richcombo",init:function(b){var c=b.config;a(b,"Font","family",b.lang.font,c.font_names,c.font_defaultLabel,c.font_style,30);a(b,"FontSize","size",b.lang.font.fontSize,c.fontSize_sizes,c.fontSize_defaultLabel,c.fontSize_style,40)}})}(),CKEDITOR.config.font_names=
"Arial/Arial, Helvetica, sans-serif;Comic Sans MS/Comic Sans MS, cursive;Courier New/Courier New, Courier, monospace;Georgia/Georgia, serif;Lucida Sans Unicode/Lucida Sans Unicode, Lucida Grande, sans-serif;Tahoma/Tahoma, Geneva, sans-serif;Times New Roman/Times New Roman, Times, serif;Trebuchet MS/Trebuchet MS, Helvetica, sans-serif;Verdana/Verdana, Geneva, sans-serif",CKEDITOR.config.font_defaultLabel="",CKEDITOR.config.font_style={element:"span",styles:{"font-family":"#(family)"},overrides:[{element:"font",
attributes:{face:null}}]},CKEDITOR.config.fontSize_sizes="8/8px;9/9px;10/10px;11/11px;12/12px;14/14px;16/16px;18/18px;20/20px;22/22px;24/24px;26/26px;28/28px;36/36px;48/48px;72/72px",CKEDITOR.config.fontSize_defaultLabel="",CKEDITOR.config.fontSize_style={element:"span",styles:{"font-size":"#(size)"},overrides:[{element:"font",attributes:{size:null}}]},CKEDITOR.plugins.add("format",{requires:"richcombo",init:function(a){if(!a.blockless){for(var c=a.config,b=a.lang.format,e=c.format_tags.split(";"),
h={},l=0,k=[],f=0;f<e.length;f++){var d=e[f],m=new CKEDITOR.style(c["format_"+d]);if(!a.filter.customConfig||a.filter.check(m))l++,h[d]=m,h[d]._.enterMode=a.config.enterMode,k.push(m)}0!==l&&a.ui.addRichCombo("Format",{label:b.label,title:b.panelTitle,toolbar:"styles,20",allowedContent:k,panel:{css:[CKEDITOR.skin.getPath("editor")].concat(c.contentsCss),multiSelect:!1,attributes:{"aria-label":b.panelTitle}},init:function(){this.startGroup(b.panelTitle);for(var a in h){var d=b["tag_"+a];this.add(a,
h[a].buildPreview(d),d)}},onClick:function(b){a.focus();a.fire("saveSnapshot");b=h[b];var d=a.elementPath();a[b.checkActive(d,a)?"removeStyle":"applyStyle"](b);setTimeout(function(){a.fire("saveSnapshot")},0)},onRender:function(){a.on("selectionChange",function(b){var d=this.getValue();b=b.data.path;this.refresh();for(var c in h)if(h[c].checkActive(b,a)){c!=d&&this.setValue(c,a.lang.format["tag_"+c]);return}this.setValue("")},this)},onOpen:function(){this.showAll();for(var b in h)a.activeFilter.check(h[b])||
this.hideItem(b)},refresh:function(){var b=a.elementPath();if(b){if(b.isContextFor("p"))for(var d in h)if(a.activeFilter.check(h[d]))return;this.setState(CKEDITOR.TRISTATE_DISABLED)}}})}}}),CKEDITOR.config.format_tags="p;h1;h2;h3;h4;h5;h6;pre;address;div",CKEDITOR.config.format_p={element:"p"},CKEDITOR.config.format_div={element:"div"},CKEDITOR.config.format_pre={element:"pre"},CKEDITOR.config.format_address={element:"address"},CKEDITOR.config.format_h1={element:"h1"},CKEDITOR.config.format_h2={element:"h2"},
CKEDITOR.config.format_h3={element:"h3"},CKEDITOR.config.format_h4={element:"h4"},CKEDITOR.config.format_h5={element:"h5"},CKEDITOR.config.format_h6={element:"h6"},CKEDITOR.plugins.add("forms",{requires:"dialog,fakeobjects",onLoad:function(){CKEDITOR.addCss(".cke_editable form{border: 1px dotted #FF0000;padding: 2px;}\n");CKEDITOR.addCss("img.cke_hidden{background-image: url("+CKEDITOR.getUrl(this.path+"images/hiddenfield.gif")+");background-position: center center;background-repeat: no-repeat;border: 1px solid #a9a9a9;width: 16px !important;height: 16px !important;}")},
init:function(a){var c=a.lang,b=0,e={email:1,password:1,search:1,tel:1,text:1,url:1},h={checkbox:"input[type,name,checked,required]",radio:"input[type,name,checked,required]",textfield:"input[type,name,value,size,maxlength,required]",textarea:"textarea[cols,rows,name,required]",select:"select[name,size,multiple,required]; option[value,selected]",button:"input[type,name,value]",form:"form[action,name,id,enctype,target,method]",hiddenfield:"input[type,name,value]",imagebutton:"input[type,alt,src]{width,height,border,border-width,border-style,margin,float}"},
l={checkbox:"input",radio:"input",textfield:"input",textarea:"textarea",select:"select",button:"input",form:"form",hiddenfield:"input",imagebutton:"input"},k=function(d,e,f){var k={allowedContent:h[e],requiredContent:l[e]};"form"==e&&(k.context="form");a.addCommand(e,new CKEDITOR.dialogCommand(e,k));a.ui.addButton&&a.ui.addButton(d,{label:c.common[d.charAt(0).toLowerCase()+d.slice(1)],command:e,toolbar:"forms,"+(b+=10)});CKEDITOR.dialog.add(e,f)},f=this.path+"dialogs/";!a.blockless&&k("Form","form",
f+"form.js");k("Checkbox","checkbox",f+"checkbox.js");k("Radio","radio",f+"radio.js");k("TextField","textfield",f+"textfield.js");k("Textarea","textarea",f+"textarea.js");k("Select","select",f+"select.js");k("Button","button",f+"button.js");var d=a.plugins.image;d&&!a.plugins.image2&&k("ImageButton","imagebutton",CKEDITOR.plugins.getPath("image")+"dialogs/image.js");k("HiddenField","hiddenfield",f+"hiddenfield.js");a.addMenuItems&&(k={checkbox:{label:c.forms.checkboxAndRadio.checkboxTitle,command:"checkbox",
group:"checkbox"},radio:{label:c.forms.checkboxAndRadio.radioTitle,command:"radio",group:"radio"},textfield:{label:c.forms.textfield.title,command:"textfield",group:"textfield"},hiddenfield:{label:c.forms.hidden.title,command:"hiddenfield",group:"hiddenfield"},button:{label:c.forms.button.title,command:"button",group:"button"},select:{label:c.forms.select.title,command:"select",group:"select"},textarea:{label:c.forms.textarea.title,command:"textarea",group:"textarea"}},d&&(k.imagebutton={label:c.image.titleButton,
command:"imagebutton",group:"imagebutton"}),!a.blockless&&(k.form={label:c.forms.form.menu,command:"form",group:"form"}),a.addMenuItems(k));a.contextMenu&&(!a.blockless&&a.contextMenu.addListener(function(a,b,d){if((a=d.contains("form",1))&&!a.isReadOnly())return{form:CKEDITOR.TRISTATE_OFF}}),a.contextMenu.addListener(function(a){if(a&&!a.isReadOnly()){var b=a.getName();if("select"==b)return{select:CKEDITOR.TRISTATE_OFF};if("textarea"==b)return{textarea:CKEDITOR.TRISTATE_OFF};if("input"==b){var c=
a.getAttribute("type")||"text";switch(c){case "button":case "submit":case "reset":return{button:CKEDITOR.TRISTATE_OFF};case "checkbox":return{checkbox:CKEDITOR.TRISTATE_OFF};case "radio":return{radio:CKEDITOR.TRISTATE_OFF};case "image":return d?{imagebutton:CKEDITOR.TRISTATE_OFF}:null}if(e[c])return{textfield:CKEDITOR.TRISTATE_OFF}}if("img"==b&&"hiddenfield"==a.data("cke-real-element-type"))return{hiddenfield:CKEDITOR.TRISTATE_OFF}}}));a.on("doubleclick",function(b){var d=b.data.element;if(!a.blockless&&
d.is("form"))b.data.dialog="form";else if(d.is("select"))b.data.dialog="select";else if(d.is("textarea"))b.data.dialog="textarea";else if(d.is("img")&&"hiddenfield"==d.data("cke-real-element-type"))b.data.dialog="hiddenfield";else if(d.is("input")){d=d.getAttribute("type")||"text";switch(d){case "button":case "submit":case "reset":b.data.dialog="button";break;case "checkbox":b.data.dialog="checkbox";break;case "radio":b.data.dialog="radio";break;case "image":b.data.dialog="imagebutton"}e[d]&&(b.data.dialog=
"textfield")}})},afterInit:function(a){var c=a.dataProcessor,b=c&&c.htmlFilter,c=c&&c.dataFilter;CKEDITOR.env.ie&&b&&b.addRules({elements:{input:function(a){a=a.attributes;var b=a.type;b||(a.type="text");"checkbox"!=b&&"radio"!=b||"on"!=a.value||delete a.value}}},{applyToAll:!0});c&&c.addRules({elements:{input:function(b){if("hidden"==b.attributes.type)return a.createFakeParserElement(b,"cke_hidden","hiddenfield")}}},{applyToAll:!0})}}),function(){var a={canUndo:!1,exec:function(a){var b=a.document.createElement("hr");
a.insertElement(b)},allowedContent:"hr",requiredContent:"hr"};CKEDITOR.plugins.add("horizontalrule",{init:function(c){c.blockless||(c.addCommand("horizontalrule",a),c.ui.addButton&&c.ui.addButton("HorizontalRule",{label:c.lang.horizontalrule.toolbar,command:"horizontalrule",toolbar:"insert,40"}))}})}(),CKEDITOR.plugins.add("htmlwriter",{init:function(a){var c=new CKEDITOR.htmlWriter;c.forceSimpleAmpersand=a.config.forceSimpleAmpersand;c.indentationChars=a.config.dataIndentationChars||"\t";a.dataProcessor.writer=
c}}),CKEDITOR.htmlWriter=CKEDITOR.tools.createClass({base:CKEDITOR.htmlParser.basicWriter,$:function(){this.base();this.indentationChars="\t";this.selfClosingEnd=" /\x3e";this.lineBreakChars="\n";this.sortAttributes=1;this._.indent=0;this._.indentation="";this._.inPre=0;this._.rules={};var a=CKEDITOR.dtd,c;for(c in CKEDITOR.tools.extend({},a.$nonBodyContent,a.$block,a.$listItem,a.$tableContent))this.setRules(c,{indent:!a[c]["#"],breakBeforeOpen:1,breakBeforeClose:!a[c]["#"],breakAfterClose:1,needsSpace:c in
a.$block&&!(c in{li:1,dt:1,dd:1})});this.setRules("br",{breakAfterOpen:1});this.setRules("title",{indent:0,breakAfterOpen:0});this.setRules("style",{indent:0,breakBeforeClose:1});this.setRules("pre",{breakAfterOpen:1,indent:0})},proto:{openTag:function(a){var c=this._.rules[a];this._.afterCloser&&c&&c.needsSpace&&this._.needsSpace&&this._.output.push("\n");this._.indent?this.indentation():c&&c.breakBeforeOpen&&(this.lineBreak(),this.indentation());this._.output.push("\x3c",a);this._.afterCloser=0},
openTagClose:function(a,c){var b=this._.rules[a];c?(this._.output.push(this.selfClosingEnd),b&&b.breakAfterClose&&(this._.needsSpace=b.needsSpace)):(this._.output.push("\x3e"),b&&b.indent&&(this._.indentation+=this.indentationChars));b&&b.breakAfterOpen&&this.lineBreak();"pre"==a&&(this._.inPre=1)},attribute:function(a,c){"string"==typeof c&&(this.forceSimpleAmpersand&&(c=c.replace(/&amp;/g,"\x26")),c=CKEDITOR.tools.htmlEncodeAttr(c));this._.output.push(" ",a,'\x3d"',c,'"')},closeTag:function(a){var c=
this._.rules[a];c&&c.indent&&(this._.indentation=this._.indentation.substr(this.indentationChars.length));this._.indent?this.indentation():c&&c.breakBeforeClose&&(this.lineBreak(),this.indentation());this._.output.push("\x3c/",a,"\x3e");"pre"==a&&(this._.inPre=0);c&&c.breakAfterClose&&(this.lineBreak(),this._.needsSpace=c.needsSpace);this._.afterCloser=1},text:function(a){this._.indent&&(this.indentation(),!this._.inPre&&(a=CKEDITOR.tools.ltrim(a)));this._.output.push(a)},comment:function(a){this._.indent&&
this.indentation();this._.output.push("\x3c!--",a,"--\x3e")},lineBreak:function(){!this._.inPre&&0<this._.output.length&&this._.output.push(this.lineBreakChars);this._.indent=1},indentation:function(){!this._.inPre&&this._.indentation&&this._.output.push(this._.indentation);this._.indent=0},reset:function(){this._.output=[];this._.indent=0;this._.indentation="";this._.afterCloser=0;this._.inPre=0;this._.needsSpace=0},setRules:function(a,c){var b=this._.rules[a];b?CKEDITOR.tools.extend(b,c,!0):this._.rules[a]=
c}}}),function(){CKEDITOR.plugins.add("iframe",{requires:"dialog,fakeobjects",onLoad:function(){CKEDITOR.addCss("img.cke_iframe{background-image: url("+CKEDITOR.getUrl(this.path+"images/placeholder.png")+");background-position: center center;background-repeat: no-repeat;border: 1px solid #a9a9a9;width: 80px;height: 80px;}")},init:function(a){var c=a.lang.iframe,b="iframe[align,longdesc,frameborder,height,name,scrolling,src,title,width]";a.plugins.dialogadvtab&&(b+=";iframe"+a.plugins.dialogadvtab.allowedContent({id:1,
classes:1,styles:1}));CKEDITOR.dialog.add("iframe",this.path+"dialogs/iframe.js");a.addCommand("iframe",new CKEDITOR.dialogCommand("iframe",{allowedContent:b,requiredContent:"iframe"}));a.ui.addButton&&a.ui.addButton("Iframe",{label:c.toolbar,command:"iframe",toolbar:"insert,80"});a.on("doubleclick",function(a){var b=a.data.element;b.is("img")&&"iframe"==b.data("cke-real-element-type")&&(a.data.dialog="iframe")});a.addMenuItems&&a.addMenuItems({iframe:{label:c.title,command:"iframe",group:"image"}});
a.contextMenu&&a.contextMenu.addListener(function(a){if(a&&a.is("img")&&"iframe"==a.data("cke-real-element-type"))return{iframe:CKEDITOR.TRISTATE_OFF}})},afterInit:function(a){var c=a.dataProcessor;(c=c&&c.dataFilter)&&c.addRules({elements:{iframe:function(b){return a.createFakeParserElement(b,"cke_iframe","iframe",!0)}}})}})}(),function(){function a(a,c){c||(c=a.getSelection().getSelectedElement());if(c&&c.is("img")&&!c.data("cke-realelement")&&!c.isReadOnly())return c}function c(a){var c=a.getStyle("float");
if("inherit"==c||"none"==c)c=0;c||(c=a.getAttribute("align"));return c}CKEDITOR.plugins.add("image",{requires:"dialog",init:function(b){if(!b.plugins.image2){CKEDITOR.dialog.add("image",this.path+"dialogs/image.js");var c="img[alt,!src]{border-style,border-width,float,height,margin,margin-bottom,margin-left,margin-right,margin-top,width}";CKEDITOR.dialog.isTabEnabled(b,"image","advanced")&&(c="img[alt,dir,id,lang,longdesc,!src,title]{*}(*)");b.addCommand("image",new CKEDITOR.dialogCommand("image",
{allowedContent:c,requiredContent:"img[alt,src]",contentTransformations:[["img{width}: sizeToStyle","img[width]: sizeToAttribute"],["img{float}: alignmentToStyle","img[align]: alignmentToAttribute"]]}));b.ui.addButton&&b.ui.addButton("Image",{label:b.lang.common.image,command:"image",toolbar:"insert,10"});b.on("doubleclick",function(a){var b=a.data.element;!b.is("img")||b.data("cke-realelement")||b.isReadOnly()||(a.data.dialog="image")});b.addMenuItems&&b.addMenuItems({image:{label:b.lang.image.menu,
command:"image",group:"image"}});b.contextMenu&&b.contextMenu.addListener(function(c){if(a(b,c))return{image:CKEDITOR.TRISTATE_OFF}})}},afterInit:function(b){function e(e){var l=b.getCommand("justify"+e);if(l){if("left"==e||"right"==e)l.on("exec",function(k){var f=a(b),d;f&&(d=c(f),d==e?(f.removeStyle("float"),e==c(f)&&f.removeAttribute("align")):f.setStyle("float",e),k.cancel())});l.on("refresh",function(k){var f=a(b);f&&(f=c(f),this.setState(f==e?CKEDITOR.TRISTATE_ON:"right"==e||"left"==e?CKEDITOR.TRISTATE_OFF:
CKEDITOR.TRISTATE_DISABLED),k.cancel())})}}b.plugins.image2||(e("left"),e("right"),e("center"),e("block"))}})}(),CKEDITOR.config.image_removeLinkByEmptyURL=!0,CKEDITOR.plugins.add("wsc",{requires:"dialog",parseApi:function(a){a.config.wsc_onFinish="function"===typeof a.config.wsc_onFinish?a.config.wsc_onFinish:function(){};a.config.wsc_onClose="function"===typeof a.config.wsc_onClose?a.config.wsc_onClose:function(){}},parseConfig:function(a){a.config.wsc_customerId=a.config.wsc_customerId||CKEDITOR.config.wsc_customerId||
"1:ua3xw1-2XyGJ3-GWruD3-6OFNT1-oXcuB1-nR6Bp4-hgQHc-EcYng3-sdRXG3-NOfFk";a.config.wsc_customDictionaryIds=a.config.wsc_customDictionaryIds||CKEDITOR.config.wsc_customDictionaryIds||"";a.config.wsc_userDictionaryName=a.config.wsc_userDictionaryName||CKEDITOR.config.wsc_userDictionaryName||"";a.config.wsc_customLoaderScript=a.config.wsc_customLoaderScript||CKEDITOR.config.wsc_customLoaderScript;a.config.wsc_interfaceLang=a.config.wsc_interfaceLang;CKEDITOR.config.wsc_cmd=a.config.wsc_cmd||CKEDITOR.config.wsc_cmd||
"spell";CKEDITOR.config.wsc_version="v4.3.0-master-d769233";CKEDITOR.config.wsc_removeGlobalVariable=!0},onLoad:function(a){"moono-lisa"==(CKEDITOR.skinName||a.config.skin)&&CKEDITOR.document.appendStyleSheet(this.path+"skins/"+CKEDITOR.skin.name+"/wsc.css")},init:function(a){var c=CKEDITOR.env;this.parseConfig(a);this.parseApi(a);a.addCommand("checkspell",new CKEDITOR.dialogCommand("checkspell")).modes={wysiwyg:!CKEDITOR.env.opera&&!CKEDITOR.env.air&&document.domain==window.location.hostname&&!(c.ie&&
(8>c.version||c.quirks))};"undefined"==typeof a.plugins.scayt&&a.ui.addButton&&a.ui.addButton("SpellChecker",{label:a.lang.wsc.toolbar,click:function(a){var c=a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?a.container.getText():a.document.getBody().getText();(c=c.replace(/\s/g,""))?a.execCommand("checkspell"):alert("Nothing to check!")},toolbar:"spellchecker,10"});CKEDITOR.dialog.add("checkspell",this.path+(CKEDITOR.env.ie&&7>=CKEDITOR.env.version?"dialogs/wsc_ie.js":window.postMessage?"dialogs/wsc.js":
"dialogs/wsc_ie.js"))}}),CKEDITOR.plugins.add("menubutton",{requires:"button,menu",onLoad:function(){var a=function(a){var b=this._,e=b.menu;b.state!==CKEDITOR.TRISTATE_DISABLED&&(b.on&&e?e.hide():(b.previousState=b.state,e||(e=b.menu=new CKEDITOR.menu(a,{panel:{className:"cke_menu_panel",attributes:{"aria-label":a.lang.common.options}}}),e.onHide=CKEDITOR.tools.bind(function(){var e=this.command?a.getCommand(this.command).modes:this.modes;this.setState(!e||e[a.mode]?b.previousState:CKEDITOR.TRISTATE_DISABLED);
b.on=0},this),this.onMenu&&e.addListener(this.onMenu)),this.setState(CKEDITOR.TRISTATE_ON),b.on=1,setTimeout(function(){e.show(CKEDITOR.document.getById(b.id),4)},0)))};CKEDITOR.ui.menuButton=CKEDITOR.tools.createClass({base:CKEDITOR.ui.button,$:function(c){delete c.panel;this.base(c);this.hasArrow=!0;this.click=a},statics:{handler:{create:function(a){return new CKEDITOR.ui.menuButton(a)}}}})},beforeInit:function(a){a.ui.addHandler(CKEDITOR.UI_MENUBUTTON,CKEDITOR.ui.menuButton.handler)}}),CKEDITOR.UI_MENUBUTTON=
"menubutton","use strict",CKEDITOR.plugins.add("scayt",{requires:"menubutton,dialog",tabToOpen:null,dialogName:"scaytDialog",onLoad:function(a){CKEDITOR.plugins.scayt.onLoadTimestamp=(new Date).getTime();"moono-lisa"==(CKEDITOR.skinName||a.config.skin)&&CKEDITOR.document.appendStyleSheet(this.path+"skins/"+CKEDITOR.skin.name+"/scayt.css");CKEDITOR.document.appendStyleSheet(this.path+"dialogs/dialog.css")},init:function(a){var c=this,b=CKEDITOR.plugins.scayt;this.bindEvents(a);this.parseConfig(a);
this.addRule(a);CKEDITOR.dialog.add(this.dialogName,CKEDITOR.getUrl(this.path+"dialogs/options.js"));this.addMenuItems(a);var e=a.lang.scayt,h=CKEDITOR.env;a.ui.add("Scayt",CKEDITOR.UI_MENUBUTTON,{label:e.text_title,title:a.plugins.wsc?a.lang.wsc.title:e.text_title,modes:{wysiwyg:!(h.ie&&(8>h.version||h.quirks))},toolbar:"spellchecker,20",refresh:function(){var c=a.ui.instances.Scayt.getState();a.scayt&&(c=b.state.scayt[a.name]?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF);a.fire("scaytButtonState",
c)},onRender:function(){var b=this;a.on("scaytButtonState",function(a){void 0!==typeof a.data&&b.setState(a.data)})},onMenu:function(){var c=a.scayt;a.getMenuItem("scaytToggle").label=a.lang.scayt[c&&b.state.scayt[a.name]?"btn_disable":"btn_enable"];var e={scaytToggle:CKEDITOR.TRISTATE_OFF,scaytOptions:c?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,scaytLangs:c?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,scaytDict:c?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,scaytAbout:c?CKEDITOR.TRISTATE_OFF:
CKEDITOR.TRISTATE_DISABLED,WSC:a.plugins.wsc?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED};a.config.scayt_uiTabs[0]||delete e.scaytOptions;a.config.scayt_uiTabs[1]||delete e.scaytLangs;a.config.scayt_uiTabs[2]||delete e.scaytDict;c&&!CKEDITOR.plugins.scayt.isNewUdSupported(c)&&(delete e.scaytDict,a.config.scayt_uiTabs[2]=0,CKEDITOR.plugins.scayt.alarmCompatibilityMessage());return e}});a.contextMenu&&a.addMenuItems&&(a.contextMenu.addListener(function(b,e){var f=a.scayt,d,h;f&&(h=f.getSelectionNode())&&
(d=c.menuGenerator(a,h),f.showBanner("."+a.contextMenu._.definition.panel.className.split(" ").join(" .")));return d}),a.contextMenu._.onHide=CKEDITOR.tools.override(a.contextMenu._.onHide,function(b){return function(){var c=a.scayt;c&&c.hideBanner();return b.apply(this)}}))},addMenuItems:function(a){var c=this,b=CKEDITOR.plugins.scayt;a.addMenuGroup("scaytButton");for(var e=a.config.scayt_contextMenuItemsOrder.split("|"),h=0;h<e.length;h++)e[h]="scayt_"+e[h];if((e=["grayt_description","grayt_suggest",
"grayt_control"].concat(e))&&e.length)for(h=0;h<e.length;h++)a.addMenuGroup(e[h],h-10);a.addCommand("scaytToggle",{exec:function(a){var c=a.scayt;b.state.scayt[a.name]=!b.state.scayt[a.name];!0===b.state.scayt[a.name]?c||b.createScayt(a):c&&b.destroy(a)}});a.addCommand("scaytAbout",{exec:function(a){a.scayt.tabToOpen="about";a.lockSelection();a.openDialog(c.dialogName)}});a.addCommand("scaytOptions",{exec:function(a){a.scayt.tabToOpen="options";a.lockSelection();a.openDialog(c.dialogName)}});a.addCommand("scaytLangs",
{exec:function(a){a.scayt.tabToOpen="langs";a.lockSelection();a.openDialog(c.dialogName)}});a.addCommand("scaytDict",{exec:function(a){a.scayt.tabToOpen="dictionaries";a.lockSelection();a.openDialog(c.dialogName)}});e={scaytToggle:{label:a.lang.scayt.btn_enable,group:"scaytButton",command:"scaytToggle"},scaytAbout:{label:a.lang.scayt.btn_about,group:"scaytButton",command:"scaytAbout"},scaytOptions:{label:a.lang.scayt.btn_options,group:"scaytButton",command:"scaytOptions"},scaytLangs:{label:a.lang.scayt.btn_langs,
group:"scaytButton",command:"scaytLangs"},scaytDict:{label:a.lang.scayt.btn_dictionaries,group:"scaytButton",command:"scaytDict"}};a.plugins.wsc&&(e.WSC={label:a.lang.wsc.toolbar,group:"scaytButton",onClick:function(){var b=CKEDITOR.plugins.scayt,c=a.scayt,e=a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?a.container.getText():a.document.getBody().getText();(e=e.replace(/\s/g,""))?(c&&b.state.scayt[a.name]&&c.setMarkupPaused&&c.setMarkupPaused(!0),a.lockSelection(),a.execCommand("checkspell")):alert("Nothing to check!")}});
a.addMenuItems(e)},bindEvents:function(a){var c=CKEDITOR.plugins.scayt,b=a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE,e=function(){c.destroy(a)},h=function(){!c.state.scayt[a.name]||a.readOnly||a.scayt||c.createScayt(a)},l=function(){var c=a.editable();c.attachListener(c,"focus",function(d){CKEDITOR.plugins.scayt&&!a.scayt&&setTimeout(h,0);d=CKEDITOR.plugins.scayt&&CKEDITOR.plugins.scayt.state.scayt[a.name]&&a.scayt;var c,e;if((b||d)&&a._.savedSelection){d=a._.savedSelection.getSelectedElement();d=
!d&&a._.savedSelection.getRanges();for(var f=0;f<d.length;f++)e=d[f],"string"===typeof e.startContainer.$.nodeValue&&(c=e.startContainer.getText().length,(c<e.startOffset||c<e.endOffset)&&a.unlockSelection(!1))}},this,null,-10)},k=function(){b?a.config.scayt_inlineModeImmediateMarkup?h():(a.on("blur",function(){setTimeout(e,0)}),a.on("focus",h),a.focusManager.hasFocus&&h()):h();l();var c=a.editable();c.attachListener(c,"mousedown",function(b){b=b.data.getTarget();var c=a.widgets&&a.widgets.getByElement(b);
c&&(c.wrapper=b.getAscendant(function(a){return a.hasAttribute("data-cke-widget-wrapper")},!0))},this,null,-10)};a.on("contentDom",k);a.on("beforeCommandExec",function(b){var d=a.scayt,e=!1,g=!1,h=!0;b.data.name in c.options.disablingCommandExec&&"wysiwyg"==a.mode?d&&(c.destroy(a),a.fire("scaytButtonState",CKEDITOR.TRISTATE_DISABLED)):"bold"!==b.data.name&&"italic"!==b.data.name&&"underline"!==b.data.name&&"strike"!==b.data.name&&"subscript"!==b.data.name&&"superscript"!==b.data.name&&"enter"!==b.data.name&&
"cut"!==b.data.name&&"language"!==b.data.name||!d||("cut"===b.data.name&&(h=!1,g=!0),"language"===b.data.name&&(g=e=!0),a.fire("reloadMarkupScayt",{removeOptions:{removeInside:h,forceBookmark:g,language:e},timeout:0}))});a.on("beforeSetMode",function(b){if("source"==b.data){if(b=a.scayt)c.destroy(a),a.fire("scaytButtonState",CKEDITOR.TRISTATE_DISABLED);a.document&&a.document.getBody().removeAttribute("_jquid")}});a.on("afterCommandExec",function(b){"wysiwyg"!=a.mode||"undo"!=b.data.name&&"redo"!=
b.data.name||setTimeout(function(){c.reloadMarkup(a.scayt)},250)});a.on("readOnly",function(b){var d;b&&(d=a.scayt,!0===b.editor.readOnly?d&&d.fire("removeMarkupInDocument",{}):d?c.reloadMarkup(d):"wysiwyg"==b.editor.mode&&!0===c.state.scayt[b.editor.name]&&(c.createScayt(a),b.editor.fire("scaytButtonState",CKEDITOR.TRISTATE_ON)))});a.on("beforeDestroy",e);a.on("setData",function(){e();(a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE||a.plugins.divarea)&&k()},this,null,50);a.on("reloadMarkupScayt",function(b){var d=
b.data&&b.data.removeOptions,e=b.data&&b.data.timeout,g=b.data&&b.data.language,h=a.scayt;h&&setTimeout(function(){g&&(d.selectionNode=a.plugins.language.getCurrentLangElement(a),d.selectionNode=d.selectionNode&&d.selectionNode.$||null);h.removeMarkupInSelectionNode(d);c.reloadMarkup(h)},e||0)});a.on("insertElement",function(){a.fire("reloadMarkupScayt",{removeOptions:{forceBookmark:!0}})},this,null,50);a.on("insertHtml",function(){a.scayt&&a.scayt.setFocused&&a.scayt.setFocused(!0);a.fire("reloadMarkupScayt")},
this,null,50);a.on("insertText",function(){a.scayt&&a.scayt.setFocused&&a.scayt.setFocused(!0);a.fire("reloadMarkupScayt")},this,null,50);a.on("scaytDialogShown",function(b){b.data.selectPage(a.scayt.tabToOpen)})},parseConfig:function(a){var c=CKEDITOR.plugins.scayt;c.replaceOldOptionsNames(a.config);"boolean"!==typeof a.config.scayt_autoStartup&&(a.config.scayt_autoStartup=!1);c.state.scayt[a.name]=a.config.scayt_autoStartup;"boolean"!==typeof a.config.grayt_autoStartup&&(a.config.grayt_autoStartup=
!1);"boolean"!==typeof a.config.scayt_inlineModeImmediateMarkup&&(a.config.scayt_inlineModeImmediateMarkup=!1);c.state.grayt[a.name]=a.config.grayt_autoStartup;a.config.scayt_contextCommands||(a.config.scayt_contextCommands="ignoreall|add");a.config.scayt_contextMenuItemsOrder||(a.config.scayt_contextMenuItemsOrder="suggest|moresuggest|control");a.config.scayt_sLang||(a.config.scayt_sLang="en_US");if(void 0===a.config.scayt_maxSuggestions||"number"!=typeof a.config.scayt_maxSuggestions||0>a.config.scayt_maxSuggestions)a.config.scayt_maxSuggestions=
5;if(void 0===a.config.scayt_minWordLength||"number"!=typeof a.config.scayt_minWordLength||1>a.config.scayt_minWordLength)a.config.scayt_minWordLength=4;if(void 0===a.config.scayt_customDictionaryIds||"string"!==typeof a.config.scayt_customDictionaryIds)a.config.scayt_customDictionaryIds="";if(void 0===a.config.scayt_userDictionaryName||"string"!==typeof a.config.scayt_userDictionaryName)a.config.scayt_userDictionaryName=null;if("string"===typeof a.config.scayt_uiTabs&&3===a.config.scayt_uiTabs.split(",").length){var b=
[],e=[];a.config.scayt_uiTabs=a.config.scayt_uiTabs.split(",");CKEDITOR.tools.search(a.config.scayt_uiTabs,function(a){1===Number(a)||0===Number(a)?(e.push(!0),b.push(Number(a))):e.push(!1)});null===CKEDITOR.tools.search(e,!1)?a.config.scayt_uiTabs=b:a.config.scayt_uiTabs=[1,1,1]}else a.config.scayt_uiTabs=[1,1,1];"string"!=typeof a.config.scayt_serviceProtocol&&(a.config.scayt_serviceProtocol=null);"string"!=typeof a.config.scayt_serviceHost&&(a.config.scayt_serviceHost=null);"string"!=typeof a.config.scayt_servicePort&&
(a.config.scayt_servicePort=null);"string"!=typeof a.config.scayt_servicePath&&(a.config.scayt_servicePath=null);a.config.scayt_moreSuggestions||(a.config.scayt_moreSuggestions="on");"string"!==typeof a.config.scayt_customerId&&(a.config.scayt_customerId="1:WvF0D4-UtPqN1-43nkD4-NKvUm2-daQqk3-LmNiI-z7Ysb4-mwry24-T8YrS3-Q2tpq2");"string"!==typeof a.config.scayt_customPunctuation&&(a.config.scayt_customPunctuation="-");"string"!==typeof a.config.scayt_srcUrl&&(c=document.location.protocol,c=-1!=c.search(/https?:/)?
c:"http:",a.config.scayt_srcUrl=c+"//svc.webspellchecker.net/spellcheck31/lf/scayt3/ckscayt/ckscayt.js");"boolean"!==typeof CKEDITOR.config.scayt_handleCheckDirty&&(CKEDITOR.config.scayt_handleCheckDirty=!0);"boolean"!==typeof CKEDITOR.config.scayt_handleUndoRedo&&(CKEDITOR.config.scayt_handleUndoRedo=!0);CKEDITOR.config.scayt_handleUndoRedo=CKEDITOR.plugins.undo?CKEDITOR.config.scayt_handleUndoRedo:!1;"boolean"!==typeof a.config.scayt_multiLanguageMode&&(a.config.scayt_multiLanguageMode=!1);"object"!==
typeof a.config.scayt_multiLanguageStyles&&(a.config.scayt_multiLanguageStyles={});a.config.scayt_ignoreAllCapsWords&&"boolean"!==typeof a.config.scayt_ignoreAllCapsWords&&(a.config.scayt_ignoreAllCapsWords=!1);a.config.scayt_ignoreDomainNames&&"boolean"!==typeof a.config.scayt_ignoreDomainNames&&(a.config.scayt_ignoreDomainNames=!1);a.config.scayt_ignoreWordsWithMixedCases&&"boolean"!==typeof a.config.scayt_ignoreWordsWithMixedCases&&(a.config.scayt_ignoreWordsWithMixedCases=!1);a.config.scayt_ignoreWordsWithNumbers&&
"boolean"!==typeof a.config.scayt_ignoreWordsWithNumbers&&(a.config.scayt_ignoreWordsWithNumbers=!1);if(a.config.scayt_disableOptionsStorage){var c=CKEDITOR.tools.isArray(a.config.scayt_disableOptionsStorage)?a.config.scayt_disableOptionsStorage:"string"===typeof a.config.scayt_disableOptionsStorage?[a.config.scayt_disableOptionsStorage]:void 0,h="all options lang ignore-all-caps-words ignore-domain-names ignore-words-with-mixed-cases ignore-words-with-numbers".split(" "),l=["lang","ignore-all-caps-words",
"ignore-domain-names","ignore-words-with-mixed-cases","ignore-words-with-numbers"],k=CKEDITOR.tools.search,f=CKEDITOR.tools.indexOf;a.config.scayt_disableOptionsStorage=function(a){for(var b=[],c=0;c<a.length;c++){var e=a[c],p=!!k(a,"options");if(!k(h,e)||p&&k(l,function(a){if("lang"===a)return!1}))return;k(l,e)&&l.splice(f(l,e),1);if("all"===e||p&&k(a,"lang"))return[];"options"===e&&(l=["lang"])}return b=b.concat(l)}(c)}},addRule:function(a){var c=CKEDITOR.plugins.scayt,b=a.dataProcessor,e=b&&b.htmlFilter,
h=a._.elementsPath&&a._.elementsPath.filters,b=b&&b.dataFilter,l=a.addRemoveFormatFilter,k=function(b){if(a.scayt&&(b.hasAttribute(c.options.data_attribute_name)||b.hasAttribute(c.options.problem_grammar_data_attribute)))return!1},f=function(b){var e=!0;a.scayt&&(b.hasAttribute(c.options.data_attribute_name)||b.hasAttribute(c.options.problem_grammar_data_attribute))&&(e=!1);return e};h&&h.push(k);b&&b.addRules({elements:{span:function(a){var b=a.hasClass(c.options.misspelled_word_class)&&a.attributes[c.options.data_attribute_name],
e=a.hasClass(c.options.problem_grammar_class)&&a.attributes[c.options.problem_grammar_data_attribute];c&&(b||e)&&delete a.name;return a}}});e&&e.addRules({elements:{span:function(a){var b=a.hasClass(c.options.misspelled_word_class)&&a.attributes[c.options.data_attribute_name],e=a.hasClass(c.options.problem_grammar_class)&&a.attributes[c.options.problem_grammar_data_attribute];c&&(b||e)&&delete a.name;return a}}});l&&l.call(a,f)},scaytMenuDefinition:function(a){var c=this;a=a.scayt;return{scayt:{scayt_ignore:{label:a.getLocal("btn_ignore"),
group:"scayt_control",order:1,exec:function(a){a.scayt.ignoreWord()}},scayt_ignoreall:{label:a.getLocal("btn_ignoreAll"),group:"scayt_control",order:2,exec:function(a){a.scayt.ignoreAllWords()}},scayt_add:{label:a.getLocal("btn_addWord"),group:"scayt_control",order:3,exec:function(a){var c=a.scayt;setTimeout(function(){c.addWordToUserDictionary()},10)}},scayt_option:{label:a.getLocal("btn_options"),group:"scayt_control",order:4,exec:function(a){a.scayt.tabToOpen="options";a.lockSelection();a.openDialog(c.dialogName)},
verification:function(a){return 1==a.config.scayt_uiTabs[0]?!0:!1}},scayt_language:{label:a.getLocal("btn_langs"),group:"scayt_control",order:5,exec:function(a){a.scayt.tabToOpen="langs";a.lockSelection();a.openDialog(c.dialogName)},verification:function(a){return 1==a.config.scayt_uiTabs[1]?!0:!1}},scayt_dictionary:{label:a.getLocal("btn_dictionaries"),group:"scayt_control",order:6,exec:function(a){a.scayt.tabToOpen="dictionaries";a.lockSelection();a.openDialog(c.dialogName)},verification:function(a){return 1==
a.config.scayt_uiTabs[2]?!0:!1}},scayt_about:{label:a.getLocal("btn_about"),group:"scayt_control",order:7,exec:function(a){a.scayt.tabToOpen="about";a.lockSelection();a.openDialog(c.dialogName)}}},grayt:{grayt_problemdescription:{label:"Grammar problem description",group:"grayt_description",order:1,state:CKEDITOR.TRISTATE_DISABLED,exec:function(a){}},grayt_ignore:{label:a.getLocal("btn_ignore"),group:"grayt_control",order:2,exec:function(a){a.scayt.ignorePhrase()}},grayt_ignoreall:{label:a.getLocal("btn_ignoreAll"),
group:"grayt_control",order:3,exec:function(a){a.scayt.ignoreAllPhrases()}}}}},buildSuggestionMenuItems:function(a,c,b){var e={},h={},l=b?"word":"phrase",k=b?"startGrammarCheck":"startSpellCheck",f=a.scayt;if(0<c.length&&"no_any_suggestions"!==c[0])if(b)for(b=0;b<c.length;b++){var d="scayt_suggest_"+CKEDITOR.plugins.scayt.suggestions[b].replace(" ","_");a.addCommand(d,this.createCommand(CKEDITOR.plugins.scayt.suggestions[b],l,k));b<a.config.scayt_maxSuggestions?(a.addMenuItem(d,{label:c[b],command:d,
group:"scayt_suggest",order:b+1}),e[d]=CKEDITOR.TRISTATE_OFF):(a.addMenuItem(d,{label:c[b],command:d,group:"scayt_moresuggest",order:b+1}),h[d]=CKEDITOR.TRISTATE_OFF,"on"===a.config.scayt_moreSuggestions&&(a.addMenuItem("scayt_moresuggest",{label:f.getLocal("btn_moreSuggestions"),group:"scayt_moresuggest",order:10,getItems:function(){return h}}),e.scayt_moresuggest=CKEDITOR.TRISTATE_OFF))}else for(b=0;b<c.length;b++)d="grayt_suggest_"+CKEDITOR.plugins.scayt.suggestions[b].replace(" ","_"),a.addCommand(d,
this.createCommand(CKEDITOR.plugins.scayt.suggestions[b],l,k)),a.addMenuItem(d,{label:c[b],command:d,group:"grayt_suggest",order:b+1}),e[d]=CKEDITOR.TRISTATE_OFF;else e.no_scayt_suggest=CKEDITOR.TRISTATE_DISABLED,a.addCommand("no_scayt_suggest",{exec:function(){}}),a.addMenuItem("no_scayt_suggest",{label:f.getLocal("btn_noSuggestions")||"no_scayt_suggest",command:"no_scayt_suggest",group:"scayt_suggest",order:0});return e},menuGenerator:function(a,c){var b=a.scayt,e=this.scaytMenuDefinition(a),h=
{},l=a.config.scayt_contextCommands.split("|"),k=c.getAttribute(b.getLangAttribute())||b.getLang(),f,d,m;f=b.isScaytNode(c);d=b.isGraytNode(c);f?(e=e.scayt,h=c.getAttribute(b.getScaytNodeAttributeName()),b.fire("getSuggestionsList",{lang:k,word:h}),h=this.buildSuggestionMenuItems(a,CKEDITOR.plugins.scayt.suggestions,f)):d&&(e=e.grayt,h=c.getAttribute(b.getGraytNodeAttributeName()),m=b.getProblemDescriptionText(h,k),e.grayt_problemdescription&&m&&(e.grayt_problemdescription.label=m),b.fire("getGrammarSuggestionsList",
{lang:k,phrase:h}),h=this.buildSuggestionMenuItems(a,CKEDITOR.plugins.scayt.suggestions,f));if(f&&"off"==a.config.scayt_contextCommands)return h;for(var g in e)f&&-1==CKEDITOR.tools.indexOf(l,g.replace("scayt_",""))&&"all"!=a.config.scayt_contextCommands||d&&"grayt_problemdescription"!==g&&-1==CKEDITOR.tools.indexOf(l,g.replace("grayt_",""))&&"all"!=a.config.scayt_contextCommands||(h[g]="undefined"!=typeof e[g].state?e[g].state:CKEDITOR.TRISTATE_OFF,"function"!==typeof e[g].verification||e[g].verification(a)||
delete h[g],a.addCommand(g,{exec:e[g].exec}),a.addMenuItem(g,{label:a.lang.scayt[e[g].label]||e[g].label,command:g,group:e[g].group,order:e[g].order}));return h},createCommand:function(a,c,b){return{exec:function(e){e=e.scayt;var h={};h[c]=a;e.replaceSelectionNode(h);"startGrammarCheck"===b&&e.removeMarkupInSelectionNode({grammarOnly:!0});e.fire(b)}}}}),CKEDITOR.plugins.scayt={charsToObserve:[{charName:"cke-fillingChar",charCode:function(){var a=CKEDITOR.version.match(/^\d(\.\d*)*/),a=a&&a[0],c;if(a){c=
"4.5.7";var b,a=a.replace(/\./g,"");c=c.replace(/\./g,"");b=a.length-c.length;b=0<=b?b:0;c=parseInt(a)>=parseInt(c)*Math.pow(10,b)}return c?Array(7).join(String.fromCharCode(8203)):String.fromCharCode(8203)}()}],onLoadTimestamp:"",state:{scayt:{},grayt:{}},warningCounter:0,suggestions:[],options:{disablingCommandExec:{source:!0,newpage:!0,templates:!0},data_attribute_name:"data-scayt-word",misspelled_word_class:"scayt-misspell-word",problem_grammar_data_attribute:"data-grayt-phrase",problem_grammar_class:"gramm-problem"},
backCompatibilityMap:{scayt_service_protocol:"scayt_serviceProtocol",scayt_service_host:"scayt_serviceHost",scayt_service_port:"scayt_servicePort",scayt_service_path:"scayt_servicePath",scayt_customerid:"scayt_customerId"},alarmCompatibilityMessage:function(){5>this.warningCounter&&(console.warn("You are using the latest version of SCAYT plugin for CKEditor with the old application version. In order to have access to the newest features, it is recommended to upgrade the application version to latest one as well. Contact us for more details at support@webspellchecker.net."),
this.warningCounter+=1)},isNewUdSupported:function(a){return a.getUserDictionary?!0:!1},reloadMarkup:function(a){var c;a&&(c=a.getScaytLangList(),a.reloadMarkup?a.reloadMarkup():(this.alarmCompatibilityMessage(),c&&c.ltr&&c.rtl&&a.fire("startSpellCheck, startGrammarCheck")))},replaceOldOptionsNames:function(a){for(var c in a)c in this.backCompatibilityMap&&(a[this.backCompatibilityMap[c]]=a[c],delete a[c])},createScayt:function(a){var c=this,b=CKEDITOR.plugins.scayt;this.loadScaytLibrary(a,function(a){function h(a){return new SCAYT.CKSCAYT(a,
function(){},function(){})}var l=a.window&&a.window.getFrame()||a.editable();if(l){l={lang:a.config.scayt_sLang,container:l.$,customDictionary:a.config.scayt_customDictionaryIds,userDictionaryName:a.config.scayt_userDictionaryName,localization:a.langCode,customer_id:a.config.scayt_customerId,customPunctuation:a.config.scayt_customPunctuation,debug:a.config.scayt_debug,data_attribute_name:c.options.data_attribute_name,misspelled_word_class:c.options.misspelled_word_class,problem_grammar_data_attribute:c.options.problem_grammar_data_attribute,
problem_grammar_class:c.options.problem_grammar_class,"options-to-restore":a.config.scayt_disableOptionsStorage,focused:a.editable().hasFocus,ignoreElementsRegex:a.config.scayt_elementsToIgnore,ignoreGraytElementsRegex:a.config.grayt_elementsToIgnore,minWordLength:a.config.scayt_minWordLength,multiLanguageMode:a.config.scayt_multiLanguageMode,multiLanguageStyles:a.config.scayt_multiLanguageStyles,graytAutoStartup:a.config.grayt_autoStartup,charsToObserve:b.charsToObserve};a.config.scayt_serviceProtocol&&
(l.service_protocol=a.config.scayt_serviceProtocol);a.config.scayt_serviceHost&&(l.service_host=a.config.scayt_serviceHost);a.config.scayt_servicePort&&(l.service_port=a.config.scayt_servicePort);a.config.scayt_servicePath&&(l.service_path=a.config.scayt_servicePath);"boolean"===typeof a.config.scayt_ignoreAllCapsWords&&(l["ignore-all-caps-words"]=a.config.scayt_ignoreAllCapsWords);"boolean"===typeof a.config.scayt_ignoreDomainNames&&(l["ignore-domain-names"]=a.config.scayt_ignoreDomainNames);"boolean"===
typeof a.config.scayt_ignoreWordsWithMixedCases&&(l["ignore-words-with-mixed-cases"]=a.config.scayt_ignoreWordsWithMixedCases);"boolean"===typeof a.config.scayt_ignoreWordsWithNumbers&&(l["ignore-words-with-numbers"]=a.config.scayt_ignoreWordsWithNumbers);var k;try{k=h(l)}catch(f){c.alarmCompatibilityMessage(),delete l.charsToObserve,k=h(l)}k.subscribe("suggestionListSend",function(a){for(var b={},c=[],e=0;e<a.suggestionList.length;e++)b["word_"+a.suggestionList[e]]||(b["word_"+a.suggestionList[e]]=
a.suggestionList[e],c.push(a.suggestionList[e]));CKEDITOR.plugins.scayt.suggestions=c});k.subscribe("selectionIsChanged",function(b){a.getSelection().isLocked&&a.lockSelection()});k.subscribe("graytStateChanged",function(d){b.state.grayt[a.name]=d.state});k.addMarkupHandler&&k.addMarkupHandler(function(b){var c=a.editable(),f=c.getCustomData(b.charName);f&&(f.$=b.node,c.setCustomData(b.charName,f))});a.scayt=k;a.fire("scaytButtonState",a.readOnly?CKEDITOR.TRISTATE_DISABLED:CKEDITOR.TRISTATE_ON)}else b.state.scayt[a.name]=
!1})},destroy:function(a){a.scayt&&a.scayt.destroy();delete a.scayt;a.fire("scaytButtonState",CKEDITOR.TRISTATE_OFF)},loadScaytLibrary:function(a,c){var b,e=function(){CKEDITOR.fireOnce("scaytReady");a.scayt||"function"===typeof c&&c(a)};"undefined"===typeof window.SCAYT||"function"!==typeof window.SCAYT.CKSCAYT?(b=a.config.scayt_srcUrl+"?"+this.onLoadTimestamp,CKEDITOR.scriptLoader.load(b,function(a){a&&e()})):window.SCAYT&&"function"===typeof window.SCAYT.CKSCAYT&&e()}},CKEDITOR.on("dialogDefinition",
function(a){var c=a.data.name;a=a.data.definition.dialog;if("scaytDialog"===c)a.on("cancel",function(a){return!1},this,null,-1);if("checkspell"===c)a.on("cancel",function(a){a=a.sender&&a.sender.getParentEditor();var c=CKEDITOR.plugins.scayt,h=a.scayt;h&&c.state.scayt[a.name]&&h.setMarkupPaused&&h.setMarkupPaused(!1);a.unlockSelection()},this,null,-2);if("link"===c)a.on("ok",function(a){var c=a.sender&&a.sender.getParentEditor();c&&setTimeout(function(){c.fire("reloadMarkupScayt",{removeOptions:{removeInside:!0,
forceBookmark:!0},timeout:0})},0)});if("replace"===c)a.on("hide",function(a){a=a.sender&&a.sender.getParentEditor();var c=CKEDITOR.plugins.scayt,h=a.scayt;a&&setTimeout(function(){h&&(h.fire("removeMarkupInDocument",{}),c.reloadMarkup(h))},0)})}),CKEDITOR.on("scaytReady",function(){if(!0===CKEDITOR.config.scayt_handleCheckDirty){var a=CKEDITOR.editor.prototype;a.checkDirty=CKEDITOR.tools.override(a.checkDirty,function(a){return function(){var c=null,h=this.scayt;if(CKEDITOR.plugins.scayt&&CKEDITOR.plugins.scayt.state.scayt[this.name]&&
this.scayt){if(c="ready"==this.status)var l=h.removeMarkupFromString(this.getSnapshot()),h=h.removeMarkupFromString(this._.previousValue),c=c&&h!==l}else c=a.call(this);return c}});a.resetDirty=CKEDITOR.tools.override(a.resetDirty,function(a){return function(){var c=this.scayt;CKEDITOR.plugins.scayt&&CKEDITOR.plugins.scayt.state.scayt[this.name]&&this.scayt?this._.previousValue=c.removeMarkupFromString(this.getSnapshot()):a.call(this)}})}if(!0===CKEDITOR.config.scayt_handleUndoRedo){var a=CKEDITOR.plugins.undo.Image.prototype,
c="function"==typeof a.equalsContent?"equalsContent":"equals";a[c]=CKEDITOR.tools.override(a[c],function(a){return function(c){var h=c.editor.scayt,l=this.contents,k=c.contents,f=null;CKEDITOR.plugins.scayt&&CKEDITOR.plugins.scayt.state.scayt[c.editor.name]&&c.editor.scayt&&(this.contents=h.removeMarkupFromString(l)||"",c.contents=h.removeMarkupFromString(k)||"");f=a.apply(this,arguments);this.contents=l;c.contents=k;return f}})}}),"use strict",function(){function a(a,b){CKEDITOR.tools.extend(this,
{editor:a,editable:a.editable(),doc:a.document,win:a.window},b,!0);this.inline=this.editable.isInline();this.inline||(this.frame=this.win.getFrame());this.target=this[this.inline?"editable":"doc"]}function c(a,b){CKEDITOR.tools.extend(this,b,{editor:a},!0)}function b(a,b){var c=a.editable();CKEDITOR.tools.extend(this,{editor:a,editable:c,inline:c.isInline(),doc:a.document,win:a.window,container:CKEDITOR.document.getBody(),winTop:CKEDITOR.document.getWindow()},b,!0);this.hidden={};this.visible={};
this.inline||(this.frame=this.win.getFrame());this.queryViewport();var e=CKEDITOR.tools.bind(this.queryViewport,this),f=CKEDITOR.tools.bind(this.hideVisible,this),k=CKEDITOR.tools.bind(this.removeAll,this);c.attachListener(this.winTop,"resize",e);c.attachListener(this.winTop,"scroll",e);c.attachListener(this.winTop,"resize",f);c.attachListener(this.win,"scroll",f);c.attachListener(this.inline?c:this.frame,"mouseout",function(a){var b=a.data.$.clientX;a=a.data.$.clientY;this.queryViewport();(b<=this.rect.left||
b>=this.rect.right||a<=this.rect.top||a>=this.rect.bottom)&&this.hideVisible();(0>=b||b>=this.winTopPane.width||0>=a||a>=this.winTopPane.height)&&this.hideVisible()},this);c.attachListener(a,"resize",e);c.attachListener(a,"mode",k);a.on("destroy",k);this.lineTpl=(new CKEDITOR.template('\x3cdiv data-cke-lineutils-line\x3d"1" class\x3d"cke_reset_all" style\x3d"{lineStyle}"\x3e\x3cspan style\x3d"{tipLeftStyle}"\x3e\x26nbsp;\x3c/span\x3e\x3cspan style\x3d"{tipRightStyle}"\x3e\x26nbsp;\x3c/span\x3e\x3c/div\x3e')).output({lineStyle:CKEDITOR.tools.writeCssText(CKEDITOR.tools.extend({},
l,this.lineStyle,!0)),tipLeftStyle:CKEDITOR.tools.writeCssText(CKEDITOR.tools.extend({},h,{left:"0px","border-left-color":"red","border-width":"6px 0 6px 6px"},this.tipCss,this.tipLeftStyle,!0)),tipRightStyle:CKEDITOR.tools.writeCssText(CKEDITOR.tools.extend({},h,{right:"0px","border-right-color":"red","border-width":"6px 6px 6px 0"},this.tipCss,this.tipRightStyle,!0))})}function e(a){var b;if(b=a&&a.type==CKEDITOR.NODE_ELEMENT)b=!(k[a.getComputedStyle("float")]||k[a.getAttribute("align")]);return b&&
!f[a.getComputedStyle("position")]}CKEDITOR.plugins.add("lineutils");CKEDITOR.LINEUTILS_BEFORE=1;CKEDITOR.LINEUTILS_AFTER=2;CKEDITOR.LINEUTILS_INSIDE=4;a.prototype={start:function(a){var b=this,c=this.editor,e=this.doc,f,h,k,l,t=CKEDITOR.tools.eventsBuffer(50,function(){c.readOnly||"wysiwyg"!=c.mode||(b.relations={},(h=e.$.elementFromPoint(k,l))&&h.nodeType&&(f=new CKEDITOR.dom.element(h),b.traverseSearch(f),isNaN(k+l)||b.pixelSearch(f,k,l),a&&a(b.relations,k,l)))});this.listener=this.editable.attachListener(this.target,
"mousemove",function(a){k=a.data.$.clientX;l=a.data.$.clientY;t.input()});this.editable.attachListener(this.inline?this.editable:this.frame,"mouseout",function(){t.reset()})},stop:function(){this.listener&&this.listener.removeListener()},getRange:function(){var a={};a[CKEDITOR.LINEUTILS_BEFORE]=CKEDITOR.POSITION_BEFORE_START;a[CKEDITOR.LINEUTILS_AFTER]=CKEDITOR.POSITION_AFTER_END;a[CKEDITOR.LINEUTILS_INSIDE]=CKEDITOR.POSITION_AFTER_START;return function(b){var c=this.editor.createRange();c.moveToPosition(this.relations[b.uid].element,
a[b.type]);return c}}(),store:function(){function a(b,c,d){var e=b.getUniqueId();e in d?d[e].type|=c:d[e]={element:b,type:c}}return function(b,c){var f;c&CKEDITOR.LINEUTILS_AFTER&&e(f=b.getNext())&&f.isVisible()&&(a(f,CKEDITOR.LINEUTILS_BEFORE,this.relations),c^=CKEDITOR.LINEUTILS_AFTER);c&CKEDITOR.LINEUTILS_INSIDE&&e(f=b.getFirst())&&f.isVisible()&&(a(f,CKEDITOR.LINEUTILS_BEFORE,this.relations),c^=CKEDITOR.LINEUTILS_INSIDE);a(b,c,this.relations)}}(),traverseSearch:function(a){var b,c,f;do if(f=a.$["data-cke-expando"],
!(f&&f in this.relations)){if(a.equals(this.editable))break;if(e(a))for(b in this.lookups)(c=this.lookups[b](a))&&this.store(a,c)}while((!a||a.type!=CKEDITOR.NODE_ELEMENT||"true"!=a.getAttribute("contenteditable"))&&(a=a.getParent()))},pixelSearch:function(){function a(c,d,f,h,k){for(var l=0,t;k(f);){f+=h;if(25==++l)break;if(t=this.doc.$.elementFromPoint(d,f))if(t==c)l=0;else if(b(c,t)&&(l=0,e(t=new CKEDITOR.dom.element(t))))return t}}var b=CKEDITOR.env.ie||CKEDITOR.env.webkit?function(a,b){return a.contains(b)}:
function(a,b){return!!(a.compareDocumentPosition(b)&16)};return function(b,c,f){var h=this.win.getViewPaneSize().height,k=a.call(this,b.$,c,f,-1,function(a){return 0<a});c=a.call(this,b.$,c,f,1,function(a){return a<h});if(k)for(this.traverseSearch(k);!k.getParent().equals(b);)k=k.getParent();if(c)for(this.traverseSearch(c);!c.getParent().equals(b);)c=c.getParent();for(;k||c;){k&&(k=k.getNext(e));if(!k||k.equals(c))break;this.traverseSearch(k);c&&(c=c.getPrevious(e));if(!c||c.equals(k))break;this.traverseSearch(c)}}}(),
greedySearch:function(){this.relations={};for(var a=this.editable.getElementsByTag("*"),b=0,c,f,h;c=a.getItem(b++);)if(!c.equals(this.editable)&&c.type==CKEDITOR.NODE_ELEMENT&&(c.hasAttribute("contenteditable")||!c.isReadOnly())&&e(c)&&c.isVisible())for(h in this.lookups)(f=this.lookups[h](c))&&this.store(c,f);return this.relations}};c.prototype={locate:function(){function a(b,c){var d=b.element[c===CKEDITOR.LINEUTILS_BEFORE?"getPrevious":"getNext"]();return d&&e(d)?(b.siblingRect=d.getClientRect(),
c==CKEDITOR.LINEUTILS_BEFORE?(b.siblingRect.bottom+b.elementRect.top)/2:(b.elementRect.bottom+b.siblingRect.top)/2):c==CKEDITOR.LINEUTILS_BEFORE?b.elementRect.top:b.elementRect.bottom}return function(b){var c;this.locations={};for(var e in b)c=b[e],c.elementRect=c.element.getClientRect(),c.type&CKEDITOR.LINEUTILS_BEFORE&&this.store(e,CKEDITOR.LINEUTILS_BEFORE,a(c,CKEDITOR.LINEUTILS_BEFORE)),c.type&CKEDITOR.LINEUTILS_AFTER&&this.store(e,CKEDITOR.LINEUTILS_AFTER,a(c,CKEDITOR.LINEUTILS_AFTER)),c.type&
CKEDITOR.LINEUTILS_INSIDE&&this.store(e,CKEDITOR.LINEUTILS_INSIDE,(c.elementRect.top+c.elementRect.bottom)/2);return this.locations}}(),sort:function(){var a,b,c,e;return function(f,h){a=this.locations;b=[];for(var k in a)for(var l in a[k])if(c=Math.abs(f-a[k][l]),b.length){for(e=0;e<b.length;e++)if(c<b[e].dist){b.splice(e,0,{uid:+k,type:l,dist:c});break}e==b.length&&b.push({uid:+k,type:l,dist:c})}else b.push({uid:+k,type:l,dist:c});return"undefined"!=typeof h?b.slice(0,h):b}}(),store:function(a,
b,c){this.locations[a]||(this.locations[a]={});this.locations[a][b]=c}};var h={display:"block",width:"0px",height:"0px","border-color":"transparent","border-style":"solid",position:"absolute",top:"-6px"},l={height:"0px","border-top":"1px dashed red",position:"absolute","z-index":9999};b.prototype={removeAll:function(){for(var a in this.hidden)this.hidden[a].remove(),delete this.hidden[a];for(a in this.visible)this.visible[a].remove(),delete this.visible[a]},hideLine:function(a){var b=a.getUniqueId();
a.hide();this.hidden[b]=a;delete this.visible[b]},showLine:function(a){var b=a.getUniqueId();a.show();this.visible[b]=a;delete this.hidden[b]},hideVisible:function(){for(var a in this.visible)this.hideLine(this.visible[a])},placeLine:function(a,b){var c,e,f;if(c=this.getStyle(a.uid,a.type)){for(f in this.visible)if(this.visible[f].getCustomData("hash")!==this.hash){e=this.visible[f];break}if(!e)for(f in this.hidden)if(this.hidden[f].getCustomData("hash")!==this.hash){this.showLine(e=this.hidden[f]);
break}e||this.showLine(e=this.addLine());e.setCustomData("hash",this.hash);this.visible[e.getUniqueId()]=e;e.setStyles(c);b&&b(e)}},getStyle:function(a,b){var c=this.relations[a],e=this.locations[a][b],f={};f.width=c.siblingRect?Math.max(c.siblingRect.width,c.elementRect.width):c.elementRect.width;f.top=this.inline?e+this.winTopScroll.y-this.rect.relativeY:this.rect.top+this.winTopScroll.y+e;if(f.top-this.winTopScroll.y<this.rect.top||f.top-this.winTopScroll.y>this.rect.bottom)return!1;this.inline?
f.left=c.elementRect.left-this.rect.relativeX:(0<c.elementRect.left?f.left=this.rect.left+c.elementRect.left:(f.width+=c.elementRect.left,f.left=this.rect.left),0<(c=f.left+f.width-(this.rect.left+this.winPane.width))&&(f.width-=c));f.left+=this.winTopScroll.x;for(var h in f)f[h]=CKEDITOR.tools.cssLength(f[h]);return f},addLine:function(){var a=CKEDITOR.dom.element.createFromHtml(this.lineTpl);a.appendTo(this.container);return a},prepare:function(a,b){this.relations=a;this.locations=b;this.hash=Math.random()},
cleanup:function(){var a,b;for(b in this.visible)a=this.visible[b],a.getCustomData("hash")!==this.hash&&this.hideLine(a)},queryViewport:function(){this.winPane=this.win.getViewPaneSize();this.winTopScroll=this.winTop.getScrollPosition();this.winTopPane=this.winTop.getViewPaneSize();this.rect=this.getClientRect(this.inline?this.editable:this.frame)},getClientRect:function(a){a=a.getClientRect();var b=this.container.getDocumentPosition(),c=this.container.getComputedStyle("position");a.relativeX=a.relativeY=
0;"static"!=c&&(a.relativeY=b.y,a.relativeX=b.x,a.top-=a.relativeY,a.bottom-=a.relativeY,a.left-=a.relativeX,a.right-=a.relativeX);return a}};var k={left:1,right:1,center:1},f={absolute:1,fixed:1};CKEDITOR.plugins.lineutils={finder:a,locator:c,liner:b}}(),function(){function a(a){return a.getName&&!a.hasAttribute("data-cke-temp")}CKEDITOR.plugins.add("widgetselection",{init:function(a){if(CKEDITOR.env.webkit){var b=CKEDITOR.plugins.widgetselection;a.on("contentDom",function(a){a=a.editor;var c=a.document,
l=a.editable();l.attachListener(c,"keydown",function(a){var c=a.data.$;65==a.data.getKey()&&(CKEDITOR.env.mac&&c.metaKey||!CKEDITOR.env.mac&&c.ctrlKey)&&CKEDITOR.tools.setTimeout(function(){b.addFillers(l)||b.removeFillers(l)},0)},null,null,-1);a.on("selectionCheck",function(a){b.removeFillers(a.editor.editable())});a.on("paste",function(a){a.data.dataValue=b.cleanPasteData(a.data.dataValue)});"selectall"in a.plugins&&b.addSelectAllIntegration(a)})}}});CKEDITOR.plugins.widgetselection={startFiller:null,
endFiller:null,fillerAttribute:"data-cke-filler-webkit",fillerContent:"\x26nbsp;",fillerTagName:"div",addFillers:function(c){var b=c.editor;if(!this.isWholeContentSelected(c)&&0<c.getChildCount()){var e=c.getFirst(a),h=c.getLast(a);e&&e.type==CKEDITOR.NODE_ELEMENT&&!e.isEditable()&&(this.startFiller=this.createFiller(),c.append(this.startFiller,1));h&&h.type==CKEDITOR.NODE_ELEMENT&&!h.isEditable()&&(this.endFiller=this.createFiller(!0),c.append(this.endFiller,0));if(this.hasFiller(c))return b=b.createRange(),
b.selectNodeContents(c),b.select(),!0}return!1},removeFillers:function(a){if(this.hasFiller(a)&&!this.isWholeContentSelected(a)){var b=a.findOne(this.fillerTagName+"["+this.fillerAttribute+"\x3dstart]"),e=a.findOne(this.fillerTagName+"["+this.fillerAttribute+"\x3dend]");this.startFiller&&b&&this.startFiller.equals(b)?this.removeFiller(this.startFiller,a):this.startFiller=b;this.endFiller&&e&&this.endFiller.equals(e)?this.removeFiller(this.endFiller,a):this.endFiller=e}},cleanPasteData:function(a){a&&
a.length&&(a=a.replace(this.createFillerRegex(),"").replace(this.createFillerRegex(!0),""));return a},isWholeContentSelected:function(a){var b=a.editor.getSelection().getRanges()[0];return!b||b&&b.collapsed?!1:(b=b.clone(),b.enlarge(CKEDITOR.ENLARGE_ELEMENT),!!(b&&a&&b.startContainer&&b.endContainer&&0===b.startOffset&&b.endOffset===a.getChildCount()&&b.startContainer.equals(a)&&b.endContainer.equals(a)))},hasFiller:function(a){return 0<a.find(this.fillerTagName+"["+this.fillerAttribute+"]").count()},
createFiller:function(a){var b=new CKEDITOR.dom.element(this.fillerTagName);b.setHtml(this.fillerContent);b.setAttribute(this.fillerAttribute,a?"end":"start");b.setAttribute("data-cke-temp",1);b.setStyles({display:"block",width:0,height:0,padding:0,border:0,margin:0,position:"absolute",top:0,left:"-9999px",opacity:0,overflow:"hidden"});return b},removeFiller:function(a,b){if(a){var e=b.editor,h=b.editor.getSelection().getRanges()[0].startPath(),l=e.createRange(),k,f;h.contains(a)&&(k=a.getHtml(),
f=!0);h="start"==a.getAttribute(this.fillerAttribute);a.remove();k&&0<k.length&&k!=this.fillerContent?(b.insertHtmlIntoRange(k,e.getSelection().getRanges()[0]),l.setStartAt(b.getChild(b.getChildCount()-1),CKEDITOR.POSITION_BEFORE_END),e.getSelection().selectRanges([l])):f&&(h?l.setStartAt(b.getFirst().getNext(),CKEDITOR.POSITION_AFTER_START):l.setEndAt(b.getLast().getPrevious(),CKEDITOR.POSITION_BEFORE_END),b.editor.getSelection().selectRanges([l]))}},createFillerRegex:function(a){var b=this.createFiller(a).getOuterHtml().replace(/style="[^"]*"/gi,
'style\x3d"[^"]*"').replace(/>[^<]*</gi,"\x3e[^\x3c]*\x3c");return new RegExp((a?"":"^")+b+(a?"$":""))},addSelectAllIntegration:function(a){var b=this;a.editable().attachListener(a,"beforeCommandExec",function(e){var h=a.editable();"selectAll"==e.data.name&&h&&b.addFillers(h)},null,null,9999)}}}(),"use strict",function(){function a(a){this.editor=a;this.registered={};this.instances={};this.selected=[];this.widgetHoldingFocusedEditable=this.focused=null;this._={nextId:0,upcasts:[],upcastCallbacks:[],
filters:{}};C(this);B(this);this.on("checkWidgets",k);this.editor.on("contentDomInvalidated",this.checkWidgets,this);u(this);r(this);w(this);t(this);z(this)}function c(a,b,d,e,f){var g=a.editor;CKEDITOR.tools.extend(this,e,{editor:g,id:b,inline:"span"==d.getParent().getName(),element:d,data:CKEDITOR.tools.extend({},"function"==typeof e.defaults?e.defaults():e.defaults),dataReady:!1,inited:!1,ready:!1,edit:c.prototype.edit,focusedEditable:null,definition:e,repository:a,draggable:!1!==e.draggable,_:{downcastFn:e.downcast&&
"string"==typeof e.downcast?e.downcasts[e.downcast]:e.downcast}},!0);a.fire("instanceCreated",this);U(this,e);this.init&&this.init();this.inited=!0;(a=this.element.data("cke-widget-data"))&&this.setData(JSON.parse(decodeURIComponent(a)));f&&this.setData(f);this.data.classes||this.setData("classes",this.getClasses());this.dataReady=!0;W(this);this.fire("data",this.data);this.isInited()&&g.editable().contains(this.wrapper)&&(this.ready=!0,this.fire("ready"))}function b(a,b,c){CKEDITOR.dom.element.call(this,
b.$);this.editor=a;this._={};b=this.filter=c.filter;CKEDITOR.dtd[this.getName()].p?(this.enterMode=b?b.getAllowedEnterMode(a.enterMode):a.enterMode,this.shiftEnterMode=b?b.getAllowedEnterMode(a.shiftEnterMode,!0):a.shiftEnterMode):this.enterMode=this.shiftEnterMode=CKEDITOR.ENTER_BR}function e(a,b){a.addCommand(b.name,{exec:function(a,c){function d(){a.widgets.finalizeCreation(h)}var e=a.widgets.focused;if(e&&e.name==b.name)e.edit();else if(b.insert)b.insert();else if(b.template){var e="function"==
typeof b.defaults?b.defaults():b.defaults,e=CKEDITOR.dom.element.createFromHtml(b.template.output(e)),f,g=a.widgets.wrapElement(e,b.name),h=new CKEDITOR.dom.documentFragment(g.getDocument());h.append(g);(f=a.widgets.initOn(e,b,c&&c.startupData))?(e=f.once("edit",function(b){if(b.data.dialog)f.once("dialog",function(b){b=b.data;var c,e;c=b.once("ok",d,null,null,20);e=b.once("cancel",function(b){b.data&&!1===b.data.hide||a.widgets.destroy(f,!0)});b.once("hide",function(){c.removeListener();e.removeListener()})});
else d()},null,null,999),f.edit(),e.removeListener()):d()}},allowedContent:b.allowedContent,requiredContent:b.requiredContent,contentForms:b.contentForms,contentTransformations:b.contentTransformations})}function h(a,b){function c(b,d,e){var f=CKEDITOR.tools.getIndex(a._.upcasts,function(a){return a[2]>e});0>f&&(f=a._.upcasts.length);a._.upcasts.splice(f,0,[b,d,e])}var d=b.upcast,e=b.upcastPriority||10;if(d)if("string"==typeof d)for(d=d.split(",");d.length;)c(b.upcasts[d.pop()],b.name,e);else c(d,
b.name,e)}function l(a,b){a.focused=null;if(b.isInited()){var c=b.editor.checkDirty();a.fire("widgetBlurred",{widget:b});b.setFocused(!1);!c&&b.editor.resetDirty()}}function k(a){a=a.data;if("wysiwyg"==this.editor.mode){var b=this.editor.editable(),d=this.instances,e,f,g,h;if(b){for(e in d)d[e].isReady()&&!b.contains(d[e].wrapper)&&this.destroy(d[e],!0);if(a&&a.initOnlyNew)d=this.initOnAll();else{var k=b.find(".cke_widget_wrapper"),d=[];e=0;for(f=k.count();e<f;e++){g=k.getItem(e);if(h=!this.getByElement(g,
!0)){a:{h=p;for(var l=g;l=l.getParent();)if(h(l)){h=!0;break a}h=!1}h=!h}h&&b.contains(g)&&(g.addClass("cke_widget_new"),d.push(this.initOn(g.getFirst(c.isDomWidgetElement))))}}a&&a.focusInited&&1==d.length&&d[0].focus()}}}function f(a,b,c){if(!c.allowedContent)return null;var d=this._.filters[a];d||(this._.filters[a]=d={});(a=d[b])||(d[b]=a=new CKEDITOR.filter(c.allowedContent));return a}function d(a){var b=[],d=a._.upcasts,e=a._.upcastCallbacks;return{toBeWrapped:b,iterator:function(a){var f,g,
h,k,l;if("data-cke-widget-wrapper"in a.attributes)return(a=a.getFirst(c.isParserWidgetElement))&&b.push([a]),!1;if("data-widget"in a.attributes)return b.push([a]),!1;if(l=d.length){if(a.attributes["data-cke-widget-upcasted"])return!1;k=0;for(f=e.length;k<f;++k)if(!1===e[k](a))return;for(k=0;k<l;++k)if(f=d[k],h={},g=f[0](a,h))return g instanceof CKEDITOR.htmlParser.element&&(a=g),a.attributes["data-cke-widget-data"]=encodeURIComponent(JSON.stringify(h)),a.attributes["data-cke-widget-upcasted"]=1,b.push([a,
f[1]]),!1}}}}function m(a,b){return{tabindex:-1,contenteditable:"false","data-cke-widget-wrapper":1,"data-cke-filter":"off","class":"cke_widget_wrapper cke_widget_new cke_widget_"+(a?"inline":"block")+(b?" cke_widget_"+b:"")}}function g(a,b,c){if(a.type==CKEDITOR.NODE_ELEMENT){var d=CKEDITOR.dtd[a.name];if(d&&!d[c.name]){var d=a.split(b),e=a.parent;b=d.getIndex();a.children.length||(--b,a.remove());d.children.length||d.remove();return g(e,b,c)}}a.add(c,b)}function n(a,b){return"boolean"==typeof a.inline?
a.inline:!!CKEDITOR.dtd.$inline[b]}function p(a){return a.hasAttribute("data-cke-temp")}function q(a,b,c,d){var e=a.editor;e.fire("lockSnapshot");c?(d=c.data("cke-widget-editable"),d=b.editables[d],a.widgetHoldingFocusedEditable=b,b.focusedEditable=d,c.addClass("cke_widget_editable_focused"),d.filter&&e.setActiveFilter(d.filter),e.setActiveEnterMode(d.enterMode,d.shiftEnterMode)):(d||b.focusedEditable.removeClass("cke_widget_editable_focused"),b.focusedEditable=null,a.widgetHoldingFocusedEditable=
null,e.setActiveFilter(null),e.setActiveEnterMode(null,null));e.fire("unlockSnapshot")}function y(a){a.contextMenu&&a.contextMenu.addListener(function(b){if(b=a.widgets.getByElement(b,!0))return b.fire("contextMenu",{})})}function v(a,b){return CKEDITOR.tools.trim(b)}function t(a){var b=a.editor,d=CKEDITOR.plugins.lineutils;b.on("dragstart",function(d){var e=d.data.target;c.isDomDragHandler(e)&&(e=a.getByElement(e),d.data.dataTransfer.setData("cke/widget-id",e.id),b.focus(),e.focus())});b.on("drop",
function(c){var d=c.data.dataTransfer,e=d.getData("cke/widget-id"),f=d.getTransferType(b),d=b.createRange();""!==e&&f===CKEDITOR.DATA_TRANSFER_CROSS_EDITORS?c.cancel():""!==e&&f==CKEDITOR.DATA_TRANSFER_INTERNAL&&(e=a.instances[e])&&(d.setStartBefore(e.wrapper),d.setEndAfter(e.wrapper),c.data.dragRange=d,delete CKEDITOR.plugins.clipboard.dragStartContainerChildCount,delete CKEDITOR.plugins.clipboard.dragEndContainerChildCount,c.data.dataTransfer.setData("text/html",b.editable().getHtmlFromRange(d).getHtml()),
b.widgets.destroy(e,!0))});b.on("contentDom",function(){var e=b.editable();CKEDITOR.tools.extend(a,{finder:new d.finder(b,{lookups:{"default":function(b){if(!b.is(CKEDITOR.dtd.$listItem)&&b.is(CKEDITOR.dtd.$block)&&!c.isDomNestedEditable(b)&&!a._.draggedWidget.wrapper.contains(b)){var d=c.getNestedEditable(e,b);if(d){b=a._.draggedWidget;if(a.getByElement(d)==b)return;d=CKEDITOR.filter.instances[d.data("cke-filter")];b=b.requiredContent;if(d&&b&&!d.check(b))return}return CKEDITOR.LINEUTILS_BEFORE|
CKEDITOR.LINEUTILS_AFTER}}}}),locator:new d.locator(b),liner:new d.liner(b,{lineStyle:{cursor:"move !important","border-top-color":"#666"},tipLeftStyle:{"border-left-color":"#666"},tipRightStyle:{"border-right-color":"#666"}})},!0)})}function r(a){var b=a.editor;b.on("contentDom",function(){var d=b.editable(),e=d.isInline()?d:b.document,f,g;d.attachListener(e,"mousedown",function(d){var e=d.data.getTarget();f=e instanceof CKEDITOR.dom.element?a.getByElement(e):null;g=0;f&&(f.inline&&e.type==CKEDITOR.NODE_ELEMENT&&
e.hasAttribute("data-cke-widget-drag-handler")?(g=1,a.focused!=f&&b.getSelection().removeAllRanges()):c.getNestedEditable(f.wrapper,e)?f=null:(d.data.preventDefault(),CKEDITOR.env.ie||f.focus()))});d.attachListener(e,"mouseup",function(){g&&f&&f.wrapper&&(g=0,f.focus())});CKEDITOR.env.ie&&d.attachListener(e,"mouseup",function(){setTimeout(function(){f&&f.wrapper&&d.contains(f.wrapper)&&(f.focus(),f=null)})})});b.on("doubleclick",function(b){var d=a.getByElement(b.data.element);if(d&&!c.getNestedEditable(d.wrapper,
b.data.element))return d.fire("doubleclick",{element:b.data.element})},null,null,1)}function w(a){a.editor.on("key",function(b){var c=a.focused,d=a.widgetHoldingFocusedEditable,e;c?e=c.fire("key",{keyCode:b.data.keyCode}):d&&(c=b.data.keyCode,b=d.focusedEditable,c==CKEDITOR.CTRL+65?(c=b.getBogus(),d=d.editor.createRange(),d.selectNodeContents(b),c&&d.setEndAt(c,CKEDITOR.POSITION_BEFORE_START),d.select(),e=!1):8==c||46==c?(e=d.editor.getSelection().getRanges(),d=e[0],e=!(1==e.length&&d.collapsed&&
d.checkBoundaryOfElement(b,CKEDITOR[8==c?"START":"END"]))):e=void 0);return e},null,null,1)}function z(a){function b(c){a.focused&&H(a.focused,"cut"==c.name)}var c=a.editor;c.on("contentDom",function(){var a=c.editable();a.attachListener(a,"copy",b);a.attachListener(a,"cut",b)})}function u(a){var b=a.editor;b.on("selectionCheck",function(){a.fire("checkSelection")});a.on("checkSelection",a.checkSelection,a);b.on("selectionChange",function(d){var e=(d=c.getNestedEditable(b.editable(),d.data.selection.getStartElement()))&&
a.getByElement(d),f=a.widgetHoldingFocusedEditable;f?f===e&&f.focusedEditable.equals(d)||(q(a,f,null),e&&d&&q(a,e,d)):e&&d&&q(a,e,d)});b.on("dataReady",function(){x(a).commit()});b.on("blur",function(){var b;(b=a.focused)&&l(a,b);(b=a.widgetHoldingFocusedEditable)&&q(a,b,null)})}function B(a){var b=a.editor,d={};b.on("toDataFormat",function(b){var e=CKEDITOR.tools.getNextNumber(),f=[];b.data.downcastingSessionId=e;d[e]=f;b.data.dataValue.forEach(function(b){var d=b.attributes,e;if("data-cke-widget-id"in
d){if(d=a.instances[d["data-cke-widget-id"]])e=b.getFirst(c.isParserWidgetElement),f.push({wrapper:b,element:e,widget:d,editables:{}}),"1"!=e.attributes["data-cke-widget-keep-attr"]&&delete e.attributes["data-widget"]}else if("data-cke-widget-editable"in d)return f[f.length-1].editables[d["data-cke-widget-editable"]]=b,!1},CKEDITOR.NODE_ELEMENT,!0)},null,null,8);b.on("toDataFormat",function(a){if(a.data.downcastingSessionId){a=d[a.data.downcastingSessionId];for(var b,c,e,f,g,h;b=a.shift();){c=b.widget;
e=b.element;f=c._.downcastFn&&c._.downcastFn.call(c,e);for(h in b.editables)g=b.editables[h],delete g.attributes.contenteditable,g.setHtml(c.editables[h].getData());f||(f=e);b.wrapper.replaceWith(f)}}},null,null,13);b.on("contentDomUnload",function(){a.destroyAll(!0)})}function C(a){var b=a.editor,e,f;b.on("toHtml",function(b){var f=d(a),g;for(b.data.dataValue.forEach(f.iterator,CKEDITOR.NODE_ELEMENT,!0);g=f.toBeWrapped.pop();){var h=g[0],k=h.parent;k.type==CKEDITOR.NODE_ELEMENT&&k.attributes["data-cke-widget-wrapper"]&&
k.replaceWith(h);a.wrapElement(g[0],g[1])}e=b.data.protectedWhitespaces?3==b.data.dataValue.children.length&&c.isParserWidgetWrapper(b.data.dataValue.children[1]):1==b.data.dataValue.children.length&&c.isParserWidgetWrapper(b.data.dataValue.children[0])},null,null,8);b.on("dataReady",function(){if(f)for(var d=b.editable().find(".cke_widget_wrapper"),e,g,h=0,k=d.count();h<k;++h)e=d.getItem(h),g=e.getFirst(c.isDomWidgetElement),g.type==CKEDITOR.NODE_ELEMENT&&g.data("widget")?(g.replace(e),a.wrapElement(g)):
e.remove();f=0;a.destroyAll(!0);a.initOnAll()});b.on("loadSnapshot",function(b){/data-cke-widget/.test(b.data)&&(f=1);a.destroyAll(!0)},null,null,9);b.on("paste",function(a){a=a.data;a.dataValue=a.dataValue.replace(da,v);a.range&&(a=c.getNestedEditable(b.editable(),a.range.startContainer))&&(a=CKEDITOR.filter.instances[a.data("cke-filter")])&&b.setActiveFilter(a)});b.on("afterInsertHtml",function(c){c.data.intoRange?a.checkWidgets({initOnlyNew:!0}):(b.fire("lockSnapshot"),a.checkWidgets({initOnlyNew:!0,
focusInited:e}),b.fire("unlockSnapshot"))})}function x(a){var b=a.selected,c=[],d=b.slice(0),e=null;return{select:function(a){0>CKEDITOR.tools.indexOf(b,a)&&c.push(a);a=CKEDITOR.tools.indexOf(d,a);0<=a&&d.splice(a,1);return this},focus:function(a){e=a;return this},commit:function(){var f=a.focused!==e,g,h;a.editor.fire("lockSnapshot");for(f&&(g=a.focused)&&l(a,g);g=d.pop();)b.splice(CKEDITOR.tools.indexOf(b,g),1),g.isInited()&&(h=g.editor.checkDirty(),g.setSelected(!1),!h&&g.editor.resetDirty());
f&&e&&(h=a.editor.checkDirty(),a.focused=e,a.fire("widgetFocused",{widget:e}),e.setFocused(!0),!h&&a.editor.resetDirty());for(;g=c.pop();)b.push(g),g.setSelected(!0);a.editor.fire("unlockSnapshot")}}}function A(a,b,c){var d=0;b=E(b);var e=a.data.classes||{},f;if(b){for(e=CKEDITOR.tools.clone(e);f=b.pop();)c?e[f]||(d=e[f]=1):e[f]&&(delete e[f],d=1);d&&a.setData("classes",e)}}function D(a){a.cancel()}function H(a,b){var c=a.editor,d=c.document;if(!d.getById("cke_copybin")){var e=c.blockless||CKEDITOR.env.ie?
"span":"div",f=d.createElement(e),g=d.createElement(e),e=CKEDITOR.env.ie&&9>CKEDITOR.env.version;g.setAttributes({id:"cke_copybin","data-cke-temp":"1"});f.setStyles({position:"absolute",width:"1px",height:"1px",overflow:"hidden"});f.setStyle("ltr"==c.config.contentsLangDirection?"left":"right","-5000px");var h=c.createRange();h.setStartBefore(a.wrapper);h.setEndAfter(a.wrapper);f.setHtml('\x3cspan data-cke-copybin-start\x3d"1"\x3e​\x3c/span\x3e'+c.editable().getHtmlFromRange(h).getHtml()+'\x3cspan data-cke-copybin-end\x3d"1"\x3e​\x3c/span\x3e');
c.fire("saveSnapshot");c.fire("lockSnapshot");g.append(f);c.editable().append(g);var k=c.on("selectionChange",D,null,null,0),l=a.repository.on("checkSelection",D,null,null,0);if(e)var m=d.getDocumentElement().$,r=m.scrollTop;h=c.createRange();h.selectNodeContents(f);h.select();e&&(m.scrollTop=r);setTimeout(function(){b||a.focus();g.remove();k.removeListener();l.removeListener();c.fire("unlockSnapshot");b&&(a.repository.del(a),c.fire("saveSnapshot"))},100)}}function E(a){return(a=(a=a.getDefinition().attributes)&&
a["class"])?a.split(/\s+/):null}function I(){var a=CKEDITOR.document.getActive(),b=this.editor,c=b.editable();(c.isInline()?c:b.document.getWindow().getFrame()).equals(a)&&b.focusManager.focus(c)}function G(){CKEDITOR.env.gecko&&this.editor.unlockSelection();CKEDITOR.env.webkit||(this.editor.forceNextSelectionCheck(),this.editor.selectionChange(1))}function K(a){var b=null;a.on("data",function(){var a=this.data.classes,c;if(b!=a){for(c in b)a&&a[c]||this.removeClass(c);for(c in a)this.addClass(c);
b=a}})}function J(a){a.on("data",function(){if(a.wrapper){var b=this.getLabel?this.getLabel():this.editor.lang.widget.label.replace(/%1/,this.pathName||this.element.getName());a.wrapper.setAttribute("role","region");a.wrapper.setAttribute("aria-label",b)}},null,null,9999)}function F(a){if(a.draggable){var b=a.editor,d=a.wrapper.getLast(c.isDomDragHandlerContainer),e;d?e=d.findOne("img"):(d=new CKEDITOR.dom.element("span",b.document),d.setAttributes({"class":"cke_reset cke_widget_drag_handler_container",
style:"background:rgba(220,220,220,0.5);background-image:url("+b.plugins.widget.path+"images/handle.png)"}),e=new CKEDITOR.dom.element("img",b.document),e.setAttributes({"class":"cke_reset cke_widget_drag_handler","data-cke-widget-drag-handler":"1",src:CKEDITOR.tools.transparentImageData,width:15,title:b.lang.widget.move,height:15,role:"presentation"}),a.inline&&e.setAttribute("draggable","true"),d.append(e),a.wrapper.append(d));a.wrapper.on("dragover",function(a){a.data.preventDefault()});a.wrapper.on("mouseenter",
a.updateDragHandlerPosition,a);setTimeout(function(){a.on("data",a.updateDragHandlerPosition,a)},50);if(!a.inline&&(e.on("mousedown",S,a),CKEDITOR.env.ie&&9>CKEDITOR.env.version))e.on("dragstart",function(a){a.data.preventDefault(!0)});a.dragHandlerContainer=d}}function S(a){function b(){var c;for(w.reset();c=h.pop();)c.removeListener();var d=k;c=a.sender;var e=this.repository.finder,f=this.repository.liner,g=this.editor,l=this.editor.editable();CKEDITOR.tools.isEmpty(f.visible)||(d=e.getRange(d[0]),
this.focus(),g.fire("drop",{dropRange:d,target:d.startContainer}));l.removeClass("cke_widget_dragging");f.hideVisible();g.fire("dragend",{target:c})}var c=this.repository.finder,d=this.repository.locator,e=this.repository.liner,f=this.editor,g=f.editable(),h=[],k=[],l,m;this.repository._.draggedWidget=this;var r=c.greedySearch(),w=CKEDITOR.tools.eventsBuffer(50,function(){l=d.locate(r);k=d.sort(m,1);k.length&&(e.prepare(r,l),e.placeLine(k[0]),e.cleanup())});g.addClass("cke_widget_dragging");h.push(g.on("mousemove",
function(a){m=a.data.$.clientY;w.input()}));f.fire("dragstart",{target:a.sender});h.push(f.document.once("mouseup",b,this));g.isInline()||h.push(CKEDITOR.document.once("mouseup",b,this))}function N(a){var b,c,d=a.editables;a.editables={};if(a.editables)for(b in d)c=d[b],a.initEditable(b,"string"==typeof c?{selector:c}:c)}function Q(a){if(a.mask){var b=a.wrapper.findOne(".cke_widget_mask");b||(b=new CKEDITOR.dom.element("img",a.editor.document),b.setAttributes({src:CKEDITOR.tools.transparentImageData,
"class":"cke_reset cke_widget_mask"}),a.wrapper.append(b));a.mask=b}}function M(a){if(a.parts){var b={},c,d;for(d in a.parts)c=a.wrapper.findOne(a.parts[d]),b[d]=c;a.parts=b}}function U(a,b){Z(a);M(a);N(a);Q(a);F(a);K(a);J(a);if(CKEDITOR.env.ie&&9>CKEDITOR.env.version)a.wrapper.on("dragstart",function(b){var d=b.data.getTarget();c.getNestedEditable(a,d)||a.inline&&c.isDomDragHandler(d)||b.data.preventDefault()});a.wrapper.removeClass("cke_widget_new");a.element.addClass("cke_widget_element");a.on("key",
function(b){b=b.data.keyCode;if(13==b)a.edit();else{if(b==CKEDITOR.CTRL+67||b==CKEDITOR.CTRL+88){H(a,b==CKEDITOR.CTRL+88);return}if(b in O||CKEDITOR.CTRL&b||CKEDITOR.ALT&b)return}return!1},null,null,999);a.on("doubleclick",function(b){a.edit()&&b.cancel()});if(b.data)a.on("data",b.data);if(b.edit)a.on("edit",b.edit)}function Z(a){(a.wrapper=a.element.getParent()).setAttribute("data-cke-widget-id",a.id)}function W(a){a.element.data("cke-widget-data",encodeURIComponent(JSON.stringify(a.data)))}CKEDITOR.plugins.add("widget",
{requires:"lineutils,clipboard,widgetselection",onLoad:function(){CKEDITOR.addCss(".cke_widget_wrapper{position:relative;outline:none}.cke_widget_inline{display:inline-block}.cke_widget_wrapper:hover\x3e.cke_widget_element{outline:2px solid yellow;cursor:default}.cke_widget_wrapper:hover .cke_widget_editable{outline:2px solid yellow}.cke_widget_wrapper.cke_widget_focused\x3e.cke_widget_element,.cke_widget_wrapper .cke_widget_editable.cke_widget_editable_focused{outline:2px solid #ace}.cke_widget_editable{cursor:text}.cke_widget_drag_handler_container{position:absolute;width:15px;height:0;display:none;opacity:0.75;transition:height 0s 0.2s;line-height:0}.cke_widget_wrapper:hover\x3e.cke_widget_drag_handler_container{height:15px;transition:none}.cke_widget_drag_handler_container:hover{opacity:1}img.cke_widget_drag_handler{cursor:move;width:15px;height:15px;display:inline-block}.cke_widget_mask{position:absolute;top:0;left:0;width:100%;height:100%;display:block}.cke_editable.cke_widget_dragging, .cke_editable.cke_widget_dragging *{cursor:move !important}")},
beforeInit:function(b){b.widgets=new a(b)},afterInit:function(a){var b=a.widgets.registered,c,d,e;for(d in b)c=b[d],(e=c.button)&&a.ui.addButton&&a.ui.addButton(CKEDITOR.tools.capitalize(c.name,!0),{label:e,command:c.name,toolbar:"insert,10"});y(a)}});a.prototype={MIN_SELECTION_CHECK_INTERVAL:500,add:function(a,b){b=CKEDITOR.tools.prototypedCopy(b);b.name=a;b._=b._||{};this.editor.fire("widgetDefinition",b);b.template&&(b.template=new CKEDITOR.template(b.template));e(this.editor,b);h(this,b);return this.registered[a]=
b},addUpcastCallback:function(a){this._.upcastCallbacks.push(a)},checkSelection:function(){var a=this.editor.getSelection(),b=a.getSelectedElement(),d=x(this),e;if(b&&(e=this.getByElement(b,!0)))return d.focus(e).select(e).commit();a=a.getRanges()[0];if(!a||a.collapsed)return d.commit();a=new CKEDITOR.dom.walker(a);for(a.evaluator=c.isDomWidgetWrapper;b=a.next();)d.select(this.getByElement(b));d.commit()},checkWidgets:function(a){this.fire("checkWidgets",CKEDITOR.tools.copy(a||{}))},del:function(a){if(this.focused===
a){var b=a.editor,c=b.createRange(),d;(d=c.moveToClosestEditablePosition(a.wrapper,!0))||(d=c.moveToClosestEditablePosition(a.wrapper,!1));d&&b.getSelection().selectRanges([c])}a.wrapper.remove();this.destroy(a,!0)},destroy:function(a,b){this.widgetHoldingFocusedEditable===a&&q(this,a,null,b);a.destroy(b);delete this.instances[a.id];this.fire("instanceDestroyed",a)},destroyAll:function(a,b){var c,d,e=this.instances;if(b&&!a){d=b.find(".cke_widget_wrapper");for(var e=d.count(),f=0;f<e;++f)(c=this.getByElement(d.getItem(f),
!0))&&this.destroy(c)}else for(d in e)c=e[d],this.destroy(c,a)},finalizeCreation:function(a){(a=a.getFirst())&&c.isDomWidgetWrapper(a)&&(this.editor.insertElement(a),a=this.getByElement(a),a.ready=!0,a.fire("ready"),a.focus())},getByElement:function(){function a(c){return c.is(b)&&c.data("cke-widget-id")}var b={div:1,span:1};return function(b,c){if(!b)return null;var d=a(b);if(!c&&!d){var e=this.editor.editable();do b=b.getParent();while(b&&!b.equals(e)&&!(d=a(b)))}return this.instances[d]||null}}(),
initOn:function(a,b,d){b?"string"==typeof b&&(b=this.registered[b]):b=this.registered[a.data("widget")];if(!b)return null;var e=this.wrapElement(a,b.name);return e?e.hasClass("cke_widget_new")?(a=new c(this,this._.nextId++,a,b,d),a.isInited()?this.instances[a.id]=a:null):this.getByElement(a):null},initOnAll:function(a){a=(a||this.editor.editable()).find(".cke_widget_new");for(var b=[],d,e=a.count();e--;)(d=this.initOn(a.getItem(e).getFirst(c.isDomWidgetElement)))&&b.push(d);return b},onWidget:function(a){var b=
Array.prototype.slice.call(arguments);b.shift();for(var c in this.instances){var d=this.instances[c];d.name==a&&d.on.apply(d,b)}this.on("instanceCreated",function(c){c=c.data;c.name==a&&c.on.apply(c,b)})},parseElementClasses:function(a){if(!a)return null;a=CKEDITOR.tools.trim(a).split(/\s+/);for(var b,c={},d=0;b=a.pop();)-1==b.indexOf("cke_")&&(c[b]=d=1);return d?c:null},wrapElement:function(a,b){var c=null,d,e;if(a instanceof CKEDITOR.dom.element){b=b||a.data("widget");d=this.registered[b];if(!d)return null;
if((c=a.getParent())&&c.type==CKEDITOR.NODE_ELEMENT&&c.data("cke-widget-wrapper"))return c;a.hasAttribute("data-cke-widget-keep-attr")||a.data("cke-widget-keep-attr",a.data("widget")?1:0);a.data("widget",b);e=n(d,a.getName());c=new CKEDITOR.dom.element(e?"span":"div");c.setAttributes(m(e,b));c.data("cke-display-name",d.pathName?d.pathName:a.getName());a.getParent(!0)&&c.replace(a);a.appendTo(c)}else if(a instanceof CKEDITOR.htmlParser.element){b=b||a.attributes["data-widget"];d=this.registered[b];
if(!d)return null;if((c=a.parent)&&c.type==CKEDITOR.NODE_ELEMENT&&c.attributes["data-cke-widget-wrapper"])return c;"data-cke-widget-keep-attr"in a.attributes||(a.attributes["data-cke-widget-keep-attr"]=a.attributes["data-widget"]?1:0);b&&(a.attributes["data-widget"]=b);e=n(d,a.name);c=new CKEDITOR.htmlParser.element(e?"span":"div",m(e,b));c.attributes["data-cke-display-name"]=d.pathName?d.pathName:a.name;d=a.parent;var f;d&&(f=a.getIndex(),a.remove());c.add(a);d&&g(d,f,c)}return c},_tests_createEditableFilter:f};
CKEDITOR.event.implementOn(a.prototype);c.prototype={addClass:function(a){this.element.addClass(a);this.wrapper.addClass(c.WRAPPER_CLASS_PREFIX+a)},applyStyle:function(a){A(this,a,1)},checkStyleActive:function(a){a=E(a);var b;if(!a)return!1;for(;b=a.pop();)if(!this.hasClass(b))return!1;return!0},destroy:function(a){this.fire("destroy");if(this.editables)for(var b in this.editables)this.destroyEditable(b,a);a||("0"==this.element.data("cke-widget-keep-attr")&&this.element.removeAttribute("data-widget"),
this.element.removeAttributes(["data-cke-widget-data","data-cke-widget-keep-attr"]),this.element.removeClass("cke_widget_element"),this.element.replace(this.wrapper));this.wrapper=null},destroyEditable:function(a,b){var c=this.editables[a];c.removeListener("focus",G);c.removeListener("blur",I);this.editor.focusManager.remove(c);b||(this.repository.destroyAll(!1,c),c.removeClass("cke_widget_editable"),c.removeClass("cke_widget_editable_focused"),c.removeAttributes(["contenteditable","data-cke-widget-editable",
"data-cke-enter-mode"]));delete this.editables[a]},edit:function(){var a={dialog:this.dialog},b=this;if(!1===this.fire("edit",a)||!a.dialog)return!1;this.editor.openDialog(a.dialog,function(a){var c,d;!1!==b.fire("dialog",a)&&(c=a.on("show",function(){a.setupContent(b)}),d=a.on("ok",function(){var c,d=b.on("data",function(a){c=1;a.cancel()},null,null,0);b.editor.fire("saveSnapshot");a.commitContent(b);d.removeListener();c&&(b.fire("data",b.data),b.editor.fire("saveSnapshot"))}),a.once("hide",function(){c.removeListener();
d.removeListener()}))});return!0},getClasses:function(){return this.repository.parseElementClasses(this.element.getAttribute("class"))},hasClass:function(a){return this.element.hasClass(a)},initEditable:function(a,c){var d=this._findOneNotNested(c.selector);return d&&d.is(CKEDITOR.dtd.$editable)?(d=new b(this.editor,d,{filter:f.call(this.repository,this.name,a,c)}),this.editables[a]=d,d.setAttributes({contenteditable:"true","data-cke-widget-editable":a,"data-cke-enter-mode":d.enterMode}),d.filter&&
d.data("cke-filter",d.filter.id),d.addClass("cke_widget_editable"),d.removeClass("cke_widget_editable_focused"),c.pathName&&d.data("cke-display-name",c.pathName),this.editor.focusManager.add(d),d.on("focus",G,this),CKEDITOR.env.ie&&d.on("blur",I,this),d._.initialSetData=!0,d.setData(d.getHtml()),!0):!1},_findOneNotNested:function(a){a=this.wrapper.find(a);for(var b,d,e=0;e<a.count();e++)if(b=a.getItem(e),d=b.getAscendant(c.isDomWidgetWrapper),this.wrapper.equals(d))return b;return null},isInited:function(){return!(!this.wrapper||
!this.inited)},isReady:function(){return this.isInited()&&this.ready},focus:function(){var a=this.editor.getSelection();if(a){var b=this.editor.checkDirty();a.fake(this.wrapper);!b&&this.editor.resetDirty()}this.editor.focus()},removeClass:function(a){this.element.removeClass(a);this.wrapper.removeClass(c.WRAPPER_CLASS_PREFIX+a)},removeStyle:function(a){A(this,a,0)},setData:function(a,b){var c=this.data,d=0;if("string"==typeof a)c[a]!==b&&(c[a]=b,d=1);else{var e=a;for(a in e)c[a]!==e[a]&&(d=1,c[a]=
e[a])}d&&this.dataReady&&(W(this),this.fire("data",c));return this},setFocused:function(a){this.wrapper[a?"addClass":"removeClass"]("cke_widget_focused");this.fire(a?"focus":"blur");return this},setSelected:function(a){this.wrapper[a?"addClass":"removeClass"]("cke_widget_selected");this.fire(a?"select":"deselect");return this},updateDragHandlerPosition:function(){var a=this.editor,b=this.element.$,c=this._.dragHandlerOffset,b={x:b.offsetLeft,y:b.offsetTop-15};c&&b.x==c.x&&b.y==c.y||(c=a.checkDirty(),
a.fire("lockSnapshot"),this.dragHandlerContainer.setStyles({top:b.y+"px",left:b.x+"px",display:"block"}),a.fire("unlockSnapshot"),!c&&a.resetDirty(),this._.dragHandlerOffset=b)}};CKEDITOR.event.implementOn(c.prototype);c.getNestedEditable=function(a,b){return!b||b.equals(a)?null:c.isDomNestedEditable(b)?b:c.getNestedEditable(a,b.getParent())};c.isDomDragHandler=function(a){return a.type==CKEDITOR.NODE_ELEMENT&&a.hasAttribute("data-cke-widget-drag-handler")};c.isDomDragHandlerContainer=function(a){return a.type==
CKEDITOR.NODE_ELEMENT&&a.hasClass("cke_widget_drag_handler_container")};c.isDomNestedEditable=function(a){return a.type==CKEDITOR.NODE_ELEMENT&&a.hasAttribute("data-cke-widget-editable")};c.isDomWidgetElement=function(a){return a.type==CKEDITOR.NODE_ELEMENT&&a.hasAttribute("data-widget")};c.isDomWidgetWrapper=function(a){return a.type==CKEDITOR.NODE_ELEMENT&&a.hasAttribute("data-cke-widget-wrapper")};c.isParserWidgetElement=function(a){return a.type==CKEDITOR.NODE_ELEMENT&&!!a.attributes["data-widget"]};
c.isParserWidgetWrapper=function(a){return a.type==CKEDITOR.NODE_ELEMENT&&!!a.attributes["data-cke-widget-wrapper"]};c.WRAPPER_CLASS_PREFIX="cke_widget_wrapper_";b.prototype=CKEDITOR.tools.extend(CKEDITOR.tools.prototypedCopy(CKEDITOR.dom.element.prototype),{setData:function(a){this._.initialSetData||this.editor.widgets.destroyAll(!1,this);this._.initialSetData=!1;a=this.editor.dataProcessor.toHtml(a,{context:this.getName(),filter:this.filter,enterMode:this.enterMode});this.setHtml(a);this.editor.widgets.initOnAll(this)},
getData:function(){return this.editor.dataProcessor.toDataFormat(this.getHtml(),{context:this.getName(),filter:this.filter,enterMode:this.enterMode})}});var da=/^(?:<(?:div|span)(?: data-cke-temp="1")?(?: id="cke_copybin")?(?: data-cke-temp="1")?>)?(?:<(?:div|span)(?: style="[^"]+")?>)?<span [^>]*data-cke-copybin-start="1"[^>]*>.?<\/span>([\s\S]+)<span [^>]*data-cke-copybin-end="1"[^>]*>.?<\/span>(?:<\/(?:div|span)>)?(?:<\/(?:div|span)>)?$/i,O={37:1,38:1,39:1,40:1,8:1,46:1};(function(){function a(){}
function b(a,c,d){return d&&this.checkElement(a)?(a=d.widgets.getByElement(a,!0))&&a.checkStyleActive(this):!1}var d={};CKEDITOR.style.addCustomHandler({type:"widget",setup:function(a){this.widget=a.widget;if(this.group="string"==typeof a.group?[a.group]:a.group){a=this.widget;var b;d[a]||(d[a]={});for(var c=0,e=this.group.length;c<e;c++)b=this.group[c],d[a][b]||(d[a][b]=[]),d[a][b].push(this)}},apply:function(a){var b;a instanceof CKEDITOR.editor&&this.checkApplicable(a.elementPath(),a)&&(b=a.widgets.focused,
this.group&&this.removeStylesFromSameGroup(a),b.applyStyle(this))},remove:function(a){a instanceof CKEDITOR.editor&&this.checkApplicable(a.elementPath(),a)&&a.widgets.focused.removeStyle(this)},removeStylesFromSameGroup:function(a){var b,c,e=!1;if(!(a instanceof CKEDITOR.editor))return!1;c=a.elementPath();if(this.checkApplicable(c,a))for(var f=0,g=this.group.length;f<g;f++){b=d[this.widget][this.group[f]];for(var h=0;h<b.length;h++)b[h]!==this&&b[h].checkActive(c,a)&&(a.widgets.focused.removeStyle(b[h]),
e=!0)}return e},checkActive:function(a,b){return this.checkElementMatch(a.lastElement,0,b)},checkApplicable:function(a,b){return b instanceof CKEDITOR.editor?this.checkElement(a.lastElement):!1},checkElementMatch:b,checkElementRemovable:b,checkElement:function(a){return c.isDomWidgetWrapper(a)?(a=a.getFirst(c.isDomWidgetElement))&&a.data("widget")==this.widget:!1},buildPreview:function(a){return a||this._.definition.name},toAllowedContentRules:function(a){if(!a)return null;a=a.widgets.registered[this.widget];
var b,c={};if(!a)return null;if(a.styleableElements){b=this.getClassesArray();if(!b)return null;c[a.styleableElements]={classes:b,propertiesOnly:!0};return c}return a.styleToAllowedContentRules?a.styleToAllowedContentRules(this):null},getClassesArray:function(){var a=this._.definition.attributes&&this._.definition.attributes["class"];return a?CKEDITOR.tools.trim(a).split(/\s+/):null},applyToRange:a,removeFromRange:a,applyToObject:a})})();CKEDITOR.plugins.widget=c;c.repository=a;c.nestedEditable=b}(),
function(){function a(a,h){var l,k;h.on("refresh",function(a){var d=[c],e;for(e in a.data.states)d.push(a.data.states[e]);this.setState(CKEDITOR.tools.search(d,b)?b:c)},h,null,100);h.on("exec",function(b){l=a.getSelection();k=l.createBookmarks(1);b.data||(b.data={});b.data.done=!1},h,null,0);h.on("exec",function(){a.forceNextSelectionCheck();l.selectBookmarks(k)},h,null,100)}var c=CKEDITOR.TRISTATE_DISABLED,b=CKEDITOR.TRISTATE_OFF;CKEDITOR.plugins.add("indent",{init:function(b){var c=CKEDITOR.plugins.indent.genericDefinition;
a(b,b.addCommand("indent",new c(!0)));a(b,b.addCommand("outdent",new c));b.ui.addButton&&(b.ui.addButton("Indent",{label:b.lang.indent.indent,command:"indent",directional:!0,toolbar:"indent,20"}),b.ui.addButton("Outdent",{label:b.lang.indent.outdent,command:"outdent",directional:!0,toolbar:"indent,10"}));b.on("dirChanged",function(a){var c=b.createRange(),f=a.data.node;c.setStartBefore(f);c.setEndAfter(f);for(var d=new CKEDITOR.dom.walker(c),h;h=d.next();)if(h.type==CKEDITOR.NODE_ELEMENT)if(!h.equals(f)&&
h.getDirection())c.setStartAfter(h),d=new CKEDITOR.dom.walker(c);else{var g=b.config.indentClasses;if(g)for(var n="ltr"==a.data.dir?["_rtl",""]:["","_rtl"],p=0;p<g.length;p++)h.hasClass(g[p]+n[0])&&(h.removeClass(g[p]+n[0]),h.addClass(g[p]+n[1]));g=h.getStyle("margin-right");n=h.getStyle("margin-left");g?h.setStyle("margin-left",g):h.removeStyle("margin-left");n?h.setStyle("margin-right",n):h.removeStyle("margin-right")}})}});CKEDITOR.plugins.indent={genericDefinition:function(a){this.isIndent=!!a;
this.startDisabled=!this.isIndent},specificDefinition:function(a,b,c){this.name=b;this.editor=a;this.jobs={};this.enterBr=a.config.enterMode==CKEDITOR.ENTER_BR;this.isIndent=!!c;this.relatedGlobal=c?"indent":"outdent";this.indentKey=c?9:CKEDITOR.SHIFT+9;this.database={}},registerCommands:function(a,b){a.on("pluginsLoaded",function(){for(var a in b)(function(a,b){var c=a.getCommand(b.relatedGlobal),e;for(e in b.jobs)c.on("exec",function(c){c.data.done||(a.fire("lockSnapshot"),b.execJob(a,e)&&(c.data.done=
!0),a.fire("unlockSnapshot"),CKEDITOR.dom.element.clearAllMarkers(b.database))},this,null,e),c.on("refresh",function(c){c.data.states||(c.data.states={});c.data.states[b.name+"@"+e]=b.refreshJob(a,e,c.data.path)},this,null,e);a.addFeature(b)})(this,b[a])})}};CKEDITOR.plugins.indent.genericDefinition.prototype={context:"p",exec:function(){}};CKEDITOR.plugins.indent.specificDefinition.prototype={execJob:function(a,b){var l=this.jobs[b];if(l.state!=c)return l.exec.call(this,a)},refreshJob:function(a,
b,l){b=this.jobs[b];a.activeFilter.checkFeature(this)?b.state=b.refresh.call(this,a,l):b.state=c;return b.state},getContext:function(a){return a.contains(this.context)}}}(),function(){function a(a){function d(c){for(var d=k.startContainer,l=k.endContainer;d&&!d.getParent().equals(c);)d=d.getParent();for(;l&&!l.getParent().equals(c);)l=l.getParent();if(!d||!l)return!1;for(var z=d,d=[],u=!1;!u;)z.equals(l)&&(u=!0),d.push(z),z=z.getNext();if(1>d.length)return!1;z=c.getParents(!0);for(l=0;l<z.length;l++)if(z[l].getName&&
h[z[l].getName()]){c=z[l];break}for(var z=e.isIndent?1:-1,l=d[0],d=d[d.length-1],u=CKEDITOR.plugins.list.listToArray(c,g),v=u[d.getCustomData("listarray_index")].indent,l=l.getCustomData("listarray_index");l<=d.getCustomData("listarray_index");l++)if(u[l].indent+=z,0<z){var y=u[l].parent;u[l].parent=new CKEDITOR.dom.element(y.getName(),y.getDocument())}for(l=d.getCustomData("listarray_index")+1;l<u.length&&u[l].indent>v;l++)u[l].indent+=z;d=CKEDITOR.plugins.list.arrayToList(u,g,null,a.config.enterMode,
c.getDirection());if(!e.isIndent){var x;if((x=c.getParent())&&x.is("li"))for(var z=d.listNode.getChildren(),A=[],D,l=z.count()-1;0<=l;l--)(D=z.getItem(l))&&D.is&&D.is("li")&&A.push(D)}d&&d.listNode.replace(c);if(A&&A.length)for(l=0;l<A.length;l++){for(D=c=A[l];(D=D.getNext())&&D.is&&D.getName()in h;)CKEDITOR.env.needsNbspFiller&&!c.getFirst(b)&&c.append(k.document.createText(" ")),c.append(D);c.insertAfter(x)}d&&a.fire("contentDomInvalidated");return!0}for(var e=this,g=this.database,h=this.context,
k,l=a.getSelection(),l=(l&&l.getRanges()).createIterator();k=l.getNextRange();){for(var y=k.getCommonAncestor();y&&(y.type!=CKEDITOR.NODE_ELEMENT||!h[y.getName()]);){if(a.editable().equals(y)){y=!1;break}y=y.getParent()}y||(y=k.startPath().contains(h))&&k.setEndAt(y,CKEDITOR.POSITION_BEFORE_END);if(!y){var v=k.getEnclosedNode();v&&v.type==CKEDITOR.NODE_ELEMENT&&v.getName()in h&&(k.setStartAt(v,CKEDITOR.POSITION_AFTER_START),k.setEndAt(v,CKEDITOR.POSITION_BEFORE_END),y=v)}y&&k.startContainer.type==
CKEDITOR.NODE_ELEMENT&&k.startContainer.getName()in h&&(v=new CKEDITOR.dom.walker(k),v.evaluator=c,k.startContainer=v.next());y&&k.endContainer.type==CKEDITOR.NODE_ELEMENT&&k.endContainer.getName()in h&&(v=new CKEDITOR.dom.walker(k),v.evaluator=c,k.endContainer=v.previous());if(y)return d(y)}return 0}function c(a){return a.type==CKEDITOR.NODE_ELEMENT&&a.is("li")}function b(a){return e(a)&&h(a)}var e=CKEDITOR.dom.walker.whitespaces(!0),h=CKEDITOR.dom.walker.bookmark(!1,!0),l=CKEDITOR.TRISTATE_DISABLED,
k=CKEDITOR.TRISTATE_OFF;CKEDITOR.plugins.add("indentlist",{requires:"indent",init:function(b){function c(b){e.specificDefinition.apply(this,arguments);this.requiredContent=["ul","ol"];b.on("key",function(a){var c=b.elementPath();if("wysiwyg"==b.mode&&a.data.keyCode==this.indentKey&&c){var d=this.getContext(c);!d||this.isIndent&&CKEDITOR.plugins.indentList.firstItemInPath(this.context,c,d)||(b.execCommand(this.relatedGlobal),a.cancel())}},this);this.jobs[this.isIndent?10:30]={refresh:this.isIndent?
function(a,b){var c=this.getContext(b),d=CKEDITOR.plugins.indentList.firstItemInPath(this.context,b,c);return c&&this.isIndent&&!d?k:l}:function(a,b){return!this.getContext(b)||this.isIndent?l:k},exec:CKEDITOR.tools.bind(a,this)}}var e=CKEDITOR.plugins.indent;e.registerCommands(b,{indentlist:new c(b,"indentlist",!0),outdentlist:new c(b,"outdentlist")});CKEDITOR.tools.extend(c.prototype,e.specificDefinition.prototype,{context:{ol:1,ul:1}})}});CKEDITOR.plugins.indentList={};CKEDITOR.plugins.indentList.firstItemInPath=
function(a,b,e){var g=b.contains(c);e||(e=b.contains(a));return e&&g&&g.equals(e.getFirst(c))}}(),function(){function a(a,b,d){if(!a.getCustomData("indent_processed")){var e=this.editor,g=this.isIndent;if(b){e=a.$.className.match(this.classNameRegex);d=0;e&&(e=e[1],d=CKEDITOR.tools.indexOf(b,e)+1);if(0>(d+=g?1:-1))return;d=Math.min(d,b.length);d=Math.max(d,0);a.$.className=CKEDITOR.tools.ltrim(a.$.className.replace(this.classNameRegex,""));0<d&&a.addClass(b[d-1])}else{b=c(a,d);d=parseInt(a.getStyle(b),
10);var h=e.config.indentOffset||40;isNaN(d)&&(d=0);d+=(g?1:-1)*h;if(0>d)return;d=Math.max(d,0);d=Math.ceil(d/h)*h;a.setStyle(b,d?d+(e.config.indentUnit||"px"):"");""===a.getAttribute("style")&&a.removeAttribute("style")}CKEDITOR.dom.element.setMarker(this.database,a,"indent_processed",1)}}function c(a,b){return"ltr"==(b||a.getComputedStyle("direction"))?"margin-left":"margin-right"}var b=CKEDITOR.dtd.$listItem,e=CKEDITOR.dtd.$list,h=CKEDITOR.TRISTATE_DISABLED,l=CKEDITOR.TRISTATE_OFF;CKEDITOR.plugins.add("indentblock",
{requires:"indent",init:function(k){function f(){d.specificDefinition.apply(this,arguments);this.allowedContent={"div h1 h2 h3 h4 h5 h6 ol p pre ul":{propertiesOnly:!0,styles:m?null:"margin-left,margin-right",classes:m||null}};this.contentTransformations=[["div: splitMarginShorthand"],["h1: splitMarginShorthand"],["h2: splitMarginShorthand"],["h3: splitMarginShorthand"],["h4: splitMarginShorthand"],["h5: splitMarginShorthand"],["h6: splitMarginShorthand"],["ol: splitMarginShorthand"],["p: splitMarginShorthand"],
["pre: splitMarginShorthand"],["ul: splitMarginShorthand"]];this.enterBr&&(this.allowedContent.div=!0);this.requiredContent=(this.enterBr?"div":"p")+(m?"("+m.join(",")+")":"{margin-left}");this.jobs={20:{refresh:function(a,d){var e=d.block||d.blockLimit;if(!e.is(b))var f=e.getAscendant(b),e=f&&d.contains(f)||e;e.is(b)&&(e=e.getParent());if(this.enterBr||this.getContext(d)){if(m){var f=m,e=e.$.className.match(this.classNameRegex),k=this.isIndent,f=e?k?e[1]!=f.slice(-1):!0:k;return f?l:h}return this.isIndent?
l:e?CKEDITOR[0>=(parseInt(e.getStyle(c(e)),10)||0)?"TRISTATE_DISABLED":"TRISTATE_OFF"]:h}return h},exec:function(b){var c=b.getSelection(),c=c&&c.getRanges()[0],d;if(d=b.elementPath().contains(e))a.call(this,d,m);else for(c=c.createIterator(),b=b.config.enterMode,c.enforceRealBlocks=!0,c.enlargeBr=b!=CKEDITOR.ENTER_BR;d=c.getNextParagraph(b==CKEDITOR.ENTER_P?"p":"div");)d.isReadOnly()||a.call(this,d,m);return!0}}}}var d=CKEDITOR.plugins.indent,m=k.config.indentClasses;d.registerCommands(k,{indentblock:new f(k,
"indentblock",!0),outdentblock:new f(k,"outdentblock")});CKEDITOR.tools.extend(f.prototype,d.specificDefinition.prototype,{context:{div:1,dl:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1,ul:1,ol:1,p:1,pre:1,table:1},classNameRegex:m?new RegExp("(?:^|\\s+)("+m.join("|")+")(?\x3d$|\\s)"):null})}})}(),function(){function a(a,b){b=void 0===b||b;var c;if(b)c=a.getComputedStyle("text-align");else{for(;!a.hasAttribute||!a.hasAttribute("align")&&!a.getStyle("text-align");){c=a.getParent();if(!c)break;a=c}c=a.getStyle("text-align")||
a.getAttribute("align")||""}c&&(c=c.replace(/(?:-(?:moz|webkit)-)?(?:start|auto)/i,""));!c&&b&&(c="rtl"==a.getComputedStyle("direction")?"right":"left");return c}function c(a,b,c){this.editor=a;this.name=b;this.value=c;this.context="p";b=a.config.justifyClasses;var k=a.config.enterMode==CKEDITOR.ENTER_P?"p":"div";if(b){switch(c){case "left":this.cssClassName=b[0];break;case "center":this.cssClassName=b[1];break;case "right":this.cssClassName=b[2];break;case "justify":this.cssClassName=b[3]}this.cssClassRegex=
new RegExp("(?:^|\\s+)(?:"+b.join("|")+")(?\x3d$|\\s)");this.requiredContent=k+"("+this.cssClassName+")"}else this.requiredContent=k+"{text-align}";this.allowedContent={"caption div h1 h2 h3 h4 h5 h6 p pre td th li":{propertiesOnly:!0,styles:this.cssClassName?null:"text-align",classes:this.cssClassName||null}};a.config.enterMode==CKEDITOR.ENTER_BR&&(this.allowedContent.div=!0)}function b(a){var b=a.editor,c=b.createRange();c.setStartBefore(a.data.node);c.setEndAfter(a.data.node);for(var k=new CKEDITOR.dom.walker(c),
f;f=k.next();)if(f.type==CKEDITOR.NODE_ELEMENT)if(!f.equals(a.data.node)&&f.getDirection())c.setStartAfter(f),k=new CKEDITOR.dom.walker(c);else{var d=b.config.justifyClasses;d&&(f.hasClass(d[0])?(f.removeClass(d[0]),f.addClass(d[2])):f.hasClass(d[2])&&(f.removeClass(d[2]),f.addClass(d[0])));d=f.getStyle("text-align");"left"==d?f.setStyle("text-align","right"):"right"==d&&f.setStyle("text-align","left")}}c.prototype={exec:function(b){var c=b.getSelection(),l=b.config.enterMode;if(c){for(var k=c.createBookmarks(),
f=c.getRanges(),d=this.cssClassName,m,g,n=b.config.useComputedState,n=void 0===n||n,p=f.length-1;0<=p;p--)for(m=f[p].createIterator(),m.enlargeBr=l!=CKEDITOR.ENTER_BR;g=m.getNextParagraph(l==CKEDITOR.ENTER_P?"p":"div");)if(!g.isReadOnly()){var q=g.getName(),y;y=b.activeFilter.check(q+"{text-align}");if((q=b.activeFilter.check(q+"("+d+")"))||y){g.removeAttribute("align");g.removeStyle("text-align");var v=d&&(g.$.className=CKEDITOR.tools.ltrim(g.$.className.replace(this.cssClassRegex,""))),t=this.state==
CKEDITOR.TRISTATE_OFF&&(!n||a(g,!0)!=this.value);d&&q?t?g.addClass(d):v||g.removeAttribute("class"):t&&y&&g.setStyle("text-align",this.value)}}b.focus();b.forceNextSelectionCheck();c.selectBookmarks(k)}},refresh:function(b,c){var l=c.block||c.blockLimit,k=l.getName(),f=l.equals(b.editable()),k=this.cssClassName?b.activeFilter.check(k+"("+this.cssClassName+")"):b.activeFilter.check(k+"{text-align}");f&&1===c.elements.length?this.setState(CKEDITOR.TRISTATE_OFF):!f&&k?this.setState(a(l,this.editor.config.useComputedState)==
this.value?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF):this.setState(CKEDITOR.TRISTATE_DISABLED)}};CKEDITOR.plugins.add("justify",{init:function(a){if(!a.blockless){var h=new c(a,"justifyleft","left"),l=new c(a,"justifycenter","center"),k=new c(a,"justifyright","right"),f=new c(a,"justifyblock","justify");a.addCommand("justifyleft",h);a.addCommand("justifycenter",l);a.addCommand("justifyright",k);a.addCommand("justifyblock",f);a.ui.addButton&&(a.ui.addButton("JustifyLeft",{label:a.lang.justify.left,
command:"justifyleft",toolbar:"align,10"}),a.ui.addButton("JustifyCenter",{label:a.lang.justify.center,command:"justifycenter",toolbar:"align,20"}),a.ui.addButton("JustifyRight",{label:a.lang.justify.right,command:"justifyright",toolbar:"align,30"}),a.ui.addButton("JustifyBlock",{label:a.lang.justify.block,command:"justifyblock",toolbar:"align,40"}));a.on("dirChanged",b)}}})}(),"use strict",function(){CKEDITOR.plugins.add("language",{requires:"menubutton",init:function(a){var c=a.config.language_list||
["ar:Arabic:rtl","fr:French","es:Spanish"],b=this,e=a.lang.language,h={},l,k,f,d;a.addCommand("language",{allowedContent:"span[!lang,!dir]",requiredContent:"span[lang,dir]",contextSensitive:!0,exec:function(a,b){var c=h["language_"+b];if(c)a[c.style.checkActive(a.elementPath(),a)?"removeStyle":"applyStyle"](c.style)},refresh:function(a){this.setState(b.getCurrentLangElement(a)?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF)}});for(d=0;d<c.length;d++)l=c[d].split(":"),k=l[0],f="language_"+k,h[f]={label:l[1],
langId:k,group:"language",order:d,ltr:"rtl"!=(""+l[2]).toLowerCase(),onClick:function(){a.execCommand("language",this.langId)},role:"menuitemcheckbox"},h[f].style=new CKEDITOR.style({element:"span",attributes:{lang:k,dir:h[f].ltr?"ltr":"rtl"}});h.language_remove={label:e.remove,group:"language_remove",state:CKEDITOR.TRISTATE_DISABLED,order:h.length,onClick:function(){var c=b.getCurrentLangElement(a);c&&a.execCommand("language",c.getAttribute("lang"))}};a.addMenuGroup("language",1);a.addMenuGroup("language_remove");
a.addMenuItems(h);a.ui.add("Language",CKEDITOR.UI_MENUBUTTON,{label:e.button,allowedContent:"span[!lang,!dir]",requiredContent:"span[lang,dir]",toolbar:"bidi,30",command:"language",onMenu:function(){var c={},d=b.getCurrentLangElement(a),e;for(e in h)c[e]=CKEDITOR.TRISTATE_OFF;c.language_remove=d?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED;d&&(c["language_"+d.getAttribute("lang")]=CKEDITOR.TRISTATE_ON);return c}})},getCurrentLangElement:function(a){var c=a.elementPath();a=c&&c.elements;var b;
if(c)for(var e=0;e<a.length;e++)c=a[e],!b&&"span"==c.getName()&&c.hasAttribute("dir")&&c.hasAttribute("lang")&&(b=c);return b}})}(),"use strict",function(){function a(a){return a.replace(/'/g,"\\$\x26")}function c(a){for(var b,c=a.length,d=[],e=0;e<c;e++)b=a.charCodeAt(e),d.push(b);return"String.fromCharCode("+d.join(",")+")"}function b(b,c){var d=b.plugins.link,e=d.compiledProtectionFunction.params,f,g;g=[d.compiledProtectionFunction.name,"("];for(var h=0;h<e.length;h++)d=e[h].toLowerCase(),f=c[d],
0<h&&g.push(","),g.push("'",f?a(encodeURIComponent(c[d])):"","'");g.push(")");return g.join("")}function e(a){a=a.config.emailProtection||"";var b;a&&"encode"!=a&&(b={},a.replace(/^([^(]+)\(([^)]+)\)$/,function(a,c,d){b.name=c;b.params=[];d.replace(/[^,\s]+/g,function(a){b.params.push(a)})}));return b}CKEDITOR.plugins.add("link",{requires:"dialog,fakeobjects",onLoad:function(){function a(b){return c.replace(/%1/g,"rtl"==b?"right":"left").replace(/%2/g,"cke_contents_"+b)}var b="background:url("+CKEDITOR.getUrl(this.path+
"images"+(CKEDITOR.env.hidpi?"/hidpi":"")+"/anchor.png")+") no-repeat %1 center;border:1px dotted #00f;background-size:16px;",c=".%2 a.cke_anchor,.%2 a.cke_anchor_empty,.cke_editable.%2 a[name],.cke_editable.%2 a[data-cke-saved-name]{"+b+"padding-%1:18px;cursor:auto;}.%2 img.cke_anchor{"+b+"width:16px;min-height:15px;height:1.15em;vertical-align:text-bottom;}";CKEDITOR.addCss(a("ltr")+a("rtl"))},init:function(a){var b="a[!href]";CKEDITOR.dialog.isTabEnabled(a,"link","advanced")&&(b=b.replace("]",
",accesskey,charset,dir,id,lang,name,rel,tabindex,title,type,download]{*}(*)"));CKEDITOR.dialog.isTabEnabled(a,"link","target")&&(b=b.replace("]",",target,onclick]"));a.addCommand("link",new CKEDITOR.dialogCommand("link",{allowedContent:b,requiredContent:"a[href]"}));a.addCommand("anchor",new CKEDITOR.dialogCommand("anchor",{allowedContent:"a[!name,id]",requiredContent:"a[name]"}));a.addCommand("unlink",new CKEDITOR.unlinkCommand);a.addCommand("removeAnchor",new CKEDITOR.removeAnchorCommand);a.setKeystroke(CKEDITOR.CTRL+
76,"link");a.ui.addButton&&(a.ui.addButton("Link",{label:a.lang.link.toolbar,command:"link",toolbar:"links,10"}),a.ui.addButton("Unlink",{label:a.lang.link.unlink,command:"unlink",toolbar:"links,20"}),a.ui.addButton("Anchor",{label:a.lang.link.anchor.toolbar,command:"anchor",toolbar:"links,30"}));CKEDITOR.dialog.add("link",this.path+"dialogs/link.js");CKEDITOR.dialog.add("anchor",this.path+"dialogs/anchor.js");a.on("doubleclick",function(b){var c=b.data.element.getAscendant({a:1,img:1},!0);c&&!c.isReadOnly()&&
(c.is("a")?(b.data.dialog=!c.getAttribute("name")||c.getAttribute("href")&&c.getChildCount()?"link":"anchor",b.data.link=c):CKEDITOR.plugins.link.tryRestoreFakeAnchor(a,c)&&(b.data.dialog="anchor"))},null,null,0);a.on("doubleclick",function(b){b.data.dialog in{link:1,anchor:1}&&b.data.link&&a.getSelection().selectElement(b.data.link)},null,null,20);a.addMenuItems&&a.addMenuItems({anchor:{label:a.lang.link.anchor.menu,command:"anchor",group:"anchor",order:1},removeAnchor:{label:a.lang.link.anchor.remove,
command:"removeAnchor",group:"anchor",order:5},link:{label:a.lang.link.menu,command:"link",group:"link",order:1},unlink:{label:a.lang.link.unlink,command:"unlink",group:"link",order:5}});a.contextMenu&&a.contextMenu.addListener(function(b){if(!b||b.isReadOnly())return null;b=CKEDITOR.plugins.link.tryRestoreFakeAnchor(a,b);if(!b&&!(b=CKEDITOR.plugins.link.getSelectedLink(a)))return null;var c={};b.getAttribute("href")&&b.getChildCount()&&(c={link:CKEDITOR.TRISTATE_OFF,unlink:CKEDITOR.TRISTATE_OFF});
b&&b.hasAttribute("name")&&(c.anchor=c.removeAnchor=CKEDITOR.TRISTATE_OFF);return c});this.compiledProtectionFunction=e(a)},afterInit:function(a){a.dataProcessor.dataFilter.addRules({elements:{a:function(b){return b.attributes.name?b.children.length?null:a.createFakeParserElement(b,"cke_anchor","anchor"):null}}});var b=a._.elementsPath&&a._.elementsPath.filters;b&&b.push(function(b,c){if("a"==c&&(CKEDITOR.plugins.link.tryRestoreFakeAnchor(a,b)||b.getAttribute("name")&&(!b.getAttribute("href")||!b.getChildCount())))return"anchor"})}});
var h=/^javascript:/,l=/^mailto:([^?]+)(?:\?(.+))?$/,k=/subject=([^;?:@&=$,\/]*)/i,f=/body=([^;?:@&=$,\/]*)/i,d=/^#(.*)$/,m=/^((?:http|https|ftp|news):\/\/)?(.*)$/,g=/^(_(?:self|top|parent|blank))$/,n=/^javascript:void\(location\.href='mailto:'\+String\.fromCharCode\(([^)]+)\)(?:\+'(.*)')?\)$/,p=/^javascript:([^(]+)\(([^)]+)\)$/,q=/\s*window.open\(\s*this\.href\s*,\s*(?:'([^']*)'|null)\s*,\s*'([^']*)'\s*\)\s*;\s*return\s*false;*\s*/,y=/(?:^|,)([^=]+)=(\d+|yes|no)/gi,v={id:"advId",dir:"advLangDir",
accessKey:"advAccessKey",name:"advName",lang:"advLangCode",tabindex:"advTabIndex",title:"advTitle",type:"advContentType","class":"advCSSClasses",charset:"advCharset",style:"advStyles",rel:"advRel"};CKEDITOR.plugins.link={getSelectedLink:function(a,b){var c=a.getSelection(),d=c.getSelectedElement(),e=c.getRanges(),f=[],g;if(!b&&d&&d.is("a"))return d;for(d=0;d<e.length;d++)if(g=c.getRanges()[d],g.shrink(CKEDITOR.SHRINK_TEXT,!1,{skipBogus:!0}),(g=a.elementPath(g.getCommonAncestor()).contains("a",1))&&
b)f.push(g);else if(g)return g;return b?f:null},getEditorAnchors:function(a){for(var b=a.editable(),c=b.isInline()&&!a.plugins.divarea?a.document:b,b=c.getElementsByTag("a"),c=c.getElementsByTag("img"),d=[],e=0,f;f=b.getItem(e++);)(f.data("cke-saved-name")||f.hasAttribute("name"))&&d.push({name:f.data("cke-saved-name")||f.getAttribute("name"),id:f.getAttribute("id")});for(e=0;f=c.getItem(e++);)(f=this.tryRestoreFakeAnchor(a,f))&&d.push({name:f.getAttribute("name"),id:f.getAttribute("id")});return d},
fakeAnchor:!0,tryRestoreFakeAnchor:function(a,b){if(b&&b.data("cke-real-element-type")&&"anchor"==b.data("cke-real-element-type")){var c=a.restoreRealElement(b);if(c.data("cke-saved-name"))return c}},parseLinkAttributes:function(a,b){var c=b&&(b.data("cke-saved-href")||b.getAttribute("href"))||"",e=a.plugins.link.compiledProtectionFunction,u=a.config.emailProtection,B,C={};c.match(h)&&("encode"==u?c=c.replace(n,function(a,b,c){c=c||"";return"mailto:"+String.fromCharCode.apply(String,b.split(","))+
c.replace(/\\'/g,"'")}):u&&c.replace(p,function(a,b,c){if(b==e.name){C.type="email";a=C.email={};b=/(^')|('$)/g;c=c.match(/[^,\s]+/g);for(var d=c.length,f,g,h=0;h<d;h++)f=decodeURIComponent,g=c[h].replace(b,"").replace(/\\'/g,"'"),g=f(g),f=e.params[h].toLowerCase(),a[f]=g;a.address=[a.name,a.domain].join("@")}}));if(!C.type)if(u=c.match(d))C.type="anchor",C.anchor={},C.anchor.name=C.anchor.id=u[1];else if(u=c.match(l)){B=c.match(k);c=c.match(f);C.type="email";var x=C.email={};x.address=u[1];B&&(x.subject=
decodeURIComponent(B[1]));c&&(x.body=decodeURIComponent(c[1]))}else c&&(B=c.match(m))&&(C.type="url",C.url={},C.url.protocol=B[1],C.url.url=B[2]);if(b){if(c=b.getAttribute("target"))C.target={type:c.match(g)?c:"frame",name:c};else if(c=(c=b.data("cke-pa-onclick")||b.getAttribute("onclick"))&&c.match(q))for(C.target={type:"popup",name:c[1]};u=y.exec(c[2]);)"yes"!=u[2]&&"1"!=u[2]||u[1]in{height:1,width:1,top:1,left:1}?isFinite(u[2])&&(C.target[u[1]]=u[2]):C.target[u[1]]=!0;null!==b.getAttribute("download")&&
(C.download=!0);var c={},A;for(A in v)(u=b.getAttribute(A))&&(c[v[A]]=u);if(A=b.data("cke-saved-name")||c.advName)c.advName=A;CKEDITOR.tools.isEmpty(c)||(C.advanced=c)}return C},getLinkAttributes:function(d,e){var f=d.config.emailProtection||"",g={};switch(e.type){case "url":var f=e.url&&void 0!==e.url.protocol?e.url.protocol:"http://",h=e.url&&CKEDITOR.tools.trim(e.url.url)||"";g["data-cke-saved-href"]=0===h.indexOf("/")?h:f+h;break;case "anchor":f=e.anchor&&e.anchor.id;g["data-cke-saved-href"]=
"#"+(e.anchor&&e.anchor.name||f||"");break;case "email":var k=e.email,h=k.address;switch(f){case "":case "encode":var l=encodeURIComponent(k.subject||""),m=encodeURIComponent(k.body||""),k=[];l&&k.push("subject\x3d"+l);m&&k.push("body\x3d"+m);k=k.length?"?"+k.join("\x26"):"";"encode"==f?(f=["javascript:void(location.href\x3d'mailto:'+",c(h)],k&&f.push("+'",a(k),"'"),f.push(")")):f=["mailto:",h,k];break;default:f=h.split("@",2),k.name=f[0],k.domain=f[1],f=["javascript:",b(d,k)]}g["data-cke-saved-href"]=
f.join("")}if(e.target)if("popup"==e.target.type){for(var f=["window.open(this.href, '",e.target.name||"","', '"],n="resizable status location toolbar menubar fullscreen scrollbars dependent".split(" "),h=n.length,l=function(a){e.target[a]&&n.push(a+"\x3d"+e.target[a])},k=0;k<h;k++)n[k]+=e.target[n[k]]?"\x3dyes":"\x3dno";l("width");l("left");l("height");l("top");f.push(n.join(","),"'); return false;");g["data-cke-pa-onclick"]=f.join("")}else"notSet"!=e.target.type&&e.target.name&&(g.target=e.target.name);
e.download&&(g.download="");if(e.advanced){for(var y in v)(f=e.advanced[v[y]])&&(g[y]=f);g.name&&(g["data-cke-saved-name"]=g.name)}g["data-cke-saved-href"]&&(g.href=g["data-cke-saved-href"]);y={target:1,onclick:1,"data-cke-pa-onclick":1,"data-cke-saved-name":1,download:1};e.advanced&&CKEDITOR.tools.extend(y,v);for(var p in g)delete y[p];return{set:g,removed:CKEDITOR.tools.objectKeys(y)}},showDisplayTextForElement:function(a,b){var c={img:1,table:1,tbody:1,thead:1,tfoot:1,input:1,select:1,textarea:1},
d=b.getSelection();return b.widgets&&b.widgets.focused||d&&1<d.getRanges().length?!1:!a||!a.getName||!a.is(c)}};CKEDITOR.unlinkCommand=function(){};CKEDITOR.unlinkCommand.prototype={exec:function(a){if(CKEDITOR.env.ie){var b=a.getSelection().getRanges()[0],c=b.getPreviousEditableNode()&&b.getPreviousEditableNode().getAscendant("a",!0)||b.getNextEditableNode()&&b.getNextEditableNode().getAscendant("a",!0),d;b.collapsed&&c&&(d=b.createBookmark(),b.selectNodeContents(c),b.select())}c=new CKEDITOR.style({element:"a",
type:CKEDITOR.STYLE_INLINE,alwaysRemoveElement:1});a.removeStyle(c);d&&(b.moveToBookmark(d),b.select())},refresh:function(a,b){var c=b.lastElement&&b.lastElement.getAscendant("a",!0);c&&"a"==c.getName()&&c.getAttribute("href")&&c.getChildCount()?this.setState(CKEDITOR.TRISTATE_OFF):this.setState(CKEDITOR.TRISTATE_DISABLED)},contextSensitive:1,startDisabled:1,requiredContent:"a[href]",editorFocus:1};CKEDITOR.removeAnchorCommand=function(){};CKEDITOR.removeAnchorCommand.prototype={exec:function(a){var b=
a.getSelection(),c=b.createBookmarks(),d;if(b&&(d=b.getSelectedElement())&&(d.getChildCount()?d.is("a"):CKEDITOR.plugins.link.tryRestoreFakeAnchor(a,d)))d.remove(1);else if(d=CKEDITOR.plugins.link.getSelectedLink(a))d.hasAttribute("href")?(d.removeAttributes({name:1,"data-cke-saved-name":1}),d.removeClass("cke_anchor")):d.remove(1);b.selectBookmarks(c)},requiredContent:"a[name]"};CKEDITOR.tools.extend(CKEDITOR.config,{linkShowAdvancedTab:!0,linkShowTargetTab:!0})}(),function(){function a(a,b,c){function d(c){if(!(!(l=
k[c?"getFirst":"getLast"]())||l.is&&l.isBlockBoundary()||!(m=b.root[c?"getPrevious":"getNext"](CKEDITOR.dom.walker.invisible(!0)))||m.is&&m.isBlockBoundary({br:1})))a.document.createElement("br")[c?"insertBefore":"insertAfter"](l)}for(var e=CKEDITOR.plugins.list.listToArray(b.root,c),f=[],g=0;g<b.contents.length;g++){var h=b.contents[g];(h=h.getAscendant("li",!0))&&!h.getCustomData("list_item_processed")&&(f.push(h),CKEDITOR.dom.element.setMarker(c,h,"list_item_processed",!0))}h=null;for(g=0;g<f.length;g++)h=
f[g].getCustomData("listarray_index"),e[h].indent=-1;for(g=h+1;g<e.length;g++)if(e[g].indent>e[g-1].indent+1){f=e[g-1].indent+1-e[g].indent;for(h=e[g].indent;e[g]&&e[g].indent>=h;)e[g].indent+=f,g++;g--}var k=CKEDITOR.plugins.list.arrayToList(e,c,null,a.config.enterMode,b.root.getAttribute("dir")).listNode,l,m;d(!0);d();k.replace(b.root);a.fire("contentDomInvalidated")}function c(a,b){this.name=a;this.context=this.type=b;this.allowedContent=b+" li";this.requiredContent=b}function b(a,b,c,d){for(var e,
f;e=a[d?"getLast":"getFirst"](q);)(f=e.getDirection(1))!==b.getDirection(1)&&e.setAttribute("dir",f),e.remove(),c?e[d?"insertBefore":"insertAfter"](c):b.append(e,d)}function e(a){function c(d){var e=a[d?"getPrevious":"getNext"](g);e&&e.type==CKEDITOR.NODE_ELEMENT&&e.is(a.getName())&&(b(a,e,null,!d),a.remove(),a=e)}c();c(1)}function h(a){return a.type==CKEDITOR.NODE_ELEMENT&&(a.getName()in CKEDITOR.dtd.$block||a.getName()in CKEDITOR.dtd.$listItem)&&CKEDITOR.dtd[a.getName()]["#"]}function l(a,c,d){a.fire("saveSnapshot");
d.enlarge(CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS);var f=d.extractContents();c.trim(!1,!0);var h=c.createBookmark(),l=new CKEDITOR.dom.elementPath(c.startContainer),m=l.block,l=l.lastElement.getAscendant("li",1)||m,p=new CKEDITOR.dom.elementPath(d.startContainer),C=p.contains(CKEDITOR.dtd.$listItem),p=p.contains(CKEDITOR.dtd.$list);m?(m=m.getBogus())&&m.remove():p&&(m=p.getPrevious(g))&&n(m)&&m.remove();(m=f.getLast())&&m.type==CKEDITOR.NODE_ELEMENT&&m.is("br")&&m.remove();(m=c.startContainer.getChild(c.startOffset))?
f.insertBefore(m):c.startContainer.append(f);C&&(f=k(C))&&(l.contains(C)?(b(f,C.getParent(),C),f.remove()):l.append(f));for(;d.checkStartOfBlock()&&d.checkEndOfBlock();){p=d.startPath();f=p.block;if(!f)break;f.is("li")&&(l=f.getParent(),f.equals(l.getLast(g))&&f.equals(l.getFirst(g))&&(f=l));d.moveToPosition(f,CKEDITOR.POSITION_BEFORE_START);f.remove()}d=d.clone();f=a.editable();d.setEndAt(f,CKEDITOR.POSITION_BEFORE_END);d=new CKEDITOR.dom.walker(d);d.evaluator=function(a){return g(a)&&!n(a)};(d=
d.next())&&d.type==CKEDITOR.NODE_ELEMENT&&d.getName()in CKEDITOR.dtd.$list&&e(d);c.moveToBookmark(h);c.select();a.fire("saveSnapshot")}function k(a){return(a=a.getLast(g))&&a.type==CKEDITOR.NODE_ELEMENT&&a.getName()in f?a:null}var f={ol:1,ul:1},d=CKEDITOR.dom.walker.whitespaces(),m=CKEDITOR.dom.walker.bookmark(),g=function(a){return!(d(a)||m(a))},n=CKEDITOR.dom.walker.bogus();CKEDITOR.plugins.list={listToArray:function(a,b,c,d,e){if(!f[a.getName()])return[];d||(d=0);c||(c=[]);for(var g=0,h=a.getChildCount();g<
h;g++){var k=a.getChild(g);k.type==CKEDITOR.NODE_ELEMENT&&k.getName()in CKEDITOR.dtd.$list&&CKEDITOR.plugins.list.listToArray(k,b,c,d+1);if("li"==k.$.nodeName.toLowerCase()){var l={parent:a,indent:d,element:k,contents:[]};e?l.grandparent=e:(l.grandparent=a.getParent(),l.grandparent&&"li"==l.grandparent.$.nodeName.toLowerCase()&&(l.grandparent=l.grandparent.getParent()));b&&CKEDITOR.dom.element.setMarker(b,k,"listarray_index",c.length);c.push(l);for(var m=0,n=k.getChildCount(),p;m<n;m++)p=k.getChild(m),
p.type==CKEDITOR.NODE_ELEMENT&&f[p.getName()]?CKEDITOR.plugins.list.listToArray(p,b,c,d+1,l.grandparent):l.contents.push(p)}}return c},arrayToList:function(a,b,c,d,e){c||(c=0);if(!a||a.length<c+1)return null;for(var h,k=a[c].parent.getDocument(),l=new CKEDITOR.dom.documentFragment(k),n=null,x=c,A=Math.max(a[c].indent,0),p=null,q,E,I=d==CKEDITOR.ENTER_P?"p":"div";;){var G=a[x];h=G.grandparent;q=G.element.getDirection(1);if(G.indent==A){n&&a[x].parent.getName()==n.getName()||(n=a[x].parent.clone(!1,
1),e&&n.setAttribute("dir",e),l.append(n));p=n.append(G.element.clone(0,1));q!=n.getDirection(1)&&p.setAttribute("dir",q);for(h=0;h<G.contents.length;h++)p.append(G.contents[h].clone(1,1));x++}else if(G.indent==Math.max(A,0)+1)G=a[x-1].element.getDirection(1),x=CKEDITOR.plugins.list.arrayToList(a,null,x,d,G!=q?q:null),!p.getChildCount()&&CKEDITOR.env.needsNbspFiller&&7>=k.$.documentMode&&p.append(k.createText(" ")),p.append(x.listNode),x=x.nextIndex;else if(-1==G.indent&&!c&&h){f[h.getName()]?(p=
G.element.clone(!1,!0),q!=h.getDirection(1)&&p.setAttribute("dir",q)):p=new CKEDITOR.dom.documentFragment(k);var n=h.getDirection(1)!=q,K=G.element,J=K.getAttribute("class"),F=K.getAttribute("style"),S=p.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT&&(d!=CKEDITOR.ENTER_BR||n||F||J),N,Q=G.contents.length,M;for(h=0;h<Q;h++)if(N=G.contents[h],m(N)&&1<Q)S?M=N.clone(1,1):p.append(N.clone(1,1));else if(N.type==CKEDITOR.NODE_ELEMENT&&N.isBlockBoundary()){n&&!N.getDirection()&&N.setAttribute("dir",q);E=N;var U=K.getAttribute("style");
U&&E.setAttribute("style",U.replace(/([^;])$/,"$1;")+(E.getAttribute("style")||""));J&&N.addClass(J);E=null;M&&(p.append(M),M=null);p.append(N.clone(1,1))}else S?(E||(E=k.createElement(I),p.append(E),n&&E.setAttribute("dir",q)),F&&E.setAttribute("style",F),J&&E.setAttribute("class",J),M&&(E.append(M),M=null),E.append(N.clone(1,1))):p.append(N.clone(1,1));M&&((E||p).append(M),M=null);p.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT&&x!=a.length-1&&(CKEDITOR.env.needsBrFiller&&(q=p.getLast())&&q.type==CKEDITOR.NODE_ELEMENT&&
q.is("br")&&q.remove(),(q=p.getLast(g))&&q.type==CKEDITOR.NODE_ELEMENT&&q.is(CKEDITOR.dtd.$block)||p.append(k.createElement("br")));q=p.$.nodeName.toLowerCase();"div"!=q&&"p"!=q||p.appendBogus();l.append(p);n=null;x++}else return null;E=null;if(a.length<=x||Math.max(a[x].indent,0)<A)break}if(b)for(a=l.getFirst();a;){if(a.type==CKEDITOR.NODE_ELEMENT&&(CKEDITOR.dom.element.clearMarkers(b,a),a.getName()in CKEDITOR.dtd.$listItem&&(c=a,k=e=d=void 0,d=c.getDirection()))){for(e=c.getParent();e&&!(k=e.getDirection());)e=
e.getParent();d==k&&c.removeAttribute("dir")}a=a.getNextSourceNode()}return{listNode:l,nextIndex:x}}};var p=/^h[1-6]$/,q=CKEDITOR.dom.walker.nodeType(CKEDITOR.NODE_ELEMENT);c.prototype={exec:function(b){this.refresh(b,b.elementPath());var c=b.config,d=b.getSelection(),h=d&&d.getRanges();if(this.state==CKEDITOR.TRISTATE_OFF){var k=b.editable();if(k.getFirst(g)){var l=1==h.length&&h[0];(c=l&&l.getEnclosedNode())&&c.is&&this.type==c.getName()&&this.setState(CKEDITOR.TRISTATE_ON)}else c.enterMode==CKEDITOR.ENTER_BR?
k.appendBogus():h[0].fixBlock(1,c.enterMode==CKEDITOR.ENTER_P?"p":"div"),d.selectRanges(h)}for(var c=d.createBookmarks(!0),k=[],m={},h=h.createIterator(),n=0;(l=h.getNextRange())&&++n;){var q=l.getBoundaryNodes(),x=q.startNode,A=q.endNode;x.type==CKEDITOR.NODE_ELEMENT&&"td"==x.getName()&&l.setStartAt(q.startNode,CKEDITOR.POSITION_AFTER_START);A.type==CKEDITOR.NODE_ELEMENT&&"td"==A.getName()&&l.setEndAt(q.endNode,CKEDITOR.POSITION_BEFORE_END);l=l.createIterator();for(l.forceBrBreak=this.state==CKEDITOR.TRISTATE_OFF;q=
l.getNextParagraph();)if(!q.getCustomData("list_block")){CKEDITOR.dom.element.setMarker(m,q,"list_block",1);for(var D=b.elementPath(q),x=D.elements,A=0,D=D.blockLimit,H,E=x.length-1;0<=E&&(H=x[E]);E--)if(f[H.getName()]&&D.contains(H)){D.removeCustomData("list_group_object_"+n);(x=H.getCustomData("list_group_object"))?x.contents.push(q):(x={root:H,contents:[q]},k.push(x),CKEDITOR.dom.element.setMarker(m,H,"list_group_object",x));A=1;break}A||(A=D,A.getCustomData("list_group_object_"+n)?A.getCustomData("list_group_object_"+
n).contents.push(q):(x={root:A,contents:[q]},CKEDITOR.dom.element.setMarker(m,A,"list_group_object_"+n,x),k.push(x)))}}for(H=[];0<k.length;)if(x=k.shift(),this.state==CKEDITOR.TRISTATE_OFF)if(f[x.root.getName()]){h=b;n=x;x=m;l=H;A=CKEDITOR.plugins.list.listToArray(n.root,x);D=[];for(q=0;q<n.contents.length;q++)E=n.contents[q],(E=E.getAscendant("li",!0))&&!E.getCustomData("list_item_processed")&&(D.push(E),CKEDITOR.dom.element.setMarker(x,E,"list_item_processed",!0));for(var E=n.root.getDocument(),
I=void 0,G=void 0,q=0;q<D.length;q++){var K=D[q].getCustomData("listarray_index"),I=A[K].parent;I.is(this.type)||(G=E.createElement(this.type),I.copyAttributes(G,{start:1,type:1}),G.removeStyle("list-style-type"),A[K].parent=G)}x=CKEDITOR.plugins.list.arrayToList(A,x,null,h.config.enterMode);A=void 0;D=x.listNode.getChildCount();for(q=0;q<D&&(A=x.listNode.getChild(q));q++)A.getName()==this.type&&l.push(A);x.listNode.replace(n.root);h.fire("contentDomInvalidated")}else{A=b;l=x;q=H;D=l.contents;h=l.root.getDocument();
n=[];1==D.length&&D[0].equals(l.root)&&(x=h.createElement("div"),D[0].moveChildren&&D[0].moveChildren(x),D[0].append(x),D[0]=x);l=l.contents[0].getParent();for(E=0;E<D.length;E++)l=l.getCommonAncestor(D[E].getParent());I=A.config.useComputedState;A=x=void 0;I=void 0===I||I;for(E=0;E<D.length;E++)for(G=D[E];K=G.getParent();){if(K.equals(l)){n.push(G);!A&&G.getDirection()&&(A=1);G=G.getDirection(I);null!==x&&(x=x&&x!=G?null:G);break}G=K}if(!(1>n.length)){D=n[n.length-1].getNext();E=h.createElement(this.type);
q.push(E);for(I=q=void 0;n.length;)q=n.shift(),I=h.createElement("li"),G=q,G.is("pre")||p.test(G.getName())||"false"==G.getAttribute("contenteditable")?q.appendTo(I):(q.copyAttributes(I),x&&q.getDirection()&&(I.removeStyle("direction"),I.removeAttribute("dir")),q.moveChildren(I),q.remove()),I.appendTo(E);x&&A&&E.setAttribute("dir",x);D?E.insertBefore(D):E.appendTo(l)}}else this.state==CKEDITOR.TRISTATE_ON&&f[x.root.getName()]&&a.call(this,b,x,m);for(E=0;E<H.length;E++)e(H[E]);CKEDITOR.dom.element.clearAllMarkers(m);
d.selectBookmarks(c);b.focus()},refresh:function(a,b){var c=b.contains(f,1),d=b.blockLimit||b.root;c&&d.contains(c)?this.setState(c.is(this.type)?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF):this.setState(CKEDITOR.TRISTATE_OFF)}};CKEDITOR.plugins.add("list",{requires:"indentlist",init:function(a){a.blockless||(a.addCommand("numberedlist",new c("numberedlist","ol")),a.addCommand("bulletedlist",new c("bulletedlist","ul")),a.ui.addButton&&(a.ui.addButton("NumberedList",{label:a.lang.list.numberedlist,
command:"numberedlist",directional:!0,toolbar:"list,10"}),a.ui.addButton("BulletedList",{label:a.lang.list.bulletedlist,command:"bulletedlist",directional:!0,toolbar:"list,20"})),a.on("key",function(b){var c=b.data.domEvent.getKey(),d;if("wysiwyg"==a.mode&&c in{8:1,46:1}){var e=a.getSelection().getRanges()[0],m=e&&e.startPath();if(e&&e.collapsed){var u=8==c,p=a.editable(),q=new CKEDITOR.dom.walker(e.clone());q.evaluator=function(a){return g(a)&&!n(a)};q.guard=function(a,b){return!(b&&a.type==CKEDITOR.NODE_ELEMENT&&
a.is("table"))};c=e.clone();if(u){var x;(x=m.contains(f))&&e.checkBoundaryOfElement(x,CKEDITOR.START)&&(x=x.getParent())&&x.is("li")&&(x=k(x))?(d=x,x=x.getPrevious(g),c.moveToPosition(x&&n(x)?x:d,CKEDITOR.POSITION_BEFORE_START)):(q.range.setStartAt(p,CKEDITOR.POSITION_AFTER_START),q.range.setEnd(e.startContainer,e.startOffset),(x=q.previous())&&x.type==CKEDITOR.NODE_ELEMENT&&(x.getName()in f||x.is("li"))&&(x.is("li")||(q.range.selectNodeContents(x),q.reset(),q.evaluator=h,x=q.previous()),d=x,c.moveToElementEditEnd(d),
c.moveToPosition(c.endPath().block,CKEDITOR.POSITION_BEFORE_END)));if(d)l(a,c,e),b.cancel();else{var A=m.contains(f);A&&e.checkBoundaryOfElement(A,CKEDITOR.START)&&(d=A.getFirst(g),e.checkBoundaryOfElement(d,CKEDITOR.START)&&(x=A.getPrevious(g),k(d)?x&&(e.moveToElementEditEnd(x),e.select()):a.execCommand("outdent"),b.cancel()))}}else if(d=m.contains("li")){if(q.range.setEndAt(p,CKEDITOR.POSITION_BEFORE_END),u=(p=d.getLast(g))&&h(p)?p:d,m=0,(x=q.next())&&x.type==CKEDITOR.NODE_ELEMENT&&x.getName()in
f&&x.equals(p)?(m=1,x=q.next()):e.checkBoundaryOfElement(u,CKEDITOR.END)&&(m=2),m&&x){e=e.clone();e.moveToElementEditStart(x);if(1==m&&(c.optimize(),!c.startContainer.equals(d))){for(d=c.startContainer;d.is(CKEDITOR.dtd.$inline);)A=d,d=d.getParent();A&&c.moveToPosition(A,CKEDITOR.POSITION_AFTER_END)}2==m&&(c.moveToPosition(c.endPath().block,CKEDITOR.POSITION_BEFORE_END),e.endPath().block&&e.moveToPosition(e.endPath().block,CKEDITOR.POSITION_AFTER_START));l(a,c,e);b.cancel()}}else q.range.setEndAt(p,
CKEDITOR.POSITION_BEFORE_END),(x=q.next())&&x.type==CKEDITOR.NODE_ELEMENT&&x.is(f)&&(x=x.getFirst(g),m.block&&e.checkStartOfBlock()&&e.checkEndOfBlock()?(m.block.remove(),e.moveToElementEditStart(x),e.select()):k(x)?(e.moveToElementEditStart(x),e.select()):(e=e.clone(),e.moveToElementEditStart(x),l(a,c,e)),b.cancel());setTimeout(function(){a.selectionChange(1)})}}}))}})}(),function(){CKEDITOR.plugins.liststyle={requires:"dialog,contextmenu",init:function(a){if(!a.blockless){var c;c=new CKEDITOR.dialogCommand("numberedListStyle",
{requiredContent:"ol",allowedContent:"ol{list-style-type}[start]; li{list-style-type}[value]",contentTransformations:[["ol: listTypeToStyle"]]});c=a.addCommand("numberedListStyle",c);a.addFeature(c);CKEDITOR.dialog.add("numberedListStyle",this.path+"dialogs/liststyle.js");c=new CKEDITOR.dialogCommand("bulletedListStyle",{requiredContent:"ul",allowedContent:"ul{list-style-type}",contentTransformations:[["ul: listTypeToStyle"]]});c=a.addCommand("bulletedListStyle",c);a.addFeature(c);CKEDITOR.dialog.add("bulletedListStyle",
this.path+"dialogs/liststyle.js");a.addMenuGroup("list",108);a.addMenuItems({numberedlist:{label:a.lang.liststyle.numberedTitle,group:"list",command:"numberedListStyle"},bulletedlist:{label:a.lang.liststyle.bulletedTitle,group:"list",command:"bulletedListStyle"}});a.contextMenu.addListener(function(a){if(!a||a.isReadOnly())return null;for(;a;){var c=a.getName();if("ol"==c)return{numberedlist:CKEDITOR.TRISTATE_OFF};if("ul"==c)return{bulletedlist:CKEDITOR.TRISTATE_OFF};a=a.getParent()}return null})}}};
CKEDITOR.plugins.add("liststyle",CKEDITOR.plugins.liststyle)}(),"use strict",function(){function a(a,b,c){return n(b)&&n(c)&&c.equals(b.getNext(function(a){return!(aa(a)||ba(a)||p(a))}))}function c(a){this.upper=a[0];this.lower=a[1];this.set.apply(this,a.slice(2))}function b(a){var b=a.element;if(b&&n(b)&&(b=b.getAscendant(a.triggers,!0))&&a.editable.contains(b)){var c=k(b);if("true"==c.getAttribute("contenteditable"))return b;if(c.is(a.triggers))return c}return null}function e(a,b,c){u(a,b);u(a,
c);a=b.size.bottom;c=c.size.top;return a&&c?0|(a+c)/2:a||c}function h(a,b,c){return b=b[c?"getPrevious":"getNext"](function(b){return b&&b.type==CKEDITOR.NODE_TEXT&&!aa(b)||n(b)&&!p(b)&&!g(a,b)})}function l(a,b,c){return a>b&&a<c}function k(a,b){if(a.data("cke-editable"))return null;for(b||(a=a.getParent());a&&!a.data("cke-editable");){if(a.hasAttribute("contenteditable"))return a;a=a.getParent()}return null}function f(a){var b=a.doc,c=H('\x3cspan contenteditable\x3d"false" style\x3d"'+T+"position:absolute;border-top:1px dashed "+
a.boxColor+'"\x3e\x3c/span\x3e',b),e=CKEDITOR.getUrl(this.path+"images/"+(E.hidpi?"hidpi/":"")+"icon"+(a.rtl?"-rtl":"")+".png");A(c,{attach:function(){this.wrap.getParent()||this.wrap.appendTo(a.editable,!0);return this},lineChildren:[A(H('\x3cspan title\x3d"'+a.editor.lang.magicline.title+'" contenteditable\x3d"false"\x3e\x26#8629;\x3c/span\x3e',b),{base:T+"height:17px;width:17px;"+(a.rtl?"left":"right")+":17px;background:url("+e+") center no-repeat "+a.boxColor+";cursor:pointer;"+(E.hc?"font-size: 15px;line-height:14px;border:1px solid #fff;text-align:center;":
"")+(E.hidpi?"background-size: 9px 10px;":""),looks:["top:-8px; border-radius: 2px;","top:-17px; border-radius: 2px 2px 0px 0px;","top:-1px; border-radius: 0px 0px 2px 2px;"]}),A(H(Y,b),{base:R+"left:0px;border-left-color:"+a.boxColor+";",looks:["border-width:8px 0 8px 8px;top:-8px","border-width:8px 0 0 8px;top:-8px","border-width:0 0 8px 8px;top:0px"]}),A(H(Y,b),{base:R+"right:0px;border-right-color:"+a.boxColor+";",looks:["border-width:8px 8px 8px 0;top:-8px","border-width:8px 8px 0 0;top:-8px",
"border-width:0 8px 8px 0;top:0px"]})],detach:function(){this.wrap.getParent()&&this.wrap.remove();return this},mouseNear:function(){u(a,this);var b=a.holdDistance,c=this.size;return c&&l(a.mouse.y,c.top-b,c.bottom+b)&&l(a.mouse.x,c.left-b,c.right+b)?!0:!1},place:function(){var b=a.view,c=a.editable,d=a.trigger,e=d.upper,f=d.lower,g=e||f,h=g.getParent(),k={};this.trigger=d;e&&u(a,e,!0);f&&u(a,f,!0);u(a,h,!0);a.inInlineMode&&B(a,!0);h.equals(c)?(k.left=b.scroll.x,k.right=-b.scroll.x,k.width=""):(k.left=
g.size.left-g.size.margin.left+b.scroll.x-(a.inInlineMode?b.editable.left+b.editable.border.left:0),k.width=g.size.outerWidth+g.size.margin.left+g.size.margin.right+b.scroll.x,k.right="");e&&f?k.top=e.size.margin.bottom===f.size.margin.top?0|e.size.bottom+e.size.margin.bottom/2:e.size.margin.bottom<f.size.margin.top?e.size.bottom+e.size.margin.bottom:e.size.bottom+e.size.margin.bottom-f.size.margin.top:e?f||(k.top=e.size.bottom+e.size.margin.bottom):k.top=f.size.top-f.size.margin.top;d.is(Q)||l(k.top,
b.scroll.y-15,b.scroll.y+5)?(k.top=a.inInlineMode?0:b.scroll.y,this.look(Q)):d.is(M)||l(k.top,b.pane.bottom-5,b.pane.bottom+15)?(k.top=a.inInlineMode?b.editable.height+b.editable.padding.top+b.editable.padding.bottom:b.pane.bottom-1,this.look(M)):(a.inInlineMode&&(k.top-=b.editable.top+b.editable.border.top),this.look(U));a.inInlineMode&&(k.top--,k.top+=b.editable.scroll.top,k.left+=b.editable.scroll.left);for(var m in k)k[m]=CKEDITOR.tools.cssLength(k[m]);this.setStyles(k)},look:function(a){if(this.oldLook!=
a){for(var b=this.lineChildren.length,c;b--;)(c=this.lineChildren[b]).setAttribute("style",c.base+c.looks[0|a/2]);this.oldLook=a}},wrap:new D("span",a.doc)});for(b=c.lineChildren.length;b--;)c.lineChildren[b].appendTo(c);c.look(U);c.appendTo(c.wrap);c.unselectable();c.lineChildren[0].on("mouseup",function(b){c.detach();d(a,function(b){var c=a.line.trigger;b[c.is(J)?"insertBefore":"insertAfter"](c.is(J)?c.lower:c.upper)},!0);a.editor.focus();E.ie||a.enterMode==CKEDITOR.ENTER_BR||a.hotNode.scrollIntoView();
b.data.preventDefault(!0)});c.on("mousedown",function(a){a.data.preventDefault(!0)});a.line=c}function d(a,b,c){var d=new CKEDITOR.dom.range(a.doc),e=a.editor,f;E.ie&&a.enterMode==CKEDITOR.ENTER_BR?f=a.doc.createText(Z):(f=(f=k(a.element,!0))&&f.data("cke-enter-mode")||a.enterMode,f=new D(K[f],a.doc),f.is("br")||a.doc.createText(Z).appendTo(f));c&&e.fire("saveSnapshot");b(f);d.moveToPosition(f,CKEDITOR.POSITION_AFTER_START);e.getSelection().selectRanges([d]);a.hotNode=f;c&&e.fire("saveSnapshot")}
function m(a,c){return{canUndo:!0,modes:{wysiwyg:1},exec:function(){function e(b){var f=E.ie&&9>E.version?" ":Z,g=a.hotNode&&a.hotNode.getText()==f&&a.element.equals(a.hotNode)&&a.lastCmdDirection===!!c;d(a,function(d){g&&a.hotNode&&a.hotNode.remove();d[c?"insertAfter":"insertBefore"](b);d.setAttributes({"data-cke-magicline-hot":1,"data-cke-magicline-dir":!!c});a.lastCmdDirection=!!c});E.ie||a.enterMode==CKEDITOR.ENTER_BR||a.hotNode.scrollIntoView();a.line.detach()}return function(d){d=d.getSelection().getStartElement();
var f;d=d.getAscendant(P,1);if(!v(a,d)&&d&&!d.equals(a.editable)&&!d.contains(a.editable)){(f=k(d))&&"false"==f.getAttribute("contenteditable")&&(d=f);a.element=d;f=h(a,d,!c);var g;n(f)&&f.is(a.triggers)&&f.is(O)&&(!h(a,f,!c)||(g=h(a,f,!c))&&n(g)&&g.is(a.triggers))?e(f):(g=b(a,d),n(g)&&(h(a,g,!c)?(d=h(a,g,!c))&&n(d)&&d.is(a.triggers)&&e(g):e(g)))}}}()}}function g(a,b){if(!b||b.type!=CKEDITOR.NODE_ELEMENT||!b.$)return!1;var c=a.line;return c.wrap.equals(b)||c.wrap.contains(b)}function n(a){return a&&
a.type==CKEDITOR.NODE_ELEMENT&&a.$}function p(a){if(!n(a))return!1;var b;(b=q(a))||(n(a)?(b={left:1,right:1,center:1},b=!(!b[a.getComputedStyle("float")]&&!b[a.getAttribute("align")])):b=!1);return b}function q(a){return!!{absolute:1,fixed:1}[a.getComputedStyle("position")]}function y(a,b){return n(b)?b.is(a.triggers):null}function v(a,b){if(!b)return!1;for(var c=b.getParents(1),d=c.length;d--;)for(var e=a.tabuList.length;e--;)if(c[d].hasAttribute(a.tabuList[e]))return!0;return!1}function t(a,b,c){b=
b[c?"getLast":"getFirst"](function(b){return a.isRelevant(b)&&!b.is(da)});if(!b)return!1;u(a,b);return c?b.size.top>a.mouse.y:b.size.bottom<a.mouse.y}function r(a){var b=a.editable,d=a.mouse,e=a.view,f=a.triggerOffset;B(a);var h=d.y>(a.inInlineMode?e.editable.top+e.editable.height/2:Math.min(e.editable.height,e.pane.height)/2),b=b[h?"getLast":"getFirst"](function(a){return!(aa(a)||ba(a))});if(!b)return null;g(a,b)&&(b=a.line.wrap[h?"getPrevious":"getNext"](function(a){return!(aa(a)||ba(a))}));if(!n(b)||
p(b)||!y(a,b))return null;u(a,b);return!h&&0<=b.size.top&&l(d.y,0,b.size.top+f)?(a=a.inInlineMode||0===e.scroll.y?Q:U,new c([null,b,J,N,a])):h&&b.size.bottom<=e.pane.height&&l(d.y,b.size.bottom-f,e.pane.height)?(a=a.inInlineMode||l(b.size.bottom,e.pane.height-f,e.pane.height)?M:U,new c([b,null,F,N,a])):null}function w(a){var d=a.mouse,e=a.view,f=a.triggerOffset,g=b(a);if(!g)return null;u(a,g);var f=Math.min(f,0|g.size.outerHeight/2),k=[],m,x;if(l(d.y,g.size.top-1,g.size.top+f))x=!1;else if(l(d.y,
g.size.bottom-f,g.size.bottom+1))x=!0;else return null;if(p(g)||t(a,g,x)||g.getParent().is(W))return null;var r=h(a,g,!x);if(r){if(r&&r.type==CKEDITOR.NODE_TEXT)return null;if(n(r)){if(p(r)||!y(a,r)||r.getParent().is(W))return null;k=[r,g][x?"reverse":"concat"]().concat([S,N])}}else g.equals(a.editable[x?"getLast":"getFirst"](a.isRelevant))?(B(a),x&&l(d.y,g.size.bottom-f,e.pane.height)&&l(g.size.bottom,e.pane.height-f,e.pane.height)?m=M:l(d.y,0,g.size.top+f)&&(m=Q)):m=U,k=[null,g][x?"reverse":"concat"]().concat([x?
F:J,N,m,g.equals(a.editable[x?"getLast":"getFirst"](a.isRelevant))?x?M:Q:U]);return 0 in k?new c(k):null}function z(a,b,c,d){for(var e=b.getDocumentPosition(),f={},g={},h={},k={},l=ca.length;l--;)f[ca[l]]=parseInt(b.getComputedStyle.call(b,"border-"+ca[l]+"-width"),10)||0,h[ca[l]]=parseInt(b.getComputedStyle.call(b,"padding-"+ca[l]),10)||0,g[ca[l]]=parseInt(b.getComputedStyle.call(b,"margin-"+ca[l]),10)||0;c&&!d||C(a,d);k.top=e.y-(c?0:a.view.scroll.y);k.left=e.x-(c?0:a.view.scroll.x);k.outerWidth=
b.$.offsetWidth;k.outerHeight=b.$.offsetHeight;k.height=k.outerHeight-(h.top+h.bottom+f.top+f.bottom);k.width=k.outerWidth-(h.left+h.right+f.left+f.right);k.bottom=k.top+k.outerHeight;k.right=k.left+k.outerWidth;a.inInlineMode&&(k.scroll={top:b.$.scrollTop,left:b.$.scrollLeft});return A({border:f,padding:h,margin:g,ignoreScroll:c},k,!0)}function u(a,b,c){if(!n(b))return b.size=null;if(!b.size)b.size={};else if(b.size.ignoreScroll==c&&b.size.date>new Date-L)return null;return A(b.size,z(a,b,c),{date:+new Date},
!0)}function B(a,b){a.view.editable=z(a,a.editable,b,!0)}function C(a,b){a.view||(a.view={});var c=a.view;if(!(!b&&c&&c.date>new Date-L)){var d=a.win,c=d.getScrollPosition(),d=d.getViewPaneSize();A(a.view,{scroll:{x:c.x,y:c.y,width:a.doc.$.documentElement.scrollWidth-d.width,height:a.doc.$.documentElement.scrollHeight-d.height},pane:{width:d.width,height:d.height,bottom:d.height+c.y},date:+new Date},!0)}}function x(a,b,d,e){for(var f=e,g=e,h=0,k=!1,l=!1,m=a.view.pane.height,n=a.mouse;n.y+h<m&&0<n.y-
h;){k||(k=b(f,e));l||(l=b(g,e));!k&&0<n.y-h&&(f=d(a,{x:n.x,y:n.y-h}));!l&&n.y+h<m&&(g=d(a,{x:n.x,y:n.y+h}));if(k&&l)break;h+=2}return new c([f,g,null,null])}CKEDITOR.plugins.add("magicline",{init:function(a){var e=a.config,k=e.magicline_triggerOffset||30,l={editor:a,enterMode:e.enterMode,triggerOffset:k,holdDistance:0|k*(e.magicline_holdDistance||.5),boxColor:e.magicline_color||"#ff0000",rtl:"rtl"==e.contentsLangDirection,tabuList:["data-cke-hidden-sel"].concat(e.magicline_tabuList||[]),triggers:e.magicline_everywhere?
P:{table:1,hr:1,div:1,ul:1,ol:1,dl:1,form:1,blockquote:1}},u,x,t;l.isRelevant=function(a){return n(a)&&!g(l,a)&&!p(a)};a.on("contentDom",function(){var k=a.editable(),n=a.document,p=a.window;A(l,{editable:k,inInlineMode:k.isInline(),doc:n,win:p,hotNode:null},!0);l.boundary=l.inInlineMode?l.editable:l.doc.getDocumentElement();k.is(G.$inline)||(l.inInlineMode&&!q(k)&&k.setStyles({position:"relative",top:null,left:null}),f.call(this,l),C(l),k.attachListener(a,"beforeUndoImage",function(){l.line.detach()}),
k.attachListener(a,"beforeGetData",function(){l.line.wrap.getParent()&&(l.line.detach(),a.once("getData",function(){l.line.attach()},null,null,1E3))},null,null,0),k.attachListener(l.inInlineMode?n:n.getWindow().getFrame(),"mouseout",function(b){if("wysiwyg"==a.mode)if(l.inInlineMode){var c=b.data.$.clientX;b=b.data.$.clientY;C(l);B(l,!0);var d=l.view.editable,e=l.view.scroll;c>d.left-e.x&&c<d.right-e.x&&b>d.top-e.y&&b<d.bottom-e.y||(clearTimeout(t),t=null,l.line.detach())}else clearTimeout(t),t=null,
l.line.detach()}),k.attachListener(k,"keyup",function(){l.hiddenMode=0}),k.attachListener(k,"keydown",function(b){if("wysiwyg"==a.mode)switch(b.data.getKeystroke()){case 2228240:case 16:l.hiddenMode=1,l.line.detach()}}),k.attachListener(l.inInlineMode?k:n,"mousemove",function(b){x=!0;if("wysiwyg"==a.mode&&!a.readOnly&&!t){var c={x:b.data.$.clientX,y:b.data.$.clientY};t=setTimeout(function(){l.mouse=c;t=l.trigger=null;C(l);x&&!l.hiddenMode&&a.focusManager.hasFocus&&!l.line.mouseNear()&&(l.element=
V(l,!0))&&((l.trigger=r(l)||w(l)||X(l))&&!v(l,l.trigger.upper||l.trigger.lower)?l.line.attach().place():(l.trigger=null,l.line.detach()),x=!1)},30)}}),k.attachListener(p,"scroll",function(){"wysiwyg"==a.mode&&(l.line.detach(),E.webkit&&(l.hiddenMode=1,clearTimeout(u),u=setTimeout(function(){l.mouseDown||(l.hiddenMode=0)},50)))}),k.attachListener(I?n:p,"mousedown",function(){"wysiwyg"==a.mode&&(l.line.detach(),l.hiddenMode=1,l.mouseDown=1)}),k.attachListener(I?n:p,"mouseup",function(){l.hiddenMode=
0;l.mouseDown=0}),a.addCommand("accessPreviousSpace",m(l)),a.addCommand("accessNextSpace",m(l,!0)),a.setKeystroke([[e.magicline_keystrokePrevious,"accessPreviousSpace"],[e.magicline_keystrokeNext,"accessNextSpace"]]),a.on("loadSnapshot",function(){var b,c,d,e;for(e in{p:1,br:1,div:1})for(b=a.document.getElementsByTag(e),d=b.count();d--;)if((c=b.getItem(d)).data("cke-magicline-hot")){l.hotNode=c;l.lastCmdDirection="true"===c.data("cke-magicline-dir")?!0:!1;return}}),this.backdoor={accessFocusSpace:d,
boxTrigger:c,isLine:g,getAscendantTrigger:b,getNonEmptyNeighbour:h,getSize:z,that:l,triggerEdge:w,triggerEditable:r,triggerExpand:X})},this)}});var A=CKEDITOR.tools.extend,D=CKEDITOR.dom.element,H=D.createFromHtml,E=CKEDITOR.env,I=CKEDITOR.env.ie&&9>CKEDITOR.env.version,G=CKEDITOR.dtd,K={},J=128,F=64,S=32,N=16,Q=4,M=2,U=1,Z=" ",W=G.$listItem,da=G.$tableContent,O=A({},G.$nonEditable,G.$empty),P=G.$block,L=100,T="width:0px;height:0px;padding:0px;margin:0px;display:block;z-index:9999;color:#fff;position:absolute;font-size: 0px;line-height:0px;",
R=T+"border-color:transparent;display:block;border-style:solid;",Y="\x3cspan\x3e"+Z+"\x3c/span\x3e";K[CKEDITOR.ENTER_BR]="br";K[CKEDITOR.ENTER_P]="p";K[CKEDITOR.ENTER_DIV]="div";c.prototype={set:function(a,b,c){this.properties=a+b+(c||U);return this},is:function(a){return(this.properties&a)==a}};var V=function(){function a(b,c){var d=b.$.elementFromPoint(c.x,c.y);return d&&d.nodeType?new CKEDITOR.dom.element(d):null}return function(b,c,d){if(!b.mouse)return null;var e=b.doc,f=b.line.wrap;d=d||b.mouse;
var h=a(e,d);c&&g(b,h)&&(f.hide(),h=a(e,d),f.show());return!h||h.type!=CKEDITOR.NODE_ELEMENT||!h.$||E.ie&&9>E.version&&!b.boundary.equals(h)&&!b.boundary.contains(h)?null:h}}(),aa=CKEDITOR.dom.walker.whitespaces(),ba=CKEDITOR.dom.walker.nodeType(CKEDITOR.NODE_COMMENT),X=function(){function b(d){var f=d.element,g,h,k;if(!n(f)||f.contains(d.editable)||f.isReadOnly())return null;k=x(d,function(a,b){return!b.equals(a)},function(a,b){return V(a,!0,b)},f);g=k.upper;h=k.lower;if(a(d,g,h))return k.set(S,
8);if(g&&f.contains(g))for(;!g.getParent().equals(f);)g=g.getParent();else g=f.getFirst(function(a){return c(d,a)});if(h&&f.contains(h))for(;!h.getParent().equals(f);)h=h.getParent();else h=f.getLast(function(a){return c(d,a)});if(!g||!h)return null;u(d,g);u(d,h);if(!l(d.mouse.y,g.size.top,h.size.bottom))return null;for(var f=Number.MAX_VALUE,m,r,t,p;h&&!h.equals(g)&&(r=g.getNext(d.isRelevant));)m=Math.abs(e(d,g,r)-d.mouse.y),m<f&&(f=m,t=g,p=r),g=r,u(d,g);if(!t||!p||!l(d.mouse.y,t.size.top,p.size.bottom))return null;
k.upper=t;k.lower=p;return k.set(S,8)}function c(a,b){return!(b&&b.type==CKEDITOR.NODE_TEXT||ba(b)||p(b)||g(a,b)||b.type==CKEDITOR.NODE_ELEMENT&&b.$&&b.is("br"))}return function(c){var d=b(c),e;if(e=d){e=d.upper;var f=d.lower;e=!e||!f||p(f)||p(e)||f.equals(e)||e.equals(f)||f.contains(e)||e.contains(f)?!1:y(c,e)&&y(c,f)&&a(c,e,f)?!0:!1}return e?d:null}}(),ca=["top","left","right","bottom"]}(),CKEDITOR.config.magicline_keystrokePrevious=CKEDITOR.CTRL+CKEDITOR.SHIFT+51,CKEDITOR.config.magicline_keystrokeNext=
CKEDITOR.CTRL+CKEDITOR.SHIFT+52,function(){function a(a){if(!a||a.type!=CKEDITOR.NODE_ELEMENT||"form"!=a.getName())return[];for(var b=[],c=["style","className"],d=0;d<c.length;d++){var e=a.$.elements.namedItem(c[d]);e&&(e=new CKEDITOR.dom.element(e),b.push([e,e.nextSibling]),e.remove())}return b}function c(a,b){if(a&&a.type==CKEDITOR.NODE_ELEMENT&&"form"==a.getName()&&0<b.length)for(var c=b.length-1;0<=c;c--){var d=b[c][0],e=b[c][1];e?d.insertBefore(e):d.appendTo(a)}}function b(b,e){var f=a(b),d=
{},h=b.$;e||(d["class"]=h.className||"",h.className="");d.inline=h.style.cssText||"";e||(h.style.cssText="position: static; overflow: visible");c(f);return d}function e(b,e){var f=a(b),d=b.$;"class"in e&&(d.className=e["class"]);"inline"in e&&(d.style.cssText=e.inline);c(f)}function h(a){if(!a.editable().isInline()){var b=CKEDITOR.instances,c;for(c in b){var d=b[c];"wysiwyg"!=d.mode||d.readOnly||(d=d.document.getBody(),d.setAttribute("contentEditable",!1),d.setAttribute("contentEditable",!0))}a.editable().hasFocus&&
(a.toolbox.focus(),a.focus())}}CKEDITOR.plugins.add("maximize",{init:function(a){function c(){var b=m.getViewPaneSize();a.resize(b.width,b.height,null,!0)}if(a.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE){var f=a.lang,d=CKEDITOR.document,m=d.getWindow(),g,n,p,q=CKEDITOR.TRISTATE_OFF;a.addCommand("maximize",{modes:{wysiwyg:!CKEDITOR.env.iOS,source:!CKEDITOR.env.iOS},readOnly:1,editorFocus:!1,exec:function(){var y=a.container.getFirst(function(a){return a.type==CKEDITOR.NODE_ELEMENT&&a.hasClass("cke_inner")}),
v=a.ui.space("contents");if("wysiwyg"==a.mode){var t=a.getSelection();g=t&&t.getRanges();n=m.getScrollPosition()}else{var r=a.editable().$;g=!CKEDITOR.env.ie&&[r.selectionStart,r.selectionEnd];n=[r.scrollLeft,r.scrollTop]}if(this.state==CKEDITOR.TRISTATE_OFF){m.on("resize",c);p=m.getScrollPosition();for(t=a.container;t=t.getParent();)t.setCustomData("maximize_saved_styles",b(t)),t.setStyle("z-index",a.config.baseFloatZIndex-5);v.setCustomData("maximize_saved_styles",b(v,!0));y.setCustomData("maximize_saved_styles",
b(y,!0));v={overflow:CKEDITOR.env.webkit?"":"hidden",width:0,height:0};d.getDocumentElement().setStyles(v);!CKEDITOR.env.gecko&&d.getDocumentElement().setStyle("position","fixed");CKEDITOR.env.gecko&&CKEDITOR.env.quirks||d.getBody().setStyles(v);CKEDITOR.env.ie?setTimeout(function(){m.$.scrollTo(0,0)},0):m.$.scrollTo(0,0);y.setStyle("position",CKEDITOR.env.gecko&&CKEDITOR.env.quirks?"fixed":"absolute");y.$.offsetLeft;y.setStyles({"z-index":a.config.baseFloatZIndex-5,left:"0px",top:"0px"});y.addClass("cke_maximized");
c();v=y.getDocumentPosition();y.setStyles({left:-1*v.x+"px",top:-1*v.y+"px"});CKEDITOR.env.gecko&&h(a)}else if(this.state==CKEDITOR.TRISTATE_ON){m.removeListener("resize",c);for(var t=[v,y],w=0;w<t.length;w++)e(t[w],t[w].getCustomData("maximize_saved_styles")),t[w].removeCustomData("maximize_saved_styles");for(t=a.container;t=t.getParent();)e(t,t.getCustomData("maximize_saved_styles")),t.removeCustomData("maximize_saved_styles");CKEDITOR.env.ie?setTimeout(function(){m.$.scrollTo(p.x,p.y)},0):m.$.scrollTo(p.x,
p.y);y.removeClass("cke_maximized");CKEDITOR.env.webkit&&(y.setStyle("display","inline"),setTimeout(function(){y.setStyle("display","block")},0));a.fire("resize",{outerHeight:a.container.$.offsetHeight,contentsHeight:v.$.offsetHeight,outerWidth:a.container.$.offsetWidth})}this.toggleState();if(t=this.uiItems[0])v=this.state==CKEDITOR.TRISTATE_OFF?f.maximize.maximize:f.maximize.minimize,t=CKEDITOR.document.getById(t._.id),t.getChild(1).setHtml(v),t.setAttribute("title",v),t.setAttribute("href",'javascript:void("'+
v+'");');"wysiwyg"==a.mode?g?(CKEDITOR.env.gecko&&h(a),a.getSelection().selectRanges(g),(r=a.getSelection().getStartElement())&&r.scrollIntoView(!0)):m.$.scrollTo(n.x,n.y):(g&&(r.selectionStart=g[0],r.selectionEnd=g[1]),r.scrollLeft=n[0],r.scrollTop=n[1]);g=n=null;q=this.state;a.fire("maximize",this.state)},canUndo:!1});a.ui.addButton&&a.ui.addButton("Maximize",{label:f.maximize.maximize,command:"maximize",toolbar:"tools,10"});a.on("mode",function(){var b=a.getCommand("maximize");b.setState(b.state==
CKEDITOR.TRISTATE_DISABLED?CKEDITOR.TRISTATE_DISABLED:q)},null,null,100)}}})}(),CKEDITOR.plugins.add("newpage",{init:function(a){a.addCommand("newpage",{modes:{wysiwyg:1,source:1},exec:function(a){var b=this;a.setData(a.config.newpage_html||"",function(){a.focus();setTimeout(function(){a.fire("afterCommandExec",{name:"newpage",command:b});a.selectionChange()},200)})},async:!0});a.ui.addButton&&a.ui.addButton("NewPage",{label:a.lang.newpage.toolbar,command:"newpage",toolbar:"document,20"})}}),"use strict",
function(){function a(a){return{"aria-label":a,"class":"cke_pagebreak",contenteditable:"false","data-cke-display-name":"pagebreak","data-cke-pagebreak":1,style:"page-break-after: always",title:a}}CKEDITOR.plugins.add("pagebreak",{requires:"fakeobjects",onLoad:function(){var a=("background:url("+CKEDITOR.getUrl(this.path+"images/pagebreak.gif")+") no-repeat center center;clear:both;width:100%;border-top:#999 1px dotted;border-bottom:#999 1px dotted;padding:0;height:7px;cursor:default;").replace(/;/g,
" !important;");CKEDITOR.addCss("div.cke_pagebreak{"+a+"}")},init:function(a){a.blockless||(a.addCommand("pagebreak",CKEDITOR.plugins.pagebreakCmd),a.ui.addButton&&a.ui.addButton("PageBreak",{label:a.lang.pagebreak.toolbar,command:"pagebreak",toolbar:"insert,70"}),CKEDITOR.env.webkit&&a.on("contentDom",function(){a.document.on("click",function(b){b=b.data.getTarget();b.is("div")&&b.hasClass("cke_pagebreak")&&a.getSelection().selectElement(b)})}))},afterInit:function(c){function b(b){CKEDITOR.tools.extend(b.attributes,
a(c.lang.pagebreak.alt),!0);b.children.length=0}var e=c.dataProcessor,h=e&&e.dataFilter,e=e&&e.htmlFilter,l=/page-break-after\s*:\s*always/i,k=/display\s*:\s*none/i;e&&e.addRules({attributes:{"class":function(a,b){var c=a.replace("cke_pagebreak","");if(c!=a){var e=CKEDITOR.htmlParser.fragment.fromHtml('\x3cspan style\x3d"display: none;"\x3e\x26nbsp;\x3c/span\x3e').children[0];b.children.length=0;b.add(e);e=b.attributes;delete e["aria-label"];delete e.contenteditable;delete e.title}return c}}},{applyToAll:!0,
priority:5});h&&h.addRules({elements:{div:function(a){if(a.attributes["data-cke-pagebreak"])b(a);else if(l.test(a.attributes.style)){var c=a.children[0];c&&"span"==c.name&&k.test(c.attributes.style)&&b(a)}}}})}});CKEDITOR.plugins.pagebreakCmd={exec:function(c){var b=c.document.createElement("div",{attributes:a(c.lang.pagebreak.alt)});c.insertElement(b)},context:"div",allowedContent:{div:{styles:"!page-break-after"},span:{match:function(a){return(a=a.parent)&&"div"==a.name&&a.styles&&a.styles["page-break-after"]},
styles:"display"}},requiredContent:"div{page-break-after}"}}(),function(){function a(a,b,e){var h=CKEDITOR.cleanWord;h?e():(a=CKEDITOR.getUrl(a.config.pasteFromWordCleanupFile||b+"filter/default.js"),CKEDITOR.scriptLoader.load(a,e,null,!0));return!h}CKEDITOR.plugins.add("pastefromword",{requires:"clipboard",init:function(c){var b=0,e=this.path;c.addCommand("pastefromword",{canUndo:!1,async:!0,exec:function(a,c){b=1;a.execCommand("paste",{type:"html",notification:c&&"undefined"!==typeof c.notification?
c.notification:!0})}});c.ui.addButton&&c.ui.addButton("PasteFromWord",{label:c.lang.pastefromword.toolbar,command:"pastefromword",toolbar:"clipboard,50"});c.on("paste",function(h){var l=h.data,k=(CKEDITOR.plugins.clipboard.isCustomDataTypesSupported?l.dataTransfer.getData("text/html",!0):null)||l.dataValue,f={dataValue:k},d=/(class=\"?Mso|style=(?:\"|\')[^\"]*?\bmso\-|w:WordDocument|<o:\w+>|<\/font>)/,d=/<meta\s*name=(?:\"|\')?generator(?:\"|\')?\s*content=(?:\"|\')?microsoft/gi.test(k)||d.test(k);
if(k&&(b||d)&&(!1!==c.fire("pasteFromWord",f)||b)){l.dontFilter=!0;var m=a(c,e,function(){if(m)c.fire("paste",l);else if(!c.config.pasteFromWordPromptCleanup||b||confirm(c.lang.pastefromword.confirmCleanup))f.dataValue=CKEDITOR.cleanWord(f.dataValue,c),c.fire("afterPasteFromWord",f),l.dataValue=f.dataValue;b=0});m&&h.cancel()}},null,null,3)}})}(),function(){var a={canUndo:!1,async:!0,exec:function(a,b){var e=a.lang,h=CKEDITOR.tools.keystrokeToString(e.common.keyboard,a.getCommandKeystroke(CKEDITOR.env.ie?
a.commands.paste:this)),l=b&&"undefined"!==typeof b.notification?b.notification:!b||!b.from||"keystrokeHandler"===b.from&&CKEDITOR.env.ie,e=l&&"string"===typeof l?l:e.pastetext.pasteNotification.replace(/%1/,'\x3ckbd aria-label\x3d"'+h.aria+'"\x3e'+h.display+"\x3c/kbd\x3e");a.execCommand("paste",{type:"text",notification:l?e:!1})}};CKEDITOR.plugins.add("pastetext",{requires:"clipboard",init:function(c){var b=CKEDITOR.env.safari?CKEDITOR.CTRL+CKEDITOR.ALT+CKEDITOR.SHIFT+86:CKEDITOR.CTRL+CKEDITOR.SHIFT+
86;c.addCommand("pastetext",a);c.setKeystroke(b,"pastetext");c.ui.addButton&&c.ui.addButton("PasteText",{label:c.lang.pastetext.button,command:"pastetext",toolbar:"clipboard,40"});if(c.config.forcePasteAsPlainText)c.on("beforePaste",function(a){"html"!=a.data.type&&(a.data.type="text")});c.on("pasteState",function(a){c.getCommand("pastetext").setState(a.data)})}})}(),function(){var a,c={modes:{wysiwyg:1,source:1},canUndo:!1,readOnly:1,exec:function(b){var c,h=b.config,l=h.baseHref?'\x3cbase href\x3d"'+
h.baseHref+'"/\x3e':"";if(h.fullPage)c=b.getData().replace(/<head>/,"$\x26"+l).replace(/[^>]*(?=<\/title>)/,"$\x26 \x26mdash; "+b.lang.preview.preview);else{var h="\x3cbody ",k=b.document&&b.document.getBody();k&&(k.getAttribute("id")&&(h+='id\x3d"'+k.getAttribute("id")+'" '),k.getAttribute("class")&&(h+='class\x3d"'+k.getAttribute("class")+'" '));h+="\x3e";c=b.config.docType+'\x3chtml dir\x3d"'+b.config.contentsLangDirection+'"\x3e\x3chead\x3e'+l+"\x3ctitle\x3e"+b.lang.preview.preview+"\x3c/title\x3e"+
CKEDITOR.tools.buildStyleHtml(b.config.contentsCss)+"\x3c/head\x3e"+h+b.getData()+"\x3c/body\x3e\x3c/html\x3e"}l=640;h=420;k=80;try{var f=window.screen,l=Math.round(.8*f.width),h=Math.round(.7*f.height),k=Math.round(.1*f.width)}catch(d){}if(!1===b.fire("contentPreview",b={dataValue:c}))return!1;var f="",m;CKEDITOR.env.ie&&(window._cke_htmlToLoad=b.dataValue,m="javascript:void( (function(){document.open();"+("("+CKEDITOR.tools.fixDomain+")();").replace(/\/\/.*?\n/g,"").replace(/parent\./g,"window.opener.")+
"document.write( window.opener._cke_htmlToLoad );document.close();window.opener._cke_htmlToLoad \x3d null;})() )",f="");CKEDITOR.env.gecko&&(window._cke_htmlToLoad=b.dataValue,f=CKEDITOR.getUrl(a+"preview.html"));f=window.open(f,null,"toolbar\x3dyes,location\x3dno,status\x3dyes,menubar\x3dyes,scrollbars\x3dyes,resizable\x3dyes,width\x3d"+l+",height\x3d"+h+",left\x3d"+k);CKEDITOR.env.ie&&f&&(f.location=m);CKEDITOR.env.ie||CKEDITOR.env.gecko||(m=f.document,m.open(),m.write(b.dataValue),m.close());return!0}};
CKEDITOR.plugins.add("preview",{init:function(b){b.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE&&(a=this.path,b.addCommand("preview",c),b.ui.addButton&&b.ui.addButton("Preview",{label:b.lang.preview.preview,command:"preview",toolbar:"document,40"}))}})}(),CKEDITOR.plugins.add("print",{init:function(a){a.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE&&(a.addCommand("print",CKEDITOR.plugins.print),a.ui.addButton&&a.ui.addButton("Print",{label:a.lang.print.toolbar,command:"print",toolbar:"document,50"}))}}),
CKEDITOR.plugins.print={exec:function(a){CKEDITOR.env.gecko?a.window.$.print():a.document.$.execCommand("Print")},canUndo:!1,readOnly:1,modes:{wysiwyg:1}},CKEDITOR.plugins.add("removeformat",{init:function(a){a.addCommand("removeFormat",CKEDITOR.plugins.removeformat.commands.removeformat);a.ui.addButton&&a.ui.addButton("RemoveFormat",{label:a.lang.removeformat.toolbar,command:"removeFormat",toolbar:"cleanup,10"})}}),CKEDITOR.plugins.removeformat={commands:{removeformat:{exec:function(a){for(var c=
a._.removeFormatRegex||(a._.removeFormatRegex=new RegExp("^(?:"+a.config.removeFormatTags.replace(/,/g,"|")+")$","i")),b=a._.removeAttributes||(a._.removeAttributes=a.config.removeFormatAttributes.split(",")),e=CKEDITOR.plugins.removeformat.filter,h=a.getSelection().getRanges(),l=h.createIterator(),k=function(a){return a.type==CKEDITOR.NODE_ELEMENT},f;f=l.getNextRange();){f.collapsed||f.enlarge(CKEDITOR.ENLARGE_ELEMENT);var d=f.createBookmark(),m=d.startNode,g=d.endNode,n=function(b){for(var d=a.elementPath(b),
f=d.elements,g=1,h;(h=f[g])&&!h.equals(d.block)&&!h.equals(d.blockLimit);g++)c.test(h.getName())&&e(a,h)&&b.breakParent(h)};n(m);if(g)for(n(g),m=m.getNextSourceNode(!0,CKEDITOR.NODE_ELEMENT);m&&!m.equals(g);)if(m.isReadOnly()){if(m.getPosition(g)&CKEDITOR.POSITION_CONTAINS)break;m=m.getNext(k)}else n=m.getNextSourceNode(!1,CKEDITOR.NODE_ELEMENT),"img"==m.getName()&&m.data("cke-realelement")||!e(a,m)||(c.test(m.getName())?m.remove(1):(m.removeAttributes(b),a.fire("removeFormatCleanup",m))),m=n;f.moveToBookmark(d)}a.forceNextSelectionCheck();
a.getSelection().selectRanges(h)}}},filter:function(a,c){for(var b=a._.removeFormatFilters||[],e=0;e<b.length;e++)if(!1===b[e](c))return!1;return!0}},CKEDITOR.editor.prototype.addRemoveFormatFilter=function(a){this._.removeFormatFilters||(this._.removeFormatFilters=[]);this._.removeFormatFilters.push(a)},CKEDITOR.config.removeFormatTags="b,big,cite,code,del,dfn,em,font,i,ins,kbd,q,s,samp,small,span,strike,strong,sub,sup,tt,u,var",CKEDITOR.config.removeFormatAttributes="class,style,lang,width,height,align,hspace,valign",
CKEDITOR.plugins.add("resize",{init:function(a){function c(b){var c=d.width,h=d.height,k=c+(b.data.$.screenX-f.x)*("rtl"==l?-1:1);b=h+(b.data.$.screenY-f.y);m&&(c=Math.max(e.resize_minWidth,Math.min(k,e.resize_maxWidth)));g&&(h=Math.max(e.resize_minHeight,Math.min(b,e.resize_maxHeight)));a.resize(m?c:null,h)}function b(){CKEDITOR.document.removeListener("mousemove",c);CKEDITOR.document.removeListener("mouseup",b);a.document&&(a.document.removeListener("mousemove",c),a.document.removeListener("mouseup",
b))}var e=a.config,h=a.ui.spaceId("resizer"),l=a.element?a.element.getDirection(1):"ltr";!e.resize_dir&&(e.resize_dir="vertical");void 0===e.resize_maxWidth&&(e.resize_maxWidth=3E3);void 0===e.resize_maxHeight&&(e.resize_maxHeight=3E3);void 0===e.resize_minWidth&&(e.resize_minWidth=750);void 0===e.resize_minHeight&&(e.resize_minHeight=250);if(!1!==e.resize_enabled){var k=null,f,d,m=("both"==e.resize_dir||"horizontal"==e.resize_dir)&&e.resize_minWidth!=e.resize_maxWidth,g=("both"==e.resize_dir||"vertical"==
e.resize_dir)&&e.resize_minHeight!=e.resize_maxHeight,n=CKEDITOR.tools.addFunction(function(g){k||(k=a.getResizable());d={width:k.$.offsetWidth||0,height:k.$.offsetHeight||0};f={x:g.screenX,y:g.screenY};e.resize_minWidth>d.width&&(e.resize_minWidth=d.width);e.resize_minHeight>d.height&&(e.resize_minHeight=d.height);CKEDITOR.document.on("mousemove",c);CKEDITOR.document.on("mouseup",b);a.document&&(a.document.on("mousemove",c),a.document.on("mouseup",b));g.preventDefault&&g.preventDefault()});a.on("destroy",
function(){CKEDITOR.tools.removeFunction(n)});a.on("uiSpace",function(b){if("bottom"==b.data.space){var c="";m&&!g&&(c=" cke_resizer_horizontal");!m&&g&&(c=" cke_resizer_vertical");var d='\x3cspan id\x3d"'+h+'" class\x3d"cke_resizer'+c+" cke_resizer_"+l+'" title\x3d"'+CKEDITOR.tools.htmlEncode(a.lang.common.resize)+'" onmousedown\x3d"CKEDITOR.tools.callFunction('+n+', event)"\x3e'+("ltr"==l?"◢":"◣")+"\x3c/span\x3e";"ltr"==l&&"ltr"==c?b.data.html+=d:b.data.html=d+b.data.html}},a,null,100);a.on("maximize",
function(b){a.ui.space("resizer")[b.data==CKEDITOR.TRISTATE_ON?"hide":"show"]()})}}}),function(){var a={readOnly:1,exec:function(a){if(a.fire("save")&&(a=a.element.$.form))try{a.submit()}catch(b){a.submit.click&&a.submit.click()}}};CKEDITOR.plugins.add("save",{init:function(c){c.elementMode==CKEDITOR.ELEMENT_MODE_REPLACE&&(c.addCommand("save",a).modes={wysiwyg:!!c.element.$.form},c.ui.addButton&&c.ui.addButton("Save",{label:c.lang.save.toolbar,command:"save",toolbar:"document,10"}))}})}(),function(){CKEDITOR.plugins.add("selectall",
{init:function(a){a.addCommand("selectAll",{modes:{wysiwyg:1,source:1},exec:function(a){var b=a.editable();if(b.is("textarea"))a=b.$,CKEDITOR.env.ie&&a.createTextRange?a.createTextRange().execCommand("SelectAll"):(a.selectionStart=0,a.selectionEnd=a.value.length),a.focus();else{if(b.is("body"))a.document.$.execCommand("SelectAll",!1,null);else{var e=a.createRange();e.selectNodeContents(b);e.select()}a.forceNextSelectionCheck();a.selectionChange()}},canUndo:!1});a.ui.addButton&&a.ui.addButton("SelectAll",
{label:a.lang.selectall.toolbar,command:"selectAll",toolbar:"selection,10"})}})}(),function(){var a={readOnly:1,preserveState:!0,editorFocus:!1,exec:function(a){this.toggleState();this.refresh(a)},refresh:function(a){if(a.document){var b=this.state!=CKEDITOR.TRISTATE_ON||a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE&&!a.focusManager.hasFocus?"removeClass":"attachClass";a.editable()[b]("cke_show_blocks")}}};CKEDITOR.plugins.add("showblocks",{onLoad:function(){var a="p div pre address blockquote h1 h2 h3 h4 h5 h6".split(" "),
b,e,h,l,k=CKEDITOR.getUrl(this.path),f=!(CKEDITOR.env.ie&&9>CKEDITOR.env.version),d=f?":not([contenteditable\x3dfalse]):not(.cke_show_blocks_off)":"",m,g;for(b=e=h=l="";m=a.pop();)g=a.length?",":"",b+=".cke_show_blocks "+m+d+g,h+=".cke_show_blocks.cke_contents_ltr "+m+d+g,l+=".cke_show_blocks.cke_contents_rtl "+m+d+g,e+=".cke_show_blocks "+m+d+"{background-image:url("+CKEDITOR.getUrl(k+"images/block_"+m+".png")+")}";CKEDITOR.addCss((b+"{background-repeat:no-repeat;border:1px dotted gray;padding-top:8px}").concat(e,
h+"{background-position:top left;padding-left:8px}",l+"{background-position:top right;padding-right:8px}"));f||CKEDITOR.addCss(".cke_show_blocks [contenteditable\x3dfalse],.cke_show_blocks .cke_show_blocks_off{border:none;padding-top:0;background-image:none}.cke_show_blocks.cke_contents_rtl [contenteditable\x3dfalse],.cke_show_blocks.cke_contents_rtl .cke_show_blocks_off{padding-right:0}.cke_show_blocks.cke_contents_ltr [contenteditable\x3dfalse],.cke_show_blocks.cke_contents_ltr .cke_show_blocks_off{padding-left:0}")},
init:function(c){function b(){e.refresh(c)}if(!c.blockless){var e=c.addCommand("showblocks",a);e.canUndo=!1;c.config.startupOutlineBlocks&&e.setState(CKEDITOR.TRISTATE_ON);c.ui.addButton&&c.ui.addButton("ShowBlocks",{label:c.lang.showblocks.toolbar,command:"showblocks",toolbar:"tools,20"});c.on("mode",function(){e.state!=CKEDITOR.TRISTATE_DISABLED&&e.refresh(c)});c.elementMode==CKEDITOR.ELEMENT_MODE_INLINE&&(c.on("focus",b),c.on("blur",b));c.on("contentDom",function(){e.state!=CKEDITOR.TRISTATE_DISABLED&&
e.refresh(c)})}}})}(),function(){var a={preserveState:!0,editorFocus:!1,readOnly:1,exec:function(a){this.toggleState();this.refresh(a)},refresh:function(a){if(a.document){var b=this.state==CKEDITOR.TRISTATE_ON?"attachClass":"removeClass";a.editable()[b]("cke_show_borders")}}};CKEDITOR.plugins.add("showborders",{modes:{wysiwyg:1},onLoad:function(){var a;a=(CKEDITOR.env.ie6Compat?[".%1 table.%2,",".%1 table.%2 td, .%1 table.%2 th","{","border : #d3d3d3 1px dotted","}"]:".%1 table.%2,;.%1 table.%2 \x3e tr \x3e td, .%1 table.%2 \x3e tr \x3e th,;.%1 table.%2 \x3e tbody \x3e tr \x3e td, .%1 table.%2 \x3e tbody \x3e tr \x3e th,;.%1 table.%2 \x3e thead \x3e tr \x3e td, .%1 table.%2 \x3e thead \x3e tr \x3e th,;.%1 table.%2 \x3e tfoot \x3e tr \x3e td, .%1 table.%2 \x3e tfoot \x3e tr \x3e th;{;border : #d3d3d3 1px dotted;}".split(";")).join("").replace(/%2/g,
"cke_show_border").replace(/%1/g,"cke_show_borders ");CKEDITOR.addCss(a)},init:function(c){var b=c.addCommand("showborders",a);b.canUndo=!1;!1!==c.config.startupShowBorders&&b.setState(CKEDITOR.TRISTATE_ON);c.on("mode",function(){b.state!=CKEDITOR.TRISTATE_DISABLED&&b.refresh(c)},null,null,100);c.on("contentDom",function(){b.state!=CKEDITOR.TRISTATE_DISABLED&&b.refresh(c)});c.on("removeFormatCleanup",function(a){a=a.data;c.getCommand("showborders").state==CKEDITOR.TRISTATE_ON&&a.is("table")&&(!a.hasAttribute("border")||
0>=parseInt(a.getAttribute("border"),10))&&a.addClass("cke_show_border")})},afterInit:function(a){var b=a.dataProcessor;a=b&&b.dataFilter;b=b&&b.htmlFilter;a&&a.addRules({elements:{table:function(a){a=a.attributes;var b=a["class"],c=parseInt(a.border,10);c&&!(0>=c)||b&&-1!=b.indexOf("cke_show_border")||(a["class"]=(b||"")+" cke_show_border")}}});b&&b.addRules({elements:{table:function(a){a=a.attributes;var b=a["class"];b&&(a["class"]=b.replace("cke_show_border","").replace(/\s{2}/," ").replace(/^\s+|\s+$/,
""))}}})}});CKEDITOR.on("dialogDefinition",function(a){var b=a.data.name;if("table"==b||"tableProperties"==b)if(a=a.data.definition,b=a.getContents("info").get("txtBorder"),b.commit=CKEDITOR.tools.override(b.commit,function(a){return function(b,c){a.apply(this,arguments);var k=parseInt(this.getValue(),10);c[!k||0>=k?"addClass":"removeClass"]("cke_show_border")}}),a=(a=a.getContents("advanced"))&&a.get("advCSSClasses"))a.setup=CKEDITOR.tools.override(a.setup,function(a){return function(){a.apply(this,
arguments);this.setValue(this.getValue().replace(/cke_show_border/,""))}}),a.commit=CKEDITOR.tools.override(a.commit,function(a){return function(b,c){a.apply(this,arguments);parseInt(c.getAttribute("border"),10)||c.addClass("cke_show_border")}})})}(),CKEDITOR.plugins.add("smiley",{requires:"dialog",init:function(a){a.config.smiley_path=a.config.smiley_path||this.path+"images/";a.addCommand("smiley",new CKEDITOR.dialogCommand("smiley",{allowedContent:"img[alt,height,!src,title,width]",requiredContent:"img"}));
a.ui.addButton&&a.ui.addButton("Smiley",{label:a.lang.smiley.toolbar,command:"smiley",toolbar:"insert,50"});CKEDITOR.dialog.add("smiley",this.path+"dialogs/smiley.js")}}),CKEDITOR.config.smiley_images="regular_smile.png sad_smile.png wink_smile.png teeth_smile.png confused_smile.png tongue_smile.png embarrassed_smile.png omg_smile.png whatchutalkingabout_smile.png angry_smile.png angel_smile.png shades_smile.png devil_smile.png cry_smile.png lightbulb.png thumbs_down.png thumbs_up.png heart.png broken_heart.png kiss.png envelope.png".split(" "),
CKEDITOR.config.smiley_descriptions="smiley;sad;wink;laugh;frown;cheeky;blush;surprise;indecision;angry;angel;cool;devil;crying;enlightened;no;yes;heart;broken heart;kiss;mail".split(";"),function(){CKEDITOR.plugins.add("sourcearea",{init:function(c){function b(){var a=h&&this.equals(CKEDITOR.document.getActive());this.hide();this.setStyle("height",this.getParent().$.clientHeight+"px");this.setStyle("width",this.getParent().$.clientWidth+"px");this.show();a&&this.focus()}if(c.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE){var e=
CKEDITOR.plugins.sourcearea;c.addMode("source",function(e){var h=c.ui.space("contents").getDocument().createElement("textarea");h.setStyles(CKEDITOR.tools.extend({width:CKEDITOR.env.ie7Compat?"99%":"100%",height:"100%",resize:"none",outline:"none","text-align":"left"},CKEDITOR.tools.cssVendorPrefix("tab-size",c.config.sourceAreaTabSize||4)));h.setAttribute("dir","ltr");h.addClass("cke_source").addClass("cke_reset").addClass("cke_enable_context_menu");c.ui.space("contents").append(h);h=c.editable(new a(c,
h));h.setData(c.getData(1));CKEDITOR.env.ie&&(h.attachListener(c,"resize",b,h),h.attachListener(CKEDITOR.document.getWindow(),"resize",b,h),CKEDITOR.tools.setTimeout(b,0,h));c.fire("ariaWidget",this);e()});c.addCommand("source",e.commands.source);c.ui.addButton&&c.ui.addButton("Source",{label:c.lang.sourcearea.toolbar,command:"source",toolbar:"mode,10"});c.on("mode",function(){c.getCommand("source").setState("source"==c.mode?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF)});var h=CKEDITOR.env.ie&&9==
CKEDITOR.env.version}}});var a=CKEDITOR.tools.createClass({base:CKEDITOR.editable,proto:{setData:function(a){this.setValue(a);this.status="ready";this.editor.fire("dataReady")},getData:function(){return this.getValue()},insertHtml:function(){},insertElement:function(){},insertText:function(){},setReadOnly:function(a){this[(a?"set":"remove")+"Attribute"]("readOnly","readonly")},detach:function(){a.baseProto.detach.call(this);this.clearCustomData();this.remove()}}})}(),CKEDITOR.plugins.sourcearea={commands:{source:{modes:{wysiwyg:1,
source:1},editorFocus:!1,readOnly:1,exec:function(a){"wysiwyg"==a.mode&&a.fire("saveSnapshot");a.getCommand("source").setState(CKEDITOR.TRISTATE_DISABLED);a.setMode("source"==a.mode?"wysiwyg":"source")},canUndo:!1}}},CKEDITOR.plugins.add("specialchar",{availableLangs:{af:1,ar:1,az:1,bg:1,ca:1,cs:1,cy:1,da:1,de:1,"de-ch":1,el:1,en:1,"en-au":1,"en-ca":1,"en-gb":1,eo:1,es:1,"es-mx":1,et:1,eu:1,fa:1,fi:1,fr:1,"fr-ca":1,gl:1,he:1,hr:1,hu:1,id:1,it:1,ja:1,km:1,ko:1,ku:1,lt:1,lv:1,nb:1,nl:1,no:1,oc:1,pl:1,
pt:1,"pt-br":1,ru:1,si:1,sk:1,sl:1,sq:1,sv:1,th:1,tr:1,tt:1,ug:1,uk:1,vi:1,zh:1,"zh-cn":1},requires:"dialog",init:function(a){var c=this;CKEDITOR.dialog.add("specialchar",this.path+"dialogs/specialchar.js");a.addCommand("specialchar",{exec:function(){var b=a.langCode,b=c.availableLangs[b]?b:c.availableLangs[b.replace(/-.*/,"")]?b.replace(/-.*/,""):"en";CKEDITOR.scriptLoader.load(CKEDITOR.getUrl(c.path+"dialogs/lang/"+b+".js"),function(){CKEDITOR.tools.extend(a.lang.specialchar,c.langEntries[b]);a.openDialog("specialchar")})},
modes:{wysiwyg:1},canUndo:!1});a.ui.addButton&&a.ui.addButton("SpecialChar",{label:a.lang.specialchar.toolbar,command:"specialchar",toolbar:"insert,50"})}}),CKEDITOR.config.specialChars="! \x26quot; # $ % \x26amp; ' ( ) * + - . / 0 1 2 3 4 5 6 7 8 9 : ; \x26lt; \x3d \x26gt; ? @ A B C D E F G H I J K L M N O P Q R S T U V W X Y Z [ ] ^ _ ` a b c d e f g h i j k l m n o p q r s t u v w x y z { | } ~ \x26euro; \x26lsquo; \x26rsquo; \x26ldquo; \x26rdquo; \x26ndash; \x26mdash; \x26iexcl; \x26cent; \x26pound; \x26curren; \x26yen; \x26brvbar; \x26sect; \x26uml; \x26copy; \x26ordf; \x26laquo; \x26not; \x26reg; \x26macr; \x26deg; \x26sup2; \x26sup3; \x26acute; \x26micro; \x26para; \x26middot; \x26cedil; \x26sup1; \x26ordm; \x26raquo; \x26frac14; \x26frac12; \x26frac34; \x26iquest; \x26Agrave; \x26Aacute; \x26Acirc; \x26Atilde; \x26Auml; \x26Aring; \x26AElig; \x26Ccedil; \x26Egrave; \x26Eacute; \x26Ecirc; \x26Euml; \x26Igrave; \x26Iacute; \x26Icirc; \x26Iuml; \x26ETH; \x26Ntilde; \x26Ograve; \x26Oacute; \x26Ocirc; \x26Otilde; \x26Ouml; \x26times; \x26Oslash; \x26Ugrave; \x26Uacute; \x26Ucirc; \x26Uuml; \x26Yacute; \x26THORN; \x26szlig; \x26agrave; \x26aacute; \x26acirc; \x26atilde; \x26auml; \x26aring; \x26aelig; \x26ccedil; \x26egrave; \x26eacute; \x26ecirc; \x26euml; \x26igrave; \x26iacute; \x26icirc; \x26iuml; \x26eth; \x26ntilde; \x26ograve; \x26oacute; \x26ocirc; \x26otilde; \x26ouml; \x26divide; \x26oslash; \x26ugrave; \x26uacute; \x26ucirc; \x26uuml; \x26yacute; \x26thorn; \x26yuml; \x26OElig; \x26oelig; \x26#372; \x26#374 \x26#373 \x26#375; \x26sbquo; \x26#8219; \x26bdquo; \x26hellip; \x26trade; \x26#9658; \x26bull; \x26rarr; \x26rArr; \x26hArr; \x26diams; \x26asymp;".split(" "),
function(){CKEDITOR.plugins.add("stylescombo",{requires:"richcombo",init:function(a){var c=a.config,b=a.lang.stylescombo,e={},h=[],l=[];a.on("stylesSet",function(b){if(b=b.data.styles){for(var f,d,m,g=0,n=b.length;g<n;g++)(f=b[g],a.blockless&&f.element in CKEDITOR.dtd.$block||"string"==typeof f.type&&!CKEDITOR.style.customHandlers[f.type]||(d=f.name,f=new CKEDITOR.style(f),a.filter.customConfig&&!a.filter.check(f)))||(f._name=d,f._.enterMode=c.enterMode,f._.type=m=f.assignedTo||f.type,f._.weight=
g+1E3*(m==CKEDITOR.STYLE_OBJECT?1:m==CKEDITOR.STYLE_BLOCK?2:3),e[d]=f,h.push(f),l.push(f));h.sort(function(a,b){return a._.weight-b._.weight})}});a.ui.addRichCombo("Styles",{label:b.label,title:b.panelTitle,toolbar:"styles,10",allowedContent:l,panel:{css:[CKEDITOR.skin.getPath("editor")].concat(c.contentsCss),multiSelect:!0,attributes:{"aria-label":b.panelTitle}},init:function(){var a,c,d,e,g,l;g=0;for(l=h.length;g<l;g++)a=h[g],c=a._name,e=a._.type,e!=d&&(this.startGroup(b["panelTitle"+String(e)]),
d=e),this.add(c,a.type==CKEDITOR.STYLE_OBJECT?c:a.buildPreview(),c);this.commit()},onClick:function(b){a.focus();a.fire("saveSnapshot");b=e[b];var c=a.elementPath();if(b.group&&b.removeStylesFromSameGroup(a))a.applyStyle(b);else a[b.checkActive(c,a)?"removeStyle":"applyStyle"](b);a.fire("saveSnapshot")},onRender:function(){a.on("selectionChange",function(b){var c=this.getValue();b=b.data.path.elements;for(var d=0,h=b.length,g;d<h;d++){g=b[d];for(var l in e)if(e[l].checkElementRemovable(g,!0,a)){l!=
c&&this.setValue(l);return}}this.setValue("")},this)},onOpen:function(){var c=a.getSelection().getSelectedElement()||a.editable(),c=a.elementPath(c),f=[0,0,0,0];this.showAll();this.unmarkAll();for(var d in e){var h=e[d],g=h._.type;h.checkApplicable(c,a,a.activeFilter)?f[g]++:this.hideItem(d);h.checkActive(c,a)&&this.mark(d)}f[CKEDITOR.STYLE_BLOCK]||this.hideGroup(b["panelTitle"+String(CKEDITOR.STYLE_BLOCK)]);f[CKEDITOR.STYLE_INLINE]||this.hideGroup(b["panelTitle"+String(CKEDITOR.STYLE_INLINE)]);f[CKEDITOR.STYLE_OBJECT]||
this.hideGroup(b["panelTitle"+String(CKEDITOR.STYLE_OBJECT)])},refresh:function(){var b=a.elementPath();if(b){for(var c in e)if(e[c].checkApplicable(b,a,a.activeFilter))return;this.setState(CKEDITOR.TRISTATE_DISABLED)}},reset:function(){e={};h=[]}})}})}(),function(){function a(a){return{editorFocus:!1,canUndo:!1,modes:{wysiwyg:1},exec:function(b){if(b.editable().hasFocus){var c=b.getSelection(),e;if(e=(new CKEDITOR.dom.elementPath(c.getCommonAncestor(),c.root)).contains({td:1,th:1},1)){var c=b.createRange(),
d=CKEDITOR.tools.tryThese(function(){var b=e.getParent().$.cells[e.$.cellIndex+(a?-1:1)];b.parentNode.parentNode;return b},function(){var b=e.getParent(),b=b.getAscendant("table").$.rows[b.$.rowIndex+(a?-1:1)];return b.cells[a?b.cells.length-1:0]});if(d||a)if(d)d=new CKEDITOR.dom.element(d),c.moveToElementEditStart(d),c.checkStartOfBlock()&&c.checkEndOfBlock()||c.selectNodeContents(d);else return!0;else{for(var m=e.getAscendant("table").$,d=e.getParent().$.cells,m=new CKEDITOR.dom.element(m.insertRow(-1),
b.document),g=0,n=d.length;g<n;g++)m.append((new CKEDITOR.dom.element(d[g],b.document)).clone(!1,!1)).appendBogus();c.moveToElementEditStart(m)}c.select(!0);return!0}}return!1}}}var c={editorFocus:!1,modes:{wysiwyg:1,source:1}},b={exec:function(a){a.container.focusNext(!0,a.tabIndex)}},e={exec:function(a){a.container.focusPrevious(!0,a.tabIndex)}};CKEDITOR.plugins.add("tab",{init:function(h){for(var l=!1!==h.config.enableTabKeyTools,k=h.config.tabSpaces||0,f="";k--;)f+=" ";if(f)h.on("key",function(a){9==
a.data.keyCode&&(h.insertText(f),a.cancel())});if(l)h.on("key",function(a){(9==a.data.keyCode&&h.execCommand("selectNextCell")||a.data.keyCode==CKEDITOR.SHIFT+9&&h.execCommand("selectPreviousCell"))&&a.cancel()});h.addCommand("blur",CKEDITOR.tools.extend(b,c));h.addCommand("blurBack",CKEDITOR.tools.extend(e,c));h.addCommand("selectNextCell",a());h.addCommand("selectPreviousCell",a(!0))}})}(),CKEDITOR.dom.element.prototype.focusNext=function(a,c){var b=void 0===c?this.getTabIndex():c,e,h,l,k,f,d;if(0>=
b)for(f=this.getNextSourceNode(a,CKEDITOR.NODE_ELEMENT);f;){if(f.isVisible()&&0===f.getTabIndex()){l=f;break}f=f.getNextSourceNode(!1,CKEDITOR.NODE_ELEMENT)}else for(f=this.getDocument().getBody().getFirst();f=f.getNextSourceNode(!1,CKEDITOR.NODE_ELEMENT);){if(!e)if(!h&&f.equals(this)){if(h=!0,a){if(!(f=f.getNextSourceNode(!0,CKEDITOR.NODE_ELEMENT)))break;e=1}}else h&&!this.contains(f)&&(e=1);if(f.isVisible()&&!(0>(d=f.getTabIndex()))){if(e&&d==b){l=f;break}d>b&&(!l||!k||d<k)?(l=f,k=d):l||0!==d||
(l=f,k=d)}}l&&l.focus()},CKEDITOR.dom.element.prototype.focusPrevious=function(a,c){for(var b=void 0===c?this.getTabIndex():c,e,h,l,k=0,f,d=this.getDocument().getBody().getLast();d=d.getPreviousSourceNode(!1,CKEDITOR.NODE_ELEMENT);){if(!e)if(!h&&d.equals(this)){if(h=!0,a){if(!(d=d.getPreviousSourceNode(!0,CKEDITOR.NODE_ELEMENT)))break;e=1}}else h&&!this.contains(d)&&(e=1);if(d.isVisible()&&!(0>(f=d.getTabIndex())))if(0>=b){if(e&&0===f){l=d;break}f>k&&(l=d,k=f)}else{if(e&&f==b){l=d;break}f<b&&(!l||
f>k)&&(l=d,k=f)}}l&&l.focus()},CKEDITOR.plugins.add("table",{requires:"dialog",init:function(a){function c(a){return CKEDITOR.tools.extend(a||{},{contextSensitive:1,refresh:function(a,b){this.setState(b.contains("table",1)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED)}})}if(!a.blockless){var b=a.lang.table;a.addCommand("table",new CKEDITOR.dialogCommand("table",{context:"table",allowedContent:"table{width,height}[align,border,cellpadding,cellspacing,summary];caption tbody thead tfoot;th td tr[scope];"+
(a.plugins.dialogadvtab?"table"+a.plugins.dialogadvtab.allowedContent():""),requiredContent:"table",contentTransformations:[["table{width}: sizeToStyle","table[width]: sizeToAttribute"],["td: splitBorderShorthand"],[{element:"table",right:function(a){a.styles&&(a.styles.border&&a.styles.border.match(/solid/)&&(a.attributes.border=1),"collapse"==a.styles["border-collapse"]&&(a.attributes.cellspacing=0))}}]]}));a.addCommand("tableProperties",new CKEDITOR.dialogCommand("tableProperties",c()));a.addCommand("tableDelete",
c({exec:function(a){var b=a.elementPath().contains("table",1);if(b){var c=b.getParent(),k=a.editable();1!=c.getChildCount()||c.is("td","th")||c.equals(k)||(b=c);a=a.createRange();a.moveToPosition(b,CKEDITOR.POSITION_BEFORE_START);b.remove();a.select()}}}));a.ui.addButton&&a.ui.addButton("Table",{label:b.toolbar,command:"table",toolbar:"insert,30"});CKEDITOR.dialog.add("table",this.path+"dialogs/table.js");CKEDITOR.dialog.add("tableProperties",this.path+"dialogs/table.js");a.addMenuItems&&a.addMenuItems({table:{label:b.menu,
command:"tableProperties",group:"table",order:5},tabledelete:{label:b.deleteTable,command:"tableDelete",group:"table",order:1}});a.on("doubleclick",function(a){a.data.element.is("table")&&(a.data.dialog="tableProperties")});a.contextMenu&&a.contextMenu.addListener(function(){return{tabledelete:CKEDITOR.TRISTATE_OFF,table:CKEDITOR.TRISTATE_OFF}})}}}),function(){function a(a,b){function c(a){return b?b.contains(a)&&a.getAscendant("table",!0).equals(b):!0}function d(a){0<e.length||a.type!=CKEDITOR.NODE_ELEMENT||
!q.test(a.getName())||a.getCustomData("selected_cell")||(CKEDITOR.dom.element.setMarker(f,a,"selected_cell",!0),e.push(a))}var e=[],f={};if(!a)return e;for(var g=a.getRanges(),h=0;h<g.length;h++){var k=g[h];if(k.collapsed)(k=k.getCommonAncestor().getAscendant({td:1,th:1},!0))&&c(k)&&e.push(k);else{var k=new CKEDITOR.dom.walker(k),l;for(k.guard=d;l=k.next();)l.type==CKEDITOR.NODE_ELEMENT&&l.is(CKEDITOR.dtd.table)||(l=l.getAscendant({td:1,th:1},!0))&&!l.getCustomData("selected_cell")&&c(l)&&(CKEDITOR.dom.element.setMarker(f,
l,"selected_cell",!0),e.push(l))}}CKEDITOR.dom.element.clearAllMarkers(f);return e}function c(b,c){for(var d=y(b)?b:a(b),e=d[0],f=e.getAscendant("table"),e=e.getDocument(),g=d[0].getParent(),h=g.$.rowIndex,d=d[d.length-1],k=d.getParent().$.rowIndex+d.$.rowSpan-1,d=new CKEDITOR.dom.element(f.$.rows[k]),h=c?h:k,g=c?g:d,d=CKEDITOR.tools.buildTableMap(f),f=d[h],h=c?d[h-1]:d[h+1],d=d[0].length,e=e.createElement("tr"),k=0;f[k]&&k<d;k++){var l;1<f[k].rowSpan&&h&&f[k]==h[k]?(l=f[k],l.rowSpan+=1):(l=(new CKEDITOR.dom.element(f[k])).clone(),
l.removeAttribute("rowSpan"),l.appendBogus(),e.append(l),l=l.$);k+=l.colSpan-1}c?e.insertBefore(g):e.insertAfter(g);return e}function b(c){if(c instanceof CKEDITOR.dom.selection){var d=c.getRanges(),e=a(c),f=e[0].getAscendant("table"),g=CKEDITOR.tools.buildTableMap(f),h=e[0].getParent().$.rowIndex,e=e[e.length-1],k=e.getParent().$.rowIndex+e.$.rowSpan-1,e=[];c.reset();for(c=h;c<=k;c++){for(var l=g[c],m=new CKEDITOR.dom.element(f.$.rows[c]),n=0;n<l.length;n++){var p=new CKEDITOR.dom.element(l[n]),
q=p.getParent().$.rowIndex;1==p.$.rowSpan?p.remove():(--p.$.rowSpan,q==c&&(q=g[c+1],q[n-1]?p.insertAfter(new CKEDITOR.dom.element(q[n-1])):(new CKEDITOR.dom.element(f.$.rows[c+1])).append(p,1)));n+=p.$.colSpan-1}e.push(m)}g=f.$.rows;d[0].moveToPosition(f,CKEDITOR.POSITION_BEFORE_START);h=new CKEDITOR.dom.element(g[k+1]||(0<h?g[h-1]:null)||f.$.parentNode);for(c=e.length;0<=c;c--)b(e[c]);return f.$.parentNode?h:(d[0].select(),null)}c instanceof CKEDITOR.dom.element&&(f=c.getAscendant("table"),1==f.$.rows.length?
f.remove():c.remove());return null}function e(a,b){for(var c=a.getParent().$.cells,d=0,e=0;e<c.length;e++){var f=c[e],d=d+(b?1:f.colSpan);if(f==a.$)break}return d-1}function h(a,b){for(var c=b?Infinity:0,d=0;d<a.length;d++){var f=e(a[d],b);if(b?f<c:f>c)c=f}return c}function l(b,c){for(var d=y(b)?b:a(b),e=d[0].getAscendant("table"),f=h(d,1),d=h(d),g=c?f:d,k=CKEDITOR.tools.buildTableMap(e),e=[],f=[],d=[],l=k.length,m=0;m<l;m++)e.push(k[m][g]),f.push(c?k[m][g-1]:k[m][g+1]);for(m=0;m<l;m++)e[m]&&(1<e[m].colSpan&&
f[m]==e[m]?(k=e[m],k.colSpan+=1):(g=new CKEDITOR.dom.element(e[m]),k=g.clone(),k.removeAttribute("colSpan"),k.appendBogus(),k[c?"insertBefore":"insertAfter"].call(k,g),d.push(k),k=k.$),m+=k.rowSpan-1);return d}function k(a,b){var c=a.getStartElement().getAscendant({td:1,th:1},!0);if(c){var d=c.clone();d.appendBogus();b?d.insertBefore(c):d.insertAfter(c)}}function f(b){if(b instanceof CKEDITOR.dom.selection){var c=b.getRanges(),e=a(b),g=e[0]&&e[0].getAscendant("table"),h;a:{var k=0;h=e.length-1;for(var l=
{},m,n;m=e[k++];)CKEDITOR.dom.element.setMarker(l,m,"delete_cell",!0);for(k=0;m=e[k++];)if((n=m.getPrevious())&&!n.getCustomData("delete_cell")||(n=m.getNext())&&!n.getCustomData("delete_cell")){CKEDITOR.dom.element.clearAllMarkers(l);h=n;break a}CKEDITOR.dom.element.clearAllMarkers(l);k=e[0].getParent();(k=k.getPrevious())?h=k.getLast():(k=e[h].getParent(),h=(k=k.getNext())?k.getChild(0):null)}b.reset();for(b=e.length-1;0<=b;b--)f(e[b]);h?d(h,!0):g&&(c[0].moveToPosition(g,CKEDITOR.POSITION_BEFORE_START),
c[0].select(),g.remove())}else b instanceof CKEDITOR.dom.element&&(c=b.getParent(),1==c.getChildCount()?c.remove():b.remove())}function d(a,b){var c=a.getDocument(),d=CKEDITOR.document;CKEDITOR.env.ie&&10==CKEDITOR.env.version&&(d.focus(),c.focus());c=new CKEDITOR.dom.range(c);c["moveToElementEdit"+(b?"End":"Start")](a)||(c.selectNodeContents(a),c.collapse(b?!1:!0));c.select(!0)}function m(a,b,c){a=a[b];if("undefined"==typeof c)return a;for(b=0;a&&b<a.length;b++){if(c.is&&a[b]==c.$)return b;if(b==
c)return new CKEDITOR.dom.element(a[b])}return c.is?-1:null}function g(b,c,d){var e=a(b),f;if((c?1!=e.length:2>e.length)||(f=b.getCommonAncestor())&&f.type==CKEDITOR.NODE_ELEMENT&&f.is("table"))return!1;var g;b=e[0];f=b.getAscendant("table");var h=CKEDITOR.tools.buildTableMap(f),k=h.length,l=h[0].length,n=b.getParent().$.rowIndex,p=m(h,n,b);if(c){var q;try{var y=parseInt(b.getAttribute("rowspan"),10)||1;g=parseInt(b.getAttribute("colspan"),10)||1;q=h["up"==c?n-y:"down"==c?n+y:n]["left"==c?p-g:"right"==
c?p+g:p]}catch(I){return!1}if(!q||b.$==q)return!1;e["up"==c||"left"==c?"unshift":"push"](new CKEDITOR.dom.element(q))}c=b.getDocument();var G=n,y=q=0,K=!d&&new CKEDITOR.dom.documentFragment(c),J=0;for(c=0;c<e.length;c++){g=e[c];var F=g.getParent(),S=g.getFirst(),N=g.$.colSpan,Q=g.$.rowSpan,F=F.$.rowIndex,M=m(h,F,g),J=J+N*Q,y=Math.max(y,M-p+N);q=Math.max(q,F-n+Q);d||(N=g,(Q=N.getBogus())&&Q.remove(),N.trim(),g.getChildren().count()&&(F==G||!S||S.isBlockBoundary&&S.isBlockBoundary({br:1})||(G=K.getLast(CKEDITOR.dom.walker.whitespaces(!0)),
!G||G.is&&G.is("br")||K.append("br")),g.moveChildren(K)),c?g.remove():g.setHtml(""));G=F}if(d)return q*y==J;K.moveChildren(b);b.appendBogus();y>=l?b.removeAttribute("rowSpan"):b.$.rowSpan=q;q>=k?b.removeAttribute("colSpan"):b.$.colSpan=y;d=new CKEDITOR.dom.nodeList(f.$.rows);e=d.count();for(c=e-1;0<=c;c--)f=d.getItem(c),f.$.cells.length||(f.remove(),e++);return b}function n(b,c){var d=a(b);if(1<d.length)return!1;if(c)return!0;var d=d[0],e=d.getParent(),f=e.getAscendant("table"),g=CKEDITOR.tools.buildTableMap(f),
h=e.$.rowIndex,k=m(g,h,d),l=d.$.rowSpan,n;if(1<l){n=Math.ceil(l/2);for(var l=Math.floor(l/2),e=h+n,f=new CKEDITOR.dom.element(f.$.rows[e]),g=m(g,e),p,e=d.clone(),h=0;h<g.length;h++)if(p=g[h],p.parentNode==f.$&&h>k){e.insertBefore(new CKEDITOR.dom.element(p));break}else p=null;p||f.append(e)}else for(l=n=1,f=e.clone(),f.insertAfter(e),f.append(e=d.clone()),p=m(g,h),k=0;k<p.length;k++)p[k].rowSpan++;e.appendBogus();d.$.rowSpan=n;e.$.rowSpan=l;1==n&&d.removeAttribute("rowSpan");1==l&&e.removeAttribute("rowSpan");
return e}function p(b,c){var d=a(b);if(1<d.length)return!1;if(c)return!0;var d=d[0],e=d.getParent(),f=e.getAscendant("table"),f=CKEDITOR.tools.buildTableMap(f),g=m(f,e.$.rowIndex,d),h=d.$.colSpan;if(1<h)e=Math.ceil(h/2),h=Math.floor(h/2);else{for(var h=e=1,k=[],l=0;l<f.length;l++){var n=f[l];k.push(n[g]);1<n[g].rowSpan&&(l+=n[g].rowSpan-1)}for(f=0;f<k.length;f++)k[f].colSpan++}f=d.clone();f.insertAfter(d);f.appendBogus();d.$.colSpan=e;f.$.colSpan=h;1==e&&d.removeAttribute("colSpan");1==h&&f.removeAttribute("colSpan");
return f}var q=/^(?:td|th)$/,y=CKEDITOR.tools.isArray;CKEDITOR.plugins.tabletools={requires:"table,dialog,contextmenu",init:function(e){function h(a){return CKEDITOR.tools.extend(a||{},{contextSensitive:1,refresh:function(a,b){this.setState(b.contains({td:1,th:1},1)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED)}})}function m(a,b){var c=e.addCommand(a,b);e.addFeature(c)}var q=e.lang.table,y=CKEDITOR.tools.style.parse;m("cellProperties",new CKEDITOR.dialogCommand("cellProperties",h({allowedContent:"td th{width,height,border-color,background-color,white-space,vertical-align,text-align}[colspan,rowspan]",
requiredContent:"table",contentTransformations:[[{element:"td",left:function(a){return a.styles.background&&y.background(a.styles.background).color},right:function(a){a.styles["background-color"]=y.background(a.styles.background).color}},{element:"td",check:"td{vertical-align}",left:function(a){return a.attributes&&a.attributes.valign},right:function(a){a.styles["vertical-align"]=a.attributes.valign;delete a.attributes.valign}}],[{element:"tr",check:"td{height}",left:function(a){return a.styles&&
a.styles.height},right:function(a){CKEDITOR.tools.array.forEach(a.children,function(b){b.name in{td:1,th:1}&&(b.attributes["cke-row-height"]=a.styles.height)});delete a.styles.height}}],[{element:"td",check:"td{height}",left:function(a){return(a=a.attributes)&&a["cke-row-height"]},right:function(a){a.styles.height=a.attributes["cke-row-height"];delete a.attributes["cke-row-height"]}}]]})));CKEDITOR.dialog.add("cellProperties",this.path+"dialogs/tableCell.js");m("rowDelete",h({requiredContent:"table",
exec:function(a){a=a.getSelection();(a=b(a))&&d(a)}}));m("rowInsertBefore",h({requiredContent:"table",exec:function(b){b=b.getSelection();b=a(b);c(b,!0)}}));m("rowInsertAfter",h({requiredContent:"table",exec:function(b){b=b.getSelection();b=a(b);c(b)}}));m("columnDelete",h({requiredContent:"table",exec:function(b){var c=b.getSelection();b=c.getRanges();var e=a(c),f=e[0],g=e[e.length-1],e=f.getAscendant("table"),h=CKEDITOR.tools.buildTableMap(e),k,l,m=[];c.reset();for(var n=0,c=h.length;n<c;n++)for(var p=
0,q=h[n].length;p<q;p++)h[n][p]==f.$&&(k=p),h[n][p]==g.$&&(l=p);for(n=k;n<=l;n++)for(p=0;p<h.length;p++)g=h[p],f=new CKEDITOR.dom.element(e.$.rows[p]),g=new CKEDITOR.dom.element(g[n]),g.$&&(1==g.$.colSpan?g.remove():--g.$.colSpan,p+=g.$.rowSpan-1,f.$.cells.length||m.push(f));l=e.$.rows[0]&&e.$.rows[0].cells;k=new CKEDITOR.dom.element(l[k]||(k?l[k-1]:e.$.parentNode));m.length==c&&(b[0].moveToPosition(e,CKEDITOR.POSITION_AFTER_END),b[0].select(),e.remove());k&&d(k,!0)}}));m("columnInsertBefore",h({requiredContent:"table",
exec:function(b){b=b.getSelection();b=a(b);l(b,!0)}}));m("columnInsertAfter",h({requiredContent:"table",exec:function(b){b=b.getSelection();b=a(b);l(b)}}));m("cellDelete",h({requiredContent:"table",exec:function(a){a=a.getSelection();f(a)}}));m("cellMerge",h({allowedContent:"td[colspan,rowspan]",requiredContent:"td[colspan,rowspan]",exec:function(a,b){b.cell=g(a.getSelection());d(b.cell,!0)}}));m("cellMergeRight",h({allowedContent:"td[colspan]",requiredContent:"td[colspan]",exec:function(a,b){b.cell=
g(a.getSelection(),"right");d(b.cell,!0)}}));m("cellMergeDown",h({allowedContent:"td[rowspan]",requiredContent:"td[rowspan]",exec:function(a,b){b.cell=g(a.getSelection(),"down");d(b.cell,!0)}}));m("cellVerticalSplit",h({allowedContent:"td[rowspan]",requiredContent:"td[rowspan]",exec:function(a){d(p(a.getSelection()))}}));m("cellHorizontalSplit",h({allowedContent:"td[colspan]",requiredContent:"td[colspan]",exec:function(a){d(n(a.getSelection()))}}));m("cellInsertBefore",h({requiredContent:"table",
exec:function(a){a=a.getSelection();k(a,!0)}}));m("cellInsertAfter",h({requiredContent:"table",exec:function(a){a=a.getSelection();k(a)}}));e.addMenuItems&&e.addMenuItems({tablecell:{label:q.cell.menu,group:"tablecell",order:1,getItems:function(){var b=e.getSelection(),c=a(b);return{tablecell_insertBefore:CKEDITOR.TRISTATE_OFF,tablecell_insertAfter:CKEDITOR.TRISTATE_OFF,tablecell_delete:CKEDITOR.TRISTATE_OFF,tablecell_merge:g(b,null,!0)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,tablecell_merge_right:g(b,
"right",!0)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,tablecell_merge_down:g(b,"down",!0)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,tablecell_split_vertical:p(b,!0)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,tablecell_split_horizontal:n(b,!0)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,tablecell_properties:0<c.length?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED}}},tablecell_insertBefore:{label:q.cell.insertBefore,group:"tablecell",command:"cellInsertBefore",order:5},tablecell_insertAfter:{label:q.cell.insertAfter,
group:"tablecell",command:"cellInsertAfter",order:10},tablecell_delete:{label:q.cell.deleteCell,group:"tablecell",command:"cellDelete",order:15},tablecell_merge:{label:q.cell.merge,group:"tablecell",command:"cellMerge",order:16},tablecell_merge_right:{label:q.cell.mergeRight,group:"tablecell",command:"cellMergeRight",order:17},tablecell_merge_down:{label:q.cell.mergeDown,group:"tablecell",command:"cellMergeDown",order:18},tablecell_split_horizontal:{label:q.cell.splitHorizontal,group:"tablecell",
command:"cellHorizontalSplit",order:19},tablecell_split_vertical:{label:q.cell.splitVertical,group:"tablecell",command:"cellVerticalSplit",order:20},tablecell_properties:{label:q.cell.title,group:"tablecellproperties",command:"cellProperties",order:21},tablerow:{label:q.row.menu,group:"tablerow",order:1,getItems:function(){return{tablerow_insertBefore:CKEDITOR.TRISTATE_OFF,tablerow_insertAfter:CKEDITOR.TRISTATE_OFF,tablerow_delete:CKEDITOR.TRISTATE_OFF}}},tablerow_insertBefore:{label:q.row.insertBefore,
group:"tablerow",command:"rowInsertBefore",order:5},tablerow_insertAfter:{label:q.row.insertAfter,group:"tablerow",command:"rowInsertAfter",order:10},tablerow_delete:{label:q.row.deleteRow,group:"tablerow",command:"rowDelete",order:15},tablecolumn:{label:q.column.menu,group:"tablecolumn",order:1,getItems:function(){return{tablecolumn_insertBefore:CKEDITOR.TRISTATE_OFF,tablecolumn_insertAfter:CKEDITOR.TRISTATE_OFF,tablecolumn_delete:CKEDITOR.TRISTATE_OFF}}},tablecolumn_insertBefore:{label:q.column.insertBefore,
group:"tablecolumn",command:"columnInsertBefore",order:5},tablecolumn_insertAfter:{label:q.column.insertAfter,group:"tablecolumn",command:"columnInsertAfter",order:10},tablecolumn_delete:{label:q.column.deleteColumn,group:"tablecolumn",command:"columnDelete",order:15}});e.contextMenu&&e.contextMenu.addListener(function(a,b,c){return(a=c.contains({td:1,th:1},1))&&!a.isReadOnly()?{tablecell:CKEDITOR.TRISTATE_OFF,tablerow:CKEDITOR.TRISTATE_OFF,tablecolumn:CKEDITOR.TRISTATE_OFF}:null})},getCellColIndex:e,
insertRow:c,insertColumn:l,getSelectedCells:a};CKEDITOR.plugins.add("tabletools",CKEDITOR.plugins.tabletools)}(),CKEDITOR.tools.buildTableMap=function(a,c,b,e,h){a=a.$.rows;b=b||0;e="number"===typeof e?e:a.length-1;h="number"===typeof h?h:-1;var l=-1,k=[];for(c=c||0;c<=e;c++){l++;!k[l]&&(k[l]=[]);for(var f=-1,d=b;d<=(-1===h?a[c].cells.length-1:h);d++){var m=a[c].cells[d];if(!m)break;for(f++;k[l][f];)f++;for(var g=isNaN(m.colSpan)?1:m.colSpan,m=isNaN(m.rowSpan)?1:m.rowSpan,n=0;n<m&&!(c+n>e);n++){k[l+
n]||(k[l+n]=[]);for(var p=0;p<g;p++)k[l+n][f+p]=a[c].cells[d]}f+=g-1;if(-1!==h&&f>=h)break}}return k},function(){function a(a,b){var c=a.getAscendant("table"),d=b.getAscendant("table"),e=CKEDITOR.tools.buildTableMap(c),f=m(a),g=m(b),h=[],k={},l,n;c.contains(d)&&(b=b.getAscendant({td:1,th:1}),g=m(b));f>g&&(c=f,f=g,g=c,c=a,a=b,b=c);for(c=0;c<e[f].length;c++)if(a.$===e[f][c]){l=c;break}for(c=0;c<e[g].length;c++)if(b.$===e[g][c]){n=c;break}l>n&&(c=l,l=n,n=c);for(c=f;c<=g;c++)for(f=l;f<=n;f++)d=new CKEDITOR.dom.element(e[c][f]),
d.$&&!d.getCustomData("selected_cell")&&(h.push(d),CKEDITOR.dom.element.setMarker(k,d,"selected_cell",!0));CKEDITOR.dom.element.clearAllMarkers(k);return h}function c(a){a=a.data.$;return CKEDITOR.env.ie&&9>CKEDITOR.env.version?1===a.button:0===a.button}function b(a){if(a)return a=a.clone(),a.enlarge(CKEDITOR.ENLARGE_ELEMENT),(a=a.getEnclosedNode())&&a.is&&a.is(CKEDITOR.dtd.$tableContent)}function e(a){return(a=a.editable().findOne(".cke_table-faked-selection"))&&a.getAscendant("table")}function h(a,
b){var c=a.editable().find(".cke_table-faked-selection"),d;a.fire("lockSnapshot");a.editable().removeClass("cke_table-faked-selection-editor");for(d=0;d<c.count();d++)c.getItem(d).removeClass("cke_table-faked-selection");0<c.count()&&c.getItem(0).getAscendant("table").data("cke-table-faked-selection-table",!1);a.fire("unlockSnapshot");b&&(t={active:!1},a.getSelection().isInTable()&&a.getSelection().reset())}function l(a,b){var c=[],d,e;for(e=0;e<b.length;e++)d=a.createRange(),d.setStartBefore(b[e]),
d.setEndAfter(b[e]),c.push(d);a.getSelection().selectRanges(c)}function k(b){var c=b.editable().find(".cke_table-faked-selection");1>c.count()||(c=a(c.getItem(0),c.getItem(c.count()-1)),l(b,c))}function f(b,c,d){var e=w(b.getSelection(!0));c=c.is("table")?null:c;var f;(f=t.active&&!t.first)&&!(f=c)&&(f=b.getSelection().getRanges(),f=1<e.length||f[0]&&!f[0].collapsed?!0:!1);if(f)t.first=c||e[0],t.dirty=c?!1:1!==e.length;else if(t.active&&c&&t.first.getAscendant("table").equals(c.getAscendant("table"))){e=
a(t.first,c);if(!t.dirty&&1===e.length)return h(b,"mouseup"===d.name);t.dirty=!0;t.last=c;l(b,e)}}function d(a){var b=(a=a.editor||a.sender.editor)&&a.getSelection(),c=b&&b.getRanges()||[],d;if(b&&(h(a),b.isInTable()&&b.isFake)){1===c.length&&c[0]._getTableElement()&&c[0]._getTableElement().is("table")&&(d=c[0]._getTableElement());d=w(b,d);a.fire("lockSnapshot");for(b=0;b<d.length;b++)d[b].addClass("cke_table-faked-selection");0<d.length&&(a.editable().addClass("cke_table-faked-selection-editor"),
d[0].getAscendant("table").data("cke-table-faked-selection-table",""));a.fire("unlockSnapshot")}}function m(a){return a.getAscendant("tr",!0).$.rowIndex}function g(a){function b(a,c){return a&&c?a.equals(c)||a.contains(c)||c.contains(a)||a.getCommonAncestor(c).is(u):!1}function d(a){return!a.getAscendant("table",!0)&&a.getDocument().equals(m.document)}function l(a,e,f,g){return"mousedown"===a.name&&(c(a)||!g)||"mouseup"===a.name&&!d(a.data.getTarget())&&!b(f,g)?!0:!1}if(a.data.getTarget().getName){var m=
a.editor||a.listenerData.editor,n=m.getSelection(1),p=e(m),q=a.data.getTarget(),r=q&&q.getAscendant({td:1,th:1},!0),q=q&&q.getAscendant("table",!0),u={table:1,thead:1,tbody:1,tfoot:1,tr:1,td:1,th:1};l(a,n,p,q)&&h(m,!0);!t.active&&"mousedown"===a.name&&c(a)&&q&&(t={active:!0},CKEDITOR.document.on("mouseup",g,null,{editor:m}));(r||q)&&f(m,r||q,a);"mouseup"===a.name&&(c(a)&&(d(a.data.getTarget())||b(p,q))&&k(m),t={active:!1},CKEDITOR.document.removeListener("mouseup",g))}}function n(a){var b=a.data.getTarget().getAscendant({td:1,
th:1},!0);b&&!b.hasClass("cke_table-faked-selection")&&(a.cancel(),a.data.preventDefault())}function p(a,b){function c(a){a.cancel()}var d=a.getSelection(),e=d.createBookmarks(),f=a.document,g=a.createRange(),h=f.getDocumentElement().$,k=CKEDITOR.env.ie&&9>CKEDITOR.env.version,l=a.blockless||CKEDITOR.env.ie?"span":"div",m,n,p,q;f.getById("cke_table_copybin")||(m=f.createElement(l),n=f.createElement(l),n.setAttributes({id:"cke_table_copybin","data-cke-temp":"1"}),m.setStyles({position:"absolute",width:"1px",
height:"1px",overflow:"hidden"}),m.setStyle("ltr"==a.config.contentsLangDirection?"left":"right","-5000px"),m.setHtml(a.getSelectedHtml(!0)),a.fire("lockSnapshot"),n.append(m),a.editable().append(n),q=a.on("selectionChange",c,null,null,0),k&&(p=h.scrollTop),g.selectNodeContents(m),g.select(),k&&(h.scrollTop=p),setTimeout(function(){n.remove();d.selectBookmarks(e);q.removeListener();a.fire("unlockSnapshot");b&&(a.extractSelectedHtml(),a.fire("saveSnapshot"))},100))}function q(a){var b=a.editor||a.sender.editor;
b.getSelection().isInTable()&&p(b,"cut"===a.name)}function y(a){this._reset();a&&this.setSelectedCells(a)}function v(a,b,c){a.on("beforeCommandExec",function(c){-1!==CKEDITOR.tools.array.indexOf(b,c.data.name)&&(c.data.selectedCells=w(a.getSelection()))});a.on("afterCommandExec",function(d){-1!==CKEDITOR.tools.array.indexOf(b,d.data.name)&&c(a,d.data)})}var t={active:!1},r,w,z,u,B;y.prototype={};y.prototype._reset=function(){this.cells={first:null,last:null,all:[]};this.rows={first:null,last:null}};
y.prototype.setSelectedCells=function(a){this._reset();a=a.slice(0);this._arraySortByDOMOrder(a);this.cells.all=a;this.cells.first=a[0];this.cells.last=a[a.length-1];this.rows.first=a[0].getAscendant("tr");this.rows.last=this.cells.last.getAscendant("tr")};y.prototype.getTableMap=function(){var a=z(this.cells.first,!0),b;a:{b=this.cells.last;var c=b.getAscendant("table"),d=m(b),c=CKEDITOR.tools.buildTableMap(c),e;for(e=0;e<c[d].length;e++)if((new CKEDITOR.dom.element(c[d][e])).equals(b)){b=e;break a}b=
void 0}return CKEDITOR.tools.buildTableMap(this._getTable(),m(this.rows.first),a,m(this.rows.last),b)};y.prototype._getTable=function(){return this.rows.first.getAscendant("table")};y.prototype.insertRow=function(a,b,c){if("undefined"===typeof a)a=1;else if(0>=a)return;for(var d=this.cells.first.$.cellIndex,e=this.cells.last.$.cellIndex,f=c?[]:this.cells.all,g,h=0;h<a;h++)g=u(c?this.cells.all:f,b),g=CKEDITOR.tools.array.filter(g.find("td, th").toArray(),function(a){return c?!0:a.$.cellIndex>=d&&a.$.cellIndex<=
e}),f=b?g.concat(f):f.concat(g);this.setSelectedCells(f)};y.prototype.insertColumn=function(a){function b(a){a=m(a);return a>=e&&a<=f}if("undefined"===typeof a)a=1;else if(0>=a)return;for(var c=this.cells,d=c.all,e=m(c.first),f=m(c.last),c=0;c<a;c++)d=d.concat(CKEDITOR.tools.array.filter(B(d),b));this.setSelectedCells(d)};y.prototype.emptyCells=function(a){a=a||this.cells.all;for(var b=0;b<a.length;b++)a[b].setHtml("")};y.prototype._arraySortByDOMOrder=function(a){a.sort(function(a,b){return a.getPosition(b)&
CKEDITOR.POSITION_PRECEDING?-1:1})};var C={onPaste:function(c){function d(a){return Math.max.apply(null,CKEDITOR.tools.array.map(a,function(a){return a.length},0))}function e(a){var b=f.createRange();b.selectNodeContents(a);b.select()}var f=c.editor,g=f.getSelection(),h=w(g),k=this.findTableInPastedContent(f,c.data.dataValue),m=g.isInTable(!0)&&this.isBoundarySelection(g),n,p;!h.length||1===h.length&&!b(g.getRanges()[0])&&!m||m&&!k||(h=h[0].getAscendant("table"),n=new y(w(g,h)),f.once("afterPaste",
function(){var b;if(p){b=new CKEDITOR.dom.element(p[0][0]);var c=p[p.length-1];b=a(b,new CKEDITOR.dom.element(c[c.length-1]))}else b=n.cells.all;l(f,b)}),k?(c.stop(),m?(n.insertRow(1,1===m,!0),g.selectElement(n.rows.first)):(n.emptyCells(),l(f,n.cells.all)),c=n.getTableMap(),p=CKEDITOR.tools.buildTableMap(k),n.insertRow(p.length-c.length),n.insertColumn(d(p)-d(c)),c=n.getTableMap(),this.pasteTable(n,c,p),f.fire("saveSnapshot"),setTimeout(function(){f.fire("afterPaste")},0)):(e(n.cells.first),f.once("afterPaste",
function(){f.fire("lockSnapshot");n.emptyCells(n.cells.all.slice(1));l(f,n.cells.all);f.fire("unlockSnapshot")})))},isBoundarySelection:function(a){a=a.getRanges()[0];var b=a.endContainer.getAscendant("tr",!0);if(b&&a.collapsed){if(a.checkBoundaryOfElement(b,CKEDITOR.START))return 1;if(a.checkBoundaryOfElement(b,CKEDITOR.END))return 2}return 0},findTableInPastedContent:function(a,b){var c=a.dataProcessor,d=new CKEDITOR.dom.element("body");c||(c=new CKEDITOR.htmlDataProcessor(a));d.setHtml(c.toHtml(b),
{fixForBody:!1});return 1<d.getChildCount()?null:d.findOne("table")},pasteTable:function(a,b,c){var d,e=z(a.cells.first,!0),f=a._getTable(),g={},h,k,l,m;for(l=0;l<c.length;l++)for(h=new CKEDITOR.dom.element(f.$.rows[a.rows.first.$.rowIndex+l]),m=0;m<c[l].length;m++)if(k=new CKEDITOR.dom.element(c[l][m]),d=b[l]&&b[l][m]?new CKEDITOR.dom.element(b[l][m]):null,k&&!k.getCustomData("processed")){if(d&&d.getParent())k.replace(d);else if(0===m||c[l][m-1])(d=0!==m?new CKEDITOR.dom.element(c[l][m-1]):null)&&
h.equals(d.getParent())?k.insertAfter(d):0<e?h.$.cells[e]?k.insertAfter(new CKEDITOR.dom.element(h.$.cells[e])):h.append(k):h.append(k,!0);CKEDITOR.dom.element.setMarker(g,k,"processed",!0)}else k.getCustomData("processed")&&d&&d.remove();CKEDITOR.dom.element.clearAllMarkers(g)}};CKEDITOR.plugins.tableselection={getCellsBetween:a,keyboardIntegration:function(a){function b(a){a.getEnclosedNode()?a.getEnclosedNode().setText(""):a.deleteContents();CKEDITOR.tools.array.forEach(a._find("td"),function(a){a.appendBogus()})}
var c=a.editable();c.attachListener(c,"keydown",function(a){function c(b,d){if(!d.length)return null;var f=a.createRange(),g=CKEDITOR.dom.range.mergeRanges(d);CKEDITOR.tools.array.forEach(g,function(a){a.enlarge(CKEDITOR.ENLARGE_ELEMENT)});var h=g[0].getBoundaryNodes(),k=h.startNode,h=h.endNode;if(k&&k.is&&k.is(e)){for(var l=k.getAscendant("table",!0),m=k.getPreviousSourceNode(!1,CKEDITOR.NODE_ELEMENT,l),n=!1,p=function(a){return!k.contains(a)&&a.is&&a.is("td","th")};m&&!p(m);)m=m.getPreviousSourceNode(!1,
CKEDITOR.NODE_ELEMENT,l);!m&&h&&h.is&&!h.is("table")&&h.getNext()&&(m=h.getNext().findOne("td, th"),n=!0);if(m)f["moveToElementEdit"+(n?"Start":"End")](m);else f.setStartBefore(k.getAscendant("table",!0)),f.collapse(!0);g[0].deleteContents();return[f]}if(k)return f.moveToElementEditablePosition(k),[f]}var d={37:1,38:1,39:1,40:1,8:1,46:1},e=CKEDITOR.tools.extend({table:1},CKEDITOR.dtd.$tableContent);delete e.td;delete e.th;return function(e){var f=e.data.getKey(),g,h=37===f||38==f,k,l,m;if(d[f]&&(g=
a.getSelection())&&g.isInTable()&&g.isFake)if(k=g.getRanges(),l=k[0]._getTableElement(),m=k[k.length-1]._getTableElement(),e.data.preventDefault(),e.cancel(),8<f&&46>f)k[0].moveToElementEditablePosition(h?l:m,!h),g.selectRanges([k[0]]);else{for(e=0;e<k.length;e++)b(k[e]);(e=c(l,k))?k=e:k[0].moveToElementEditablePosition(l);g.selectRanges(k);a.fire("saveSnapshot")}}}(a),null,null,-1);c.attachListener(c,"keypress",function(c){var d=a.getSelection(),e=c.data.$.charCode||13===c.data.getKey(),f;if(d&&
d.isInTable()&&d.isFake&&e&&!(c.data.getKeystroke()&CKEDITOR.CTRL)){c=d.getRanges();e=c[0].getEnclosedNode().getAscendant({td:1,th:1},!0);for(f=0;f<c.length;f++)b(c[f]);c[0].moveToElementEditablePosition(e);d.selectRanges([c[0]])}},null,null,-1)},isSupportedEnvironment:!(CKEDITOR.env.ie&&11>CKEDITOR.env.version)};CKEDITOR.plugins.add("tableselection",{requires:"clipboard,tabletools",onLoad:function(){r=CKEDITOR.plugins.tabletools;w=r.getSelectedCells;z=r.getCellColIndex;u=r.insertRow;B=r.insertColumn;
CKEDITOR.document.appendStyleSheet(this.path+"styles/tableselection.css")},init:function(a){CKEDITOR.plugins.tableselection.isSupportedEnvironment&&(a.addContentsCss&&a.addContentsCss(this.path+"styles/tableselection.css"),a.on("contentDom",function(){var b=a.editable(),c=b.isInline()?b:a.document,e={editor:a};b.attachListener(c,"mousedown",g,null,e);b.attachListener(c,"mousemove",g,null,e);b.attachListener(c,"mouseup",g,null,e);b.attachListener(b,"dragstart",n);b.attachListener(a,"selectionCheck",
d);CKEDITOR.plugins.tableselection.keyboardIntegration(a);CKEDITOR.plugins.clipboard&&!CKEDITOR.plugins.clipboard.isCustomCopyCutSupported&&(b.attachListener(b,"cut",q),b.attachListener(b,"copy",q))}),a.on("paste",C.onPaste,C),v(a,"rowInsertBefore rowInsertAfter columnInsertBefore columnInsertAfter cellInsertBefore cellInsertAfter".split(" "),function(a,b){l(a,b.selectedCells)}),v(a,["cellMerge","cellMergeRight","cellMergeDown"],function(a,b){l(a,[b.commandData.cell])}),v(a,["cellDelete"],function(a){h(a,
!0)}))}})}(),function(){CKEDITOR.plugins.add("templates",{requires:"dialog",init:function(a){CKEDITOR.dialog.add("templates",CKEDITOR.getUrl(this.path+"dialogs/templates.js"));a.addCommand("templates",new CKEDITOR.dialogCommand("templates"));a.ui.addButton&&a.ui.addButton("Templates",{label:a.lang.templates.button,command:"templates",toolbar:"doctools,10"})}});var a={},c={};CKEDITOR.addTemplates=function(b,c){a[b]=c};CKEDITOR.getTemplates=function(b){return a[b]};CKEDITOR.loadTemplates=function(a,
e){for(var h=[],l=0,k=a.length;l<k;l++)c[a[l]]||(h.push(a[l]),c[a[l]]=1);h.length?CKEDITOR.scriptLoader.load(h,e):setTimeout(e,0)}}(),CKEDITOR.config.templates_files=[CKEDITOR.getUrl("plugins/templates/templates/default.js")],CKEDITOR.config.templates_replaceContent=!0,"use strict",function(){var a=[CKEDITOR.CTRL+90,CKEDITOR.CTRL+89,CKEDITOR.CTRL+CKEDITOR.SHIFT+90],c={8:1,46:1};CKEDITOR.plugins.add("undo",{init:function(c){function d(a){g.enabled&&!1!==a.data.command.canUndo&&g.save()}function e(){g.enabled=
c.readOnly?!1:"wysiwyg"==c.mode;g.onChange()}var g=c.undoManager=new b(c),h=g.editingHandler=new l(g),k=c.addCommand("undo",{exec:function(){g.undo()&&(c.selectionChange(),this.fire("afterUndo"))},startDisabled:!0,canUndo:!1}),q=c.addCommand("redo",{exec:function(){g.redo()&&(c.selectionChange(),this.fire("afterRedo"))},startDisabled:!0,canUndo:!1});c.setKeystroke([[a[0],"undo"],[a[1],"redo"],[a[2],"redo"]]);g.onChange=function(){k.setState(g.undoable()?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED);
q.setState(g.redoable()?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED)};c.on("beforeCommandExec",d);c.on("afterCommandExec",d);c.on("saveSnapshot",function(a){g.save(a.data&&a.data.contentOnly)});c.on("contentDom",h.attachListeners,h);c.on("instanceReady",function(){c.fire("saveSnapshot")});c.on("beforeModeUnload",function(){"wysiwyg"==c.mode&&g.save(!0)});c.on("mode",e);c.on("readOnly",e);c.ui.addButton&&(c.ui.addButton("Undo",{label:c.lang.undo.undo,command:"undo",toolbar:"undo,10"}),c.ui.addButton("Redo",
{label:c.lang.undo.redo,command:"redo",toolbar:"undo,20"}));c.resetUndo=function(){g.reset();c.fire("saveSnapshot")};c.on("updateSnapshot",function(){g.currentImage&&g.update()});c.on("lockSnapshot",function(a){a=a.data;g.lock(a&&a.dontUpdate,a&&a.forceUpdate)});c.on("unlockSnapshot",g.unlock,g)}});CKEDITOR.plugins.undo={};var b=CKEDITOR.plugins.undo.UndoManager=function(a){this.strokesRecorded=[0,0];this.locked=null;this.previousKeyGroup=-1;this.limit=a.config.undoStackSize||20;this.strokesLimit=
25;this.editor=a;this.reset()};b.prototype={type:function(a,c){var e=b.getKeyGroup(a),g=this.strokesRecorded[e]+1;c=c||g>=this.strokesLimit;this.typing||(this.hasUndo=this.typing=!0,this.hasRedo=!1,this.onChange());c?(g=0,this.editor.fire("saveSnapshot")):this.editor.fire("change");this.strokesRecorded[e]=g;this.previousKeyGroup=e},keyGroupChanged:function(a){return b.getKeyGroup(a)!=this.previousKeyGroup},reset:function(){this.snapshots=[];this.index=-1;this.currentImage=null;this.hasRedo=this.hasUndo=
!1;this.locked=null;this.resetType()},resetType:function(){this.strokesRecorded=[0,0];this.typing=!1;this.previousKeyGroup=-1},refreshState:function(){this.hasUndo=!!this.getNextImage(!0);this.hasRedo=!!this.getNextImage(!1);this.resetType();this.onChange()},save:function(a,b,c){var g=this.editor;if(this.locked||"ready"!=g.status||"wysiwyg"!=g.mode)return!1;var h=g.editable();if(!h||"ready"!=h.status)return!1;h=this.snapshots;b||(b=new e(g));if(!1===b.contents)return!1;if(this.currentImage)if(b.equalsContent(this.currentImage)){if(a||
b.equalsSelection(this.currentImage))return!1}else!1!==c&&g.fire("change");h.splice(this.index+1,h.length-this.index-1);h.length==this.limit&&h.shift();this.index=h.push(b)-1;this.currentImage=b;!1!==c&&this.refreshState();return!0},restoreImage:function(a){var b=this.editor,c;a.bookmarks&&(b.focus(),c=b.getSelection());this.locked={level:999};this.editor.loadSnapshot(a.contents);a.bookmarks?c.selectBookmarks(a.bookmarks):CKEDITOR.env.ie&&(c=this.editor.document.getBody().$.createTextRange(),c.collapse(!0),
c.select());this.locked=null;this.index=a.index;this.currentImage=this.snapshots[this.index];this.update();this.refreshState();b.fire("change")},getNextImage:function(a){var b=this.snapshots,c=this.currentImage,e;if(c)if(a)for(e=this.index-1;0<=e;e--){if(a=b[e],!c.equalsContent(a))return a.index=e,a}else for(e=this.index+1;e<b.length;e++)if(a=b[e],!c.equalsContent(a))return a.index=e,a;return null},redoable:function(){return this.enabled&&this.hasRedo},undoable:function(){return this.enabled&&this.hasUndo},
undo:function(){if(this.undoable()){this.save(!0);var a=this.getNextImage(!0);if(a)return this.restoreImage(a),!0}return!1},redo:function(){if(this.redoable()&&(this.save(!0),this.redoable())){var a=this.getNextImage(!1);if(a)return this.restoreImage(a),!0}return!1},update:function(a){if(!this.locked){a||(a=new e(this.editor));for(var b=this.index,c=this.snapshots;0<b&&this.currentImage.equalsContent(c[b-1]);)--b;c.splice(b,this.index-b+1,a);this.index=b;this.currentImage=a}},updateSelection:function(a){if(!this.snapshots.length)return!1;
var b=this.snapshots,c=b[b.length-1];return c.equalsContent(a)&&!c.equalsSelection(a)?(this.currentImage=b[b.length-1]=a,!0):!1},lock:function(a,b){if(this.locked)this.locked.level++;else if(a)this.locked={level:1};else{var c=null;if(b)c=!0;else{var g=new e(this.editor,!0);this.currentImage&&this.currentImage.equalsContent(g)&&(c=g)}this.locked={update:c,level:1}}},unlock:function(){if(this.locked&&!--this.locked.level){var a=this.locked.update;this.locked=null;if(!0===a)this.update();else if(a){var b=
new e(this.editor,!0);a.equalsContent(b)||this.update()}}}};b.navigationKeyCodes={37:1,38:1,39:1,40:1,36:1,35:1,33:1,34:1};b.keyGroups={PRINTABLE:0,FUNCTIONAL:1};b.isNavigationKey=function(a){return!!b.navigationKeyCodes[a]};b.getKeyGroup=function(a){var d=b.keyGroups;return c[a]?d.FUNCTIONAL:d.PRINTABLE};b.getOppositeKeyGroup=function(a){var c=b.keyGroups;return a==c.FUNCTIONAL?c.PRINTABLE:c.FUNCTIONAL};b.ieFunctionalKeysBug=function(a){return CKEDITOR.env.ie&&b.getKeyGroup(a)==b.keyGroups.FUNCTIONAL};
var e=CKEDITOR.plugins.undo.Image=function(a,b){this.editor=a;a.fire("beforeUndoImage");var c=a.getSnapshot();CKEDITOR.env.ie&&c&&(c=c.replace(/\s+data-cke-expando=".*?"/g,""));this.contents=c;b||(this.bookmarks=(c=c&&a.getSelection())&&c.createBookmarks2(!0));a.fire("afterUndoImage")},h=/\b(?:href|src|name)="[^"]*?"/gi;e.prototype={equalsContent:function(a){var b=this.contents;a=a.contents;CKEDITOR.env.ie&&(CKEDITOR.env.ie7Compat||CKEDITOR.env.quirks)&&(b=b.replace(h,""),a=a.replace(h,""));return b!=
a?!1:!0},equalsSelection:function(a){var b=this.bookmarks;a=a.bookmarks;if(b||a){if(!b||!a||b.length!=a.length)return!1;for(var c=0;c<b.length;c++){var e=b[c],h=a[c];if(e.startOffset!=h.startOffset||e.endOffset!=h.endOffset||!CKEDITOR.tools.arrayCompare(e.start,h.start)||!CKEDITOR.tools.arrayCompare(e.end,h.end))return!1}}return!0}};var l=CKEDITOR.plugins.undo.NativeEditingHandler=function(a){this.undoManager=a;this.ignoreInputEvent=!1;this.keyEventsStack=new k;this.lastKeydownImage=null};l.prototype=
{onKeydown:function(c){var d=c.data.getKey();if(229!==d)if(-1<CKEDITOR.tools.indexOf(a,c.data.getKeystroke()))c.data.preventDefault();else if(this.keyEventsStack.cleanUp(c),c=this.undoManager,this.keyEventsStack.getLast(d)||this.keyEventsStack.push(d),this.lastKeydownImage=new e(c.editor),b.isNavigationKey(d)||this.undoManager.keyGroupChanged(d))if(c.strokesRecorded[0]||c.strokesRecorded[1])c.save(!1,this.lastKeydownImage,!1),c.resetType()},onInput:function(){if(this.ignoreInputEvent)this.ignoreInputEvent=
!1;else{var a=this.keyEventsStack.getLast();a||(a=this.keyEventsStack.push(0));this.keyEventsStack.increment(a.keyCode);this.keyEventsStack.getTotalInputs()>=this.undoManager.strokesLimit&&(this.undoManager.type(a.keyCode,!0),this.keyEventsStack.resetInputs())}},onKeyup:function(a){var c=this.undoManager;a=a.data.getKey();var h=this.keyEventsStack.getTotalInputs();this.keyEventsStack.remove(a);if(!(b.ieFunctionalKeysBug(a)&&this.lastKeydownImage&&this.lastKeydownImage.equalsContent(new e(c.editor,
!0))))if(0<h)c.type(a);else if(b.isNavigationKey(a))this.onNavigationKey(!0)},onNavigationKey:function(a){var b=this.undoManager;!a&&b.save(!0,null,!1)||b.updateSelection(new e(b.editor));b.resetType()},ignoreInputEventListener:function(){this.ignoreInputEvent=!0},attachListeners:function(){var a=this.undoManager.editor,c=a.editable(),e=this;c.attachListener(c,"keydown",function(a){e.onKeydown(a);if(b.ieFunctionalKeysBug(a.data.getKey()))e.onInput()},null,null,999);c.attachListener(c,CKEDITOR.env.ie?
"keypress":"input",e.onInput,e,null,999);c.attachListener(c,"keyup",e.onKeyup,e,null,999);c.attachListener(c,"paste",e.ignoreInputEventListener,e,null,999);c.attachListener(c,"drop",e.ignoreInputEventListener,e,null,999);c.attachListener(c.isInline()?c:a.document.getDocumentElement(),"click",function(){e.onNavigationKey()},null,null,999);c.attachListener(this.undoManager.editor,"blur",function(){e.keyEventsStack.remove(9)},null,null,999)}};var k=CKEDITOR.plugins.undo.KeyEventsStack=function(){this.stack=
[]};k.prototype={push:function(a){a=this.stack.push({keyCode:a,inputs:0});return this.stack[a-1]},getLastIndex:function(a){if("number"!=typeof a)return this.stack.length-1;for(var b=this.stack.length;b--;)if(this.stack[b].keyCode==a)return b;return-1},getLast:function(a){a=this.getLastIndex(a);return-1!=a?this.stack[a]:null},increment:function(a){this.getLast(a).inputs++},remove:function(a){a=this.getLastIndex(a);-1!=a&&this.stack.splice(a,1)},resetInputs:function(a){if("number"==typeof a)this.getLast(a).inputs=
0;else for(a=this.stack.length;a--;)this.stack[a].inputs=0},getTotalInputs:function(){for(var a=this.stack.length,b=0;a--;)b+=this.stack[a].inputs;return b},cleanUp:function(a){a=a.data.$;a.ctrlKey||a.metaKey||this.remove(17);a.shiftKey||this.remove(16);a.altKey||this.remove(18)}}}(),function(){function a(a){function b(a){var c=!1;g.attachListener(g,"keydown",function(){var b=f.getBody().getElementsByTag(a);if(!c){for(var d=0;d<b.count();d++)b.getItem(d).setCustomData("retain",!0);c=!0}},null,null,
1);g.attachListener(g,"keyup",function(){var b=f.getElementsByTag(a);c&&(1!=b.count()||b.getItem(0).getCustomData("retain")||b.getItem(0).hasAttribute("data-cke-temp")||b.getItem(0).remove(1),c=!1)})}var e=this.editor,f=a.document,d=f.body,m=f.getElementById("cke_actscrpt");m&&m.parentNode.removeChild(m);(m=f.getElementById("cke_shimscrpt"))&&m.parentNode.removeChild(m);(m=f.getElementById("cke_basetagscrpt"))&&m.parentNode.removeChild(m);d.contentEditable=!0;CKEDITOR.env.ie&&(d.hideFocus=!0,d.disabled=
!0,d.removeAttribute("disabled"));delete this._.isLoadingData;this.$=d;f=new CKEDITOR.dom.document(f);this.setup();this.fixInitialSelection();var g=this;CKEDITOR.env.ie&&!CKEDITOR.env.edge&&f.getDocumentElement().addClass(f.$.compatMode);CKEDITOR.env.ie&&!CKEDITOR.env.edge&&e.enterMode!=CKEDITOR.ENTER_P?b("p"):CKEDITOR.env.edge&&e.enterMode!=CKEDITOR.ENTER_DIV&&b("div");if(CKEDITOR.env.webkit||CKEDITOR.env.ie&&10<CKEDITOR.env.version)f.getDocumentElement().on("mousedown",function(a){a.data.getTarget().is("html")&&
setTimeout(function(){e.editable().focus()})});c(e);try{e.document.$.execCommand("2D-position",!1,!0)}catch(n){}(CKEDITOR.env.gecko||CKEDITOR.env.ie&&"CSS1Compat"==e.document.$.compatMode)&&this.attachListener(this,"keydown",function(a){var b=a.data.getKeystroke();if(33==b||34==b)if(CKEDITOR.env.ie)setTimeout(function(){e.getSelection().scrollIntoView()},0);else if(e.window.$.innerHeight>this.$.offsetHeight){var c=e.createRange();c[33==b?"moveToElementEditStart":"moveToElementEditEnd"](this);c.select();
a.data.preventDefault()}});CKEDITOR.env.ie&&this.attachListener(f,"blur",function(){try{f.$.selection.empty()}catch(a){}});CKEDITOR.env.iOS&&this.attachListener(f,"touchend",function(){a.focus()});d=e.document.getElementsByTag("title").getItem(0);d.data("cke-title",d.getText());CKEDITOR.env.ie&&(e.document.$.title=this._.docTitle);CKEDITOR.tools.setTimeout(function(){"unloaded"==this.status&&(this.status="ready");e.fire("contentDom");this._.isPendingFocus&&(e.focus(),this._.isPendingFocus=!1);setTimeout(function(){e.fire("dataReady")},
0)},0,this)}function c(a){function b(){var d;a.editable().attachListener(a,"selectionChange",function(){var b=a.getSelection().getSelectedElement();b&&(d&&(d.detachEvent("onresizestart",c),d=null),b.$.attachEvent("onresizestart",c),d=b.$)})}function c(a){a.returnValue=!1}if(CKEDITOR.env.gecko)try{var e=a.document.$;e.execCommand("enableObjectResizing",!1,!a.config.disableObjectResizing);e.execCommand("enableInlineTableEditing",!1,!a.config.disableNativeTableHandles)}catch(d){}else CKEDITOR.env.ie&&
11>CKEDITOR.env.version&&a.config.disableObjectResizing&&b(a)}function b(){var a=[];if(8<=CKEDITOR.document.$.documentMode){a.push("html.CSS1Compat [contenteditable\x3dfalse]{min-height:0 !important}");var b=[],c;for(c in CKEDITOR.dtd.$removeEmpty)b.push("html.CSS1Compat "+c+"[contenteditable\x3dfalse]");a.push(b.join(",")+"{display:inline-block}")}else CKEDITOR.env.gecko&&(a.push("html{height:100% !important}"),a.push("img:-moz-broken{-moz-force-broken-image-icon:1;min-width:24px;min-height:24px}"));
a.push("html{cursor:text;*cursor:auto}");a.push("img,input,textarea{cursor:default}");return a.join("\n")}var e;CKEDITOR.plugins.add("wysiwygarea",{init:function(a){a.config.fullPage&&a.addFeature({allowedContent:"html head title; style [media,type]; body (*)[id]; meta link [*]",requiredContent:"body"});a.addMode("wysiwyg",function(b){function c(f){f&&f.removeListener();a.editable(new e(a,d.$.contentWindow.document.body));a.setData(a.getData(1),b)}var f="document.open();"+(CKEDITOR.env.ie?"("+CKEDITOR.tools.fixDomain+
")();":"")+"document.close();",f=CKEDITOR.env.air?"javascript:void(0)":CKEDITOR.env.ie&&!CKEDITOR.env.edge?"javascript:void(function(){"+encodeURIComponent(f)+"}())":"",d=CKEDITOR.dom.element.createFromHtml('\x3ciframe src\x3d"'+f+'" frameBorder\x3d"0"\x3e\x3c/iframe\x3e');d.setStyles({width:"100%",height:"100%"});d.addClass("cke_wysiwyg_frame").addClass("cke_reset");f=a.ui.space("contents");f.append(d);var m=CKEDITOR.env.ie&&!CKEDITOR.env.edge||CKEDITOR.env.gecko;if(m)d.on("load",c);var g=a.title,
n=a.fire("ariaEditorHelpLabel",{}).label;g&&(CKEDITOR.env.ie&&n&&(g+=", "+n),d.setAttribute("title",g));if(n){var g=CKEDITOR.tools.getNextId(),p=CKEDITOR.dom.element.createFromHtml('\x3cspan id\x3d"'+g+'" class\x3d"cke_voice_label"\x3e'+n+"\x3c/span\x3e");f.append(p,1);d.setAttribute("aria-describedby",g)}a.on("beforeModeUnload",function(a){a.removeListener();p&&p.remove()});d.setAttributes({tabIndex:a.tabIndex,allowTransparency:"true"});!m&&c();a.fire("ariaWidget",d)})}});CKEDITOR.editor.prototype.addContentsCss=
function(a){var b=this.config,c=b.contentsCss;CKEDITOR.tools.isArray(c)||(b.contentsCss=c?[c]:[]);b.contentsCss.push(a)};e=CKEDITOR.tools.createClass({$:function(){this.base.apply(this,arguments);this._.frameLoadedHandler=CKEDITOR.tools.addFunction(function(b){CKEDITOR.tools.setTimeout(a,0,this,b)},this);this._.docTitle=this.getWindow().getFrame().getAttribute("title")},base:CKEDITOR.editable,proto:{setData:function(a,c){var e=this.editor;if(c)this.setHtml(a),this.fixInitialSelection(),e.fire("dataReady");
else{this._.isLoadingData=!0;e._.dataStore={id:1};var f=e.config,d=f.fullPage,m=f.docType,g=CKEDITOR.tools.buildStyleHtml(b()).replace(/<style>/,'\x3cstyle data-cke-temp\x3d"1"\x3e');d||(g+=CKEDITOR.tools.buildStyleHtml(e.config.contentsCss));var n=f.baseHref?'\x3cbase href\x3d"'+f.baseHref+'" data-cke-temp\x3d"1" /\x3e':"";d&&(a=a.replace(/<!DOCTYPE[^>]*>/i,function(a){e.docType=m=a;return""}).replace(/<\?xml\s[^\?]*\?>/i,function(a){e.xmlDeclaration=a;return""}));a=e.dataProcessor.toHtml(a);d?(/<body[\s|>]/.test(a)||
(a="\x3cbody\x3e"+a),/<html[\s|>]/.test(a)||(a="\x3chtml\x3e"+a+"\x3c/html\x3e"),/<head[\s|>]/.test(a)?/<title[\s|>]/.test(a)||(a=a.replace(/<head[^>]*>/,"$\x26\x3ctitle\x3e\x3c/title\x3e")):a=a.replace(/<html[^>]*>/,"$\x26\x3chead\x3e\x3ctitle\x3e\x3c/title\x3e\x3c/head\x3e"),n&&(a=a.replace(/<head[^>]*?>/,"$\x26"+n)),a=a.replace(/<\/head\s*>/,g+"$\x26"),a=m+a):a=f.docType+'\x3chtml dir\x3d"'+f.contentsLangDirection+'" lang\x3d"'+(f.contentsLanguage||e.langCode)+'"\x3e\x3chead\x3e\x3ctitle\x3e'+
this._.docTitle+"\x3c/title\x3e"+n+g+"\x3c/head\x3e\x3cbody"+(f.bodyId?' id\x3d"'+f.bodyId+'"':"")+(f.bodyClass?' class\x3d"'+f.bodyClass+'"':"")+"\x3e"+a+"\x3c/body\x3e\x3c/html\x3e";CKEDITOR.env.gecko&&(a=a.replace(/<body/,'\x3cbody contenteditable\x3d"true" '),2E4>CKEDITOR.env.version&&(a=a.replace(/<body[^>]*>/,"$\x26\x3c!-- cke-content-start --\x3e")));f='\x3cscript id\x3d"cke_actscrpt" type\x3d"text/javascript"'+(CKEDITOR.env.ie?' defer\x3d"defer" ':"")+"\x3evar wasLoaded\x3d0;function onload(){if(!wasLoaded)window.parent.CKEDITOR.tools.callFunction("+
this._.frameLoadedHandler+",window);wasLoaded\x3d1;}"+(CKEDITOR.env.ie?"onload();":'document.addEventListener("DOMContentLoaded", onload, false );')+"\x3c/script\x3e";CKEDITOR.env.ie&&9>CKEDITOR.env.version&&(f+='\x3cscript id\x3d"cke_shimscrpt"\x3ewindow.parent.CKEDITOR.tools.enableHtml5Elements(document)\x3c/script\x3e');n&&CKEDITOR.env.ie&&10>CKEDITOR.env.version&&(f+='\x3cscript id\x3d"cke_basetagscrpt"\x3evar baseTag \x3d document.querySelector( "base" );baseTag.href \x3d baseTag.href;\x3c/script\x3e');
a=a.replace(/(?=\s*<\/(:?head)>)/,f);this.clearCustomData();this.clearListeners();e.fire("contentDomUnload");var p=this.getDocument();try{p.write(a)}catch(q){setTimeout(function(){p.write(a)},0)}}},getData:function(a){if(a)return this.getHtml();a=this.editor;var b=a.config,c=b.fullPage,e=c&&a.docType,d=c&&a.xmlDeclaration,m=this.getDocument(),c=c?m.getDocumentElement().getOuterHtml():m.getBody().getHtml();CKEDITOR.env.gecko&&b.enterMode!=CKEDITOR.ENTER_BR&&(c=c.replace(/<br>(?=\s*(:?$|<\/body>))/,
""));c=a.dataProcessor.toDataFormat(c);d&&(c=d+"\n"+c);e&&(c=e+"\n"+c);return c},focus:function(){this._.isLoadingData?this._.isPendingFocus=!0:e.baseProto.focus.call(this)},detach:function(){var a=this.editor,b=a.document,c;try{c=a.window.getFrame()}catch(f){}e.baseProto.detach.call(this);this.clearCustomData();b.getDocumentElement().clearCustomData();CKEDITOR.tools.removeFunction(this._.frameLoadedHandler);c&&c.getParent()?(c.clearCustomData(),(a=c.removeCustomData("onResize"))&&a.removeListener(),
c.remove()):CKEDITOR.warn("editor-destroy-iframe")}}})}(),CKEDITOR.config.disableObjectResizing=!1,CKEDITOR.config.disableNativeTableHandles=!0,CKEDITOR.config.disableNativeSpellChecker=!0,CKEDITOR.config.plugins="dialogui,dialog,a11yhelp,about,basicstyles,bidi,blockquote,notification,button,toolbar,clipboard,panelbutton,panel,floatpanel,colorbutton,colordialog,copyformatting,menu,contextmenu,dialogadvtab,div,elementspath,enterkey,entities,popup,filebrowser,find,fakeobjects,flash,floatingspace,listblock,richcombo,font,format,forms,horizontalrule,htmlwriter,iframe,image,wsc,menubutton,scayt,lineutils,widgetselection,widget,indent,indentlist,indentblock,justify,language,link,list,liststyle,magicline,maximize,newpage,pagebreak,pastefromword,pastetext,preview,print,removeformat,resize,save,selectall,showblocks,showborders,smiley,sourcearea,specialchar,stylescombo,tab,table,tabletools,tableselection,templates,undo,wysiwygarea",
CKEDITOR.config.skin="moono-lisa",function(){var a=function(a,b){var e=CKEDITOR.getUrl("plugins/"+b);a=a.split(",");for(var h=0;h<a.length;h++)CKEDITOR.skin.icons[a[h]]={path:e,offset:-a[++h],bgsize:a[++h]}};CKEDITOR.env.hidpi?a("about,0,,bold,24,,italic,48,,strike,72,,subscript,96,,superscript,120,,underline,144,,bidiltr,168,,bidirtl,192,,blockquote,216,,copy-rtl,240,,copy,264,,cut-rtl,288,,cut,312,,paste-rtl,336,,paste,360,,codesnippet,384,,bgcolor,408,,textcolor,432,,copyformatting,456,,creatediv,480,,docprops-rtl,504,,docprops,528,,embed,552,,embedsemantic,576,,find-rtl,600,,find,624,,replace,648,,flash,672,,button,696,,checkbox,720,,form,744,,hiddenfield,768,,imagebutton,792,,radio,816,,select-rtl,840,,select,864,,textarea-rtl,888,,textarea,912,,textfield-rtl,936,,textfield,960,,horizontalrule,984,,iframe,1008,,image,1032,,indent-rtl,1056,,indent,1080,,outdent-rtl,1104,,outdent,1128,,justifyblock,1152,,justifycenter,1176,,justifyleft,1200,,justifyright,1224,,language,1248,,anchor-rtl,1272,,anchor,1296,,link,1320,,unlink,1344,,bulletedlist-rtl,1368,,bulletedlist,1392,,numberedlist-rtl,1416,,numberedlist,1440,,mathjax,1464,,maximize,1488,,newpage-rtl,1512,,newpage,1536,,pagebreak-rtl,1560,,pagebreak,1584,,pastefromword-rtl,1608,,pastefromword,1632,,pastetext-rtl,1656,,pastetext,1680,,placeholder,1704,,preview-rtl,1728,,preview,1752,,print,1776,,removeformat,1800,,save,1824,,scayt,1848,,selectall,1872,,showblocks-rtl,1896,,showblocks,1920,,smiley,1944,,source-rtl,1968,,source,1992,,sourcedialog-rtl,2016,,sourcedialog,2040,,specialchar,2064,,table,2088,,templates-rtl,2112,,templates,2136,,uicolor,2160,,redo-rtl,2184,,redo,2208,,undo-rtl,2232,,undo,2256,,simplebox,4560,auto,spellchecker,2304,",
"icons_hidpi.png"):a("about,0,auto,bold,24,auto,italic,48,auto,strike,72,auto,subscript,96,auto,superscript,120,auto,underline,144,auto,bidiltr,168,auto,bidirtl,192,auto,blockquote,216,auto,copy-rtl,240,auto,copy,264,auto,cut-rtl,288,auto,cut,312,auto,paste-rtl,336,auto,paste,360,auto,codesnippet,384,auto,bgcolor,408,auto,textcolor,432,auto,copyformatting,456,auto,creatediv,480,auto,docprops-rtl,504,auto,docprops,528,auto,embed,552,auto,embedsemantic,576,auto,find-rtl,600,auto,find,624,auto,replace,648,auto,flash,672,auto,button,696,auto,checkbox,720,auto,form,744,auto,hiddenfield,768,auto,imagebutton,792,auto,radio,816,auto,select-rtl,840,auto,select,864,auto,textarea-rtl,888,auto,textarea,912,auto,textfield-rtl,936,auto,textfield,960,auto,horizontalrule,984,auto,iframe,1008,auto,image,1032,auto,indent-rtl,1056,auto,indent,1080,auto,outdent-rtl,1104,auto,outdent,1128,auto,justifyblock,1152,auto,justifycenter,1176,auto,justifyleft,1200,auto,justifyright,1224,auto,language,1248,auto,anchor-rtl,1272,auto,anchor,1296,auto,link,1320,auto,unlink,1344,auto,bulletedlist-rtl,1368,auto,bulletedlist,1392,auto,numberedlist-rtl,1416,auto,numberedlist,1440,auto,mathjax,1464,auto,maximize,1488,auto,newpage-rtl,1512,auto,newpage,1536,auto,pagebreak-rtl,1560,auto,pagebreak,1584,auto,pastefromword-rtl,1608,auto,pastefromword,1632,auto,pastetext-rtl,1656,auto,pastetext,1680,auto,placeholder,1704,auto,preview-rtl,1728,auto,preview,1752,auto,print,1776,auto,removeformat,1800,auto,save,1824,auto,scayt,1848,auto,selectall,1872,auto,showblocks-rtl,1896,auto,showblocks,1920,auto,smiley,1944,auto,source-rtl,1968,auto,source,1992,auto,sourcedialog-rtl,2016,auto,sourcedialog,2040,auto,specialchar,2064,auto,table,2088,auto,templates-rtl,2112,auto,templates,2136,auto,uicolor,2160,auto,redo-rtl,2184,auto,redo,2208,auto,undo-rtl,2232,auto,undo,2256,auto,simplebox,2280,auto,spellchecker,2304,auto",
"icons.png")}())})();